@@ -64,7 +64,6 @@ static void process_COM (const uchar * Data, int length)
     }
 
     strcpy(ImageInfo.Comments,Comment);
-    ImageInfo.CommentWidchars = 0;
 }
 
  
@@ -134,11 +133,11 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
 
         CheckSectionsAllocated();
 
-        for (a=0;a<=16;a++){
+        for (a=0;a<7;a++){
             marker = fgetc(infile);
             if (marker != 0xff) break;
 
-            if (a >= 16){
+            if (a >= 32){
                 fprintf(stderr,"too many padding bytes\n");
                 return FALSE;
             }
@@ -359,7 +358,7 @@ int SaveThumbnail(char * ThumbFileName)
         ExifSection = FindSection(M_EXIF);
         ThumbnailPointer = ExifSection->Data+ImageInfo.ThumbnailOffset+8;
 
-        int iRet = fwrite(ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile); iRet=iRet;
+        fwrite(ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile);
         fclose(ThumbnailFile);
         return TRUE;
     }else{
@@ -425,7 +424,7 @@ int ReplaceThumbnail(const char * ThumbFileName)
     ThumbnailPointer = ExifSection->Data+ImageInfo.ThumbnailOffset+8;
 
     if (ThumbnailFile){
-        int iRet = fread(ThumbnailPointer, ThumbLen, 1, ThumbnailFile); iRet=iRet;
+        fread(ThumbnailPointer, ThumbLen, 1, ThumbnailFile);
         fclose(ThumbnailFile);
     }
 
@@ -518,18 +517,18 @@ void WriteJpegFile(const char * FileName)
             0x00, 0x10, 'J' , 'F' , 'I' , 'F' , 0x00, 0x01, 
             0x01, 0x01, 0x01, 0x2C, 0x01, 0x2C, 0x00, 0x00 
         };
-        int iRet = fwrite(JfifHead, 18, 1, outfile); iRet=iRet;
+        fwrite(JfifHead, 18, 1, outfile);
     }
 
     // Write all the misc sections
     for (a=0;a<SectionsRead-1;a++){
         fputc(0xff,outfile);
         fputc((unsigned char)Sections[a].Type, outfile);
-        int iRet = fwrite(Sections[a].Data, Sections[a].Size, 1, outfile); iRet=iRet;
+        fwrite(Sections[a].Data, Sections[a].Size, 1, outfile);
     }
 
     // Write the remaining image data.
-    int iRet = fwrite(Sections[a].Data, Sections[a].Size, 1, outfile); iRet=iRet;
+    fwrite(Sections[a].Data, Sections[a].Size, 1, outfile);
        
     fclose(outfile);
 }
@@ -663,7 +662,6 @@ void ResetJpgfile(void)
         Sections = (Section_t *)malloc(sizeof(Section_t)*5);
         SectionsAllocated = 5;
     }
-
     SectionsRead = 0;
     HaveAll = 0;
 }
