@@ -1,5 +1,6 @@
 
-#include <qapplication.h>
+//#include <qapplication.h> //ooo
+#include <QApplication> //xxx
 
 #include "window.h"
 
