@@ -3,9 +3,11 @@
 #define WINDOW_H
 
 #include "../interface.h"
-#include "uidialog.h"
+//#include "uidialog.h" //ooo
+#include "ui_uidialog.h"    //xxx
 
-class Window : public uiDialog
+//class Window : public uiDialog    //ooo
+class Window : public QDialog, public Ui::uiDialog	//xxx
 {
     Q_OBJECT
 
