@@ -1,4 +1,4 @@
-
+#!/bin/bash
 if [ "x$1" == "xinstall" ]
 then
 
@@ -16,7 +16,8 @@ then
   rm -r *.o core* *~
 
   cd libjhead; make clean
-  rm -r .ui .moc .obj ../../../lib/libjhead*
+  #rm -r .ui .moc .obj ../../../lib/libjhead*
+  rm -r .ui .moc .obj ./lib/libjhead*
   rm Makefile* Makefile core*
 
   cd jheadGui; make clean
@@ -31,7 +32,9 @@ else
     fi;
   fi;
 
-  QMAKE=$QTDIR/bin/qmake
+  #QMAKE=$QTDIR/bin/qmake-qt5
+  QMAKE=$QTDIR/qmake-qt5
+  #QMAKE=/usr/bin/qmake-qt5
   if [ ! -e $QMAKE ]; then
     QMAKE=qmake
   fi;
