@@ -1,36 +1,35 @@
-/****************************************************************************
-** ButtonPreview class
-**
-**   Created : Tue Feb 02 22:06:51 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class is the encapsulation of the ButtonPreview from the FileSelection
-** Dialog.
-**
+/***************************************************************************
+    buttonpreview.cpp
+                             -------------------
+    ButtonPreview class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is the encapsulation of the ButtonPreview from the FileSelection
+   Dialog.
+    
 ****************************************************************************/
 
-#include <qvaluelist.h>
-#include <qpopupmenu.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qcursor.h>
-#include <qlabel.h>
-#include <qdom.h>
-#include <qdir.h>
+#include <QPainter>
+#include <QCursor>
+#include <QMessageBox>
+#include <QFileInfo>
+#include <QDir>
 
-#include "global.h"
 #include "undobuffer.h"
-#include "dialogtextfont.h"
-#include "dialogbutton.h"
 #include "buttonpreview.h"
 #include "dvdmenuundoobject.h"
 #include "qimagehelper.h"
 #include "dvdmenu.h"
-
-ButtonPreview::ButtonPreview(QWidget * parent, const char * name, WFlags f)
-  : QLabel (parent, name, f),
+#include "xml_dvd.h"    //xxx
+ 
+//ButtonPreview::ButtonPreview(QWidget * parent, const char * name, Qt::WindowFlags f)	//ooo
+ButtonPreview::ButtonPreview(QWidget * parent)						//xxx
+  //: QLabel (parent, name, f)	//ooo
+  : QLabel (parent), 		//xxx
     m_pUndoBuffer   ( NULL ),
     m_pActiveObject ( NULL )
 {
@@ -48,10 +47,10 @@ ButtonPreview::~ButtonPreview()
     delete m_pUndoBuffer;
 
  uint t;
- for ( t=0; t<m_listMenuObjects.count ( ); t++ )
+ for ( t=0; t<(uint)m_listMenuObjects.count ( ); t++ )
    delete m_listMenuObjects.at ( t );
 
- m_listMenuObjects.clear ( );
+ m_listMenuObjects.clear ( );  
 }
 
 ButtonPreview &ButtonPreview::operator= ( ButtonPreview &theOther )
@@ -92,7 +91,8 @@ bool ButtonPreview::removeObject ( MenuObject *pTheObject )
   if ( m_pActiveObject == pTheObject )
        m_pActiveObject  = NULL;
 
-  bool bReturn = m_listMenuObjects.remove ( pTheObject );
+  //bool bReturn = m_listMenuObjects.remove ( pTheObject );	//ooo
+  bool bReturn = m_listMenuObjects.removeOne ( pTheObject );	//xxx
 
   update ( );
   return bReturn;
@@ -111,10 +111,11 @@ void ButtonPreview::slotDeleteObject ( MenuObject *pTheObject )
   if ( m_pActiveObject == pTheObject )
        m_pActiveObject  = NULL;
 
-  if ( m_listMenuObjects.remove ( pTheObject ) == false )
+  //if ( m_listMenuObjects.remove ( pTheObject ) == false )	//ooo
+  if ( m_listMenuObjects.removeOne ( pTheObject ) == false )	//xxx
     return;
 
-  undoBuffer ( )->push ( new DVDMenuUndoObject ( DVDMenuUndoObject::DELETED_OBJECT, pTheObject, this ) );
+  undoBuffer ( )->push ( new DVDMenuUndoObject ( DVDMenuUndoObject::DELETED_OBJECT, pTheObject, this ) );	//oooo
 //  delete pTheObject;
 
   update ( );
@@ -135,26 +136,26 @@ void ButtonPreview::setViewport(QRect &rectViewport)
 
 MenuObject *ButtonPreview::childContains (QPoint &pos)
 {
-	// Here we check if the mouse click appeared withtin one of the MenuObjects,
-	// in which case the object will take over ...
-	int t;
-	QPoint theCorrectedPos = pos;
-	if (m_rectViewport.width() > 10)	{
-		theCorrectedPos.setX(pos.x()-m_rectViewport.x());
-		theCorrectedPos.setY(pos.y()-m_rectViewport.y());
-	}
+  // Here we check if the mouse click appeared withtin one of the MenuObjects,
+  // in which case the object will take over ...
+  int t;
+  QPoint theCorrectedPos = pos;
+  if (m_rectViewport.width() > 10)	{
+    theCorrectedPos.setX(pos.x()-m_rectViewport.x());
+    theCorrectedPos.setY(pos.y()-m_rectViewport.y());
+  }
 
-	for (t=m_listMenuObjects.count()-1;t>=0;t--)	{
-		if (m_listMenuObjects.at(t)->contains (theCorrectedPos))	{
-			return m_listMenuObjects.at(t);
-		}
-	}
-	return NULL;
+  for (t=m_listMenuObjects.count()-1;t>=0;t--)	{
+    if (m_listMenuObjects.at(t)->contains (theCorrectedPos))	{
+      return m_listMenuObjects.at(t);
+    }
+  }
+  return NULL;
 }
 
 MenuObject *ButtonPreview::menuObject (uint iNr)
 {
-	if (iNr < m_listMenuObjects.count())
+	if (iNr < (uint)m_listMenuObjects.count())
 		return m_listMenuObjects.at(iNr);
 	else 
 		return NULL;
@@ -162,7 +163,7 @@ MenuObject *ButtonPreview::menuObject (uint iNr)
 
 uint ButtonPreview::objectCount()
 {
-	return m_listMenuObjects.count ( );
+  return m_listMenuObjects.count ( );
 }
 
 UndoBuffer *ButtonPreview::undoBuffer()
@@ -173,7 +174,8 @@ UndoBuffer *ButtonPreview::undoBuffer()
 void ButtonPreview::toTop ( MenuObject *pObject )
 {
   // This function pushes the currently selected child to the top of the stack as to draw it last (on the top).
-  m_listMenuObjects.remove (pObject);
+  //m_listMenuObjects.remove (pObject);		//ooo
+  m_listMenuObjects.removeOne (pObject);	//xxx
   m_listMenuObjects.append (pObject);
 }
 
@@ -211,9 +213,11 @@ void ButtonPreview::setObjectCursor ( MenuObject::enState theState )
 }
 
 void ButtonPreview::setMouseCursor ( enPointerShape iPointerShape )
-{
+{ 
   QCursor theCursor;
-  theCursor.setShape ( iPointerShape );
+  //theCursor.setShape ( iPointerShape );			//ooo
+  //theCursor.setShape ( Qt::CrossCursor );			//xxx
+  theCursor.setShape ( (enum Qt::CursorShape)iPointerShape );	//xxx
   setCursor ( theCursor );
   m_iCursorStyle = iPointerShape;
 }
@@ -229,39 +233,43 @@ void ButtonPreview::slotMoveOnStack(MenuObject *pObject, int iHowMany)
 	if ( ! pObject ) 
 		return;
 
-	int iIndex = m_listMenuObjects.find (pObject);
+	//int iIndex = m_listMenuObjects.find (pObject);   //ooo
+    int iIndex = m_listMenuObjects.indexOf (pObject);   //xxx
 	iIndex += iHowMany;
 	if (iIndex < 0)
 		iIndex = 0;
 	if (iIndex >(int)m_listMenuObjects.count ()-1)
 		iIndex = m_listMenuObjects.count()-1;
 
-	m_listMenuObjects.remove (pObject);
+	//m_listMenuObjects.remove (pObject);  //ooo
+    m_listMenuObjects.removeOne (pObject);  //xxx
 
 	m_listMenuObjects.insert (iIndex, pObject);
 	updatePixmap ( );
 }
 
 void ButtonPreview::mousePressEvent ( QMouseEvent *pEvent )
-{
+{ 
   // Here we check if the mouse click appeared withtin one of the MenuObjects,
   // in which case the Object will take over the mouse handling ...
   QPoint thePos  = pEvent->pos ( );
   MenuObject *pObject = childContains ( thePos );
   if ( pObject )  {
-    MenuObject::enState currentState = pObject->setObjectState ( thePos, pEvent->state ( ) );
+    //MenuObject::enState currentState = pObject->setObjectState ( thePos, pEvent->state ( ) );		//oooo
+    MenuObject::enState currentState = pObject->setObjectState ( thePos, pEvent->button ( ) );		//xxx
     setObjectCursor ( currentState );
     m_bMouseEventDone = pObject->mousePressEvent ( pEvent );
+ 
     // Here we protect the action toTop for creation of Buttons, which delete the returned pObject
     if ( ! m_bMouseEventDone )  {
       toTop ( pObject );
-      undoBuffer ( )->push ( new DVDMenuUndoObject ( pObject, currentState ) );
+      undoBuffer ( )->push ( new DVDMenuUndoObject ( pObject, currentState ) );	//oooo
     }
   }
 }
 
 void ButtonPreview::mouseReleaseEvent (QMouseEvent *pEvent)
-{
+{  
   // Here we check if the mouse click appeared withtin one of the MenuObjects,
   // in which case the object will take over ...
   //  QPoint thePos = pEvent->pos();
@@ -276,7 +284,8 @@ void ButtonPreview::mouseReleaseEvent (QMouseEvent *pEvent)
   //      delete pUndo;
   //    }
   //  }
-  for ( uint t=0; t<m_listMenuObjects.count( );t++ )  {
+  //for ( uint t=0; t<(uint)m_listMenuObjects.count( );t++ )  {                 //ooo
+  for ( uint t=0; t<static_cast<uint> ( m_listMenuObjects.count( ) );t++ )  {   //xxx
     if ( m_listMenuObjects.at  ( t )->isActive ( ) )  {
       m_bMouseEventDone = m_listMenuObjects.at ( t )->mouseReleaseEvent ( pEvent );
       // here we get the last object on the undoBuffer
@@ -284,71 +293,14 @@ void ButtonPreview::mouseReleaseEvent (QMouseEvent *pEvent)
       if ( pUndo && ! pUndo->hasMoved ( ) )  {
         undoBuffer  ( )->removeLast   ( );
         delete pUndo;
-      }
+      }	//oooo
     }
   }
   unsetCursor  ( );
 }
 
-void ButtonPreview::mouseDoubleClickEvent ( QMouseEvent *pEvent )
-{
-  // Here we check if the mouse click appeared withtin one of the buttons,
-  // in which case the button will take over ...
-  QPoint thePos = pEvent->pos ( );
-  MenuObject *pObject = childContains ( thePos );
-  if ( pObject != NULL )
-    m_bMouseEventDone = pObject->mouseDoubleClickEvent ( pEvent );
-}
-
-void ButtonPreview::keyPressEvent ( QKeyEvent *pEvent )
-{
-  QLabel::keyPressEvent ( pEvent );
-
-  if ( ( pEvent->key ( ) == Qt::Key_Up    ) ||
-       ( pEvent->key ( ) == Qt::Key_Down  ) ||
-       ( pEvent->key ( ) == Qt::Key_Left  ) ||
-       ( pEvent->key ( ) == Qt::Key_Right ) )  {
-
-    QPoint pos = mapFromGlobal ( QCursor::pos ( ) );
-    MenuObject *pObject = childContains ( pos );
-
-    if ( ! pObject )
-      return;
-
-    pos = pObject->position ( );
-
-    if ( pEvent->key      ( ) == Qt::Key_Up    )
-      pos.setY ( pos.y ( ) - 1 );
-    else if ( pEvent->key ( ) == Qt::Key_Down  )
-      pos.setY ( pos.y ( ) + 1 );
-    else if ( pEvent->key ( ) == Qt::Key_Left  )
-      pos.setX ( pos.x ( ) - 1 );
-    else if ( pEvent->key ( ) == Qt::Key_Right )
-      pos.setX ( pos.x ( ) + 1 );
-
-    pObject->setPosition ( pos );
-    updatePixmap ( );
-
-    bool bNeedUndo = true;
-    DVDMenuUndoObject *pUndo = (DVDMenuUndoObject *) undoBuffer ( )->last ( );
-    if ( pUndo && ( pUndo->getMenuObject ( ) ==  pObject ) )
-         bNeedUndo = ( ! pUndo->isMoving ( pEvent->key ( ) ) );
-    if ( bNeedUndo )
-         undoBuffer ( )->push ( new DVDMenuUndoObject ( DVDMenuUndoObject::MOVED_OBJECT, pObject, NULL, pEvent->key ( ) ) );
-  }
-  if ( pEvent->key ( ) == Qt::Key_Delete )  {
-
-    QPoint pos = mapFromGlobal ( QCursor::pos ( ) );
-    MenuObject *pObject = childContains ( pos );
-
-    if ( ! pObject )
-      return;
-    slotDeleteObject ( pObject );
-  }
-}
-
 QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderFrameNumber, long iTotalFramesToRender)
-{
+{    
 	if (m_backgroundPixmap.isNull())
 		return m_backgroundPixmap;
 	if (!pInterface)
@@ -374,7 +326,10 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 
 	// Okay here we get the Directory list of the extracted image files from the directory
 	theDir.setPath(qsFullPath);
-	QStringList listFiles = theDir.entryList ("0*.jpg");
+	//QStringList listFiles = theDir.entryList ("0*.jpg");					//ooo
+	QStringList listFiles = theDir.entryList ( QStringList( QString( "0*.jpg" ) ) );	//xxx
+    //QStringList listFiles = theDir.entryList ( QStringList() << QString( "0*.jpg" ).split( QString(" ") ), QDir::Files );	//xxx
+    
 	//QStringList listFiles = theDir.entryList ("rendered_*.png");
 	if (listFiles.count () == 0)	{
 		qsFullPath = QString ("%1/%2/").arg(Global::qsTempPath).arg(Global::qsProjectName);
@@ -394,7 +349,9 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 	// of the media files (background / movie-clips etc.)
 
 	// Version 1 will stretch the found files to fit exactly to the required framesToRender
-	iCurrentBackgroundFile = (int)((float)listFiles.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
+	//iCurrentBackgroundFile = (int)((float)listFiles.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);    //ooo
+	iCurrentBackgroundFile = static_cast<int>(static_cast<float>(listFiles.count()) * static_cast<float>(iRenderFrameNumber)/static_cast<float>(iTotalFramesToRender));    //xxx
+
 	// second alternative : render each frame 1:1 and at the end stay at the last frame
 	if (0)	{
 		iCurrentBackgroundFile = iRenderFrameNumber-1;
@@ -403,8 +360,11 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 	}
 
 	// Here we determine the fileName ...
-	qsFileName = QString ("%1/%2").arg(theDir.absPath()).arg(listFiles[iCurrentBackgroundFile]);
-	theFile.setName (qsFileName);
+    //qsFileName = QString ("%1/%2").arg(theDir.absPath()).arg(listFiles[iCurrentBackgroundFile]);		//ooo
+    qsFileName = QString ("%1/%2").arg(theDir.absolutePath()).arg(listFiles[iCurrentBackgroundFile]);	//xxx
+ 
+	//theFile.setName (qsFileName);		//ooo
+	theFile.setFileName (qsFileName);	//xxx
 
 	if (!theFile.exists())	{
 		//error ...
@@ -421,7 +381,7 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
 
 	QPainter thePainter(&thePixmap);
 	// And here we draw the objects ...
-	for (t=0;t<m_listMenuObjects.count();t++)	{
+	for (t=0;t<(uint)m_listMenuObjects.count();t++)	{
 	  pMenuObject = m_listMenuObjects.at(t);
 	  // Filter out if StopFrame is > 0(property is used) AND the current frame is within the limits
 	  if ( ( pMenuObject->modifiers ( )->iStopFrame < 1 )  ||
@@ -431,58 +391,79 @@ QPixmap &ButtonPreview::renderMenu (CDVDMenuInterface *pInterface, long iRenderF
       }
 
 	float fProgress = (float)iRenderFrameNumber / iTotalFramesToRender;
+ 
 	emit (signalRenderProgress (fProgress));
 
 	m_backgroundPixmap = thePixmap;
+    
 	return m_backgroundPixmap;
 }
 
 void ButtonPreview::fitDVDMenuBackground (QPixmap *pPixmap, int iResizeAlgorithm, int iStretchType, QSize posOffset, int iWidth, int iHeight)
 {
-	// Okay to tackle the background image generation
-	QImageHelper theImage;
-	((QImage&)theImage) = *pPixmap;
-	// set orig Pixmap to zero to save memory ...
-	*pPixmap = QPixmap();
-	// Next we handle the resizing pending the checked RadioButton algo ...
-	if (iStretchType > CDVDMenuInterface::StretchToFit)	{
-		// we create a tempImage 
-		QImage tempImage;
-		int iDeltaX, iDeltaY, iResizeAlgorithm;
-		iDeltaX = iDeltaY = iResizeAlgorithm = 0;
+  // Okay to tackle the background image generation
+  QImageHelper theImage;
+  //((QImage&)theImage) = *pPixmap;		//ooo
+  ((QImage&)theImage) = pPixmap->toImage();	//xxx
+  // set orig Pixmap to zero to save memory ...
+  *pPixmap = QPixmap();
+  // Next we handle the resizing pending the checked RadioButton algo ...
+  if (iStretchType > CDVDMenuInterface::StretchToFit)	{
+    // we create a tempImage 
+    QImage tempImage;
+    int iDeltaX, iDeltaY, iResizeAlgorithm;
+    iDeltaX = iDeltaY = iResizeAlgorithm = 0;
 
-		if (iStretchType == CDVDMenuInterface::StretchCutOff)	{	// Cut Off
-			tempImage = theImage.smoothScale (iWidth, iHeight, QImage::ScaleMax);
-			iDeltaX = posOffset.width ();
-			iDeltaY = posOffset.height();
-		}
-		else	{	// m_DVDMenuInterface::StretchBlackBorder
-			tempImage = theImage.smoothScale (iWidth, iHeight, QImage::ScaleMin);
-			// Note: The tempImage does not need to have the same extensions due to the ScaleMin flag.
-			iDeltaX = iWidth - tempImage.width();
-			if (iDeltaX > 0)
-				iDeltaX = (int)((float)iDeltaX / 2.0);
-			iDeltaY = iHeight - tempImage.height();
-			if (iDeltaY > 0)
-				iDeltaY = (int)((float)iDeltaY / 2.0);
-		}
+    if (iStretchType == CDVDMenuInterface::StretchCutOff)	{	// Cut Off
+      //tempImage = theImage.smoothScale (iWidth, iHeight, Qt::KeepAspectRatioByExpanding);	//ooo
+      tempImage = theImage.scaled (iWidth, iHeight, Qt::KeepAspectRatioByExpanding);		//xxx
+      iDeltaX = posOffset.width ();
+      iDeltaY = posOffset.height();
+    }
+    else	{	// m_DVDMenuInterface::StretchBlackBorder
+      //tempImage = theImage.smoothScale (iWidth, iHeight, Qt::KeepAspectRatio);	//ooo
+      tempImage = theImage.scaled (iWidth, iHeight, Qt::KeepAspectRatio);		//xxx
+      // Note: The tempImage does not need to have the same extensions due to the ScaleMin flag.
+      iDeltaX = iWidth - tempImage.width();
+      if (iDeltaX > 0)
+        iDeltaX = (int)((float)iDeltaX / 2.0);
+      iDeltaY = iHeight - tempImage.height();
+      if (iDeltaY > 0)
+        iDeltaY = (int)((float)iDeltaY / 2.0);
+    }
 
-		theImage.fill (0);  //Qt::black);
-		theImage.resize (iWidth, iHeight, iResizeAlgorithm);
-		bitBlt (&theImage, iDeltaX, iDeltaY, &tempImage, 0, 0, tempImage.width(), tempImage.height(), Qt::CopyROP);
-	}
-	else	// StretchToFit
-		theImage.resize (iWidth, iHeight, iResizeAlgorithm);
+    theImage.fill (0);  //Qt::black);
+    theImage.resize (iWidth, iHeight, iResizeAlgorithm);
+    //bitBlt (&theImage, iDeltaX, iDeltaY, &tempImage, 0, 0, tempImage.width(), tempImage.height(), Qt::CopyROP);	//oooo
+    //bitBlt (&theImage, iDeltaX, iDeltaY, &tempImage, 0, 0, tempImage.width(), tempImage.height());		//xxx
+    QPainter p( &theImage );
+    p.drawImage( iDeltaX, iDeltaY, tempImage, 0, 0, tempImage.width(), tempImage.height() );			//xxx
+  }
+  else	// StretchToFit
+    theImage.resize (iWidth, iHeight, iResizeAlgorithm);
 
-	*pPixmap = QPixmap (iWidth, iHeight);
+  *pPixmap = QPixmap (iWidth, iHeight);
 
-	// and here we set the final pixmap.	
-	pPixmap->convertFromImage (theImage);
+  // and here we set the final pixmap.	
+  pPixmap->convertFromImage (theImage);
 }
 
-void ButtonPreview::drawContents ( QPainter *painter )
+void ButtonPreview::paint() //xxx
 {
-  QLabel::drawContents ( painter );
+  ButtonPreview::repaint();
+  //QLabel::update();
+}
+
+void ButtonPreview::paint2() //xxx
+{
+  QPixmap thePixmap;
+  thePixmap = QPixmap ( m_backgroundPixmap );
+  QPainter thePainter ( &thePixmap  );
+  //drawVisibleRegion   ( &thePainter );
+  QPainter *painter;
+  painter = &thePainter;
+  
+  //QLabel::drawContents ( painter );		//ooo
   // We use the viewport to draw the Object in the Center for the ButtonDialog.
   // The Viewport is not used in the MenuPreview for the main window, thus drawing the button
   // on the right location ...
@@ -492,9 +473,58 @@ void ButtonPreview::drawContents ( QPainter *painter )
   // Note: we draw usually all objects into the pixmap, which we have set as a background see updatePixmap()
   if ( m_backgroundPixmap.isNull ( ) )  {
     uint t;
-    erase ( 5, 5, width ( ) - 10, height ( ) - 10 );
+    //erase ( 5, 5, width ( ) - 10, height ( ) - 10 );		//ooo
+    //eraseRect ( 5, 5, width ( ) - 10, height ( ) - 10 );	//xxx
     drawVisibleRegion ( painter );
-    for ( t=0; t<m_listMenuObjects.count ( ); t++ )  {
+    for ( t=0; t<(uint)m_listMenuObjects.count ( ); t++ )  {
+      m_listMenuObjects.at ( t )->drawContents ( painter );
+    }
+    return;
+  }
+
+  // This will draw the currentObject on top of the 'copy' we already painted into the pixmap.
+  if ( m_pActiveObject )
+       m_pActiveObject->drawContents ( painter );
+}
+
+void ButtonPreview::paintEvent( QPaintEvent* event )    //xxxx
+{
+  QLabel::paintEvent(event);
+  
+  //QLabel::paintEvent( event );  
+  //QPainter painter(this);
+  //drawContents( &painter ); // ... additional drawing  
+  
+  //QPainter thePainter;
+  //thePainter.begin      ( this );
+  //QPixmap doubleBuffer;
+  //doubleBuffer = QPixmap ( m_doubleBuffer );
+  //thePainter.begin  ( &doubleBuffer );
+  //drawContents( &thePainter );
+  
+  QPixmap thePixmap;
+  thePixmap = QPixmap ( m_backgroundPixmap );
+
+  QPainter thePainter ( &thePixmap  );
+  ButtonPreview::drawContents( &thePainter );
+}
+
+void ButtonPreview::drawContents ( QPainter *painter )
+{ 
+  //QLabel::drawContents ( painter );		//ooo
+  // We use the viewport to draw the Object in the Center for the ButtonDialog.
+  // The Viewport is not used in the MenuPreview for the main window, thus drawing the button
+  // on the right location ...
+  if ( m_rectViewport.width ( ) > 10 )
+       painter->setViewport ( m_rectViewport );
+  // In case the user has not yet defined a background Image, we want to show the Objects anyways ...
+  // Note: we draw usually all objects into the pixmap, which we have set as a background see updatePixmap()
+  if ( m_backgroundPixmap.isNull ( ) )  {
+    uint t;
+    //erase ( 5, 5, width ( ) - 10, height ( ) - 10 );		//ooo
+    //eraseRect ( 5, 5, width ( ) - 10, height ( ) - 10 );	//xxx
+    drawVisibleRegion ( painter );
+    for ( t=0; t<(uint)m_listMenuObjects.count ( ); t++ )  {
       m_listMenuObjects.at ( t )->drawContents ( painter );
     }
     return;
@@ -527,7 +557,8 @@ void ButtonPreview::drawVisibleRegion(QPainter *pPainter)
 	}
 }
 
-void ButtonPreview::setPixmap ( const QPixmap &pixmap )
+//void ButtonPreview::setPixmap ( const QPixmap &pixmap )   //ooo
+void ButtonPreview::set_Pixmap ( const QPixmap &pixmap )    //xxx
 {
   // This is an overloaded function from QLabel
   // We are going to handle the double buffer here ...
@@ -541,11 +572,12 @@ void ButtonPreview::updatePixmap ( )
 	if ( m_backgroundPixmap.isNull ( ) )
 		return;
 	// Set the waiting cursor ...
-	QCursor myCursor ( QCursor::WaitCursor );
+	QCursor myCursor ( Qt::WaitCursor );
 	setCursor ( myCursor );
 
 	// This is the function, which updates the background Pixmap
 	QPixmap thePixmap;
+
 	drawBackground ( thePixmap );
 
 	// This will check if we load the transparent background (extensions are much smaller)
@@ -555,17 +587,25 @@ void ButtonPreview::updatePixmap ( )
 		setFixedSize  ( thePixmap.width ( ), thePixmap.height ( ) );
 
 	setBackground ( thePixmap );
+	
 	// re-set the cursor ...
-	myCursor = QCursor ( QCursor::ArrowCursor );
+	//myCursor = QCursor ( QCursor::ArrowCursor );		//ooo
+	myCursor = QCursor ( Qt::ArrowCursor );			//xxx
 	setCursor ( myCursor );
 }
 
 void ButtonPreview::setBackground ( QPixmap &thePixmap )
 {
-  if ( parentWidget ( )->parentWidget ( )->name ( ) == QString ( "usingScrollView" ) )
-    setPaletteBackgroundPixmap ( thePixmap );
-  else
-    QLabel::setPixmap ( thePixmap );
+  //if ( parentWidget ( )->parentWidget ( )->name ( ) == QString ( "usingScrollView" ) )		//ooo
+  if ( parentWidget ( )->parentWidget ( )->accessibleName ( ) == QString ( "usingScrollView" ) ) {	//xxx
+    //setPaletteBackgroundPixmap ( thePixmap );		//oooo
+    QPalette palette;								//xxx
+    palette.setBrush(QPalette::Window, QBrush(thePixmap));				//xxx
+    this->setPalette(palette);					//xxx
+  } else {
+    //QLabel::setPixmap ( thePixmap );  //oooo
+    this->setPixmap ( thePixmap );  //  //xxx
+  }
 }
 
 void ButtonPreview::drawBackground ( QPixmap &thePixmap, MenuObject *pOmitMe )
@@ -573,17 +613,27 @@ void ButtonPreview::drawBackground ( QPixmap &thePixmap, MenuObject *pOmitMe )
   uint t;
   MenuObject *pObject;
   thePixmap = QPixmap ( m_backgroundPixmap );
+                                                                                                                             
   QPainter thePainter ( &thePixmap  );
   // First lets imprint the visibleRegionR - rect (if neccesarry).
   drawVisibleRegion   ( &thePainter );
+  
   // And here we draw the objects ...
-  for  ( t=0; t<m_listMenuObjects.count ( ); t++ ) {
+  for  ( t=0; t<(uint)m_listMenuObjects.count ( ); t++ ) {
     pObject = m_listMenuObjects.at ( t );
     if ( ! pObject )
       continue;
     if ( pOmitMe && ( pOmitMe == pObject ) )
       continue;
-    pObject->drawContents ( &thePainter );
+
+    if (pObject->objectType ( ) == TEXT_OBJECT)  //xxx
+       pObject->the_Pixmap = thePixmap;
+    
+    pObject->drawContents ( &thePainter );    //ooo
   }
 }
 
+/*void ButtonPreview::paintEvent (QPaintEvent *event)   //xxx
+{
+    
+}*/
