@@ -1,32 +1,35 @@
-/****************************************************************************
-** cachethumbs.cpp
-**
-**   Created : December 20'st 2007
-**        by : Varol Okan unsing XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This file holds the implementation of the caching logic. 
-** Note: Each video file will get N numbers of thumbs to allow a short anim
-**       of the contents.
-**       Only those image files which do not hold Exif thumbnails OR which
-**       have been tagged / modified by the user will get 1 thumb.
-**
-** Note2: The 'timeout' effect to keep cache size down needs to be
-**         implemented.
-**
-*****************************************************************************/
+/***************************************************************************
+    cachethumbs.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This file holds the implementation of the caching logic.
+   Note: Each video file will get N numbers of thumbs to allow a short anim
+         of the contents. 
+         Only those image files which do not hold Exif thumbnails OR which
+         have been tagged / modified by the user will get 1 thumb.
+         
+   Note2: The 'timeout' effect to keep cache size down needs to be
+           implemented.
+    
+****************************************************************************/
 
 #include <dlfcn.h>
 #include <stdio.h>
 
 #include <qfileinfo.h>
-#include <qwmatrix.h>
+#include <qmatrix.h>
 #include <qstring.h>
 #include <qimage.h>
 #include <qfile.h>
 #include <qdir.h>
 #include <qdom.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 #include "global.h"
 #include "utils.h"
@@ -51,9 +54,10 @@ Thumbs::MultiThumbRequest::MultiThumbRequest ( QObject *pObj, Entry *p )
        pEntry->freeImages  ( );
 
   pEntry->arrayOfThumbs      = new QImage *[pEntry->iNumberOfThumbs];
-  for ( uint t=0; t<pEntry->iNumberOfThumbs; t++ )
-    pEntry->arrayOfThumbs[t] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );
-
+  for ( uint t=0; t<pEntry->iNumberOfThumbs; t++ ) {
+    //pEntry->arrayOfThumbs[t] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );	//ooo
+    pEntry->arrayOfThumbs[t] = new QImage ( ":/images/error.jpg" );				//xxx
+  }
   // init base class variables
   theType    = TYPE_MULTI_THUMB;
   qsFileName = pEntry->qsFileName;
@@ -86,7 +90,8 @@ bool Thumbs::MultiThumbRequest::response ( )
   }
   // here we store the image and increase the iMScOffset for the next thumbnail.
   if ( iCurrentThumb-1 < (int)pEntry->iNumberOfThumbs )
-    *pEntry->arrayOfThumbs[iCurrentThumb] = pImage->smoothScale ( 300, 300, QImage::ScaleMin );
+    //*pEntry->arrayOfThumbs[iCurrentThumb] = pImage->smoothScale ( 300, 300, Qt::KeepAspectRatio );    //ooo
+    *pEntry->arrayOfThumbs[iCurrentThumb] = pImage->scaled ( 300, 300, Qt::KeepAspectRatio );           //xxx
 
   iMSecondsOffset = ++iCurrentThumb * iDelta;
 
@@ -145,7 +150,8 @@ bool Thumbs::Entry::readXml ( QDomElement *pSource )
 
   dateCreated  = QDateTime::fromString ( qsDateCreated  );
   dateLastUsed = QDateTime::fromString ( qsDateLastUsed );
-  listVirtualFolders = QStringList::split ( ";", qsVirtualFolder );
+  //listVirtualFolders = QStringList::split ( ";", qsVirtualFolder );   //ooo
+  listVirtualFolders = qsVirtualFolder.split ( ";" );                   //xxx
 
   // At this point we have all bu the thumbnails
   //iHashValue = pCache->hashFromFile ( qsFileName );
@@ -187,7 +193,9 @@ bool Thumbs::Entry::writeXml ( QDomElement *pCacheElement )
   entryNode.setAttribute  ( CACHE_COMMENT,   qsComment                 );
   entryNode.setAttribute  ( CACHE_CREATED,   dateCreated.toString  ( ) );
   entryNode.setAttribute  ( CACHE_LENGTH,    qsLength                  );
-  entryNode.setAttribute  ( CACHE_FILE_NAME, qsFileName.utf8       ( ) );
+  //entryNode.setAttribute  ( CACHE_FILE_NAME, qsFileName.utf8       ( ) );	//ooo
+  //entryNode.setAttribute  ( CACHE_FILE_NAME, QString(qsFileName.utf8 ( )) );	//xxx
+  entryNode.setAttribute  ( CACHE_FILE_NAME, QString(qsFileName.toUtf8 ( )) );	//xxx
   entryNode.setAttribute  ( CACHE_LAST_USED, dateLastUsed.toString ( ) );
   entryNode.appendChild   ( entryText );
 
@@ -203,7 +211,7 @@ bool Thumbs::Entry::loadImages ( )
   uint t;
   QImage *pImage, theImage;
   QString qsFilePath, qsHashBaseName, qsFullName, qsCount;
-  QValueList<QImage *>list;
+  QList<QImage *>list;			//oxx
   QFileInfo fileInfo ( qsFileName );
 
   qsFilePath     = pCache->getCachePath ( fileInfo.baseName ( ).left ( 1 ) );
@@ -221,14 +229,16 @@ bool Thumbs::Entry::loadImages ( )
   if ( list.count ( ) > 0 ) {
     iNumberOfThumbs = list.count ( );
     arrayOfThumbs   = new QImage *[list.count ( )];
-    for ( t=0; t<list.count ( ); t++ ) {
+    //for ( t=0; t<list.count ( ); t++ ) {                      //ooo
+    for ( t=0; t<static_cast<uint> ( list.count ( ) ); t++ ) {  //xxx
       arrayOfThumbs[t] = list[t];
     }
   }
   else {
     iNumberOfThumbs  = 1;
     arrayOfThumbs    = new QImage *[1];
-    arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );
+    //arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );	//ooo
+    arrayOfThumbs[0] = new QImage ( ":/images/error.jpg" );				//xxx
     return false;
   }
   return true;
@@ -280,7 +290,7 @@ void Thumbs::Entry::scanImages ( QObject *pTarget )
   MediaCreator::registerWithMediaScanner ( pRequest );
 }
 
-QWMatrix *Thumbs::Entry::getMatrix ( )
+QMatrix *Thumbs::Entry::getMatrix ( )
 {
   return NULL;
 }
@@ -336,9 +346,11 @@ bool Thumbs::ImageEntry::readXml ( QDomElement *pSource )
   qsImageInfo  = pSource->text ( );
   dateCreated  = QDateTime::fromString ( qsDateCreated,  Qt::ISODate );
   dateLastUsed = QDateTime::fromString ( qsDateLastUsed, Qt::ISODate );
-  listVirtualFolders = QStringList::split ( ";", qsVirtualFolder );
+  //listVirtualFolders = QStringList::split ( ";", qsVirtualFolder );   //ooo
+  listVirtualFolders = qsVirtualFolder.split ( ";" );                   //xxx
 
-  QStringList listSize = QStringList::split ( "x", qsDimension );
+  //QStringList listSize = QStringList::split ( "x", qsDimension );     //ooo
+  QStringList listSize = qsDimension.split ( "x" );                     //xxx
   bSaveImage = true;
   if ( listSize.count ( ) > 1 )  {
     int iWidth  = listSize[0].toInt ( );
@@ -392,7 +404,9 @@ bool Thumbs::ImageEntry::writeXml ( QDomElement *pCacheElement )
     entryNode.setAttribute ( CACHE_COMMENT,    qsComment                 );
   entryNode.setAttribute   ( CACHE_DIMENSION,  qsDimension               );
   entryNode.setAttribute   ( CACHE_CREATED,    dateCreated.toString  ( "yyyy-MM-dd hh:mm:ss" ) );
-  entryNode.setAttribute   ( CACHE_FILE_NAME,  qsFileName.utf8       ( ) );
+  //entryNode.setAttribute   ( CACHE_FILE_NAME,  qsFileName.utf8       ( ) );		//ooo
+  //entryNode.setAttribute   ( CACHE_FILE_NAME,  QString(qsFileName.utf8 ( )) );		//xxx
+  entryNode.setAttribute   ( CACHE_FILE_NAME,  QString(qsFileName.toUtf8 ( )) );		//xxx
   entryNode.setAttribute   ( CACHE_LAST_USED,  dateLastUsed.toString ( "yyyy-MM-dd hh:mm:ss" ) );
   entryNode.appendChild    ( entryText );
 
@@ -431,7 +445,8 @@ bool Thumbs::ImageEntry::loadImages ( ) // load images from cache or from the fi
 
   QImage theImage;
   QFileInfo fileInfo ( qsFileName );
-  QString qsExt = fileInfo.extension ( FALSE ).lower ( );
+  //QString qsExt = fileInfo.extension ( FALSE ).lower ( );     //ooo
+  QString qsExt = fileInfo.suffix ( ).toLower ( );              //xxx
   QString qsFilePath, qsHashBaseName, qsFullName;
   arrayOfThumbs = new QImage *[1];
 
@@ -456,15 +471,17 @@ bool Thumbs::ImageEntry::loadImages ( ) // load images from cache or from the fi
     if ( pInfo )  {
       if ( pInfo->pThumbnail )  {
         // take ownership of the thumbnail
-        arrayOfThumbs[0]  = pInfo->pThumbnail;
+        //arrayOfThumbs[0]  = pInfo->pThumbnail;    //ooo
+        *arrayOfThumbs[0]  = pInfo->pThumbnail->pixmap(pInfo->pThumbnail->actualSize(QSize(32, 32))).toImage();      //xxx  
         pInfo->pThumbnail = NULL;
         bSaveImage        = false;  // Set to false if the image size is < 641 x 481
 //      bStoreData        = false;  // no need to keep the record in the cache
         iScanStatus       = 2;      // 0=undef, 1=scanning, 2=scanning done.
       }
-      else
-        arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );
-
+      else {
+        //arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );		//ooo
+        arrayOfThumbs[0] = new QImage ( ":/images/error.jpg" );					//xxx
+      }
       qsDimension     = QString ( "%1x%2" ).arg ( pInfo->iWidth ).arg ( pInfo->iHeight ); // The width x height
       iOrientation    = pInfo->iOrientation;
       iNumberOfThumbs = 1;
@@ -478,11 +495,13 @@ bool Thumbs::ImageEntry::loadImages ( ) // load images from cache or from the fi
       bSaveImage       = ( ( theImage.width ( ) > 640 ) || ( theImage.height ( ) > 480 ) );
       bStoreData       = true;
       iNumberOfThumbs  = 1;
-      arrayOfThumbs[0] = new QImage ( theImage.smoothScale ( 300, 300, QImage::ScaleMin ) );
+      //arrayOfThumbs[0] = new QImage ( theImage.smoothScale ( 300, 300, Qt::KeepAspectRatio ) );   //ooo
+      arrayOfThumbs[0] = new QImage ( theImage.scaled ( 300, 300, Qt::KeepAspectRatio ) );          //xxx
       saveImages   ( );
     }
     else  {
-      arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );
+      //arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );	//ooo
+      arrayOfThumbs[0] = new QImage ( ":/images/error.jpg" );				//xxx
       bSaveImage       = false;
       bStoreData       = false;
       return false;
@@ -498,7 +517,8 @@ void Thumbs::ImageEntry::scanImages ( QObject * ) // load images from cache
 
   QFileInfo fileInfo ( qsFileName );
   iFileSize     = fileInfo.size ( );
-  QString qsExt = fileInfo.extension ( FALSE ).lower ( );
+  //QString qsExt = fileInfo.extension ( FALSE ).lower ( );     //ooo
+  QString qsExt = fileInfo.suffix ( ).toLower ( );              //xxx
   arrayOfThumbs = new QImage *[1];
   jhead::JHead *pPlugin = NULL;
 
@@ -513,7 +533,8 @@ void Thumbs::ImageEntry::scanImages ( QObject * ) // load images from cache
         dateCreated = pInfo->imageDate;
 
       // Take ownership of the thumbnail
-      arrayOfThumbs[0]  = pInfo->pThumbnail;
+      //arrayOfThumbs[0]  = pInfo->pThumbnail;  //ooo
+      *arrayOfThumbs[0]  = pInfo->pThumbnail->pixmap(pInfo->pThumbnail->actualSize(QSize(32, 32))).toImage();      //xxx
       pInfo->pThumbnail = NULL;
       iOrientation = pInfo->iOrientation;
       qsDimension  = QString ( "%1x%2" ).arg ( pInfo->iWidth ).arg ( pInfo->iHeight ); // The width x height
@@ -528,14 +549,17 @@ void Thumbs::ImageEntry::scanImages ( QObject * ) // load images from cache
   if ( theImage.load ( qsFileName ) )  {
     qsDimension = QString ( "%1x%2" ).arg ( theImage.width ( ) ).arg ( theImage.height ( ) );
     bSaveImage  = ( ( theImage.width ( ) > 640 ) || ( theImage.height ( ) > 480 ) );
-    arrayOfThumbs[0] = new QImage ( theImage.smoothScale ( 300, 300, QImage::ScaleMin ) );
+    //arrayOfThumbs[0] = new QImage ( theImage.smoothScale ( 300, 300, Qt::KeepAspectRatio ) );     //ooo
+    arrayOfThumbs[0] = new QImage ( theImage.scaled ( 300, 300, Qt::KeepAspectRatio ) );            //xxx
     saveImages   ( );
   }
-  else
-    arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );
+  else {
+    //arrayOfThumbs[0] = new QImage ( QImage ( ).fromMimeSource( "error.jpg" ) );	//ooo
+    arrayOfThumbs[0] = new QImage ( ":/images/error.jpg" );				//xxx
+  }
 }
 
-QWMatrix *Thumbs::ImageEntry::getMatrix ( )
+QMatrix *Thumbs::ImageEntry::getMatrix ( )
 {
   return pMatrix;
 }
@@ -574,9 +598,9 @@ void Thumbs::ImageEntry::initMatrix ( )
   }
 
   // And finally we set the matrix ...
-  QWMatrix flip ( -1, 0, 0, 1, 1, 0 );
+  QMatrix flip ( -1, 0, 0, 1, 1, 0 );
   if ( ! pMatrix )
-    pMatrix = new QWMatrix;
+    pMatrix = new QMatrix;
   else
     pMatrix->reset ( );
 
@@ -593,7 +617,7 @@ Thumbs::VirtualFolder::VirtualFolder ( Thumbs *pThumbs )
 
 Thumbs::VirtualFolder::~VirtualFolder ( )
 {
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) )
     delete *it++;
@@ -645,7 +669,7 @@ bool Thumbs::VirtualFolder::writeXml ( QDomElement *pFolderElement )
   folderNode.appendChild  ( entryText );
 
   VFile *pFile;
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) ) {
     pFile = *it++;
@@ -666,7 +690,7 @@ void Thumbs::VirtualFolder::append ( Entry *pEntry )
   if ( ! pEntry )
     return;
   VFile *pFile;
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) ) {
     pFile = *it++;
@@ -685,7 +709,7 @@ void Thumbs::VirtualFolder::append ( ImageEntry *pEntry )
   if ( ! pEntry )
     return;
   VFile *pFile;
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) ) {
     pFile = *it++;
@@ -701,7 +725,7 @@ void Thumbs::VirtualFolder::append ( ImageEntry *pEntry )
 
 void Thumbs::VirtualFolder::clear ( )
 {
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) )
     delete *it++;
@@ -712,7 +736,7 @@ Thumbs::VirtualFolder *Thumbs::VirtualFolder::clone ( )
 {
   VirtualFolder *pFolder = new VirtualFolder ( pCache );
   VFile         *pFile,  *pNewFile;
-  QValueList<VFile *>::iterator it;
+  QList<VFile *>::iterator it;		//oxx
   it = listOfFiles.begin ( );
   while ( it != listOfFiles.end ( ) ) {
     pFile = *it++;
@@ -777,9 +801,11 @@ bool Thumbs::loadPlugin ( )
   m_pPlugin          = NULL;
 
   QString  qsFilePath ( Global::qsSystemPath + "/share/qdvdauthor/lib/libjhead.so" );
-  m_pLibrary = dlopen ( qsFilePath.ascii ( ), RTLD_LAZY );
+  //m_pLibrary = dlopen ( qsFilePath.ascii ( ), RTLD_LAZY );            //ooo
+  m_pLibrary = dlopen ( qsFilePath.toLatin1().data ( ), RTLD_LAZY );    //xxx
   if ( ! m_pLibrary ) {
-    printf ( "Fatal: Cannot load library <%s>\n       %s\n", qsFilePath.ascii ( ), dlerror ( ) );
+    //printf ( "Fatal: Cannot load library <%s>\n       %s\n", qsFilePath.ascii ( ), dlerror ( ) );         //ooo
+    printf ( "Fatal: Cannot load library <%s>\n       %s\n", qsFilePath.toLatin1().data ( ), dlerror ( ) ); //xxx  
     return false;
   }
 
@@ -787,14 +813,16 @@ bool Thumbs::loadPlugin ( )
   dlerror ( );
 
   // load the symbols
-  createJHead_t *pCreateLibrary = (createJHead_t *) dlsym ( m_pLibrary, "createPlugin" );
+  createJHead_t *pCreateLibrary = (createJHead_t *) dlsym ( m_pLibrary, "createPlugin" ); //ooo
+  //create_t *pCreateLibrary = (create_t *) dlsym ( m_pLibrary, "createPlugin" ); //xxx
   const char    *pErrorString   = dlerror ( );
   if ( pErrorString ) {
     printf ( "Cannot load symbol create: %s\n", pErrorString );
     return false;
   }
 
-  m_pDestroyFunction = (destroyJHead_t *) dlsym ( m_pLibrary, "destroyPlugin" );
+  m_pDestroyFunction = (destroyJHead_t *) dlsym ( m_pLibrary, "destroyPlugin" );  //ooo
+  //m_pDestroyFunction = (destroy_t *) dlsym ( m_pLibrary, "destroyPlugin" ); //xxx
   pErrorString = dlerror ( );
   if ( pErrorString ) {
     printf ( "Cannot load symbol destroy: %s\n", pErrorString );
@@ -824,7 +852,7 @@ void Thumbs::unloadPlugin ( )
 
 void Thumbs::clearCache ( )
 {
-  QValueList<Entry *>::iterator it;
+  QList<Entry *>::iterator it;		//oxx
   it = m_listOfThumbs.begin ( );
   while ( it != m_listOfThumbs.end ( ) ) 
     delete *it++;
@@ -832,17 +860,18 @@ void Thumbs::clearCache ( )
 }
 
 void Thumbs::clearImages ( )
-{
-  QValueList<ImageEntry *>::iterator it;
+{ 
+  QList<ImageEntry *>::iterator it;	//oxx
+  //QList<ImageEntry *>::const_iterator it;	//xxx
   it = m_listOfImages.begin ( );
   while ( it != m_listOfImages.end ( ) ) 
     delete *it++;
-  m_listOfImages.clear ( );
+  m_listOfImages.clear ( );   //ooooo
 }
 
 void Thumbs::clearVirtualFolder ( )
 {
-  QValueList<VirtualFolder *>::iterator it;
+  QList<VirtualFolder *>::iterator it;		//oxx
   it = m_listOfVirtualFolders.begin ( );
   while ( it != m_listOfVirtualFolders.end ( ) ) 
     delete *it++;
@@ -858,7 +887,7 @@ void Thumbs::freeImages ( )
 { 
   // to free some space after closing dialog
   Entry *pEntry;
-  QValueList<Entry *>::iterator it;
+  QList<Entry *>::iterator it;		//oxx
   it = m_listOfThumbs.begin ( );
   while ( it != m_listOfThumbs.end ( ) ) {
     pEntry = *it++;
@@ -873,14 +902,16 @@ jhead::JHead *Thumbs::plugin ( )
 
 QString Thumbs::getCachePath ( QString c )
 {
-  QString qsPath = QString ( "%1/.qdvdauthor/cache/%2/" ). arg ( QDir::homeDirPath ( ) ).arg ( c.lower ( ) );
+  //QString qsPath = QString ( "%1/.qdvdauthor/cache/%2/" ). arg ( QDir::homeDirPath ( ) ).arg ( c.lower ( ) );     //ooo
+  QString qsPath = QString ( "%1/.qdvdauthor/cache/%2/" ). arg ( QDir::homePath ( ) ).arg ( c.toLower ( ) );        //xxx
   return qsPath;
 }
 
 bool Thumbs::loadCacheDB ( )
 {
   // Assign the file
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
   QString qsFileName = qsPath + QString ( CACHE_DB_FILE );
 
   QDir theDir ( qsPath );
@@ -894,7 +925,7 @@ bool Thumbs::loadCacheDB ( )
   if ( ! projectFile.exists ( ) )
     return true;
 
-  if ( ! projectFile.open ( IO_ReadOnly ) )
+  if ( ! projectFile.open ( QIODevice::ReadOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -931,14 +962,15 @@ bool Thumbs::loadCacheDB ( )
 }
 
 bool Thumbs::saveCacheDB ( )
-{
+{ 
   // Assign the file
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
   QString qsFileName = qsPath  + QString ( CACHE_DB_FILE );
   QString qsTempName = qsFileName + ".tmp";
 
   QFile projectFile ( qsTempName );
-  if ( ! projectFile.open ( IO_WriteOnly ) )
+  if ( ! projectFile.open ( QIODevice::WriteOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -947,7 +979,7 @@ bool Thumbs::saveCacheDB ( )
   xmlDoc.appendChild( root );
 
   Entry *pEntry = NULL;
-  QValueList<Entry *>::iterator it;
+  QList<Entry *>::iterator it;		//oxx
   it = m_listOfThumbs.begin ( );
   while ( it != m_listOfThumbs.end ( ) ) {
     pEntry = *it++;
@@ -959,7 +991,8 @@ bool Thumbs::saveCacheDB ( )
   // the generated file, we should replace them here.
   xml.replace ( "&lt;", "<"); 
   //debug_out ("%s\n", (const char *)xml);
-  projectFile.writeBlock ( xml, qstrlen ( xml ) );
+  //projectFile.writeBlock ( xml, qstrlen ( xml ) );                                //ooo
+  projectFile.write ( xml.toLatin1().data(), qstrlen ( xml.toLatin1().data() ) );    //xxx
   projectFile.close ( );
 
   // At this point we are sure to have written the whole file and can copy it over the original file.
@@ -974,9 +1007,11 @@ void Thumbs::cleanCacheDB ( )
 }
 
 bool Thumbs::loadImageDB ( )
-{
+{  
   // Assign the file
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
+
   QString qsFileName = qsPath + QString ( IMAGE_DB_FILE );
 
   QDir theDir ( qsPath );
@@ -990,7 +1025,7 @@ bool Thumbs::loadImageDB ( )
   if ( ! projectFile.exists ( ) )
     return true;
 
-  if ( ! projectFile.open ( IO_ReadOnly ) )
+  if ( ! projectFile.open ( QIODevice::ReadOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -1011,31 +1046,43 @@ bool Thumbs::loadImageDB ( )
   QDomNode xmlNode = docElem.firstChild ( );
   while( ! xmlNode.isNull ( ) )  {
     QDomElement sourceElem = xmlNode.toElement ( );
-    if ( sourceElem.tagName ( ) == CACHE_TAG_IMAGE ) {
+    if ( sourceElem.tagName ( ) == CACHE_TAG_IMAGE ) {      
       pEntry  = new ImageEntry ( this );
       pEntry->readXml ( &sourceElem );
       // If there has been a problem then return false.
-      //printf ( "Thumbs::loadCacheDB Entry<%s> <%016llX> \n", pEntry->qsFileName.ascii(), pEntry->iHashValue );
-      m_listOfImages.append ( pEntry );
+      //printf ( "Thumbs::loadCacheDB Entry<%s> <%016llX> \n", pEntry->qsFileName.ascii(), pEntry->iHashValue );            //ooo
+      //printf ( "Thumbs::loadCacheDB Entry<%s> <%016llX> \n", pEntry->qsFileName.toLatin1().data(), pEntry->iHashValue );    //xxx
+      m_listOfImages.append ( pEntry );   //ooooo
     }
     // Otherwise go to the next node ...
     xmlNode = xmlNode.nextSibling ( );
   }
 
+  ImageEntry *p_Entry = NULL;  //xxx
+  QList<ImageEntry *>::const_iterator it;   //xxx
+  it = m_listOfImages.begin ( );    //xxx
+  
+  while ( it != m_listOfImages.end ( ) ) {  //xxx
+    p_Entry = *it++;
+    //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.ascii(), pEntry->iHashValue );   //ooo
+    //printf ( "  Looking at <%s> = <0x%016llX>\n", p_Entry->qsFileName.toLatin1().data(), p_Entry->iHashValue );   //xxx
+  }
+
   projectFile.close ( );
   return true;
 }
 
 bool Thumbs::saveImageDB ( )
-{
+{ 
   // Assign the file
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
   QString qsFileName = qsPath  + QString ( IMAGE_DB_FILE );
 
   QString qsTempName = qsFileName + ".tmp";
 
   QFile projectFile ( qsTempName );
-  if ( ! projectFile.open ( IO_WriteOnly ) )
+  if ( ! projectFile.open ( QIODevice::WriteOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -1044,8 +1091,11 @@ bool Thumbs::saveImageDB ( )
   xmlDoc.appendChild( root );
 
   ImageEntry *pEntry = NULL;
-  QValueList<ImageEntry *>::iterator it;
+  //QList<ImageEntry *>::iterator it;	//oxx
+  QList<ImageEntry *>::const_iterator it;	//xxx
+ 
   it = m_listOfImages.begin ( );
+ 
   while ( it != m_listOfImages.end ( ) ) {
     pEntry = *it++;
     pEntry->writeXml ( &root );
@@ -1056,7 +1106,8 @@ bool Thumbs::saveImageDB ( )
   // the generated file, we should replace them here.
   xml.replace ( "&lt;", "<"); 
   //debug_out ("%s\n", (const char *)xml);
-  projectFile.writeBlock ( xml, qstrlen ( xml ) );
+  //projectFile.writeBlock ( xml, qstrlen ( xml ) );                               //ooo
+  projectFile.write ( xml.toLatin1().data(), qstrlen ( xml.toLatin1().data() ) );  //xxx
   projectFile.close ( );
 
   // At this point we are sure to have written the whole file and can copy it over the original file.
@@ -1071,8 +1122,9 @@ void Thumbs::cleanImageDB ( )
 }
 
 bool Thumbs::loadVirtualFolder ( bool bImageFolder )
-{
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+{  
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
   QString qsFileName;
   if ( bImageFolder )
     qsFileName = qsPath  + QString ( VIMAGE_DB_FILE );
@@ -1090,7 +1142,7 @@ bool Thumbs::loadVirtualFolder ( bool bImageFolder )
   if ( ! projectFile.exists ( ) )
     return true;
 
-  if ( ! projectFile.open ( IO_ReadOnly ) )
+  if ( ! projectFile.open ( QIODevice::ReadOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -1132,7 +1184,8 @@ bool Thumbs::loadVirtualFolder ( bool bImageFolder )
 bool Thumbs::saveVirtualFolder ( bool bImageFolder )
 {
   // Assign the file
-  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );
+  //QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homeDirPath ( ) );    //ooo
+  QString qsPath     = QString ( "%1/.qdvdauthor/cache/" ). arg ( QDir::homePath ( ) );         //xxx
   QString qsFileName, qsTempName;
   if ( bImageFolder )
     qsFileName = qsPath  + QString ( VIMAGE_DB_FILE );
@@ -1142,7 +1195,7 @@ bool Thumbs::saveVirtualFolder ( bool bImageFolder )
   qsTempName = qsFileName + ".tmp";
 
   QFile projectFile ( qsTempName );
-  if ( ! projectFile.open ( IO_WriteOnly ) )
+  if ( ! projectFile.open ( QIODevice::WriteOnly ) )
     return false;
 
   QDomDocument xmlDoc( CACHE_DOCTYPE );
@@ -1151,7 +1204,7 @@ bool Thumbs::saveVirtualFolder ( bool bImageFolder )
   xmlDoc.appendChild( root );
 
   VirtualFolder *pFolder = NULL;
-  QValueList<VirtualFolder *>::iterator it, itEnd;
+  QList<VirtualFolder *>::iterator it, itEnd;		//oxx
   it    = m_listOfVirtualFolders.begin ( );
   itEnd = m_listOfVirtualFolders.end   ( );
   if ( bImageFolder )  {
@@ -1169,7 +1222,8 @@ bool Thumbs::saveVirtualFolder ( bool bImageFolder )
   // the generated file, we should replace them here.
   xml.replace ( "&lt;", "<"); 
   //debug_out ("%s\n", (const char *)xml);
-  projectFile.writeBlock ( xml, qstrlen ( xml ) );
+  //projectFile.writeBlock ( xml, qstrlen ( xml ) );                                //ooo
+  projectFile.write ( xml.toLatin1().data(), qstrlen ( xml.toLatin1().data() ) );   //xxx
   projectFile.close ( );
 
   // At this point we are sure to have written the whole file and can copy it over the original file.
@@ -1180,7 +1234,7 @@ bool Thumbs::saveVirtualFolder ( bool bImageFolder )
 
 
 bool Thumbs::copyOver ( QString &qsTempFile, QString &qsFileName )
-{
+{   
   // Copy the temp file over the original file
   QFile fileOrig ( qsFileName );
   QFile fileTemp ( qsTempFile );
@@ -1189,7 +1243,8 @@ bool Thumbs::copyOver ( QString &qsTempFile, QString &qsFileName )
       if ( !fileOrig.remove ( ) )
         return false;
     }
-    int iRet = rename ( qsTempFile.utf8 ( ), qsFileName.utf8 ( ) );
+    //int iRet = rename ( qsTempFile.utf8 ( ), qsFileName.utf8 ( ) );   //ooo
+    int iRet = rename ( qsTempFile.toUtf8 ( ), qsFileName.toUtf8 ( ) ); //xxx
     if ( iRet != 0 )
          iRet  = iRet; // Error
   }
@@ -1197,8 +1252,9 @@ bool Thumbs::copyOver ( QString &qsTempFile, QString &qsFileName )
 }
 
 Thumbs::Entry *Thumbs::find ( QString &qsFileName, bool bImage )
-{
+{   
   unsigned long long iHash = hashFromFile ( qsFileName );
+
   return find ( iHash, bImage );
 }
 
@@ -1206,31 +1262,36 @@ Thumbs::Entry *Thumbs::find ( unsigned long long iHash, bool bImage )
 {
   if ( bImage )  {
     ImageEntry *pEntry = NULL;
-    QValueList<ImageEntry *>::iterator it;
+    QList<ImageEntry *>::iterator it;		//oxx
+ 
     it = m_listOfImages.begin ( );
+
     while ( it != m_listOfImages.end ( ) ) {
       pEntry = *it++;
-      //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.ascii(), pEntry->iHashValue );
+      //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.ascii(), pEntry->iHashValue );   //ooo
+      //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.toLatin1().data(), pEntry->iHashValue );   //xxx
       if ( pEntry->iHashValue == iHash )
         return pEntry;
     }
   }
   else  {
     Entry *pEntry = NULL;
-    QValueList<Entry *>::iterator it;
+    QList<Entry *>::iterator it;	//oxx
     it = m_listOfThumbs.begin ( );
     while ( it != m_listOfThumbs.end ( ) ) {
       pEntry = *it++;
       //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.ascii(), pEntry->iHashValue );
-      if ( pEntry->iHashValue == iHash )
+      //printf ( "  Looking at <%s> = <0x%016llX>\n", pEntry->qsFileName.toLatin1().data(), pEntry->iHashValue ); //xxx
+      if ( pEntry->iHashValue == iHash ) {
         return pEntry;
+      }
     }
   }
   return NULL;
 }
 
 Thumbs::Entry *Thumbs::append ( QString &qsFile, QString qsLength, uint iThumbs, QImage **ppArray )
-{
+{ 
   // Here we create a entry in the cache for this file and copy the images over
   // plus we have to store them into the cache under $HOME/.qdvdauthor/cache/X/<HasName>_xx.png
   QFileInfo fileInfo ( qsFile );
@@ -1261,8 +1322,8 @@ Thumbs::Entry *Thumbs::append ( QString &qsFile, QString qsLength, uint iThumbs,
   return pEntry; 
 }
 
-Thumbs::Entry *Thumbs::append ( QString &qsFile, QImage *pImage )
-{
+Thumbs::Entry *Thumbs::append ( QString &qsFile, QImage *pImage )   //ooooo
+{    
   // Here we create a entry in the cache for this file and copy the images over
   // plus we have to store them into the cache under $HOME/.qdvdauthor/cache/X/<HasName>_xx.png
   QFileInfo fileInfo ( qsFile );
@@ -1277,7 +1338,7 @@ Thumbs::Entry *Thumbs::append ( QString &qsFile, QImage *pImage )
     return NULL;
   }
 
-  m_listOfImages.append ( pEntry );
+  m_listOfImages.append ( pEntry );   //ooooo
 
   // And after we have stored the xml file we will save the images in the cache.
   if ( pImage )  {
@@ -1297,7 +1358,7 @@ Thumbs::Entry *Thumbs::append ( QString &qsFile, QImage *pImage )
 }
 
 Thumbs::Entry *Thumbs::append ( QString &qsFile, QObject *pTarget, uint iThumbs )
-{
+{  
   // Here we create a entry in the cache for this file and copy the images over
   // plus we have to store them into the cache under $HOME/.qdvdauthor/cache/X/<HasName>_xx.png
   QFileInfo fileInfo ( qsFile );
@@ -1325,7 +1386,7 @@ Thumbs::Entry *Thumbs::append ( QString &qsFile, QObject *pTarget, uint iThumbs
 Thumbs::VirtualFolder *Thumbs::findVirtualFolder ( unsigned int iHash, bool bImageFolder )
 {
   VirtualFolder *pVFolder = NULL;
-  QValueList<VirtualFolder *>::iterator it, itEnd;
+  QList<VirtualFolder *>::iterator it, itEnd;		//oxx
   it    = m_listOfVirtualFolders.begin ( );
   itEnd = m_listOfVirtualFolders.end   ( );
   if ( bImageFolder )  {
@@ -1345,7 +1406,7 @@ Thumbs::VirtualFolder *Thumbs::findVirtualFolder ( unsigned int iHash, bool bIma
 Thumbs::VirtualFolder *Thumbs::findVirtualFolder ( QString &qsFolderName, bool bImageFolder )
 {
   VirtualFolder *pVFolder = NULL;
-  QValueList<VirtualFolder *>::iterator it, itEnd;
+  QList<VirtualFolder *>::iterator it, itEnd;		//oxx
   it    = m_listOfVirtualFolders.begin ( );
   itEnd = m_listOfVirtualFolders.end   ( );
   if ( bImageFolder )  {
@@ -1396,15 +1457,17 @@ void Thumbs::deleteVirtualFolder ( unsigned int iHash, bool bImageFolder )
   //  printf ( "Thumbs::deleteVirtualFolder <%08X><%p>\n", iHash, pVFolder );
   if ( pVFolder ) {
     if ( bImageFolder )
-      m_listOfImageFolders.remove ( pVFolder );
+      //m_listOfImageFolders.remove ( pVFolder );       //ooo
+      m_listOfImageFolders.removeOne ( pVFolder );      //xxx
     else
-      m_listOfVirtualFolders.remove ( pVFolder );
+      //m_listOfVirtualFolders.remove ( pVFolder );     //ooo
+      m_listOfVirtualFolders.removeOne ( pVFolder );    //xxx
     delete pVFolder;
   }
   saveVirtualFolder ( bImageFolder );
 }
 
-QValueList<Thumbs::VirtualFolder *> &Thumbs::getVirtualFolders ( bool bImageFolder )
+QList<Thumbs::VirtualFolder *> &Thumbs::getVirtualFolders ( bool bImageFolder )		//oxx
 {
   if ( bImageFolder )
     return m_listOfImageFolders;
@@ -1412,12 +1475,12 @@ QValueList<Thumbs::VirtualFolder *> &Thumbs::getVirtualFolders ( bool bImageFold
   return m_listOfVirtualFolders;
 }
 
-QValueList<Thumbs::Entry *> Thumbs::getScannedThumbs ( )
+QList<Thumbs::Entry *> Thumbs::getScannedThumbs ( )	//oxx
 {
-  QValueList<Entry *> list;
+  QList<Entry *> list;		//oxx
 
   Entry *pEntry;
-  QValueList<Entry *>::iterator it;
+  QList<Entry *>::iterator it;		//oxx
   it = m_listOfThumbs.begin ( );
   while ( it != m_listOfThumbs.end ( ) ) {
     pEntry = *it++;
@@ -1428,13 +1491,14 @@ QValueList<Thumbs::Entry *> Thumbs::getScannedThumbs ( )
   return list;
 }
 
-QValueList<Thumbs::Entry *> Thumbs::getThumbsByStar ( uint iStar, bool bImage )
+QList<Thumbs::Entry *> Thumbs::getThumbsByStar ( uint iStar, bool bImage )	//oxx
 {
-  QValueList<Entry *> list;
+  QList<Entry *> list;		//oxx
 
   if ( bImage )  {
     ImageEntry *pEntry;
-    QValueList<ImageEntry *>::iterator it;
+    //QList<ImageEntry *>::iterator it;		//oxx
+    QList<ImageEntry *>::const_iterator it;		//xxx
     it = m_listOfImages.begin ( );
     while ( it != m_listOfImages.end ( ) ) {
       pEntry = *it++;
@@ -1444,7 +1508,7 @@ QValueList<Thumbs::Entry *> Thumbs::getThumbsByStar ( uint iStar, bool bImage )
   }
   else  {
     Entry *pEntry;
-    QValueList<Entry *>::iterator it;
+    QList<Entry *>::iterator it;	//oxx
     it = m_listOfThumbs.begin ( );
     while ( it != m_listOfThumbs.end ( ) ) {
       pEntry = *it++;
@@ -1456,7 +1520,7 @@ QValueList<Thumbs::Entry *> Thumbs::getThumbsByStar ( uint iStar, bool bImage )
 }
 
 unsigned long long Thumbs::hashFromFile ( QString &qsFileName )
-{
+{  
   QString   qsFingerprint;
   QFileInfo fileInfo ( qsFileName );
 
@@ -1487,10 +1551,13 @@ unsigned long long Thumbs::hashFromPath ( QString &qsPathName )
 }
 
 unsigned long long Thumbs::SDBMHash ( QString &str )
-{
+{   
    unsigned long long hash = 0;
-   for ( unsigned int i = 0; i < str.length ( ); i++ )
-     hash = str[i].latin1 ( ) + (hash << 6) + (hash << 16) - hash;
+   //for ( unsigned int i = 0; i < str.length ( ); i++ )                        //ooo
+   for ( unsigned int i = 0; i < static_cast<uint> ( str.length ( ) ); i++ ) {    //xxx
+     //hash = str[i].latin1 ( ) + (hash << 6) + (hash << 16) - hash;            //ooo
+     hash = str[i].toLatin1 ( ) + (hash << 6) + (hash << 16) - hash;            //xxx
+   }
 
    return hash;
 }
