@@ -1,33 +1,47 @@
-/****************************************************************************
-** StructureToolBar - class
-**
-**   Created : Tue May 08 12:09:08 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class will create a toolbar, which holds only one widget.
-** The StructureWidget is displaying the current structure of the DVD.
-**
+/***************************************************************************
+    colortoolbar.cpp
+                             -------------------
+    StructureToolBar - class                         
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class will create a toolbar, which holds only one widget.
+    The StructureWidget is displaying the current structure of the DVD.
+    
+    
 ****************************************************************************/
-#include <qmainwindow.h>
-#include <qmessagebox.h>
-#include <qcolordialog.h>
-#include <qtooltip.h>
-#include <qpainter.h>
+
+#include <QMainWindow>	//ooo
+#include <QMessageBox>
+#include <QColorDialog>
+#include <QToolTip>
+#include <QPainter>
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QFrame>
+#include <QPaintEvent>
 
 #include "global.h"
 #include "colortoolbar.h"
 #include "dvdmenu.h"
 
-QColorFrame::QColorFrame ( int iWhichColor, Rgba theColor, QWidget *pParent, const char *pName, WFlags f )
-  : QFrame ( pParent, pName, f )
+QColorFrame::QColorFrame ( int iWhichColor, Rgba theColor, QWidget *pParent, const char *pName, Qt::WindowFlags f )	//ooo
+  //: QFrame ( pParent, pName, f )	//ooo
+  : QFrame ( pParent, f )
 {
   m_color       = theColor;
   m_iWhichColor = iWhichColor;
-  setPaletteBackgroundColor ( theColor.color ( ) );
+  //setPaletteBackgroundColor ( theColor.color ( ) );			//ooo
+  QPalette palette;							//xxx
+  palette.setBrush(backgroundRole(), theColor.color ( ));		//xxx
+  setAutoFillBackground ( true );    //xxx
+  setPalette(palette);						//xxx
+
   setFixedSize  ( QSize( 45, 45 ) );
-  setFrameShape ( QFrame::GroupBoxPanel );
+  setFrameShape ( QFrame::StyledPanel );
   setFrameShadow( QFrame::Raised );
   //  setText       ( "1.33" );
   setLineWidth  ( 3 );
@@ -49,6 +63,7 @@ void QColorFrame::paintEvent ( QPaintEvent *pPaint )
     thePainter.setPen   ( QPen ( QColor (  0, 0, 0 ), 2 ) );
     thePainter.drawLine ( 6, 6, width ( )-6, height ( )-6 );
     thePainter.drawLine ( 6, height ( )-6, width ( )-6, 6 );
+    //thePainter.end ( ); //xxx
   }
 }
 
@@ -65,19 +80,24 @@ Rgba QColorFrame::getColor()
 }
 
 void QColorFrame::setColor ( Rgba newColor )
-{
+{ 
   m_color = newColor;
-  setPaletteBackgroundColor( newColor.color ( ) );
+  //setPaletteBackgroundColor( newColor.color ( ) );			//ooo
+  QPalette palette;							//xxx
+  palette.setBrush(backgroundRole(), newColor.color ( ));		//xxx
+  setAutoFillBackground(true);    //xxx
+  setPalette(palette);	//xxx
 }
 
 
 ColorToolBar::ColorToolBar ( const char *pName, QMainWindow *pMainWindow )
-  : QToolBar ( pName, pMainWindow, pMainWindow, false, pName )
+  //: QToolBar ( pName, pMainWindow, pMainWindow, false, pName )	//ooo
+  : QToolBar ( pName, pMainWindow )	//xxx
 {
   m_pCurrentDVDMenu = NULL;
-  setResizeEnabled ( false );
-  setMovingEnabled ( true  );
-  pMainWindow->addDockWindow ( this, Top );
+  //setResizeEnabled ( false );		//ooo
+  //setMovingEnabled ( true  );		//ooo
+  //pMainWindow->addDockWindow ( this, Qt::DockTop );	//ooo
   
   // Next we include the 4 colors (MAX_MASK_COLORS) for the Button masks into the main toolbar.
   m_colorFrames[0] = new QColorFrame ( 0, Rgba ( TRANSPARENT_COLOR       ), this );
@@ -85,11 +105,21 @@ ColorToolBar::ColorToolBar ( const char *pName, QMainWindow *pMainWindow )
   m_colorFrames[2] = new QColorFrame ( 2, Rgba ( START_SELECTED_COLOR    ), this );
   m_colorFrames[3] = new QColorFrame ( 3, Rgba ( START_FRAME_COLOR       ), this );
   
-  QToolTip::add( m_colorFrames[0], "This color is always the transparent color for the DVDMenu\nNote: this is regardless of the alpha channel." );
-  QToolTip::add( m_colorFrames[1], "Change DVD mask colors\nFor button masks." );
-  QToolTip::add( m_colorFrames[2], "Change DVD mask colors\nFor button masks." );
-  QToolTip::add( m_colorFrames[3], "Change DVD mask colors\nFor button masks." );
-  
+  addWidget(m_colorFrames[0]);  //xxx
+  addWidget(m_colorFrames[1]);  //xxx
+  addWidget(m_colorFrames[2]);  //xxx
+  addWidget(m_colorFrames[3]);  //xxx
+
+  //QToolTip::add( m_colorFrames[0], "This color is always the transparent color for the DVDMenu\nNote: this is regardless of the alpha channel." );	//ooo
+  //QToolTip::add( m_colorFrames[1], "Change DVD mask colors\nFor button masks." );	//ooo
+  //QToolTip::add( m_colorFrames[2], "Change DVD mask colors\nFor button masks." );	//ooo
+  //QToolTip::add( m_colorFrames[3], "Change DVD mask colors\nFor button masks." );	//ooo
+ 
+  m_colorFrames[0]->setToolTip("This color is always the transparent color for the DVDMenu\nNote: this is regardless of the alpha channel.");   //xxx
+  m_colorFrames[1]->setToolTip("Change DVD mask colors\nFor button masks.");   //xxx
+  m_colorFrames[2]->setToolTip("Change DVD mask colors\nFor button masks.");   //xxx
+  m_colorFrames[3]->setToolTip("Change DVD mask colors\nFor button masks.");   //xxx
+
   connect ( m_colorFrames[0], SIGNAL ( signalRightButtonClicked (int) ), this, SLOT ( slotColorClicked (int) ) );
   connect ( m_colorFrames[1], SIGNAL ( signalRightButtonClicked (int) ), this, SLOT ( slotColorClicked (int) ) );
   connect ( m_colorFrames[2], SIGNAL ( signalRightButtonClicked (int) ), this, SLOT ( slotColorClicked (int) ) );
@@ -192,3 +222,4 @@ void ColorToolBar::modifyColor(QColor theColor, uint iWhichColor, void *pMenu)
 	emit (signalChangeMaskColor (theColor, iWhichColor));
 }
 */
+ 
