@@ -20,8 +20,13 @@
 #include <qcombobox.h>
 #include <qtabwidget.h>
 #include <qpushbutton.h>
-#include <qprogressbar.h>
+//#include <q3progressbar.h>    //ooo
+#include <QProgressBar> //xxx
 #include <qapplication.h>
+//Added by qt3to4:
+//#include <Q3GridLayout>   //ooo
+// #include <QGridLayout>  //xxx
+#include <QPixmap>
 
 #include "global.h"
 #include "dialogalphatrans.h"
@@ -100,8 +105,10 @@ static const char * xpmCheck[] = {
 
 
 
-DialogAlphaTrans::Item::Item ( QIconView *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )
-  : QIconViewItem ( pIconView )
+//DialogAlphaTrans::Item::Item ( Q3IconView *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )   //ooo
+DialogAlphaTrans::Item::Item ( QListWidget *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )    //xxx
+  //: Q3IconViewItem ( pIconView )  //ooo
+  : QListWidgetItem ( pIconView )   //xxx
 {
   m_bChecked   = bChecked;
   m_pixmap     = thePix;
@@ -123,10 +130,13 @@ void DialogAlphaTrans::Item::setChecked ( bool bChecked )
 void DialogAlphaTrans::Item::toggleCheck ( )
 {
   m_bChecked = ! m_bChecked;
-  QPoint position = pos ( );
+  //QPoint position = pos ( );  //ooo
+  QPoint position = listWidget()->pos ( );  //xxx
   refreshIcon   ( );
-  move ( position );
-  iconView ( )->updateContents ( );
+  //move ( position );  //ooo
+  listWidget()->move ( position );    //xxx
+  //iconView ( )->updateContents ( );   //ooo
+  //listWidget()->iconView ( )->updateContents ( ); //xxx
 }
 
 bool DialogAlphaTrans::Item::isChecked ( )
@@ -136,10 +146,11 @@ bool DialogAlphaTrans::Item::isChecked ( )
 
 void DialogAlphaTrans::Item::calcRect ( const QString &string )
 {
-  QIconViewItem::calcRect ( string );
+  /*//Q3IconViewItem::calcRect ( string );    //ooo
+  QListWidgetItem::calcRect ( string );     //xxx
   QRect rect  ( 0, 0, 0, 0 );
   setTextRect ( rect );
-  setItemRect ( pixmapRect ( ) );
+  setItemRect ( pixmapRect ( ) );*/ //oooo
 }
 
 void DialogAlphaTrans::Item::refreshIcon ( )
@@ -168,12 +179,15 @@ void DialogAlphaTrans::Item::refreshIcon ( )
   iX = (int)( ( iSize - iWidth  ) / 2.0 ) + 1;
   iY = (int)( ( iSize - iHeight ) / 2.0 ) + 1;
 
-  copyBlt ( &thePix, iX, iY, &m_pixmap );
+  QPainter thePainter    ( &thePix );    //xxx
+  
+  //copyBlt ( &thePix, iX, iY, &m_pixmap ); //ooo
+  thePainter.drawPixmap ( iX, iY, m_pixmap );   //xxx
 
   // Frame the pix
   iWidth  += 2;
   iHeight += 2;
-  QPainter thePainter ( &thePix );
+  //QPainter thePainter ( &thePix );    //ooo
   thePainter.setPen   ( clrBlue );
   thePainter.drawLine (       0,       0, iSize-1,       0 );
   thePainter.drawLine ( iSize-1,       0, iSize-1, iSize-1 );
@@ -182,20 +196,26 @@ void DialogAlphaTrans::Item::refreshIcon ( )
 
   // next we copy the check box
   iX = (int)( ( (float)iWidth - 16.0 ) / 2.0 );
-  copyBlt ( &thePix, iX, iSize + 1, &pixCheck, 0, 0, 16, 16 );
+  //copyBlt ( &thePix, iX, iSize + 1, &pixCheck, 0, 0, 16, 16 );    //ooo
+  thePainter.drawPixmap ( iX, iSize + 1, pixCheck, 0, 0, 16, 16 );   //xxx
 
-  setPixmap ( thePix );
+  //setPixmap ( thePix );   //ooo
+  setIcon ( thePix );       //xxx
 }
 
-DialogAlphaTrans::FilterPart::FilterPart ( QIconView *pView, QString qsPath )
+//DialogAlphaTrans::FilterPart::FilterPart ( Q3IconView *pView, QString qsPath )    //ooo
+DialogAlphaTrans::FilterPart::FilterPart ( QListWidget *pView, QString qsPath ) //xxx
 {
   pIconView    = pView;
   qsFilterPath = qsPath;
 }
 
-DialogAlphaTrans::DialogAlphaTrans ( QStringList &listEnabled, QWidget *pParent, const char *pName, bool bModal, WFlags flags )
-  : uiDialogLibrary ( pParent, pName, bModal, flags )
+//DialogAlphaTrans::DialogAlphaTrans ( QStringList &listEnabled, QWidget *pParent, const char *pName, bool bModal, Qt::WFlags flags )	//ooo
+DialogAlphaTrans::DialogAlphaTrans ( QStringList &listEnabled, QWidget *pParent )							//xxx
+  //: uiDialogLibrary ( pParent, pName, bModal, flags )		//ooo
+  : QDialog ( pParent )						//xxx
 {
+  setupUi(this);	//xxx
   m_listEnabled = listEnabled;
   initMe ( );
 }
@@ -226,21 +246,26 @@ void DialogAlphaTrans::initMe ( )
   m_pComboStretch->hide ( );
   m_pLabelWidth->setText ( tr ( "Size : " ) );
 
-  QWidget *pTab = m_pTabWidget->page ( 0 );
+  //QWidget *pTab = m_pTabWidget->page ( 0 );   //ooo
+  QWidget *pTab = m_pTabWidget->widget ( 0 ); //xxx
   while  ( pTab ) {
     delete pTab;
-    pTab = m_pTabWidget->page ( 0 );
+    //pTab = m_pTabWidget->page ( 0 );  //ooo
+    pTab = m_pTabWidget->widget ( 0 );    //xxx
   }
 
-  theDir.cd ( qsPrefixDir, TRUE );
+  //theDir.cd ( qsPrefixDir, TRUE );	//ooo
+  theDir.cd ( qsPrefixDir );		//xxx
   listDirs = theDir.entryList ( QDir::Dirs, QDir::Name );
   if ( listDirs.count ( ) < 3 ) // 3 = this dir / parent dir / background file
     return;
 
   // The following widgets will create th progress dialog on the fly.
   QDialog       progressDialog  ( NULL );
-  QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog ); //, 1, 1 ); //, 11, 6, "progressWidgetLayout" );
-  QProgressBar *pProgressBar    = new QProgressBar ( &progressDialog );
+  //Q3GridLayout  *pProgressLayout = new Q3GridLayout  ( &progressDialog ); //, 1, 1 ); //, 11, 6, "progressWidgetLayout" );    //ooo
+  QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog ); //, 1, 1 ); //, 11, 6, "progressWidgetLayout" );  //xxx
+  //Q3ProgressBar *pProgressBar    = new Q3ProgressBar ( &progressDialog ); //ooo
+  QProgressBar *pProgressBar    = new QProgressBar ( &progressDialog );   //xxx
   pProgressLayout->addWidget( pProgressBar, 0, 0 );
   progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
   progressDialog.show  ( );
@@ -251,7 +276,8 @@ void DialogAlphaTrans::initMe ( )
     if ( ( qsDirName == ".") || ( qsDirName == "..") )
       continue;
 
-    progressDialog.setCaption ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) );
+    //progressDialog.setCaption ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) ); //ooo
+    progressDialog.setWindowTitle ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) );   //xxx
 
     // Next we need to get the file list of the found directory
     QString qsPath = qsPrefixDir + "/" + qsDirName;
@@ -259,8 +285,10 @@ void DialogAlphaTrans::initMe ( )
     listFiles = theDir.entryList ( QDir::Files, QDir::Name );
     createTab ( qsDirName, qsPath, listFiles );
 
-    pProgressBar->setProgress ( (int)((float)t / listDirs.count ( ) * 100.0) );
-    qApp->processEvents ( 100 ); // do some event processing ...
+    //pProgressBar->setProgress ( (int)((float)t / listDirs.count ( ) * 100.0) );   //ooo
+    pProgressBar->setValue ( (int)((float)t / listDirs.count ( ) * 100.0) );    //xxx
+    //qApp->processEvents ( 100 ); // do some event processing ...				//ooo
+    qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
   }
 
   QSize size ( m_iThumbSize, m_iThumbSize );
@@ -289,15 +317,19 @@ void DialogAlphaTrans::createTab ( QString qsDirName, QString qsPath, QStringLis
   QFileInfo fileInfo;
   QString qsFileName;
   QSize grid ( 80, 80 );
-  QWidget     *pTab      = new QWidget     ( m_pTabWidget, "pTab" );
-  QGridLayout *pLayout   = new QGridLayout ( pTab, 1, 1, 4, 2, "pLayout" );
-  QIconView   *pIconView = new QIconView   ( pTab, "pIconViewLibrary" );
+  //QWidget     *pTab      = new QWidget     ( m_pTabWidget, "pTab" );  //ooo
+  QWidget     *pTab      = new QWidget     ( m_pTabWidget );    //xxx
+  //Q3GridLayout *pLayout   = new Q3GridLayout ( pTab, 1, 1, 4, 2, "pLayout" ); //ooo
+  QGridLayout *pLayout   = new QGridLayout ( pTab );    //xxx
+  //Q3IconView   *pIconView = new Q3IconView   ( pTab, "pIconViewLibrary" );    //ooo
+  QListWidget   *pIconView = new QListWidget   ( pTab );    //xxx
   FilterPart  *pNewPart  = new FilterPart  ( pIconView, qsPath );
   m_listFilter.append ( pNewPart );
 
   pLayout->addWidget        ( pIconView,  0, 0 );
-  pIconView->setAutoArrange ( true  );
-  m_pTabWidget->insertTab   ( pTab,  qsDirName );
+  //pIconView->setAutoArrange ( true  );    //oooo
+  //m_pTabWidget->insertTab   ( pTab,  qsDirName ); //ooo
+  m_pTabWidget->addTab    ( pTab,  qsDirName );  //xxx
 
   for ( t=0; t<(int)listFiles.count ( ); t++ ) {
     qsFileName = qsPath + "/" + listFiles[t];
@@ -308,7 +340,8 @@ void DialogAlphaTrans::createTab ( QString qsDirName, QString qsPath, QStringLis
       continue;
 
     if ( ( theImage.width ( ) > m_iThumbSize ) || ( theImage.height ( ) > m_iThumbSize ) )
-      theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, QImage::ScaleMin );
+      //theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, Qt::KeepAspectRatio );    //ooo
+      theImage = theImage.scaled ( m_iThumbSize, m_iThumbSize, Qt::KeepAspectRatio, Qt::SmoothTransformation );		//xxx
 
     thePix.convertFromImage ( theImage );
 
@@ -319,14 +352,16 @@ void DialogAlphaTrans::createTab ( QString qsDirName, QString qsPath, QStringLis
     new Item ( pIconView, listFiles[t], thePix, bChecked );
   }
 
-  pIconView->setSelectionMode ( QIconView::NoSelection );
-  pIconView->setAutoArrange   (  TRUE );
-  pIconView->setItemsMovable  ( FALSE );
-  pIconView->setResizeMode    ( QIconView::Adjust );
-  pIconView->sort ( );
-  pIconView->arrangeItemsInGrid ( grid, TRUE );
+  //pIconView->setSelectionMode ( Q3IconView::NoSelection );    //ooo
+  pIconView->setViewMode(QListView::IconMode); //xxx
+  //pIconView->setAutoArrange   (  TRUE );
+  //pIconView->setItemsMovable  ( FALSE );
+  //pIconView->setResizeMode    ( Q3IconView::Adjust ); //ooo
+  pIconView->setResizeMode    ( QListView::ResizeMode::Adjust );   //xxx
+  //pIconView->sort ( );
+  //pIconView->arrangeItemsInGrid ( grid, TRUE );   //oooo
 
-  connect ( pIconView, SIGNAL ( mouseButtonClicked ( int, QIconViewItem *, const QPoint & ) ), this, SLOT ( slotClicked ( int, QIconViewItem *, const QPoint & ) ) );
+  connect ( pIconView, SIGNAL ( mouseButtonClicked ( int, Q3IconViewItem *, const QPoint & ) ), this, SLOT ( slotClicked ( int, Q3IconViewItem *, const QPoint & ) ) );
 }
 
 void DialogAlphaTrans::slotAfterInit ( )
@@ -337,10 +372,11 @@ void DialogAlphaTrans::slotAfterInit ( )
     return;
 
   FilterPart *pFilterPart = m_listFilter [ 0 ];
-  pFilterPart->pIconView->sort ( true );
+  //pFilterPart->pIconView->sort ( true );  //oooo
 }
 
-void DialogAlphaTrans::slotClicked ( int iButton, QIconViewItem *pItm, const QPoint & )
+//void DialogAlphaTrans::slotClicked ( int iButton, Q3IconViewItem *pItm, const QPoint & )  //ooo
+void DialogAlphaTrans::slotClicked ( int iButton, QListWidgetItem *pItm, const QPoint & )   //xxx
 {
   if ( ! pItm )
     return;
@@ -359,9 +395,11 @@ void DialogAlphaTrans::slotRefresh ( )
   QFileInfo    fileInfo;
   QString      qsFileName;
   QStringList  listFiles;
-  QIconView   *pCurrentView = NULL;
+  //Q3IconView   *pCurrentView = NULL;  //ooo
+  QListWidget   *pCurrentView = NULL;    //xxx
   FilterPart  *pFilterPart = NULL;
-  int          iCurrentTab = m_pTabWidget->currentPageIndex ( );
+  //int          iCurrentTab = m_pTabWidget->currentPageIndex ( );  //ooo
+  int          iCurrentTab = m_pTabWidget->currentIndex ( );    //xxx
   QSize        grid ( 10, 10 );
   if ( iCurrentTab <(int)m_listFilter.count ( ) )
     pFilterPart = m_listFilter [ iCurrentTab ];
@@ -387,9 +425,10 @@ void DialogAlphaTrans::slotRefresh ( )
     if ( theImage.isNull ( ) )
       continue;
 
-    if ( ( theImage.width ( ) > m_iThumbSize ) || ( theImage.height ( ) > m_iThumbSize ) )
-      theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, QImage::ScaleFree );
-
+    if ( ( theImage.width ( ) > m_iThumbSize ) || ( theImage.height ( ) > m_iThumbSize ) ) {
+      //theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, QImage::ScaleFree );				//ooo
+      theImage = theImage.scaled ( m_iThumbSize, m_iThumbSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    }
     thePix.convertFromImage ( theImage );
 
     fileInfo.setFile  ( listFiles[t] );
@@ -399,7 +438,8 @@ void DialogAlphaTrans::slotRefresh ( )
     new Item ( pCurrentView, listFiles[t], thePix, bChecked );
   }
 
-  pCurrentView->arrangeItemsInGrid ( grid, TRUE );
+  //pCurrentView->arrangeItemsInGrid ( grid, TRUE );    //ooo
+  pCurrentView->sortItems ( Qt::AscendingOrder );      //xxx
 }
 
 bool DialogAlphaTrans::isChecked ( QString &qsString )
@@ -418,7 +458,8 @@ void DialogAlphaTrans::accept ( )
   // do si do
   FilterPart *pPart     = NULL;
   Item       *pItem     = NULL;
-  QIconView  *pIconView = NULL;
+  //Q3IconView  *pIconView = NULL;  //ooo
+  QListWidget  *pIconView = NULL;    //xxx
   QString     qsName ( "Cross Fade" );
   QFileInfo   fileInfo;
   if ( isChecked ( qsName ) ) {
@@ -431,18 +472,21 @@ void DialogAlphaTrans::accept ( )
   for ( uint t=0; t<m_listFilter.count ( ) ; t++ )  {
     pPart = m_listFilter[t];
     pIconView = pPart->pIconView;
-    pItem = (Item *)pIconView->firstItem ( );
+    //pItem = (Item *)pIconView->firstItem ( ); //ooo
+    pItem = (Item *)pIconView->item ( 0 );    //xxx
     while ( pItem )  {
       if  ( pItem->isChecked ( ) )  {
         fileInfo.setFile ( pItem->fileName ( ) );
         qsName = fileInfo.baseName  ( );
         m_listEnabled.append ( qsName );
       }
-      pItem = (Item *)pItem->nextItem ( );
+      //pItem = (Item *)pItem->nextItem ( );    //ooo
+      pItem = (Item *)pIconView->item ( pIconView->row ( pItem ) + 1 ); //xxx
     }
   }
 
   // Skip the DialogFilter accept
-  uiDialogLibrary::accept ( );
+  //uiDialogLibrary::accept ( );	//ooo
+  QDialog::accept ( );			//xxx
 }
 
