@@ -1,23 +1,25 @@
-/****************************************************************************
-** dialogaudio.cpp
-**
-** This file handles the audio setting for multiple audio tracks for a 
-** SourceFileInfo, or DVDMenu.
-**
-**   Created : 
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-*****************************************************************************/
+/***************************************************************************
+    dialogaudio.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This file handles the audio setting for multiple audio tracks for a 
+   SourceFileInfo, or DVDMenu.
+    
+****************************************************************************/
 
 #include <qlabel.h>
 #include <qtimer.h>
 #include <qlayout.h>
 #include <qspinbox.h>
 #include <qfileinfo.h>
-#include <qgroupbox.h>
-#include <qlistview.h>
+//#include <q3groupbox.h>   //ooo
+//#include <q3listview.h>   //ooo
+#include <QListView>    //xxx
 #include <qcombobox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
@@ -26,12 +28,17 @@
 #include "dvdmenu.h"
 #include "messagebox.h"
 #include "dialogaudio.h"
-#include "uidialogsubtitle.h"
+//#include "uidialogsubtitle.h"		//ooo
+#include "dialogsubtitle.h"		//xxx
 #include "sourcefileentry.h"
 
-DialogAudio::DialogAudio ( QWidget* parent, const char* name, bool modal, WFlags fl )
-  : uiDialogAudio ( parent, name, modal, fl )
+//DialogAudio::DialogAudio ( QWidget* parent, const char* name, bool modal, Qt::WFlags fl )	//ooo
+DialogAudio::DialogAudio ( QWidget* pParent )							//xxx
+  //: uiDialogAudio ( parent, name, modal, fl )		//ooo
+  : QDialog ( pParent )					//xxx
 {
+  setupUi(this);	//xxx
+  
   m_pSourceFileEntry     = NULL;
   m_pOrigSourceFileEntry = NULL;
   m_pSourceFileInfo      = NULL;
@@ -45,7 +52,8 @@ DialogAudio::DialogAudio ( QWidget* parent, const char* name, bool modal, WFlags
   connect( m_pButtonEdit,   SIGNAL( clicked (      ) ), this, SLOT( slotEdit        (      ) ) );
   connect( m_pButtonDelete, SIGNAL( clicked (      ) ), this, SLOT( slotDelete      (      ) ) );
   connect( m_pCheckEnable,  SIGNAL( toggled ( bool ) ), this, SLOT( slotTranscoding ( bool ) ) );
-  connect( m_pListViewAudio,SIGNAL( currentChanged ( QListViewItem * ) ), this,  SLOT ( slotCurrentChanged ( QListViewItem * ) ) );
+  //connect( m_pListViewAudio,SIGNAL( currentChanged ( Q3ListViewItem * ) ), this,  SLOT ( slotCurrentChanged ( Q3ListViewItem * ) ) ); //ooo
+  connect( m_pListViewAudio,SIGNAL( currentChanged ( QTreeWidgetItem *, int ) ), this,  SLOT ( slotCurrentChanged ( QTreeWidgetItem *, int ) ) ); //xxx
 }
 
 /*
@@ -117,12 +125,18 @@ void DialogAudio::initMe ( SourceFileInfo *pInfo, SourceFileEntry *pEntry, QStri
       continue;
     bStartLanguageDialog = false;
     qsLang = theUtils.iso639 ( pAudio->qsIso639, false );
-    new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, qsLang );
+    //new Q3ListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, qsLang ); //ooo
+    QTreeWidgetItem *pItem;   //xxx
+    pItem = new QTreeWidgetItem ( m_pListViewAudio );    //xxx
+    pItem->setText ( 0, QString ( "%1" ).arg ( pAudio->iAudioNumber ));   //xxx
+    pItem->setText ( 1, pAudio->qsIso639);   //xxx
+    pItem->setText ( 2, qsLang);   //xxx
   }
   if ( bStartLanguageDialog )
     slotAdd ( );
   else { 
-    QListViewItem *pFirst = m_pListViewAudio->firstChild ( );
+    //Q3ListViewItem *pFirst = m_pListViewAudio->firstChild ( );    //ooo
+    QTreeWidgetItem *pFirst = m_pListViewAudio->topLevelItem ( 0 );     //xxx
     //    if ( pFirst )
     //         pFirst->setSelected    ( true );
     qsLang = pFirst->text       ( 2 );
@@ -164,12 +178,18 @@ void DialogAudio::initMe ( SourceFileEntry *pEntry )
       continue;
     bStartLanguageDialog = false;
     qsLang = theUtils.iso639 ( pAudio->qsIso639, false );
-    new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, qsLang );
+    //new Q3ListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, qsLang ); //ooo
+    QTreeWidgetItem *pItem;   //xxx
+    pItem = new QTreeWidgetItem ( m_pListViewAudio );    //xxx
+    pItem->setText ( 0, QString ( "%1" ).arg ( pAudio->iAudioNumber ));   //xxx
+    pItem->setText ( 1, pAudio->qsIso639);   //xxx
+    pItem->setText ( 2, qsLang);   //xxx
   }
   if ( bStartLanguageDialog )
     slotAdd ( );
   else { 
-    QListViewItem *pFirst = m_pListViewAudio->firstChild ( );
+    //Q3ListViewItem *pFirst = m_pListViewAudio->firstChild ( );    //ooo
+    QTreeWidgetItem *pFirst = m_pListViewAudio->topLevelItem ( 0 );      //xxx
     //    qsLang = pFirst->text       ( 2 );
     //    m_pLabelLanguage->setText   ( tr ( "<p align=\"right\"><b>Assign %1 to : </b></p>" ).arg ( qsLang ) );
     m_pButtonEdit->setEnabled   ( true );
@@ -194,10 +214,16 @@ void DialogAudio::initMe ( DVDMenu *pDVDMenu )
     if ( ! pAudio )
       continue;
     fileInfo.setFile ( pAudio->qsFileName );
-    m_pComboAudioEntry->insertItem ( fileInfo.fileName ( ) );
+    //m_pComboAudioEntry->insertItem ( fileInfo.fileName ( ) ); //ooo
+    m_pComboAudioEntry->addItem ( fileInfo.fileName ( ) );  //xxx
 
     qsLang = theUtils.iso639 ( pAudio->qsIso639, false );
-    new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( t ), pAudio->qsIso639, qsLang );
+    //new Q3ListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( t ), pAudio->qsIso639, qsLang );    //ooo
+    QTreeWidgetItem *pItem;   //xxx
+    pItem = new QTreeWidgetItem ( m_pListViewAudio );    //xxx
+    pItem->setText ( 0, QString ( "%1" ).arg ( t ));   //xxx
+    pItem->setText ( 1, pAudio->qsIso639);   //xxx
+    pItem->setText ( 2, qsLang);   //xxx
   }
   slotAudioEntryChanged ( 0 );
 
@@ -224,7 +250,8 @@ void DialogAudio::initAudioSource ( SourceFileEntry *pEntry )
   for ( t=0; t<(int)pEntry->listFileInfos.count ( ); t++ ) {
     pInfo = pEntry->listFileInfos[t];
     fileInfo.setFile ( pInfo->qsFileName );
-    m_pComboAudioEntry->insertItem ( fileInfo.fileName ( ) );
+    //m_pComboAudioEntry->insertItem ( fileInfo.fileName ( ) ); //ooo
+    m_pComboAudioEntry->addItem ( fileInfo.fileName ( ) );  //xxx
   }
   // Finally we set the current file ...
   slotAudioEntryChanged ( 0 );
@@ -316,7 +343,8 @@ int DialogAudio::getSelectedNumber ( )
 {
   int  iSelectedAudioTrack = -1;
   bool bOkay;
-  QListViewItem *pItem = m_pListViewAudio->currentItem ( );
+  //Q3ListViewItem *pItem = m_pListViewAudio->currentItem ( );  //ooo
+  QTreeWidgetItem *pItem = m_pListViewAudio->currentItem ( );   //xxx
   if ( ! pItem )
     return -1;
 
@@ -353,10 +381,12 @@ QString DialogAudio::showLanguageDialog ( )
 {
   // This will add a new audio track to the PGC (Title)
   // For simplicity we abuse the SubtitleDialog.
-  uiDialogSubtitle theDialog;
+  //uiDialogSubtitle theDialog;		//ooo
+  DialogSubtitle theDialog;		//xxx
   theDialog.m_pTextNumber->hide ( );
   theDialog.m_pSpinboxNumber->hide ( );
-  theDialog.setCaption ( "Select language" );
+  //theDialog.setCaption ( "Select language" ); //ooo
+  theDialog.setWindowTitle ( "Select language" );   //xxx
   int     t;
   Utils   theUtils;
   QString qsLang, qsCode, qsEmpty;
@@ -372,7 +402,8 @@ QString DialogAudio::showLanguageDialog ( )
   theDialog.m_pComboLanguage->clear ( );
   while ( ! qsLang.isEmpty ( ) ) {
     qsLang = theUtils.iso639 ( qsCode,  false,  t++ );
-    theDialog.m_pComboLanguage->insertItem ( qsLang );
+    //theDialog.m_pComboLanguage->insertItem ( qsLang );    //ooo
+    theDialog.m_pComboLanguage->addItem ( qsLang ); //xxx
   }
 
   if ( theDialog.exec ( ) == QDialog::Rejected )
@@ -383,7 +414,8 @@ QString DialogAudio::showLanguageDialog ( )
   return qsLang;
 }
 
-void DialogAudio::slotCurrentChanged ( QListViewItem *pItem )
+//void DialogAudio::slotCurrentChanged ( Q3ListViewItem *pItem )    //ooo
+void DialogAudio::slotCurrentChanged ( QTreeWidgetItem *pItem, int ) //xxx
 {
   if ( pItem ) {
     QString qsLang = pItem->text ( 2 );
@@ -396,7 +428,8 @@ void DialogAudio::slotAdd ( )
   int     t;
   Utils   theUtils;
   QString qsLang, qsCode;
-  QListViewItem *pItem;
+  //Q3ListViewItem *pItem;  //ooo
+  QTreeWidgetItem *pItem;   //xxx
 
   qsLang = showLanguageDialog ( );
   if ( qsLang.isEmpty ( ) )
@@ -414,7 +447,11 @@ void DialogAudio::slotAdd ( )
   }
   m_pSourceFileEntry->arrayAudioEntries [ t ].iAudioNumber = t;
   m_pSourceFileEntry->arrayAudioEntries [ t ].qsIso639     = qsCode;
-  pItem = new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( t ), qsCode, qsLang );
+  //pItem = new Q3ListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( t ), qsCode, qsLang );    //ooo
+  pItem = new QTreeWidgetItem ( m_pListViewAudio );    //xxx
+  pItem->setText ( 0, QString ( "%1" ).arg ( t ));   //xxx
+  pItem->setText ( 1, qsCode);   //xxx
+  pItem->setText ( 2, qsLang);   //xxx
   //  pItem->setSelected ( true );
   m_pLabelLanguage->setText ( tr ( "<p align=\"right\"><b>Assign %1 to : </b></p>" ).arg ( qsLang ) );
 
@@ -439,7 +476,8 @@ void DialogAudio::slotSetSelectedItem ( )
 
 void DialogAudio::slotEdit ( )
 {
-  QListViewItem *pItem = m_pListViewAudio->currentItem ( );
+  //Q3ListViewItem *pItem = m_pListViewAudio->currentItem ( );  //ooo
+  QTreeWidgetItem *pItem = m_pListViewAudio->currentItem ( );   //xxx
   if ( ! pItem )
     return;
   QString qsLang, qsCode;
@@ -473,7 +511,8 @@ void DialogAudio::slotEdit ( )
 void DialogAudio::slotDelete ( )
 {
   // This will delete the currently selected audio track from the PGC (Title)
-  QListViewItem *pItem = m_pListViewAudio->currentItem ( );
+  //Q3ListViewItem *pItem = m_pListViewAudio->currentItem ( );  //ooo
+  QTreeWidgetItem *pItem = m_pListViewAudio->currentItem ( );   //xxx
   if ( ! pItem )
     return;
 
@@ -492,11 +531,13 @@ void DialogAudio::slotDelete ( )
   m_pSourceFileEntry->arrayAudioEntries [ iAudioNumber ].iAudioNumber = -1;
 
   delete pItem;
-  pItem = m_pListViewAudio->firstChild ( );
+  //pItem = m_pListViewAudio->firstChild ( );   //ooo
+  pItem = m_pListViewAudio->topLevelItem ( 0 ); //xxx
   //  if ( pItem )
   //    pItem->setSelected ( true );
   //  else if ( m_pListViewAudio->childCount ( ) < 1 ){
-  if ( ( !pItem ) || ( m_pListViewAudio->childCount ( ) < 1 ) ) {
+  //if ( ( !pItem ) || ( m_pListViewAudio->childCount ( ) < 1 ) ) { //ooo
+  if ( ( !pItem ) || ( m_pListViewAudio->topLevelItemCount ( ) < 1 ) ) {    //xxx
     buttonOk->setEnabled ( false );
     m_pButtonEdit->setEnabled   ( false );
     m_pButtonDelete->setEnabled ( false );
@@ -606,7 +647,8 @@ void DialogAudio::accept ( )
   // which is the original Entry.
   // and to m_pOrigSourceFileInfo, which is the copy from DialogMovie.
   int t, i, iAudioNumber;
-  QListViewItem *pItem;
+  //Q3ListViewItem *pItem;  //ooo
+  QTreeWidgetItem *pItem;   //xxx
   Audio *pAudio;
   SourceFileInfo *pInfo1, *pInfo2;
 
