@@ -1,20 +1,26 @@
-/****************************************************************************
-** DialogAudio
-**
-**   Created : Tue Dec 5 12:09:08 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class encapsulates the Dialog to assign audio to a language and / or
-** mark the audio stream or transcoding.
-**
+/***************************************************************************
+    dialogaudio.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   DialogAudio 
+    
+   This class encapsulates the Dialog to assign audio to a language and / or
+   mark the audio stream or transcoding.
+    
 ****************************************************************************/
 
 #ifndef DIALOGAUDIO_H
 #define DIALOGAUDIO_H
 
-#include "uidialogaudio.h"
+#include <QTreeWidgetItem>   //xxx
+
+//#include "uidialogaudio.h"		//ooo
+#include "ui_uidialogaudio.h"		//xxx
 
 class TranscodeInterface;
 class SourceFileEntry;
@@ -23,12 +29,14 @@ class AudioEntry;
 class DVDMenu;
 class Audio;
 
-class DialogAudio : public uiDialogAudio
+//class DialogAudio : public uiDialogAudio			//ooo
+class DialogAudio : public QDialog, public Ui::uiDialogAudio	//xxx
 {
     Q_OBJECT
 
 public:
-     DialogAudio ( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+     //DialogAudio ( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, Qt::WFlags fl = 0 );	//ooo
+     DialogAudio ( QWidget* pParent = 0 );									//xxx
     ~DialogAudio ( );
 
     void initMe ( SourceFileInfo  *, SourceFileEntry *, QString & );
@@ -48,7 +56,8 @@ protected slots:
     virtual void slotSetSelectedItem   ( );
     virtual void slotAudioEntryChanged ( int );
     virtual void slotTranscoding       ( bool );
-    virtual void slotCurrentChanged    ( QListViewItem * );
+    //virtual void slotCurrentChanged    ( Q3ListViewItem * );  //ooo
+    virtual void slotCurrentChanged    ( QTreeWidgetItem *, int );   //xxx
 
 private:
     void initAudioInfo    ( Audio * );
@@ -65,7 +74,8 @@ private:
     SourceFileEntry  *m_pOrigSourceFileEntry;
     SourceFileInfo   *m_pSourceFileInfo;
     SourceFileInfo   *m_pOrigSourceFileInfo;
-    QListViewItem    *m_pSelectItem;
+    //Q3ListViewItem    *m_pSelectItem; //ooo
+    QTreeWidgetItem    *m_pSelectItem;  //xxx
     DVDMenu          *m_pDVDMenu;
 };
 
