@@ -20,16 +20,26 @@
 #include <qfileinfo.h>
 #include <qlineedit.h>
 #include <qtabwidget.h>
-#include <qmessagebox.h>
+//#include <qmessagebox.h>  //ooo
+#include <QMessageBox>      //xxx
 #include <qpushbutton.h>
-#include <qprogressbar.h>
+//#include <q3progressbar.h>    //ooo
+#include <QProgressBar>         //xxx
 #include <qapplication.h>
+#include <QListWidget>      //xxx
+#include <QListWidgetItem>  //xxx
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QGridLayout>
+#include <QPixmap>
 
 #include "global.h"
 #include "qdvdauthor.h"
 #include "buttonobject.h"
 #include "filepreviewdialog.h"
+#include "preview_file_dialog.h"    //xxx
 #include "dialogbuttontrans.h"
+#include "messagebox.h" //xxx
 
 static const char * xpmNoCheck[] = {
 "16 16 17 1",
@@ -103,8 +113,10 @@ static const char * xpmCheck[] = {
 "     )          ",
 "                "};
 
-DialogButtonTrans::Item::Item ( QIconView *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )
-  : QIconViewItem ( pIconView )
+//DialogButtonTrans::Item::Item ( Q3IconView *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )  //ooo
+DialogButtonTrans::Item::Item ( QListWidget *pIconView, const QString &qsText, const QPixmap &thePix, bool bChecked )   //xxx
+  //: Q3IconViewItem ( pIconView )  //ooo
+  : QListWidgetItem ( pIconView )   //xxx
 {
   m_bChecked   = bChecked;
   m_pixmap     = thePix;
@@ -123,10 +135,11 @@ void DialogButtonTrans::Item::setChecked ( bool bChecked )
     return;
 
   m_bChecked = bChecked;
-  QPoint position = pos ( );
+  //QPoint position = pos ( );  //ooo
+  QPoint position = listWidget()->pos ( );  //xxx
   refreshIcon   ( );
-  move ( position );
-  iconView ( )->updateContents ( );
+  //move ( position );  //oooo
+  //iconView ( )->updateContents ( );   //oooo
 }
 
 bool DialogButtonTrans::Item::toggle ( )
@@ -142,10 +155,10 @@ bool DialogButtonTrans::Item::isChecked ( )
 
 void DialogButtonTrans::Item::calcRect ( const QString &string )
 {
-  QIconViewItem::calcRect ( string );
+  /*Q3IconViewItem::calcRect ( string );
   QRect rect  ( 0, 0, 0, 0 );
   setTextRect ( rect );
-  setItemRect ( pixmapRect ( ) );
+  setItemRect ( pixmapRect ( ) );*/ //oooo
 }
 
 void DialogButtonTrans::Item::refreshIcon ( )
@@ -170,16 +183,19 @@ void DialogButtonTrans::Item::refreshIcon ( )
        iSize = 16;
   thePix = QPixmap ( iSize + 2, iSize + 2 + 16);
   thePix.fill ( 0xFFFFFF );
-
+  
   iX = (int)( ( iSize - iWidth  ) / 2.0 ) + 1;
   iY = (int)( ( iSize - iHeight ) / 2.0 ) + 1;
+  
+  QPainter thePainter    ( &thePix );    //xxx
 
-  copyBlt ( &thePix, iX, iY, &m_pixmap );
+  //copyBlt ( &thePix, iX, iY, &m_pixmap ); //ooo
+  thePainter.drawPixmap ( iX, iY, m_pixmap );   //xxx
 
   // Frame the pix
   iWidth  += 2;
   iHeight += 2;
-  QPainter thePainter ( &thePix );
+  //QPainter thePainter ( &thePix );    //ooo
   thePainter.setPen   ( clrBlue );
   thePainter.drawLine (       0,       0, iSize-1,       0 );
   thePainter.drawLine ( iSize-1,       0, iSize-1, iSize-1 );
@@ -188,14 +204,18 @@ void DialogButtonTrans::Item::refreshIcon ( )
 
   // next we copy the check box
   iX = (int)( ( (float)iWidth - 16.0 ) / 2.0 );
-  copyBlt ( &thePix, iX, iSize + 1, &pixCheck, 0, 0, 16, 16 );
+  //copyBlt ( &thePix, iX, iSize + 1, &pixCheck, 0, 0, 16, 16 );    //ooo
+  thePainter.drawPixmap ( iX, iSize + 1, pixCheck, 0, 0, 16, 16 );   //xxx
 
-  setPixmap ( thePix );
+  //setPixmap ( thePix );   //ooo
+  setIcon ( thePix );       //xxx
 }
 
 DialogButtonTrans::DialogButtonTrans ( ButtonTransition *pTransition, QWidget *pParent )
-  : uiDialogButtonTrans ( pParent )
+  //: uiDialogButtonTrans ( pParent )	//ooo
+  : QDialog ( pParent )			//xxx
 {
+  setupUi(this);			//xxx
   m_pTransition = new ButtonTransition;
   if ( pTransition )
     *m_pTransition = *pTransition;
@@ -204,8 +224,10 @@ DialogButtonTrans::DialogButtonTrans ( ButtonTransition *pTransition, QWidget *p
 }
 
 DialogButtonTrans::DialogButtonTrans ( ButtonTransition *pTransition, QStringList &list, QWidget *pParent )
-  : uiDialogButtonTrans ( pParent )
+  //: uiDialogButtonTrans ( pParent )	//ooo
+  : QDialog ( pParent )			//xxx
 {
+  setupUi(this);			//xxx
   m_pTransition = new ButtonTransition;
   if ( pTransition )
     *m_pTransition = *pTransition;
@@ -230,7 +252,7 @@ DialogButtonTrans::~DialogButtonTrans ( )
 }
 
 void DialogButtonTrans::initMe ( bool bMultiMode )
-{
+{    
   m_pTimer      =  NULL;
   m_iThumbSize  =    80;
   m_iCurrentPix =     0;
@@ -239,10 +261,12 @@ void DialogButtonTrans::initMe ( bool bMultiMode )
 
   if ( bMultiMode )  {
     m_pButtonNoTransition->setText ( tr ( "&No Transitions" ) ); // plural in case wecome from the DVDMenu
-    QWidget *pTab = m_pTabWidget->page ( 0 );
+    //QWidget *pTab = m_pTabWidget->page ( 0 ); //ooo
+    QWidget *pTab = m_pTabWidget->widget ( 0 ); //xxx
     while  ( pTab ) {
       delete pTab;
-      pTab = m_pTabWidget->page ( 0 );
+      //pTab = m_pTabWidget->page ( 0 );    //ooo
+      pTab = m_pTabWidget->widget ( 0 );    //xxx
     }
 
     connect ( m_pButtonSelectAll, SIGNAL ( clicked ( ) ), this, SLOT ( slotSelectAll ( ) ) );
@@ -257,6 +281,10 @@ void DialogButtonTrans::initMe ( bool bMultiMode )
     connect ( m_pButtonBrowse,     SIGNAL ( clicked ( ) ), this, SLOT ( slotBrowse      ( ) ) );
     connect ( m_pCheckUserDefined, SIGNAL ( clicked ( ) ), this, SLOT ( slotUserDefined ( ) ) );
   }
+  
+  connect ( m_pButtonHelp,         SIGNAL ( clicked ( ) ), this, SLOT ( slotHelp         ( ) ) );   //xxx
+  connect ( buttonOk,              SIGNAL ( clicked ( ) ), this, SLOT ( accept           ( ) ) );   //xxx
+  connect ( buttonCancel,          SIGNAL ( clicked ( ) ), this, SLOT ( reject           ( ) ) );   //xxx
 
   for ( int t=0; t<THUMBNAIL_COUNT; t++ )
     m_arrayPix[t] = new QPixmap;
@@ -276,15 +304,18 @@ void DialogButtonTrans::initMe ( bool bMultiMode )
   if ( !  theDir.exists ( qsPrefixDir ) )
     return;
 
-  theDir.cd ( qsPrefixDir, TRUE );
+  //theDir.cd ( qsPrefixDir, TRUE );	//ooo
+  theDir.cd ( qsPrefixDir );		//xxx
   listDirs = theDir.entryList ( QDir::Dirs, QDir::Name );
   if ( listDirs.count ( ) < 3 ) // 3 = this dir / parent dir / background file
     return;
 
   // The following widgets will create th progress dialog on the fly.
   QDialog       progressDialog  ( NULL );
-  QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );
-  QProgressBar *pProgressBar    = new QProgressBar ( &progressDialog );
+  //Q3GridLayout  *pProgressLayout = new Q3GridLayout  ( &progressDialog ); //ooo
+  QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );     //xxx
+  //Q3ProgressBar *pProgressBar    = new Q3ProgressBar ( &progressDialog ); //ooo
+  QProgressBar *pProgressBar    = new QProgressBar ( &progressDialog );     //xxx
   pProgressLayout->addWidget( pProgressBar, 0, 0 );
   progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
   progressDialog.show  ( );
@@ -295,7 +326,8 @@ void DialogButtonTrans::initMe ( bool bMultiMode )
     if ( ( qsDirName == ".") || ( qsDirName == "..") )
       continue;
 
-    progressDialog.setCaption ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) );
+    //progressDialog.setCaption ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) ); //ooo
+    progressDialog.setWindowTitle ( tr ( "Creating preview for buttons : %1" ).arg ( listDirs[t] ) );   //xxx
 
     // Next we need to get the file list of the found directory
     QString qsPath = qsPrefixDir + "/" + qsDirName;
@@ -303,10 +335,12 @@ void DialogButtonTrans::initMe ( bool bMultiMode )
     listFiles = theDir.entryList ( QDir::Files, QDir::Name );
     createTab ( qsDirName, qsPath, listFiles );
 
-    pProgressBar->setProgress ( (int)((float)t / listDirs.count ( ) * 100.0) );
-    qApp->processEvents ( 100 ); // do some event processing ...
+    //pProgressBar->setProgress ( (int)((float)t / listDirs.count ( ) * 100.0) );   //ooo
+    pProgressBar->setValue ( (int)((float)t / listDirs.count ( ) * 100.0) );    //xxx
+    //qApp->processEvents ( 100 ); // do some event processing ...				//ooo
+    qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
   }
-
+  
   connect ( m_pButtonNoTransition, SIGNAL ( clicked ( ) ), this, SLOT ( slotNoTransition ( ) ) );
   connect ( m_pButtonAnim,         SIGNAL ( clicked ( ) ), this, SLOT ( slotAnim         ( ) ) );
 
@@ -345,16 +379,21 @@ void DialogButtonTrans::createTab ( QString qsDirName, QString qsPath, QStringLi
   QFileInfo fileInfo;
   QString qsFileName, qsFile;
   QSize grid ( 80, 80 );
-  QWidget       *pTab      = new QWidget     ( m_pTabWidget, "pTab" );
-  QGridLayout   *pLayout   = new QGridLayout ( pTab, 1, 1, 4, 2, "pLayout" );
-  QIconView     *pIconView = new QIconView   ( pTab, "pIconViewLibrary" );
-  QIconViewItem *pItem     = NULL;
+  //QWidget       *pTab      = new QWidget     ( m_pTabWidget, "pTab" );    //ooo
+  QWidget       *pTab      = new QWidget     ( m_pTabWidget );  //xxx
+  //Q3GridLayout   *pLayout   = new Q3GridLayout ( pTab, 1, 1, 4, 2, "pLayout" );   //ooo
+  QGridLayout   *pLayout   = new QGridLayout ( pTab );  //xxx
+  //Q3IconView     *pIconView = new Q3IconView   ( pTab, "pIconViewLibrary" );  //ooo
+  QListWidget     *pIconView = new QListWidget   ( pTab );   //xxx
+  //Q3IconViewItem *pItem     = NULL;   //ooo
+  QListWidgetItem *pItem     = NULL;    //xxx
   m_listViews.append ( pIconView );
 
   pLayout->addWidget         ( pIconView,  0, 0 );
-  pIconView->setAutoArrange  ( true  );
-  pIconView->setShowToolTips ( true );
-  m_pTabWidget->insertTab    ( pTab,  qsDirName, 0 );
+  //pIconView->setAutoArrange  ( true  );   //oooo
+  //pIconView->setShowToolTips ( true );    //oooo
+  //m_pTabWidget->insertTab    ( pTab,  qsDirName, 0 ); //ooo
+  m_pTabWidget->addTab    ( pTab,  qsDirName );  //xxx
 
   for ( t=0; t<(int)listFiles.count ( ); t++ ) {
     if ( listFiles[t] == "crossfade.png" )
@@ -367,7 +406,8 @@ void DialogButtonTrans::createTab ( QString qsDirName, QString qsPath, QStringLi
       continue;
 
     if ( ( theImage.width ( ) > m_iThumbSize ) || ( theImage.height ( ) > m_iThumbSize ) )
-      theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, QImage::ScaleMin );
+      //theImage = theImage.smoothScale ( m_iThumbSize, m_iThumbSize, Qt::KeepAspectRatio );				//ooo
+      theImage = theImage.scaled ( m_iThumbSize, m_iThumbSize, Qt::KeepAspectRatio, Qt::SmoothTransformation );		//xxx
 
     thePix.convertFromImage ( theImage );
     fileInfo.setFile ( listFiles[t] );
@@ -375,17 +415,18 @@ void DialogButtonTrans::createTab ( QString qsDirName, QString qsPath, QStringLi
     bChecked = isChecked   ( qsFile );
 
     pItem = new Item ( pIconView, listFiles[t], thePix, bChecked );
-    pItem->setKey ( qsFileName );
+    //pItem->setKey ( qsFileName ); //oooo
+    pItem->setText ( qsFileName );  //xxx
   }
 
-  pIconView->setSelectionMode ( QIconView::NoSelection );
+  /*pIconView->setSelectionMode ( Q3IconView::NoSelection );
   pIconView->setAutoArrange   (  TRUE );
   pIconView->setItemsMovable  ( FALSE );
-  pIconView->setResizeMode    ( QIconView::Adjust );
+  pIconView->setResizeMode    ( Q3IconView::Adjust );
   pIconView->sort ( );
-  pIconView->arrangeItemsInGrid ( grid, TRUE );
+  pIconView->arrangeItemsInGrid ( grid, TRUE );*/   //oooo
 
-  connect ( pIconView, SIGNAL ( mouseButtonClicked ( int, QIconViewItem *, const QPoint & ) ), this, SLOT ( slotClicked ( int, QIconViewItem *, const QPoint & ) ) );
+  connect ( pIconView, SIGNAL ( mouseButtonClicked ( int, Q3IconViewItem *, const QPoint & ) ), this, SLOT ( slotClicked ( int, Q3IconViewItem *, const QPoint & ) ) );
 }
 
 bool DialogButtonTrans::isChecked ( QString &qsString )
@@ -407,29 +448,36 @@ void DialogButtonTrans::slotAfterInit ( )
     return;
 
   const QPoint pos;
-  m_listViews[0]->sort ( true );
+  //m_listViews[0]->sort ( true );  //oooo
 
   int  iTabCounter = 0;
   Item      *pItem = NULL;
-  QIconView *pView = NULL;
-  QValueList<QIconView *>::iterator it = m_listViews.begin ( );
+  //Q3IconView *pView = NULL;   //ooo
+  QListWidget *pView = NULL;    //xxx
+  //QList<Q3IconView *>::iterator it = m_listViews.begin ( );	//oxx
+  QList<QListWidget *>::iterator it = m_listViews.begin ( );	//xxx
   while ( it != m_listViews.end ( ) )  {
     pView = *it++;
 
-    pItem = (Item *)pView->firstItem ( );
+    //pItem = (Item *)pView->firstItem ( ); //ooo
+    pItem = (Item *)pView->item ( 0 );  //xxx
     while ( pItem )  {
-      if  ( pItem->key ( ) == m_pTransition->qsTransitionName )  {
-        m_pTabWidget->setCurrentPage ( iTabCounter );
+      //if  ( pItem->key ( ) == m_pTransition->qsTransitionName )  {    //ooo
+      if  ( pItem->text ( ) == m_pTransition->qsTransitionName )  {     //xxx
+        //m_pTabWidget->setCurrentPage ( iTabCounter ); //ooo
+        m_pTabWidget->setCurrentIndex ( iTabCounter );  //xxx
         slotClicked   ( Qt::LeftButton, pItem, pos );
-        pView->ensureItemVisible ( pItem );
+        //pView->ensureItemVisible ( pItem );   //oooo
         return;
       }
-      pItem = (Item *)pItem->nextItem ( );
+      //pItem = (Item *)pItem->nextItem ( );    //ooo
+      pItem = (Item *)pView->item ( pView->row ( pItem ) + 1 ); //xxx
     }
     iTabCounter ++;
   }
 
-  slotClicked ( Qt::LeftButton, m_listViews[0]->firstItem ( ), pos );
+  //slotClicked ( Qt::LeftButton, m_listViews[0]->firstItem ( ), pos ); //ooo
+  slotClicked ( Qt::LeftButton, m_listViews[0]->item ( 0 ), pos ); //xxx
 }
 
 ButtonTransition *DialogButtonTrans::getTransition ( )
@@ -437,7 +485,8 @@ ButtonTransition *DialogButtonTrans::getTransition ( )
   return m_pTransition;
 }
 
-void DialogButtonTrans::slotClicked ( int iButton, QIconViewItem *pItm, const QPoint & )
+//void DialogButtonTrans::slotClicked ( int iButton, Q3IconViewItem *pItm, const QPoint & ) //ooo
+void DialogButtonTrans::slotClicked ( int iButton, QListWidgetItem *pItm, const QPoint & )  //xxx
 {
   if ( ! pItm )
     return;
@@ -447,16 +496,20 @@ void DialogButtonTrans::slotClicked ( int iButton, QIconViewItem *pItm, const QP
 
   Item *pItem = NULL;
   if ( ! m_bMultiMode )  {
-    QValueList<QIconView *>::iterator it = m_listViews.begin ( );
+    //QList<Q3IconView *>::iterator it = m_listViews.begin ( );		//oxx
+      QList<QListWidget *>::iterator it = m_listViews.begin ( );		//xxx
     while ( it !=m_listViews.end ( ) )  {
-      QIconView *pIconView = *it++; //pItm->iconView ( );
+      //Q3IconView *pIconView = *it++; //pItm->iconView ( );    //ooo
+      QListWidget *pIconView = *it++; //pItm->iconView ( );     //xxx
       if ( ! pIconView )
         continue;
 
-      pItem = (Item *)pIconView->firstItem ( );
+      //pItem = (Item *)pIconView->firstItem ( );   //ooo
+      pItem = (Item *)pIconView->item ( 0 );        //xxx
       while ( pItem )  {
         pItem->setChecked ( pItem == pItm );
-        pItem = (Item *)pItem->nextItem ( );
+        //pItem = (Item *)pItem->nextItem ( );  //ooo
+        pItem = (Item *)pIconView->item ( pIconView->row ( pItem ) + 1 );   //xxx
       }
     }
   }
@@ -466,20 +519,29 @@ void DialogButtonTrans::slotClicked ( int iButton, QIconViewItem *pItm, const QP
   }
 
   pItem = (Item *)pItm;
-  QImage theImage ( pItem->key ( ) );
+  //QImage theImage ( pItem->key ( ) ); //ooo
+  QImage theImage ( pItem->text ( ) );  //xxx
   if ( theImage.isNull ( ) )
     return;
 
-  m_qsTransitionName = pItem->key ( );
+  //m_qsTransitionName = pItem->key ( );    //ooo
+  m_qsTransitionName = pItem->text ( );     //xxx
   // Stop the animation if currently ongoing.
   if ( m_bAnimated )
     slotAnim ( );
 
-  setLabel ( pItem->key ( ) );
-  theImage = theImage.smoothScale ( m_pLabelPreview->size ( ) );
+  //setLabel ( pItem->key ( ) );    //ooo
+  setLabel ( pItem->text ( ) );     //xxx
+  //theImage = theImage.smoothScale ( m_pLabelPreview->size ( ) );						//ooo
+  theImage = theImage.scaled ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
   QPixmap thePix;
   thePix.convertFromImage ( theImage );
-  m_pLabelPreview->setPaletteBackgroundPixmap ( thePix );
+  m_pLabelPreview->setScaledContents         ( true );		//xxx	
+  m_pLabelPreview->setAutoFillBackground     ( true );		//xxx
+  //m_pLabelPreview->setPaletteBackgroundPixmap ( thePix );	//ooo
+  QPalette palette;						//xxx
+  palette.setBrush(QPalette::Window, QBrush(thePix));		//xxx
+  m_pLabelPreview->setPalette(palette);				//xxx
 }
 
 void DialogButtonTrans::slotUserDefined  ( )
@@ -491,30 +553,46 @@ void DialogButtonTrans::slotBrowse ( )
 {
   QString qsVideoFilter = Global::pApp->getMovieFilter ( );
   QString qsFilter      = QString ( "Videos ( " ) + qsVideoFilter + QString (" );;All ( * )" );
-  QString qsVideoName   = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, qsFilter, this, tr ( "Select video" ), tr ( "Select a video." ) );
-  if ( qsVideoName.isNull ( ) )
+  //QString qsVideoName   = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, qsFilter, this, tr ( "Select video" ), tr ( "Select a video." ) );    //ooo
+  
+  QStringList qsVideoName;  //xxx
+  QFileDialog* pDialog = new PreviewFileDialog(this, tr ( "Select video" ), Global::qsCurrentPath, qsFilter); //xxx
+  pDialog->setAcceptMode(QFileDialog::AcceptOpen);  //xxx
+  
+  if ( pDialog->exec ( ) == QDialog::Accepted ) //xxx
+    qsVideoName = pDialog->selectedFiles ( );
+  
+  //if ( qsVideoName.isNull ( ) )   //ooo
+  if (qsVideoName.isEmpty())   //xxx
     return;
 
-  QFileInfo fileInfo  ( qsVideoName );
-  Global::qsCurrentPath = fileInfo.dirPath ( TRUE );
+  //QFileInfo fileInfo  ( qsVideoName );    //ooo
+  QFileInfo fileInfo  ( qsVideoName[0] );          //xxx
+  //Global::qsCurrentPath = fileInfo.dirPath ( TRUE );  //ooo
+  Global::qsCurrentPath = fileInfo.path ( );    //xxx
 
-  m_pEditUserFile->setText ( qsVideoName );
+  //m_pEditUserFile->setText ( qsVideoName );   //ooo
+  m_pEditUserFile->setText ( qsVideoName[0] );  //xxx
 }
 
 void DialogButtonTrans::slotSelectAll ( )
 {
   if ( m_bMultiMode )  {
     Item *pItem = NULL;
-    QValueList<QIconView *>::iterator it = m_listViews.begin ( );
+    //QList<Q3IconView *>::iterator it = m_listViews.begin ( );		//oxx
+    QList<QListWidget *>::iterator it = m_listViews.begin ( );		//xxx
     while ( it !=m_listViews.end ( ) )  {
-      QIconView *pIconView = *it++; //pItm->iconView ( );
+      //Q3IconView *pIconView = *it++; //pItm->iconView ( );    //ooo
+      QListWidget *pIconView = *it++; //pItm->iconView ( );     //xxx
       if ( ! pIconView )
         continue;
 
-      pItem = (Item *)pIconView->firstItem ( );
+      //pItem = (Item *)pIconView->firstItem ( );   //ooo
+      pItem = (Item *)pIconView->item ( 0 );    //xxx
       while ( pItem )  {
         pItem->setChecked ( true );
-        pItem = (Item *)pItem->nextItem ( );
+        //pItem = (Item *)pItem->nextItem ( );  //ooo
+        pItem = (Item *)pIconView->item ( pIconView->row ( pItem ) + 1 );   //xxx
       }
     }
   }
@@ -524,16 +602,20 @@ void DialogButtonTrans::slotClearAll ( )
 {
   if ( m_bMultiMode )  {
     Item *pItem = NULL;
-    QValueList<QIconView *>::iterator it = m_listViews.begin ( );
+    //QList<Q3IconView *>::iterator it = m_listViews.begin ( );		//oxx
+    QList<QListWidget *>::iterator it = m_listViews.begin ( );		//xxx
     while ( it !=m_listViews.end ( ) )  {
-      QIconView *pIconView = *it++; //pItm->iconView ( );
+      //Q3IconView *pIconView = *it++; //pItm->iconView ( );    //ooo
+      QListWidget *pIconView = *it++; //pItm->iconView ( );     //xxx
       if ( ! pIconView )
         continue;
 
-      pItem = (Item *)pIconView->firstItem ( );
+      //pItem = (Item *)pIconView->firstItem ( );   //ooo
+      pItem = (Item *)pIconView->item ( 0 );    //xxx
       while ( pItem )  {
         pItem->setChecked ( false );
-        pItem = (Item *)pItem->nextItem ( );
+        //pItem = (Item *)pItem->nextItem ( );  //ooo
+        pItem = (Item *)pIconView->item ( pIconView->row ( pItem ) + 1 );   //xxx
       }
     }
   }
@@ -577,16 +659,22 @@ void DialogButtonTrans::slotAnimPix ( )
   }
   if ( m_arrayPix[m_iCurrentPix]->isNull ( ) )
     return;
-  m_pLabelPreview->setPaletteBackgroundPixmap ( *m_arrayPix[m_iCurrentPix] );
+  m_pLabelPreview->setScaledContents         ( true );					//xxx	
+  m_pLabelPreview->setAutoFillBackground     ( true );					//xxx
+  //m_pLabelPreview->setPaletteBackgroundPixmap ( *m_arrayPix[m_iCurrentPix] );		//ooo
+  QPalette palette;									//xxx
+  palette.setBrush(QPalette::Window, QBrush(*m_arrayPix[m_iCurrentPix]));		//xxx
+  m_pLabelPreview->setPalette(palette);							//xxx
 }
 
 void DialogButtonTrans::recreatePix ( )
 {
   Utils theUtils;
-  QCursor myCursor     ( QCursor::WaitCursor );
+  QCursor myCursor     ( Qt::WaitCursor );
   QApplication::setOverrideCursor ( myCursor );
 
-  QPixmap *pPixmap = (QPixmap *)m_pLabelPreview->paletteBackgroundPixmap ( );
+  //QPixmap *pPixmap = (QPixmap *)m_pLabelPreview->paletteBackgroundPixmap ( ); //ooo
+  QPixmap *pPixmap = (QPixmap *)m_pLabelPreview->pixmap ( );    //xxx
   if ( ! pPixmap )
     return;
   QPixmap filterPix = *pPixmap;
@@ -599,16 +687,23 @@ void DialogButtonTrans::recreatePix ( )
     for ( t=0; t<THUMBNAIL_COUNT; t++ )
       array[t] = new QPixmap ( m_pLabelPreview->size ( ) );
 
-    QImage filter = filterPix.convertToImage ( ); //( qsFilterName );
-    QImage start  = QImage::fromMimeSource ( "default.jpg" ).copy ( );
-    QImage stop   = QImage::fromMimeSource (  "splash.jpg" ).copy ( );
+    //QImage filter = filterPix.convertToImage ( ); //( qsFilterName ); //ooo
+    QImage filter = filterPix.toImage ( ); //( qsFilterName );  //xxx
+    //QImage start  = QImage::fromMimeSource ( "default.jpg" ).copy ( );	//ooo
+    QImage start  = QImage ( ":/images/default.jpg" ).copy ( );			//xxx
+    //QImage stop   = QImage::fromMimeSource (  "splash.jpg" ).copy ( );	//ooo
+    QImage stop   = QImage (  ":/images/splash.jpg" ).copy ( );			//xxx
     QImage result     ( start ); // init the size
-    QImage background ( m_pLabelPreview->size ( ), 32 );
+    //QImage background ( m_pLabelPreview->size ( ), 32 );  //ooo
+    QImage background ( m_pLabelPreview->size ( ), QImage::Format_RGB32 );  //xxx
     background.fill   ( 0x000000 );
 
-    filter = filter.smoothScale ( m_pLabelPreview->size ( ) );
-    start  = start.smoothScale  ( m_pLabelPreview->size ( ) );
-    stop   = stop.smoothScale   ( m_pLabelPreview->size ( ) );
+    //filter = filter.smoothScale ( m_pLabelPreview->size ( ) );						//ooo
+    filter = filter.scaled ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    //start  = start.smoothScale  ( m_pLabelPreview->size ( ) );						//ooo
+    start  = start.scaled  ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    //stop   = stop.smoothScale   ( m_pLabelPreview->size ( ) );						//ooo
+    stop   = stop.scaled   ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
     fDelta = 512.0f / ( THUMBNAIL_COUNT - iDiff - 1 );
 
     for ( t=0; t<THUMBNAIL_COUNT; t++ )  {
@@ -633,7 +728,7 @@ QStringList &DialogButtonTrans::getEnabledList ( )
 }
 
 void DialogButtonTrans::accept ( )
-{
+{    
   if ( m_bMultiMode )  {
     int   iCount = 0;
     Item *pItem  = NULL;
@@ -641,13 +736,16 @@ void DialogButtonTrans::accept ( )
     QFileInfo fileInfo;
     m_listEnabled.clear ( );
 
-    QValueList<QIconView *>::iterator it = m_listViews.begin ( );
+    //QList<Q3IconView *>::iterator it = m_listViews.begin ( );		//oxx
+    QList<QListWidget *>::iterator it = m_listViews.begin ( );		//xxx
     while ( it !=m_listViews.end ( ) )  {
-      QIconView *pIconView = *it++; //pItm->iconView ( );
+      //Q3IconView *pIconView = *it++; //pItm->iconView ( );    //ooo
+      QListWidget *pIconView = *it++; //pItm->iconView ( );     //xxx
       if ( ! pIconView )
         continue;
 
-      pItem = (Item *)pIconView->firstItem ( );
+      //pItem = (Item *)pIconView->firstItem ( );   //ooo
+      pItem = (Item *)pIconView->item ( 0 );        //xxx
       while ( pItem )  {
         if  ( pItem->isChecked ( ) )  {
           fileInfo.setFile     ( pItem->fileName ( ) );
@@ -655,7 +753,8 @@ void DialogButtonTrans::accept ( )
           m_listEnabled.append ( qsName );
           iCount ++;
         }
-        pItem   = (Item *)pItem->nextItem ( );
+        //pItem   = (Item *)pItem->nextItem ( );    //ooo
+        pItem = (Item *)pIconView->item ( pIconView->row ( pItem ) + 1 );   //xxx
       }
     }
     if ( iCount == 0 )  {
@@ -674,16 +773,24 @@ void DialogButtonTrans::accept ( )
          m_pTransition->qsTransitionVideoFileName = m_pEditUserFile->text ( );
        }
   }
-  uiDialogButtonTrans::accept ( );
+  //uiDialogButtonTrans::accept ( );	//ooo
+  QDialog::accept ( );			//xxx
 }
 
 void DialogButtonTrans::slotNoTransition ( )
-{
+{    
   if ( m_pTransition )
     delete m_pTransition;
   m_pTransition   = NULL;
   m_listEnabled.clear( );
 
-  uiDialogButtonTrans::accept ( );
+  //uiDialogButtonTrans::accept ( );	//ooo
+  QDialog::accept ( );			//xxx
+}
+
+void DialogButtonTrans::slotHelp()  //xxx
+{
+	MessageBox::warning(this, "ButtonDialog", "Cool you got a button !!!\n", 
+		QMessageBox::Ok, QMessageBox::NoButton);
 }
 
