@@ -11,24 +11,32 @@
  **
  *****************************************************************************/
 
-#include <qframe.h>
+//#include <q3frame.h>  //ooo
+#include <QFrame>
 #include <qslider.h>
 #include <qpainter.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+//#include <q3listbox.h>    //ooo
+#include <QListWidget>  //xxx
+//#include <q3textedit.h>   //ooo
+#include <QTextEdit>    //xxx
 #include <qcombobox.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qcolordialog.h>
 #include <qfontdatabase.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 
 #include "dialogfont.h"
 
-DialogFont::DialogFont ( QWidget *p, const char * n, WFlags f )
-  : uiDialogFont ( p, n, f )
+//DialogFont::DialogFont ( QWidget *p, const char * n, Qt::WFlags f )	//ooo
+DialogFont::DialogFont ( QWidget *pParent )				//xxx
+  //: uiDialogFont ( p, n, f )		//ooo
+  : QDialog ( pParent )			//xxx
 {
+  setupUi(this);	//xxx
 }
 
 DialogFont::~DialogFont ( )
@@ -48,12 +56,15 @@ void DialogFont::initMe ( QString qsText )
   QFontDatabase database;
   //  setTransparency (0.0);
   QStringList listFonts = database.families ( );
-  m_pListFonts->insertStringList  ( listFonts );
+  //m_pListFonts->insertStringList  ( listFonts );  //ooo
+  //m_pListFonts->addTopLevelItems  ( listFonts ); //xxx
+  m_pListFonts->insertItems  ( 0, listFonts ); //xxx
   // Next we search for a good starting font ...
   uint t, iIndex;
   QString fontName;
   for (iIndex=0;iIndex<m_pListFonts->count();iIndex++)	{
-    fontName = m_pListFonts->text(iIndex);
+    //fontName = m_pListFonts->text(iIndex);    //ooo
+    fontName = m_pListFonts->item(iIndex)->text();  //xxx
     if (fontName == QString ("Arial"))
       break;
     else if (fontName == QString ("Courier"))
@@ -68,17 +79,22 @@ void DialogFont::initMe ( QString qsText )
       break;
   }
   if ( iIndex < listFonts.count ( ) )
-    fontName = m_pListFonts->text(iIndex);
+    //fontName = m_pListFonts->text(iIndex);    //ooo
+    fontName = m_pListFonts->item(iIndex)->text();      //xxx
   else
-    fontName = m_pListFonts->text( 0 );
+    //fontName = m_pListFonts->text( 0 );   //ooo
+    fontName = m_pListFonts->item( 0 )->text();     //xxx
 
   QStringList listStyles = database.styles    ( fontName );
-  m_pComboFontStyle->insertStringList         ( listStyles );
-  QString styleName = m_pComboFontStyle->text ( 0 );
-  m_pComboFontStyle->setCurrentItem           ( 0 );
+  //m_pComboFontStyle->insertStringList         ( listStyles ); //ooo
+  m_pComboFontStyle->insertItems         ( 0, listStyles );   //xxx
+  //QString styleName = m_pComboFontStyle->text ( 0 );  //ooo
+  QString styleName = m_pComboFontStyle->itemText ( 0 );    //xxx
+  //m_pComboFontStyle->setCurrentItem           ( 0 );  //ooo
+  m_pComboFontStyle->setCurrentIndex           ( 0 );   //xxx
 
   // Here we get the sizes of the font.
-  QValueList<int> listSizes = database.pointSizes(fontName);
+  QList<int> listSizes = database.pointSizes(fontName);		//oxx
   if (listSizes.isEmpty())	{
     listSizes = database.smoothSizes(fontName, styleName);
     if (listSizes.isEmpty())	{
@@ -86,20 +102,25 @@ void DialogFont::initMe ( QString qsText )
     }
   }
   // So lets say we can set the fontFamily at least ...
-  m_pListFonts->setCurrentItem(iIndex);
+  //m_pListFonts->setCurrentItem(iIndex);   //ooo
+  m_pListFonts->setCurrentRow(iIndex);  //xxx
   // And here we take care of the FontSize ...
   iIndex = 0;
   for (t=0;t<listSizes.count();t++)	{
-    m_pComboFontSizes->insertItem (QString ("%1").arg(listSizes[t]));
+    //m_pComboFontSizes->insertItem (QString ("%1").arg(listSizes[t])); //ooo
+    m_pComboFontSizes->insertItem (t, QString ("%1").arg(listSizes[t]));    //xxx
     if (listSizes[t] < 19)	// Lets get at least a nice big raedable size
       iIndex = t;
   }
-  m_pComboFontSizes->setCurrentItem (iIndex);
+  //m_pComboFontSizes->setCurrentItem (iIndex); //ooo
+  m_pComboFontSizes->setCurrentIndex (iIndex);    //xxx
 
   QPainter thePainter ( m_pFrameBackgroundColor );
   thePainter.drawLine ( 0, 0, m_pFrameBackgroundColor->width ( ), m_pFrameFontColor->height ( ) );
   
-  m_pTextEdit->setTextFormat ( PlainText );
+  //m_pTextEdit->setTextFormat ( PlainText );		//ooo
+  //m_pTextEdit->setTextFormat ( Qt::PlainText );		//xxx
+  m_pTextEdit->setAcceptRichText ( false );		//xxx
   m_pTextEdit->setAlignment  ( Qt::AlignHCenter | Qt::AlignVCenter );
   m_pTextEdit->setText       ( qsText );
   
@@ -215,9 +236,12 @@ void DialogFont::updateFont(uint iSwitch)
   int iIndex;
   // First see what styles are avail ...
   QFontDatabase database;
-  QString fontName  = m_pListFonts->text(m_pListFonts->currentItem());
-  QString styleName = m_pComboFontStyle->text(m_pComboFontStyle->currentItem());
-  int iFontSize     = m_pComboFontSizes->text(m_pComboFontSizes->currentItem()).toInt();
+  //QString fontName  = m_pListFonts->text(m_pListFonts->currentItem());    //ooo
+  QString fontName  = m_pListFonts->item(m_pListFonts->currentRow())->text();  //xxx
+  //QString styleName = m_pComboFontStyle->text(m_pComboFontStyle->currentItem());  //ooo
+  QString styleName = m_pComboFontStyle->itemText(m_pComboFontStyle->currentIndex());    //xxx
+  //int iFontSize     = m_pComboFontSizes->text(m_pComboFontSizes->currentItem()).toInt();  //ooo
+  int iFontSize     = m_pComboFontSizes->itemText(m_pComboFontSizes->currentIndex()).toInt();   //xxx
 
   //  QSize size = m_pTextEdit->size ( );
   //  m_pTextEdit->setFixedSize ( size );
@@ -227,17 +251,20 @@ void DialogFont::updateFont(uint iSwitch)
     // The fontName has changed, so we need to get the styles avail for this new font.
     QStringList listStyles = database.styles ( fontName );
     m_pComboFontStyle->clear();
-    m_pComboFontStyle->insertStringList ( listStyles );
+    //m_pComboFontStyle->insertStringList ( listStyles );   //ooo
+    m_pComboFontStyle->insertItems ( 0, listStyles ); //xxx
     iIndex = findString ( listStyles, styleName );
     if (iIndex == -1)
       iIndex = 0;
-    styleName = m_pComboFontStyle->text(iIndex);
-    m_pComboFontStyle->setCurrentItem(iIndex);
+    //styleName = m_pComboFontStyle->text(iIndex);  //ooo
+    styleName = m_pComboFontStyle->itemText(iIndex);    //xxx
+    //m_pComboFontStyle->setCurrentItem(iIndex);    //ooo
+    m_pComboFontStyle->setCurrentIndex(iIndex);  //xxx
   }
   case 1:
     // The style has changed
     m_pComboFontSizes->clear ( );
-    QValueList<int> listSizes = database.pointSizes ( fontName );
+    QList<int> listSizes = database.pointSizes ( fontName );	//oxx
     if ( listSizes.isEmpty ( ) )	{
       listSizes = database.smoothSizes ( fontName, styleName );
       if ( listSizes.isEmpty ( ) )	{
@@ -246,14 +273,17 @@ void DialogFont::updateFont(uint iSwitch)
     }
     iIndex = 0;
     for (t=0;t<listSizes.count();t++)	{
-      m_pComboFontSizes->insertItem ( QString ("%1").arg ( listSizes[t] ) );
+      //m_pComboFontSizes->insertItem ( QString ("%1").arg ( listSizes[t] ) );  //ooo
+      m_pComboFontSizes->insertItem ( t, QString ("%1").arg ( listSizes[t] ) );    //xxx
       if ( listSizes[t] == iFontSize )
 	iIndex = t;
     }
-    m_pComboFontSizes->setCurrentItem ( iIndex );
+    //m_pComboFontSizes->setCurrentItem ( iIndex ); //ooo
+    m_pComboFontSizes->setCurrentIndex ( iIndex );  //xxx
   }
 
-  QString qsText = m_pTextEdit->text ( );
+  //QString qsText = m_pTextEdit->text ( ); //ooo
+  QString qsText = m_pTextEdit->toPlainText ( );   //xxx
   m_pTextEdit->setText ( qsText );
   // and last we update the TextEdit accordingly
   m_pTextEdit->setFont ( getFont ( ) );
@@ -274,9 +304,12 @@ void DialogFont::setTheFont ( QFont &theFont )
   // Here we set the fields ...
   // Underline / strikeout / pointSize / fontFamily / script / fontStyle
   int t, iIndex;
-  for ( iIndex=0; iIndex<(int)m_pListFonts->count ( ); iIndex++ )	{
-    if ( m_pListFonts->text ( iIndex ) == theFont.family ( ) )	{
-      m_pListFonts->setCurrentItem ( iIndex );
+  //for ( iIndex=0; iIndex<(int)m_pListFonts->count ( ); iIndex++ )	{   //ooo
+  for ( iIndex=0; iIndex<m_pListFonts->count ( ); iIndex++ )	{ //xxx
+    //if ( m_pListFonts->text ( iIndex ) == theFont.family ( ) )	{  //ooo
+    if ( m_pListFonts->item ( iIndex )->text() == theFont.family ( ) )	{    //xxx
+      //m_pListFonts->setCurrentItem ( iIndex );    //ooo
+      m_pListFonts->setCurrentRow ( iIndex );     //xxx
       break;
     }
   }
@@ -286,21 +319,25 @@ void DialogFont::setTheFont ( QFont &theFont )
   QFontDatabase database;
   QString qsStyle = database.styleString ( theFont );
   for ( t=0; t<m_pComboFontStyle->count ( ); t++ )	{
-    if ( m_pComboFontStyle->text ( t ) == qsStyle )	{
+    //if ( m_pComboFontStyle->text ( t ) == qsStyle )	{ //ooo
+    if ( m_pComboFontStyle->itemText ( t ) == qsStyle )	{   //xxx
       iIndex = t;
       break;
     }
   }
-  m_pComboFontStyle->setCurrentItem ( iIndex );
+  //m_pComboFontStyle->setCurrentItem ( iIndex );   //ooo
+  m_pComboFontStyle->setCurrentIndex ( iIndex );    //xxx
   updateFont ( 1 );
   // Here we get the font size which comes closest to the newFont pointSize (or the same).
   int iAvailFontSize, iFontSize = theFont.pointSize ( );
   for ( iIndex=0; iIndex<m_pComboFontSizes->count ( );iIndex++ )	{
-    iAvailFontSize = m_pComboFontSizes->text ( iIndex ).toInt ( );
+    //iAvailFontSize = m_pComboFontSizes->text ( iIndex ).toInt ( );    //ooo
+    iAvailFontSize = m_pComboFontSizes->itemText ( iIndex ).toInt ( );  //xxx
     if ( iAvailFontSize >= iFontSize )
       break;
   }
-  m_pComboFontSizes->setCurrentItem(iIndex);
+  //m_pComboFontSizes->setCurrentItem(iIndex);  //ooo
+  m_pComboFontSizes->setCurrentIndex(iIndex);    //xxx
  
   if ( theFont.underline ( ) )
     m_pCheckUnderline->setChecked ( true );
@@ -314,9 +351,12 @@ QFont &DialogFont::getFont ()
 {
   QFontDatabase database;
 
-  QString qsFamily = m_pListFonts->text ( m_pListFonts->currentItem ( ) );
-  QString qsStyle  = m_pComboFontStyle->text(m_pComboFontStyle->currentItem ( ) );
-  int iPointSize   = m_pComboFontSizes->text(m_pComboFontSizes->currentItem ( ) ).toInt ( );
+  //QString qsFamily = m_pListFonts->text ( m_pListFonts->currentItem ( ) );    //ooo
+  QString qsFamily = m_pListFonts->item ( m_pListFonts->currentRow ( ) )->text();  //xxx
+  //QString qsStyle  = m_pComboFontStyle->text(m_pComboFontStyle->currentItem ( ) );    //ooo
+  QString qsStyle  = m_pComboFontStyle->itemText(m_pComboFontStyle->currentIndex ( ) );  //xxx
+  //int iPointSize   = m_pComboFontSizes->text(m_pComboFontSizes->currentItem ( ) ).toInt ( );  //ooo
+  int iPointSize   = m_pComboFontSizes->itemText(m_pComboFontSizes->currentIndex ( ) ).toInt ( );   //xxx
   m_qfFont =  database.font( qsFamily, qsStyle, iPointSize );
   m_qfFont.setUnderline ( m_pCheckUnderline->isChecked ( ) );
   m_qfFont.setStrikeOut ( m_pCheckStrikethrough->isChecked ( ) );
@@ -347,8 +387,12 @@ void DialogFont::setBackgroundColor  ( const QColor &newColor )
   // Check if the user pressed cancel ...
   if (!newColor.isValid())
     return;
-  m_pFrameBackgroundColor->setPaletteBackgroundColor(newColor);
-  m_pTextEdit->setPaletteBackgroundColor   (newColor);
+  //m_pFrameBackgroundColor->setPaletteBackgroundColor(newColor);   //ooo
+  QPalette palette; //xxx
+  palette.setBrush(m_pFrameBackgroundColor->backgroundRole(), newColor);	//xxx
+  m_pFrameBackgroundColor->setPalette(palette); //xxx
+  //m_pTextEdit->setPaletteBackgroundColor   (newColor);    //ooo
+  m_pTextEdit->setTextBackgroundColor   (QColor(newColor));    //xxx
   m_backgroundColor = newColor;
 }
 
@@ -357,15 +401,22 @@ void DialogFont::setForegroundColor ( const QColor &newColor )
   // Check if the user pressed cancel ...
   if (!newColor.isValid())
     return;
-  m_pFrameFontColor->setPaletteBackgroundColor(newColor);
-  m_pTextEdit->setPaletteForegroundColor (newColor);
+  //m_pFrameFontColor->setPaletteBackgroundColor(newColor); //ooo
+  QPalette palette; //xxx
+  palette.setBrush(m_pFrameFontColor->backgroundRole(), newColor);	//xxx
+  m_pFrameFontColor->setPalette(palette); //xxx
+
+  //m_pTextEdit->setPaletteForegroundColor (newColor);  //ooo
+  m_pTextEdit->setTextBackgroundColor   (QColor(newColor));    //xxx
   m_foregroundColor = newColor;
 }
 
 QRgb DialogFont::backgroundColor ( )
 {
   QRgb     rgba = 0x00000000;
-  QColor   clrBackground      = m_pFrameBackgroundColor->paletteBackgroundColor ( );
+  //QColor   clrBackground      = m_pFrameBackgroundColor->paletteBackgroundColor ( );  //ooo
+  QPalette palette; //xxx
+  QColor   clrBackground      = palette.color(m_pFrameBackgroundColor->backgroundRole ( ));  //xxx
   unsigned char iTransparency = m_pSliderBGTransparency->value ( );
   rgba  =  clrBackground.rgb ( ) & 0x00FFFFFF;
   rgba |=  iTransparency  <<  24;
@@ -375,7 +426,9 @@ QRgb DialogFont::backgroundColor ( )
 QRgb DialogFont::foregroundColor ( )
 {
   QRgb     rgba = 0x00000000;
-  QColor   clrBackground      = m_pFrameFontColor->paletteBackgroundColor ( );
+  //QColor   clrBackground      = m_pFrameFontColor->paletteBackgroundColor ( );    //ooo
+  QPalette palette; //xxx
+  QColor   clrBackground      = palette.color(m_pFrameFontColor->foregroundRole ( ));  //xxx
   unsigned char iTransparency = m_pSliderTransparency->value ( );
   rgba  =  clrBackground.rgb ( ) & 0x00FFFFFF;
   rgba |=  iTransparency  <<  24;
