@@ -1,31 +1,40 @@
-/****************************************************************************
-** DialogFrame class
-**
-**   Created : Tue Feb 18 22:48:00 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    dialogframe.cpp
+                             -------------------
+    DialogFrame class                             
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
-#include <qradiobutton.h>
-#include <qcolordialog.h>
-#include <qpushbutton.h>
-#include <qcombobox.h>
-#include <qlineedit.h>
-#include <qgroupbox.h>
-#include <qspinbox.h>
-#include <qpainter.h>
-#include <qtimer.h>
-#include <qlabel.h>
-#include <qpen.h>
+
+#include <QRadioButton>
+#include <QColorDialog>
+#include <QPushButton>
+#include <QComboBox>
+#include <QLineEdit>
+#include <QGroupBox>
+#include <QSpinBox>
+#include <QPainter>
+#include <QTimer>
+#include <QLabel>
+#include <QPen>
+#include <QPalette> //xxx
+#include <QMessageBox>
+//Added by qt3to4:
+#include <QPaintEvent>
 
 #include "global.h"
 #include "dialogframe.h"
 
-DialogFrame::DialogFrame(QWidget *parent, const char *name, WFlags f )
-	: uiDialogFrame (parent, name, f )
-{
+//DialogFrame::DialogFrame(QWidget *parent, const char *name, Qt::WFlags f )	//ooo
+DialogFrame::DialogFrame(QWidget *pParent)					//xxx
+	//: uiDialogFrame (parent, name, f )	//ooo
+	: QDialog(pParent)			//xxx
+{  
+  setupUi(this);	//xxx
   m_pOrigFrame  = NULL;
   m_iFrameWidth = 4;
   m_iFrameStyle = Qt::SolidLine;
@@ -42,9 +51,16 @@ void DialogFrame::initMe( int iStyle, int iWidth, int iJoin, Rgba rgb )
   m_pFrameSelect->hide    ( );
   m_pGroupGeometry->hide  ( );
   m_pGroupAnimation->hide ( );
-  m_pGroupGeometry->setEnabled ( FALSE );
+  //m_pGroupGeometry->setEnabled ( FALSE );	//ooo
+  m_pGroupGeometry->setEnabled ( false );	//xxx
 
-  m_pFrameColor->setPaletteBackgroundColor ( rgb.color ( ) );
+  //m_pFrameColor->setPaletteBackgroundColor ( rgb.color ( ) );	//ooo
+  QPalette palette;						                           //xxx
+  //palette.setBrush(QPalette::Base, QBrush(rgb.color ( )));	   //xxx
+  //palette.setColor(m_pFrameColor->backgroundRole(), rgb.color ( ));	//xxx
+  palette.setColor(QPalette::Window, rgb.color ( ));	//xxx
+  m_pFrameColor->setAutoFillBackground(true);                       //xxx
+  m_pFrameColor->setPalette(palette);				               //xxx
   m_colorFrame  = rgb;
   m_iFrameWidth = iWidth;
   m_iFrameStyle = iStyle;
@@ -56,7 +72,15 @@ void DialogFrame::initMe( int iStyle, int iWidth, int iJoin, Rgba rgb )
 void DialogFrame::initMe ( FrameObject *pFrame )
 {
   // Here we continue with the standard initialization.
-  m_pFrameColor->setPaletteBackgroundColor ( pFrame->color ( ).color ( ) );
+  //m_pFrameColor->setPaletteBackgroundColor ( pFrame->color ( ).color ( ) );	//ooo
+  QPalette palette;								//xxx
+  //palette.setBrush(QPalette::Base, QBrush(pFrame->color ( ).color ( )));	//xxx
+  //palette.setColor(m_pFrameColor->backgroundRole(), pFrame->color ( ).color ( ));	//xxx
+  palette.setColor(QPalette::Window, pFrame->color ( ).color ( ));	//xxx
+  //palette.setBrush(m_pFrameColor->backgroundRole(), QColor( 0, 0, 0));	//xxx
+  //palette.setBrush(QPalette::Window, pFrame->color ( ).color ( ));	//xxx
+  m_pFrameColor->setAutoFillBackground(true);                       //xxx
+  m_pFrameColor->setPalette(palette);						//xxx
   m_colorFrame  = pFrame->color ( );
   m_iFrameWidth = pFrame->width ( );
   m_qsAnimation = pFrame->animation ( );
@@ -71,15 +95,15 @@ void DialogFrame::initMe ( FrameObject *pFrame )
 }
 
 void DialogFrame::initMe ( )
-{
-  m_pComboStyle->insertItem ( QString ("SolidLine"      ) );
-  m_pComboStyle->insertItem ( QString ("DashLine"       ) );
-  m_pComboStyle->insertItem ( QString ("DashDotLine"    ) );
-  m_pComboStyle->insertItem ( QString ("DashDotDotLine" ) );
+{ 
+  m_pComboStyle->addItem ( QString ("SolidLine"      ) );
+  m_pComboStyle->addItem ( QString ("DashLine"       ) );
+  m_pComboStyle->addItem ( QString ("DashDotLine"    ) );
+  m_pComboStyle->addItem ( QString ("DashDotDotLine" ) );
 	
-  m_pComboJoin->insertItem  ( QString ("MiterJoin") );
-  m_pComboJoin->insertItem  ( QString ("BevelJoin") );
-  m_pComboJoin->insertItem  ( QString ("RoundJoin") );
+  m_pComboJoin->addItem  ( QString ("MiterJoin") );
+  m_pComboJoin->addItem  ( QString ("BevelJoin") );
+  m_pComboJoin->addItem  ( QString ("RoundJoin") );
   
   connect ( m_pButtonAnimation,SIGNAL ( clicked ( ) ), this, SLOT ( slotAnimation ( ) ) );
   connect ( m_pButtonColor,    SIGNAL ( clicked ( ) ), this, SLOT ( slotColor     ( ) ) );
@@ -94,7 +118,8 @@ void DialogFrame::initMe ( )
 
 void DialogFrame::polish ( )
 {
-  uiDialogFrame::polish ( );
+  //uiDialogFrame::polish ( );	//oooo
+  //QDialog::polish ( );		//xxx
   //resize ( 250, 250 );
   //drawPreview ( );
 
@@ -104,11 +129,12 @@ void DialogFrame::polish ( )
 void DialogFrame::slotRefresh ( )
 {
   //  resize ( 250, 250 );
-  drawPreview ( );
+  //drawPreview ( );    //ooo
+  repaint();            //xxx  
 }
 
 void DialogFrame::slotColor ()
-{
+{  
   bool bOkay;
 //  Rgba transparentColor = Rgba ( TRANSPARENT_COLOR );
 //  QRgb rgbColor = QColorDialog::getRgba ( transparentColor.rgb ( ), &bOkay, this );
@@ -117,9 +143,15 @@ void DialogFrame::slotColor ()
     return;
 
   Rgba newColor ( rgbColor );
-  m_pFrameColor->setPaletteBackgroundColor ( newColor.color ( ) );
+  //m_pFrameColor->setPaletteBackgroundColor ( newColor.color ( ) );	//ooo
+  QPalette palette;							//xxx
+  //palette.setBrush(QPalette::Base, QBrush(newColor.color ( )));		//xxx
+  //palette.setColor(m_pFrameColor->backgroundRole(), newColor.color ( ));		//xxx
+  palette.setColor(QPalette::Window, newColor.color ( ));		//xxx
+  m_pFrameColor->setPalette(palette);					//xxx
   m_colorFrame = newColor;
-  drawPreview ( );
+  //drawPreview ( );    //ooo
+  repaint();            //xxx
 }
 
 void DialogFrame::slotImage()
@@ -156,7 +188,8 @@ QString &DialogFrame::animation ( )
 void DialogFrame::slotWidth(int iNewValue)
 {
 	m_iFrameWidth = iNewValue;
-	drawPreview();
+	//drawPreview();   //ooo
+    repaint();          //xxx
 }
 
 void DialogFrame::slotJoin(int iNewValue)
@@ -171,7 +204,8 @@ void DialogFrame::slotJoin(int iNewValue)
 	default:
 		m_iFrameJoin = Qt::MiterJoin;
 	}
-	drawPreview();
+	//drawPreview();   //ooo
+	repaint();         //xxx
 }
 
 void DialogFrame::slotStyle(int iNewValue)
@@ -189,22 +223,25 @@ void DialogFrame::slotStyle(int iNewValue)
 	default:
 		m_iFrameStyle = Qt::SolidLine;
 	}
-	drawPreview();
+	//drawPreview();   //ooo
+	repaint();         //xxx
 }
 
 void DialogFrame::drawPreview()
-{
+{  
   //m_pPreview => QFrame
   QPainter thePainter (m_pPreview);
   QPen thePen ( color ( ).color ( ), frameWidth(), (Qt::PenStyle)style(), Qt::FlatCap, (Qt::PenJoinStyle)join());
   thePainter.setPen (thePen);
   thePainter.setBrush(Qt::NoBrush);
-  m_pPreview->repaint();
+
+  //m_pPreview->repaint();  //oooo
   //m_pPreview->update();
-	
+  //m_pPreview->update();   //xxx
+
   // Note: the drawing range is 32 pixels
   QRect theRect (16, 16, m_pPreview->width()-32, m_pPreview->height()-32);
-  thePainter.drawRect (theRect);	
+  thePainter.drawRect (theRect);
 }
 
 void DialogFrame::paintEvent (QPaintEvent *)
