@@ -1,21 +1,25 @@
-/****************************************************************************
-** DialogImage2 - class implementation
-**
-** This class handles the DialogImage - dialog for QDVDAutor.
-**
-** Note that QSlideshow has its own class, GUI to handle the same interface
-**
-**   Created :
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-*****************************************************************************/
+/***************************************************************************
+    dialogimage2.cpp
+                             -------------------
+                             
+    DialogImage2 - class implementation
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class handles the DialogImage - dialog for QDVDAutor.
+    
+    Note that QSlideshow has its own class, GUI to handle the same interface
+    
+****************************************************************************/
 
 #include <qdesktopwidget.h>
 #include <qpushbutton.h>
-#include <qscrollview.h>
-#include <qpopupmenu.h>
+//#include <q3scrollview.h> //ooo
+#include <QScrollArea>      //xxx
+//#include <q3popupmenu.h>  //ooo
 #include <qcheckbox.h>
 #include <qlineedit.h>
 #include <qpainter.h>
@@ -24,16 +28,22 @@
 #include <qslider.h>
 #include <qtimer.h>
 #include <qlabel.h>
+//Added by qt3to4:
+//#include <Q3GridLayout>   //ooo
+#include <QGridLayout>   //xxx
+#include <QMouseEvent>
 
 #include "modifiers.h"
-#include "dialogshadow.h"
+//#include "dialogshadow.h" //ooo
 #include "dialogimage2.h"
 #include "menuobject.h"
 #include "imageobject.h"
 #include "movieobject.h"
 
-DialogImage2::ImagePreview::ImagePreview ( ImageObject *pImageObject, DialogImage2 *pDialog, QWidget *pParent, const char *pName, WFlags theFlags )
-  : QLabel ( pParent, pName, theFlags )
+//DialogImage2::ImagePreview::ImagePreview ( ImageObject *pImageObject, DialogImage2 *pDialog, QWidget *pParent, const char *pName, Qt::WFlags theFlags )   //ooo
+DialogImage2::ImagePreview::ImagePreview ( ImageObject *pImageObject, DialogImage2 *pDialog, QWidget *pParent )                                             //xxx
+  //: QLabel ( pParent, pName, theFlags )   //ooo
+  : QLabel ( pParent )                      //xxx
 {
   m_pParent      = pDialog;
   m_pImageObject = pImageObject;
@@ -45,18 +55,18 @@ DialogImage2::ImagePreview::~ImagePreview ( )
 
 void DialogImage2::ImagePreview::mousePressEvent ( QMouseEvent *pEvent )
 {
-  if ( pEvent->button ( ) == LeftButton )    {
+  if ( pEvent->button ( ) == Qt::LeftButton )    {
     m_pParent->createActiveBackground ( true );
     m_pImageObject->mousePressEvent ( pEvent );
     return;
   }
     
-  QString qsShadow;
+/*  QString qsShadow;
   qsShadow = tr ( "Add Shadow ..." );
   if ( m_pImageObject->shadow ( ) )
      qsShadow = tr ( "Edit Shadow ..." );
 
-  QPopupMenu *pMenu = new QPopupMenu (this);
+  Q3PopupMenu *pMenu = new Q3PopupMenu (this);
   pMenu->insertItem ( tr ("Properties ..."),  m_pParent, SLOT ( slotButtonProperties ( ) ) );
   pMenu->insertItem ( qsShadow,               m_pParent, SLOT ( slotButtonShadow     ( ) ) );
   pMenu->insertSeparator ();
@@ -64,6 +74,13 @@ void DialogImage2::ImagePreview::mousePressEvent ( QMouseEvent *pEvent )
   pMenu->insertItem ( tr ("Rotate 180"),      m_pParent, SLOT ( slotRotate180  ( ) ) );
   pMenu->insertItem ( tr ("Rotate 270"),      m_pParent, SLOT ( slotRotate270  ( ) ) );
   pMenu->exec ( pEvent->globalPos ( ) );
+  */    //ooo
+
+  QMenu *pMenu = new QMenu (this);
+  pMenu->addAction( tr ("Rotate 90") );
+  connect ( pMenu, SIGNAL ( activated ( ) ), m_pParent, SLOT ( slotRotate90 ( ) ) );
+  pMenu->exec ( pEvent->globalPos ( ) );
+
 }
 
 void DialogImage2::ImagePreview::mouseReleaseEvent (QMouseEvent * )
@@ -91,9 +108,12 @@ void DialogImage2::ImagePreview::mouseDoubleClickEvent (QMouseEvent *)
   m_pParent->slotButtonProperties ( );
 }
 
-DialogImage2::DialogImage2 ( QWidget *pParent, const char *pName, bool bModal, WFlags flags )
-    : uiDialogImage ( pParent, pName, bModal, flags )
+//DialogImage2::DialogImage2 ( QWidget *pParent, const char *pName, bool bModal, Qt::WFlags flags )	//ooo
+DialogImage2::DialogImage2 ( QWidget *pParent )								//xxx
+    //: uiDialogImage ( pParent, pName, bModal, flags )		//ooo
+    : QDialog ( pParent )					//xxx
 {
+  setupUi(this);		//xxx
   m_pImagePreview    = NULL;
   m_pImageObject     = NULL;
   m_pOrigImageObject = NULL;
@@ -173,19 +193,22 @@ void DialogImage2::initMe ( ImageObject *pImageObject, QPixmap *pBackground )
   // use QDVDAuthor.
   int iScreenWidth, iScreenHeight, iScreens, t;
   QDesktopWidget desktop;
-  QGridLayout   *pLayout = new QGridLayout (m_pFrameImage, 1, 1, 2, 2, "m_pFrameImageLayout");
+  //Q3GridLayout   *pLayout = new Q3GridLayout (m_pFrameImage, 1, 1, 2, 2, "m_pFrameImageLayout");  //ooo
+  QGridLayout   *pLayout = new QGridLayout (m_pFrameImage);                                       //xxx
   iScreenWidth = iScreenHeight = 0;
   iScreens = desktop.numScreens();
   for (t=0;t<iScreens;t++)	{
     iScreenWidth  += desktop.screenGeometry(t).width();
     iScreenHeight += desktop.screenGeometry(t).height();
   }
-  uint iFlags = 0;
-#if (QT_VERSION > 0x0301FF)
-  iFlags = Qt::WNoAutoErase;
-#else
-  iFlags = Qt::WPaintClever;
-#endif
+  //uint iFlags = 0;		//ooo
+//#if (QT_VERSION > 0x0301FF)	//ooo
+//  iFlags = Qt::WNoAutoErase;
+//#else
+//  iFlags = Qt::WPaintClever;
+//#endif
+  
+  //Qt::WindowFlags iFlags = Qt::WNoAutoErase;	//xxx
 
   m_pOrigImageObject = pImageObject;
   m_pImageObject     = (ImageObject *) pImageObject->clone ( );
@@ -195,20 +218,29 @@ void DialogImage2::initMe ( ImageObject *pImageObject, QPixmap *pBackground )
 
   if ( (iScreenHeight <= 768) || (iScreenWidth <= 1024) )	{
     // Here we embed the MenuPreview into a ScrollView object ...
-    m_pScrollView   = new QScrollView  ( m_pFrameImage, "m_pScrollView",   iFlags );
-    m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pScrollView, "m_pImagePreview", iFlags );
-    m_pScrollView->addChild            ( m_pImagePreview );
+    //m_pScrollView   = new Q3ScrollView  ( m_pFrameImage, "m_pScrollView",   iFlags ); //ooo
+    m_pScrollView   = new QScrollArea  ( m_pFrameImage );                              //xxx
+    //m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pScrollView, "m_pImagePreview", iFlags );    //ooo
+    m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pScrollView );                                 //xxx
+    //m_pScrollView->addChild            ( m_pImagePreview );   //ooo
+    m_pScrollView->setWidget            ( m_pImagePreview );    //xxx
     m_pImagePreview->resize            ( 720, 480 );
     pLayout->addWidget                 ( m_pScrollView, 0, 0 );
   }
   else	{
-    m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pFrameImage, "m_pPreview", iFlags );
+    //m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pFrameImage, "m_pPreview", iFlags ); //ooo
+    m_pImagePreview = new ImagePreview ( m_pImageObject, this, m_pFrameImage );                         //xxx
     pLayout->addWidget                 ( m_pImagePreview, 0, 0 );
   }
   
   if ( pBackground && ( pBackground->width () > 10 ) && ( pBackground->height () > 10 ) ) {
     m_backgroundBuffer = *pBackground;
-    m_pImagePreview->setPaletteBackgroundPixmap ( *pBackground );
+    m_pImagePreview->setScaledContents         ( true );		//xxx	
+    m_pImagePreview->setAutoFillBackground     ( true );		//xxx
+    //m_pImagePreview->setPaletteBackgroundPixmap ( *pBackground );	//ooo
+    QPalette palette;							//xxx
+    palette.setBrush(QPalette::Window, QBrush(*pBackground));		//xxx
+    m_pImagePreview->setPalette(palette);				//xxx
     m_pImagePreview->setFixedWidth  ( pBackground->width  ( ) );
     m_pImagePreview->setFixedHeight ( pBackground->height ( ) );
   }
@@ -249,12 +281,14 @@ void DialogImage2::slotOk ( )
   m_pOrigImageObject->setAnimation  ( m_pImageObject->animation ( ) );
   m_pOrigImageObject->updatePixmap  ( );
   
-  uiDialogImage::accept ( );
+  //uiDialogImage::accept ( );	//ooo
+  QDialog::accept ( );		//xxx
 }
 
 void DialogImage2::reject ( )
 {
-  uiDialogImage::reject ( );
+  //uiDialogImage::reject ( );	//ooo
+  QDialog::reject ( );		//xxx
 }
 
 void DialogImage2::slotRotate90 ( )
@@ -288,7 +322,9 @@ void DialogImage2::slotCenterScrollView ( )
     iScrollToY = m_pImageObject->rect ( ).y ( ) - 15;
     if ( iScrollToY < 1 )
       iScrollToY = 1;
-    m_pScrollView->setContentsPos ( iScrollToX, iScrollToY );
+    //m_pScrollView->setContentsPos ( iScrollToX, iScrollToY ); //ooo
+    //m_pScrollView->scrollContentsBy ( iScrollToX, iScrollToY ); //xxx
+    m_pScrollView->move ( iScrollToX, iScrollToY );             //xxx
   }
 }
 
@@ -303,7 +339,12 @@ void DialogImage2::redrawObject ( )
 
     QPainter thePainter ( &tempPixmap );
     m_pImageObject->drawContents ( &thePainter );
-    m_pImagePreview->setPaletteBackgroundPixmap ( tempPixmap );
+    m_pImagePreview->setScaledContents         ( true );		//xxx	
+    m_pImagePreview->setAutoFillBackground     ( true );		//xxx
+    //m_pImagePreview->setPaletteBackgroundPixmap ( tempPixmap );	//ooo
+    QPalette palette;							//xxx
+    palette.setBrush(QPalette::Window, QBrush(tempPixmap));		//xxx
+    m_pImagePreview->setPalette(palette);				//xxx
   }
 }
 
@@ -365,7 +406,8 @@ void DialogImage2::slotZoomValueChanged( int iValue )
 
 void DialogImage2::slotBrightnessValueChanged( int iValue )
 {
-  float fBrightness = (float)iValue / 1000.0;
+  //float fBrightness = (float)iValue / 1000.0;                 //ooo
+  float fBrightness = static_cast<float> ( iValue ) / 1000.0;   //xxx
   m_pLabelStatus->setText(tr ("Brightness"));
   m_pEditStatus->setText (QString ("%1").arg(fBrightness));
   if ( m_pImageObject )
@@ -375,7 +417,8 @@ void DialogImage2::slotBrightnessValueChanged( int iValue )
 
 void DialogImage2::slotRedValueChanged( int iValue )
 {
-  float fRed = 1.0 - (float)iValue / 1000.0;
+  //float fRed = 1.0 - (float)iValue / 1000.0;                  //ooo
+  float fRed = 1.0 - static_cast<float> ( iValue ) / 1000.0;  //xxx
   m_pLabelStatus->setText(tr ("Red"));
   m_pEditStatus->setText (QString ("%1").arg(fRed));
   if ( m_pImageObject )
@@ -385,7 +428,8 @@ void DialogImage2::slotRedValueChanged( int iValue )
 
 void DialogImage2::slotGreenValueChanged( int iValue )
 {
-  float fGreen = 1.0 - (float)iValue / 1000.0;
+  //float fGreen = 1.0 - (float)iValue / 1000.0;                    //ooo
+  float fGreen = 1.0 - static_cast<float> ( iValue ) / 1000.0;      //xxx
   m_pLabelStatus->setText(tr ("Green"));
   m_pEditStatus->setText (QString ("%1").arg(fGreen));
   if ( m_pImageObject )
@@ -395,7 +439,8 @@ void DialogImage2::slotGreenValueChanged( int iValue )
 
 void DialogImage2::slotBlueValueChanged( int iValue )
 {
-  float fBlue = 1.0 - (float)iValue / 1000.0;
+  //float fBlue = 1.0 - (float)iValue / 1000.0;                 //ooo
+  float fBlue = 1.0 - static_cast<float> ( iValue ) / 1000.0;   //xxx
   m_pLabelStatus->setText(tr ("Blue"));
   m_pEditStatus->setText (QString ("%1").arg(fBlue));
   if ( m_pImageObject )
@@ -453,26 +498,35 @@ void DialogImage2::slotValueChanged( const QString & newText )
   // The user typed in a new value in the status. Thus we need to check which value was changed and do the do ...
   float fNewValue = newText.toFloat();
   if (m_pLabelStatus->text() == tr("ShearX"))
-    m_pSliderShearX->setValue((int)(fNewValue * 1000.0));
+    //m_pSliderShearX->setValue((int)(fNewValue * 1000.0));             //ooo
+    m_pSliderShearX->setValue(static_cast<int>(fNewValue * 1000.0));    //xxx
   else if (m_pLabelStatus->text() == tr("ShearY"))
-    m_pSliderShearY->setValue((int)(fNewValue * 1000.0));
+    //m_pSliderShearY->setValue((int)(fNewValue * 1000.0));             //ooo
+    m_pSliderShearY->setValue(static_cast<int>(fNewValue * 1000.0));    //xxx
   else if (m_pLabelStatus->text() == tr("Rotate"))
-    m_pSliderRotate->setValue((int)(fNewValue * 10.0));
+    //m_pSliderRotate->setValue((int)(fNewValue * 10.0));               //ooo
+    m_pSliderRotate->setValue(static_cast<int>(fNewValue * 10.0));      //xxx
   else if (m_pLabelStatus->text() == tr("Zoom")) {
     if ( fNewValue > 1.0 )
       fNewValue = (fNewValue - 1.0) / 3.0 + 1.0;
-    m_pSliderZoom->setValue((int)(fNewValue * 1000.0)-1000);
+    //m_pSliderZoom->setValue((int)(fNewValue * 1000.0)-1000);          //ooo
+    m_pSliderZoom->setValue(static_cast<int>(fNewValue * 1000.0)-1000); //xxx
   }
   else if (m_pLabelStatus->text() == tr("Transparency"))
-    m_pSliderTransparency->setValue((int)(fNewValue * 1000.0));
+    //m_pSliderTransparency->setValue((int)(fNewValue * 1000.0));               //ooo
+    m_pSliderTransparency->setValue(static_cast<int>(fNewValue * 1000.0));      //xxx
   else if (m_pLabelStatus->text() == tr("Brightness"))
-    m_pSliderBrightness->setValue((int)(fNewValue * 1000.0));
+    //m_pSliderBrightness->setValue((int)(fNewValue * 1000.0));                 //ooo
+    m_pSliderBrightness->setValue(static_cast<int>(fNewValue * 1000.0));        //xxx
   else if (m_pLabelStatus->text() == tr("Red"))
-    m_pSliderRed->setValue((int)(1000 - fNewValue * 1000.0));
+    //m_pSliderRed->setValue((int)(1000 - fNewValue * 1000.0));                 //ooo
+    m_pSliderRed->setValue(static_cast<int>(1000 - fNewValue * 1000.0));        //xxx
   else if (m_pLabelStatus->text() == tr("Green"))
-    m_pSliderGreen->setValue((int)(1000 - fNewValue * 1000.0));
+    //m_pSliderGreen->setValue((int)(1000 - fNewValue * 1000.0));               //ooo
+    m_pSliderGreen->setValue(static_cast<int>(1000 - fNewValue * 1000.0));      //xxx
   else if (m_pLabelStatus->text() == tr("Blue"))
-    m_pSliderBlue->setValue((int)(1000 - fNewValue * 1000.0)); 
+    //m_pSliderBlue->setValue((int)(1000 - fNewValue * 1000.0));                //ooo
+    m_pSliderBlue->setValue(static_cast<int>(1000 - fNewValue * 1000.0));       //xxx
 
   redrawObject ( );
 }
@@ -487,7 +541,7 @@ void DialogImage2::slotButtonProperties ( )
 
 void DialogImage2::slotButtonShadow ( )
 {
-  DialogShadow dialog ( this );
+/*  DialogShadow dialog ( this );
   dialog.initMe       ( m_pImageObject, &m_backgroundBuffer );
   if ( dialog.exec    ( ) == QDialog::Rejected )
     return;
@@ -497,7 +551,7 @@ void DialogImage2::slotButtonShadow ( )
   else
     m_pButtonShadow->setText ( tr ( "Add Shadow ..." ) );
 
-  redrawObject ( );
+  redrawObject ( );*/   //oooo
 }
 
 
