@@ -1,33 +1,41 @@
-/****************************************************************************
-** DialogImage2 - class
-**
-**   Created : Sat Aug 26 12:09:08 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** After all the extensions to the MenuObjects (Shadows, groups etc)
-** the original DialogImage - dialog was no longer sufficient and 
-** became unmaintanable.
-**
-** This class recreates the exact same user interface and handles
-** all user interaction and displaying internally.
-**
-****************************************************************************/
+/***************************************************************************
+    dialogimage2.h
+                             -------------------
+                             
+    DialogImage2 - class                         
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    After all the extensions to the MenuObjects (Shadows, groups etc)
+    the original DialogImage - dialog was no longer sufficient and
+    became unmaintanable.
+    
+    This class recreates the exact same user interface and handles
+    all user interaction and displaying internally.
+    
+ ***************************************************************************/
 
 #ifndef DIALOGIMAGE2_H
 #define DIALOGIMAGE2_H
 
 #include <qlabel.h>
 #include <qpixmap.h>
+//Added by qt3to4:
+#include <QMouseEvent>
 
-#include "uidialogimage.h"
+//#include "uidialogimage.h"	//ooo
+#include "ui_uidialogimage.h"	//xxx
 
-class QScrollView;
+//class Q3ScrollView;   //ooo
+class QScrollArea;     //xxx
 class ImageObject;
 class ImageManipulator;
 
-class DialogImage2 : public uiDialogImage
+//class DialogImage2 : public uiDialogImage			//ooo
+class DialogImage2 : public QDialog, Ui::uiDialogImage		//xxx
 {
     Q_OBJECT
 
@@ -35,7 +43,8 @@ class DialogImage2 : public uiDialogImage
     {
       //      Q_OBJECT
     public:
-      ImagePreview ( ImageObject *, DialogImage2 *, QWidget *p=NULL, const char *n=NULL, WFlags f=0 );
+      //ImagePreview ( ImageObject *, DialogImage2 *, QWidget *p=NULL, const char *n=NULL, Qt::WFlags f=0 );    //ooo
+      ImagePreview ( ImageObject *, DialogImage2 *, QWidget *p=NULL );                                          //xxx
       virtual ~ImagePreview ( );
 
     protected:
@@ -50,7 +59,8 @@ class DialogImage2 : public uiDialogImage
     };
 
 public:
-     DialogImage2 ( QWidget *p=NULL, const char *n=NULL, bool m=FALSE, WFlags f=0 );
+     //DialogImage2 ( QWidget *p=NULL, const char *n=NULL, bool m=FALSE, Qt::WFlags f=0 );	//ooo
+     DialogImage2 ( QWidget *pParent=NULL );							//xxx
     ~DialogImage2 ( );
 
     void initMe ( ImageObject *, QPixmap * );
@@ -85,7 +95,8 @@ protected slots:
 
 private:
     QLabel      *m_pImagePreview;
-    QScrollView *m_pScrollView;
+    //Q3ScrollView *m_pScrollView;  //ooo
+    QScrollArea *m_pScrollView;     //xxx
     ImageObject *m_pImageObject;
     ImageObject *m_pOrigImageObject;
     QPixmap      m_backgroundBuffer;      
