@@ -12,26 +12,32 @@
 #ifndef DIALOGLIBRARY_H
 #define DIALOGLIBRARY_H
 
-#include <qvaluelist.h>
+//#include <q3valuelist.h>	//oxx
 
-#include "uidialoglibrary.h"
+//#include "uidialoglibrary.h"		//ooo
+#include "ui_uidialoglibrary.h"		//xxx
 
-class QIconView;
+//class Q3IconView; //ooo
+class QListWidget;   //xxx
 
-class DialogLibrary : public uiDialogLibrary
+//class DialogLibrary : public uiDialogLibrary				//ooo
+class DialogLibrary : public QDialog, public Ui::uiDialogLibrary	//xxx
 {
     Q_OBJECT
 
 protected:
     class LibraryPart {
     public:
-      LibraryPart ( QIconView *, QString );
-      QIconView *pIconView;
+      //LibraryPart ( Q3IconView *, QString );  //ooo
+      LibraryPart ( QListWidget *, QString );    //xxx
+      //Q3IconView *pIconView;  //ooo
+      QListWidget *pIconView;    //xxx
       QString    qsLibraryPath;
     };
 
 public:
-           DialogLibrary ( QWidget *p=0, const char *n=NULL, bool m=FALSE, WFlags f=0 );
+           //DialogLibrary ( QWidget *p=0, const char *n=NULL, bool m=FALSE, Qt::WFlags f=0 );		//ooo
+	   DialogLibrary ( QWidget *pParent=0 );							//xxx
   virtual ~DialogLibrary ( );
 
   void createTab ( QString, QString, QStringList & );
@@ -51,7 +57,7 @@ protected slots:
 protected:
   int m_iWidth;
   int m_iHeight;
-  QValueList<LibraryPart *>  m_listLibrary;
+  QList<LibraryPart *>  m_listLibrary;		//oxx
 };
 
 #endif // DIALOGLIBRARY_H
