@@ -1,12 +1,14 @@
-/****************************************************************************
-** DialogAnimation class
-**
-**   Created : Mon Jun 10 22:48:00 2005
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    dialogmediainfo.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   DialogAnimation class
+    
 ****************************************************************************/
 
 #include <qmessagebox.h>
@@ -14,14 +16,18 @@
 //#include <qcombobox.h>
 //#include <qspinbox.h>
 //#include <qslider.h>
+#include <QMessageBox>		//xxx
 
 #include "sourcefileentry.h"
 #include "dialogmovie.h"
 #include "dialogmediainfo.h"
 
-DialogMediaInfo::DialogMediaInfo (QWidget *pParent, const char *pName, WFlags f )
-	: uiDialogMediaInfo (pParent, pName, f)
+//DialogMediaInfo::DialogMediaInfo (QWidget *pParent, const char *pName, Qt::WFlags f )		//ooo
+DialogMediaInfo::DialogMediaInfo (QWidget *pParent)						//xxx
+	//: uiDialogMediaInfo (pParent, pName, f)	//ooo
+	: QDialog (pParent)				//xxx
 {
+  setupUi(this);	//xxx
 }
 
 DialogMediaInfo::~DialogMediaInfo ()
