@@ -1,11 +1,13 @@
-/****************************************************************************
-** DialogShadow
-**
-**   Created : Sat Aug 3 22:05:28 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    dialogshadow.cpp
+                             -------------------
+    DialogShadow
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #include <qdial.h>
@@ -17,10 +19,15 @@
 #include <qpainter.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
-#include <qgroupbox.h>
-#include <qscrollview.h>
+//#include <q3groupbox.h>   //ooo
+#include <QGroupBox>        //xxx
+//#include <q3scrollview.h> //ooo
+#include <QScrollArea>      //xxx
 #include <qpushbutton.h>
 #include <qcolordialog.h>
+//Added by qt3to4:
+#include <QGridLayout>
+#include <QPixmap>
 
 
 #include "global.h" // for PI
@@ -47,9 +54,13 @@ float  DialogShadow::m_keepColorFade     =  0.0f;
 QColor DialogShadow::m_keepTargetColor   = QColor ( 0, 0, 0 );
 
 
-DialogShadow::DialogShadow ( QWidget* parent, const char* name, bool modal, WFlags fl )
-  : uiDialogShadow   ( parent, name, modal, fl )
+//DialogShadow::DialogShadow ( QWidget* parent, const char* name, bool modal, Qt::WFlags fl )	//ooo
+DialogShadow::DialogShadow ( QWidget* pParent )							//xxx
+  //: uiDialogShadow   ( parent, name, modal, fl )	//ooo
+  : QDialog ( pParent )					//xxx
 {
+  setupUi(this);	//xxx
+  
   m_pBackground    = NULL;
   m_pShadow        = NULL;
   m_pOrigShadow    = NULL;
@@ -59,56 +70,94 @@ DialogShadow::DialogShadow ( QWidget* parent, const char* name, bool modal, WFla
   m_iAdvancedWidth = 100;
   m_bStoredActiveState = false;
 
-  m_pDialSunAngle->setMinValue       (     0 );
-  m_pDialSunAngle->setMaxValue       ( 36000 );
-  m_pSliderBlur->setMinValue         (     2 );
-  m_pSliderBlur->setMaxValue         (    50 );
-  m_pSliderDistance->setMinValue     (  -300 );
-  m_pSliderDistance->setMaxValue     (   300 );
+  //m_pDialSunAngle->setMinValue       (     0 );   //ooo
+  m_pDialSunAngle->setMinimum          (     0 );   //xxx
+  //m_pDialSunAngle->setMaxValue       ( 36000 );   //ooo
+  m_pDialSunAngle->setMaximum          ( 36000 );   //xxx
+  //m_pSliderBlur->setMinValue         (     2 );   //ooo
+  m_pSliderBlur->setMinimum            (     2 );   //xxx
+  //m_pSliderBlur->setMaxValue         (    50 );   //ooo
+  m_pSliderBlur->setMaximum            (    50 );   //xxx
+  //m_pSliderDistance->setMinValue     (  -300 );   //ooo
+  m_pSliderDistance->setMinimum        (  -300 );   //xxx
+  //m_pSliderDistance->setMaxValue     (   300 );   //ooo
+  m_pSliderDistance->setMaximum     (   300 );      //xxx
   m_pSliderDistance->setValue        (     0 );
-  m_pSliderTransparency->setMinValue (     0 );
-  m_pSliderTransparency->setMaxValue ( 10000 );
+  //m_pSliderTransparency->setMinValue (     0 );   //ooo
+  m_pSliderTransparency->setMinimum    (     0 );   //xxx
+  //m_pSliderTransparency->setMaxValue ( 10000 );   //ooo
+  m_pSliderTransparency->setMaximum ( 10000 );      //xxx
   m_pDialSunAngle->setValue          ( 31500 );
 
-  m_pSliderShearX->setMaxValue       (  1000 );
-  m_pSliderShearX->setMinValue       ( -1000 );
+  //m_pSliderShearX->setMaxValue       (  1000 );   //ooo
+  m_pSliderShearX->setMaximum          (  1000 );   //xxx
+  //m_pSliderShearX->setMinValue       ( -1000 );   //ooo
+  m_pSliderShearX->setMinimum          ( -1000 );   //xxx
   m_pSliderShearX->setValue          (     0 );
-  m_pSliderShearY->setMaxValue       (  1000 );
-  m_pSliderShearY->setMinValue       ( -1000 );
+  //m_pSliderShearY->setMaxValue       (  1000 );   //ooo
+  m_pSliderShearY->setMaximum          (  1000 );   //xxx
+  //m_pSliderShearY->setMinValue       ( -1000 );   //ooo
+  m_pSliderShearY->setMinimum          ( -1000 );   //xxx
   m_pSliderShearY->setValue          (     0 );
-  m_pSliderScaleX->setMaxValue       (  1000 );
-  m_pSliderScaleY->setMaxValue       (  1000 );
-  m_pSliderCutOff->setMaxValue       (  1000 );
-  m_pSliderCutOffRadius->setMaxValue (  1000 );
-  m_pSliderColorFade->setMaxValue    (  1000 );
+  //m_pSliderScaleX->setMaxValue       (  1000 );   //ooo
+  m_pSliderScaleX->setMaximum          (  1000 );   //xxx
+  //m_pSliderScaleY->setMaxValue       (  1000 );   //ooo
+  m_pSliderScaleY->setMaximum          (  1000 );   //xxx
+  //m_pSliderCutOff->setMaxValue       (  1000 );   //ooo
+  m_pSliderCutOff->setMaximum          (  1000 );   //xxx
+  //m_pSliderCutOffRadius->setMaxValue (  1000 );   //ooo
+  m_pSliderCutOffRadius->setMaximum    (  1000 );   //xxx
+  //m_pSliderColorFade->setMaxValue    (  1000 );   //ooo
+  m_pSliderColorFade->setMaximum       (  1000 );   //xxx
 
-  m_pSliderBlur->setTickmarks            ( QSlider::Below );
-  m_pSliderDistance->setTickmarks        ( QSlider::Below );
-  m_pSliderTransparency->setTickmarks    ( QSlider::Right );
-  m_pSliderTransparency->setLineStep     (  100 );
+  //m_pSliderBlur->setTickmarks            ( QSlider::TicksBelow ); //ooo
+  m_pSliderBlur->setTickPosition         ( QSlider::TicksBelow );   //xxx
+  //m_pSliderDistance->setTickmarks        ( QSlider::TicksBelow ); //ooo
+  m_pSliderDistance->setTickPosition     ( QSlider::TicksBelow );   //xxx
+  //m_pSliderTransparency->setTickmarks    ( QSlider::TicksRight ); //ooo
+  m_pSliderTransparency->setTickPosition ( QSlider::TicksRight );   //xxx
+  //m_pSliderTransparency->setLineStep     (  100 );    //ooo
   m_pSliderTransparency->setPageStep     ( 1000 );
   m_pSliderDistance->setTickInterval     (   50 );
   m_pSliderTransparency->setTickInterval ( 1000 );
 
-  QGridLayout *pLayout;
-  uint iFlags = 0;
+  //Q3GridLayout *pLayout;  //ooo
+  QGridLayout *pLayout;     //xxx
+  //uint iFlags = 0;	//ooo
 
-#if (QT_VERSION > 0x0301FF)
-	iFlags = Qt::WNoAutoErase;
-#else
-	iFlags = Qt::WPaintClever;
-#endif
+//#if (QT_VERSION > 0x0301FF)		//ooo
+//	iFlags = Qt::WNoAutoErase;
+//#else
+//	iFlags = Qt::WPaintClever;
+//#endif
+	
+  //Qt::WindowFlags iFlags = Qt::WNoAutoErase;	//xxx
 
-  pLayout       = new QGridLayout ( m_pLabelPreview, 1, 1, 2, 2, "pFramePreviewLayout");
-  m_pScrollView = new QScrollView ( m_pLabelPreview, "m_pScrollView", iFlags );
-  m_pPreview    = new QLabel      ( m_pScrollView,   "pPreview",      iFlags );
-  m_pScrollView->addChild ( m_pPreview );
+  //pLayout       = new Q3GridLayout ( m_pLabelPreview, 1, 1, 2, 2, "pFramePreviewLayout"); //ooo
+  pLayout       = new QGridLayout ( m_pLabelPreview);                                       //xxx
+  //m_pScrollView = new Q3ScrollView ( m_pLabelPreview, "m_pScrollView", iFlags );          //ooo
+  m_pScrollView = new QScrollArea ( m_pLabelPreview );                                      //xxx
+  //m_pPreview    = new QLabel      ( m_pScrollView,   "pPreview",      iFlags );           //ooo
+  m_pPreview    = new QLabel      ( m_pScrollView );                                        //xxx
+  //m_pScrollView->addChild ( m_pPreview ); //ooo
+  m_pScrollView->setWidget ( m_pPreview );  //xxx
   m_pPreview->resize      (  720, 480  );
   pLayout->addWidget      ( m_pScrollView, 0, 0 );
 
   m_pEditDistance->setText   ( "25" );
   m_pSliderDistance->setValue ( 25 );
-  m_pLabelColor->setPaletteBackgroundColor ( QColor ( 0, 0, 0 ) );
+  //m_pLabelColor->setPaletteBackgroundColor ( QColor ( 0, 0, 0 ) );        //ooo
+  QPalette palette;							                                //xxx
+  //palette.setColor(m_pLabelColor->backgroundRole(), QColor ( 0, 0, 0 ));    //xxx
+  palette.setColor(QPalette::Window, QColor ( 0, 0, 0 ));    //xxx
+  //palette.setColor(QPalette::Button, QColor ( 0, 0, 0 ));    //xxx
+  //palette.setBrush(QPalette::Base, QBrush(QColor ( "#BACBE9" ) ) );	//xxx
+  //palette.setBrush(QPalette::Window, QBrush(QColor ( "#aaaaff" ) ) );	//xxx
+  m_pLabelColor->setAutoFillBackground(true);   //xxx
+  m_pLabelColor->setPalette(palette);						                //xxx
+  //this->setPalette(palette);   //xxx
+  //this->m_pLabelColor->setPalette(palette);   //xxx
+  //m_pGroupBoxColor->setPalette(palette);    //xxx
 }
 
 DialogShadow::~DialogShadow ( )
@@ -155,7 +204,16 @@ void DialogShadow::initMe ( MenuObject *pMenuObject, QPixmap *pBackground )
      m_pSliderTransparency->setValue ( iTransparency );
      m_pDialSunAngle->setValue       (   iSunAngle   );
      m_pSliderBlur->setValue         (     iBlur     );
-     m_pLabelColor->setPaletteBackgroundColor ( m_pShadow->color ( ) );
+
+     //m_pLabelColor->setPaletteBackgroundColor ( m_pShadow->color ( ) );       //ooo
+     QPalette palette;							                                //xxx
+     //palette.setColor(m_pLabelColor->backgroundRole(), m_pShadow->color ( ));	//xxx
+     palette.setColor(QPalette::Window, m_pShadow->color ( ));	//xxx
+     //palette.setBrush(QPalette::Base, QBrush(QColor ( "#BACBE9" ) ) );	//xxx
+     //palette.setBrush(QPalette::Window, m_pShadow->color ( ) );	//xxx
+     //m_pLabelColor->setBackgroundRole(QPalette::Base);    //xxx
+     m_pLabelColor->setPalette(palette);					                    //xxx
+     
      m_pSliderDistance->setPageStep  ( 1 );
 
      m_pSliderShearX->setValue       ( (int) ( m_pShadow->shearX ( ) * 1000.0 ) );
@@ -292,12 +350,14 @@ void DialogShadow::slotCenterScrollView ( )
   iScrollToY = m_pMenuObject->rect ( ).y ( ) - 15;
   if ( iScrollToY < 1 )
        iScrollToY = 1;
-  m_pScrollView->setContentsPos ( iScrollToX, iScrollToY );
+  //m_pScrollView->setContentsPos ( iScrollToX, iScrollToY );   //ooo
+  m_pScrollView->move ( iScrollToX, iScrollToY );               //xxx
 
   m_iAdvancedWidth = m_pFrameMirror->width ( );
 
   if ( m_pShadow->type ( ) == ShadowObject::TYPE_MIRROR ) {
-    m_pComboStyle ->setCurrentItem ( 1 );
+    //m_pComboStyle ->setCurrentItem ( 1 ); //ooo
+    m_pComboStyle ->setCurrentIndex ( 1 );  //xxx
     m_pGroupBoxColor->setTitle ( "Target Color" );
   }
   else {
@@ -325,9 +385,21 @@ void DialogShadow::displayAdvanced ( bool bDisplayOrHide )
 }
 
 void DialogShadow::slotShadowColor ( )
-{
-  QColor newColor = QColorDialog::getColor ( m_pShadow->color ( ), this );
-  m_pLabelColor->setPaletteBackgroundColor ( newColor );
+{ 
+  QColor newColor = QColorDialog::getColor ( m_pShadow->color ( ), this );    //ooo
+  //QColor newColor = QColorDialog::getColor ( QColor(45,60,230), this );         //xxx
+
+  //m_pLabelColor->setPaletteBackgroundColor ( newColor );      //ooo
+  QPalette palette;							                    //xxx
+  //palette.setColor(m_pLabelColor->backgroundRole(), newColor);	//xxx
+  palette.setColor(QPalette::Window, newColor);	//xxx
+  //palette.setBrush(m_pLabelColor->backgroundRole(), QBrush(newColor));	//xxx
+  //palette.setBrush(m_pLabelColor->backgroundRole(), newColor);	//xxx
+  //palette.setBrush(QPalette::Base, newColor);	//xxx
+  m_pLabelColor->setPalette(palette);					        //xxx
+  
+  m_pShadow->setColor        ( newColor );  //xxxx
+
   if ( m_pShadow && m_pShadow->type ( ) == ShadowObject::TYPE_MIRROR ) {
     float fColorFading = m_pShadow->colorFading ( );
     m_pShadow->setColorFading ( newColor, fColorFading );
@@ -338,7 +410,8 @@ void DialogShadow::slotShadowColor ( )
 void DialogShadow::slotColorFade ( int iValue )
 {
   if ( m_pShadow ) {
-    float  fColorFade = (float)iValue / 1000.0;
+    //float  fColorFade = (float)iValue / 1000.0;   //ooo
+    float  fColorFade = static_cast<float>(iValue) / 1000.0;    //xxx
     QColor theColor   = m_pShadow->colorFadeTo ( );
     m_pShadow->setColorFading ( theColor, fColorFade );
     m_pShadow->updateShadow ( false );
@@ -403,7 +476,8 @@ void DialogShadow::slotBlur ( int iBlur ) // [ 0 .. 50 ]
   QString qsText;
   if ( iBlur < 3 )  
        iBlur = 0;
-  qsText.sprintf ( tr ("<B><CENTER>Blur radius [%d]</CENTER></B>" ), iBlur );
+  //qsText.sprintf ( tr ("<B><CENTER>Blur radius [%d]</CENTER></B>" ), iBlur );     //oooo
+  qsText.sprintf ( "<B><CENTER>Blur radius [%d]</CENTER></B>", iBlur );     //xxx
   m_pLabelBlur->setText ( qsText );
   
   //  printf ( "%s::%s::%d shadow<%p>\n", __FILE__, __FUNCTION__, __LINE__, m_pShadow );
@@ -458,7 +532,8 @@ void DialogShadow::slotSunAngle ( int iAngle )
   if ( m_pShadow &&  m_pShadow->type ( ) == ShadowObject::TYPE_SHADOW )
     qsText.sprintf ( "<p align=\"center\"><b>SunAngle [%0.2f%%]</b></p>", fAngle );
   else
-    qsText.sprintf ( "<p align=\"center\"><b>Position [%s]</b></p>", strPos.ascii ( ) );
+    //qsText.sprintf ( "<p align=\"center\"><b>Position [%s]</b></p>", strPos.ascii ( ) );          //ooo
+    qsText.sprintf ( "<p align=\"center\"><b>Position [%s]</b></p>", strPos.toLatin1().data ( ) );  //xxx
   m_pLabelSunAngle->setText ( qsText );
 
   refresh ( );
@@ -516,7 +591,8 @@ void DialogShadow::slotScaleY ( int iValue )
   if ( m_pShadow ) {
     float fScaleX, fScaleY;
     fScaleX = m_pShadow->scaleX ( );
-    fScaleY = (float)iValue / 1000.0;
+    //fScaleY = (float)iValue / 1000.0; //ooo
+    fScaleY = static_cast<float>(iValue) / 1000.0;  //xxx
     m_pShadow->setScale ( fScaleX, fScaleY );
     m_pEditScaleY->setText  ( tr ( "%1").arg ( fScaleY ) );
     m_pShadow->updateShadow ( false );
@@ -526,7 +602,8 @@ void DialogShadow::slotScaleY ( int iValue )
 
 void DialogShadow::slotCutOff ( int iValue )
 {
-  float fCutOff = (float)iValue / 1000.0;
+  //float fCutOff = (float)iValue / 1000.0; //ooo
+  float fCutOff = static_cast<float>(iValue) / 1000.0;      //xxx
   m_pEditCutOff->setText  ( tr ( "%1").arg ( fCutOff ) );
 }
 
@@ -535,7 +612,8 @@ void DialogShadow::slotCutOff ( )
   int iValue = m_pSliderCutOff->value ( );
   if ( m_pShadow ) {
     float fCutOff, fCutOffRadius;
-    fCutOff       = (float)iValue / 1000.0;
+    //fCutOff       = (float)iValue / 1000.0;   //ooo
+    fCutOff       = static_cast<float>(iValue) / 1000.0;    //xxx
     fCutOffRadius = m_pShadow->cutOffRadius ( );
     m_pShadow->setCutOff ( fCutOff, fCutOffRadius );
     m_pEditCutOff->setText  ( tr ( "%1").arg ( fCutOff ) );
@@ -556,7 +634,8 @@ void DialogShadow::slotCutOffRadius ( )
   if ( m_pShadow ) {
     float fCutOff, fCutOffRadius;
     fCutOff       = m_pShadow->cutOff ( );
-    fCutOffRadius = (float)iValue / 1000.0;
+    //fCutOffRadius = (float)iValue / 1000.0;   //ooo
+    fCutOffRadius = static_cast<float>(iValue) / 1000.0;    //xxx
     m_pShadow->setCutOff ( fCutOff, fCutOffRadius );
     m_pEditCutOffRadius->setText  ( tr ( "%1").arg ( fCutOffRadius ) );
     m_pShadow->updateShadow ( true );
@@ -569,7 +648,13 @@ void DialogShadow::refresh ( )
   if ( ( ! m_pMenuObject ) || ( ! m_pShadow ) )
     return;
 
-  QColor backgroundColor =   m_pLabelColor->paletteBackgroundColor ( );
+  //QColor backgroundColor =   m_pLabelColor->paletteBackgroundColor ( );           //ooo
+  //QPalette palette;	//xxx
+  //QColor backgroundColor =   palette.color ( m_pLabelColor->backgroundRole ( ) );   //xxx
+  //QColor backgroundColor =   QColor ( m_pLabelColor->backgroundRole ( ) );   //xxx
+  QColor backgroundColor =   QColor ( m_pShadow->color ( ) );   //xxx
+  //QColor backgroundColor =   QColor(45,60,230);   //xxx
+
   float  fTransparency   =   m_pSliderTransparency->value ( ) / 10000.0;
   int    iBlurRadius     =   m_pSliderBlur->value   ( );
   float  fDistance       =   m_pEditDistance->text  ( ).toFloat ( );
@@ -600,7 +685,13 @@ void DialogShadow::drawShadow ( )
   m_pShadow    ->drawContents ( &thePainter );
   m_pMenuObject->drawContents ( &thePainter );
 
-  m_pPreview->setPaletteBackgroundPixmap  ( thePixmap );
+  m_pPreview->setScaledContents         ( true );			//xxx	
+  m_pPreview->setAutoFillBackground     ( true );			//xxx
+  //m_pPreview->setPaletteBackgroundPixmap  ( thePixmap );		//ooo
+  QPalette palette;							//xxx
+  palette.setBrush(QPalette::Window, QBrush(thePixmap));		//xxx
+  //palette.setBrush(m_pPreview->backgroundRole(), QBrush(thePixmap));		//xxx
+  m_pPreview->setPalette(palette);					//xxx
   m_pPreview->resize ( thePixmap.width ( ), thePixmap.height ( ) );
 }
 
