@@ -1,30 +1,39 @@
-/****************************************************************************
-** DialogShadow - class
-**
-**   Created : Thu Aug 3 22:05:18 2006
-**        by : Varol Okan Using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    dialogshadow.h
+                             -------------------
+    DialogShadow - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #ifndef DIALOGSHADOW_H
 #define DIALOGSHADOW_H
 
-#include "uidialogshadow.h"
+//#include "uidialogshadow.h"	//ooo
+#include "ui_uidialogshadow.h"	//xxx
+//Added by qt3to4:
+#include <QPixmap>
+#include <QLabel>
 
 class ShadowObject;
-class QScrollView;
+//class Q3ScrollView;   //ooo
+class QScrollArea;      //xxx
 class ImageObject;
 class MenuObject;
 class QPixmap;
 class QLabel;
 
-class DialogShadow : public uiDialogShadow
+//class DialogShadow : public uiDialogShadow				//ooo
+class DialogShadow : public QDialog, public Ui::uiDialogShadow		//xxx
 {
   Q_OBJECT
 public:
-   DialogShadow ( QWidget *p=0, const char *n=0, bool m=false, WFlags fl=0 );
+   //DialogShadow ( QWidget *p=0, const char *n=0, bool m=false, Qt::WFlags fl=0 );	//ooo
+   DialogShadow ( QWidget *pParent=0 );							//xxx
   ~DialogShadow ( );
 
   void initMe ( MenuObject *, QPixmap * );
@@ -67,7 +76,9 @@ private:
   ShadowObject *m_pOrigShadow; // stores the original shadow in case we click cancel.
   MenuObject   *m_pMenuObject;
   QLabel       *m_pPreview;
-  QScrollView  *m_pScrollView;
+  //Q3ScrollView  *m_pScrollView;   //ooo
+  QScrollArea  *m_pScrollView;      //xxx
+  //QPalette palette;                 //xxx
 
   // some playfield varialbles for the animation of the advanced part.
   int m_iAdvancedWidth; // stores the width of the m_pFrameMirror for the animation effect
