@@ -16,13 +16,15 @@
 #include <qpixmap.h>
 #include <qcursor.h>
 #include <qspinbox.h>
-#include <qlistbox.h>
+//#include <q3listbox.h>    //ooo
 #include <qfileinfo.h>
 #include <qcheckbox.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
-#include <qgroupbox.h>
-#include <qlistview.h>
+//#include <q3groupbox.h>   //ooo
+#include <QGroupBox>        //xxx
+//#include <q3listview.h>   //ooo
+#include <QTreeWidget>      //xxx
 #include <qpushbutton.h>
 #include <qapplication.h>
 #include <qradiobutton.h>
@@ -35,9 +37,9 @@
 #include "messagebox.h"
 #include "xml_slideshow.h"
 #include "render_client.h"
-#include "dialogkenburns.h"
+#include "dialogkenburns.h"   //ooo
 #include "dialogslideshow.h"
-#include "dialogalphatrans.h"
+//#include "dialogalphatrans.h" //ooo
 #include "filepreviewdialog.h"
 #include "qplayer/mediainfo.h"
 
@@ -45,7 +47,8 @@ namespace Input
 {
 
 DialogSlideshow::DialogSlideshow ( QWidget *pParent )
-  : uiSlideshow ( pParent )
+  //: uiSlideshow ( pParent )	//ooo
+  : QDialog ( pParent )		//xxx
 {
   int t;
   for ( t=0; t<THUMBNAIL_COUNT; t++ )  {
@@ -56,6 +59,8 @@ DialogSlideshow::DialogSlideshow ( QWidget *pParent )
   m_bExitNow    = false;
   m_bAnimated   = false;
   m_pSlideshow  = NULL;
+  
+  setupUi(this);	//xxx
 
   connect ( m_pButtonOkay,      SIGNAL ( clicked ( ) ), this, SLOT ( accept ( ) ) );
   connect ( m_pButtonCancel,    SIGNAL ( clicked ( ) ), this, SLOT ( reject ( ) ) );
@@ -72,7 +77,7 @@ DialogSlideshow::DialogSlideshow ( QWidget *pParent )
   connect ( m_pCheckKenBurns,   SIGNAL ( toggled     ( bool ) ), this, SLOT ( slotKenBurns    ( bool ) ) );
   connect ( m_pSpinImageDelay,  SIGNAL ( valueChanged ( int ) ), this, SLOT ( slotValueChanged ( int ) ) );
   connect ( m_pSpinFilterDelay, SIGNAL ( valueChanged ( int ) ), this, SLOT ( slotValueChanged ( int ) ) );
-  connect ( m_pListViewTransitions,  SIGNAL  ( selectionChanged ( QListViewItem * ) ), this, SLOT ( slotSelectionChanged ( QListViewItem * ) ) );
+  connect ( m_pListViewTransitions,  SIGNAL  ( selectionChanged ( Q3ListViewItem * ) ), this, SLOT ( slotSelectionChanged ( Q3ListViewItem * ) ) );
 }
 
 /*
@@ -124,14 +129,18 @@ QStringList DialogSlideshow::filterList ( )
 {
   QStringList listOfCurrentSelections;
 
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );   //xxx
   bool bAllFilter = true;
   while ( pItem )  {
-    if  ( pItem->isOn ( ) )
-      listOfCurrentSelections.append ( pItem->text ( ) );
+    //if  ( pItem->isOn ( ) )   //ooo
+    if  ( pItem->checkState ( 0 ) )    //xxx
+      //listOfCurrentSelections.append ( pItem->text ( ) ); //ooo
+      listOfCurrentSelections.append ( pItem->text ( 0 ) ); //xxx
     else
       bAllFilter = false;
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);	//xxx
   }
   // If all filter were selected, then we don't need to bother
   // But hey we only know if we go through all of them ... right ?
@@ -163,7 +172,8 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
   else
     iFormat = ( pSlideshow->aspect == 0 ) ? 0 : 2;
 
-  m_pComboFormat->setCurrentItem ( iFormat );
+  //m_pComboFormat->setCurrentItem ( iFormat ); //ooo
+  m_pComboFormat->setCurrentIndex ( iFormat );  //xxx
 
   bool      bBackgroundImage = false;
   QString   qsAudio;
@@ -173,7 +183,9 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
     qsAudio = *it++;
     fileInfo.setFile ( qsAudio );
     qsAudio = fileInfo.fileName ( );
-    m_pListAudio->insertItem    ( qsAudio );
+    //m_pListAudio->insertItem    ( qsAudio );  //ooo
+    m_pListAudio->insertItem    ( 0, qsAudio );  //xxx
+    //m_pListAudio->addTopLevelItem ( new QTreeWidgetItem ( qsAudio ) );    //xxx
   }
   m_listAudio = pSlideshow->audio_list;
 
@@ -190,7 +202,8 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
       show ( );
       QPixmap thePixmap;
       QImage  theImage ( pSlideshow->background );
-      thePixmap.convertFromImage    ( theImage.smoothScale ( m_pLabelBackground->size ( ), QImage::ScaleFree ) );
+      //thePixmap.convertFromImage    ( theImage.smoothScale ( m_pLabelBackground->size ( ), Qt::IgnoreAspectRatio ) );				//ooo
+      thePixmap.convertFromImage    ( theImage.scaled ( m_pLabelBackground->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );	//xxx
       m_pLabelBackground->setPixmap ( thePixmap );
       bBackgroundImage = true;
     }
@@ -201,14 +214,18 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
   m_qsBackground  = pSlideshow->background;
   if ( ! bBackgroundImage )  {
     QColor theColor ( pSlideshow->background );
-    m_pLabelBackground->setPaletteBackgroundColor ( theColor );
+    //m_pLabelBackground->setPaletteBackgroundColor ( theColor );   //ooo
+    QPalette palette;		//xxx
+    palette.setBrush(QPalette::Base, theColor);	//xxx
+    m_pLabelBackground->setPalette(palette);						//xxx
   }
 
   QString qsTitle = "Slideshow [";
   qsTitle += m_pSlideshow->slideshow_name + "] <";
   qsTitle += QString ( "%1 Imgs+ %2 Vids>" ).arg ( m_pSlideshow->countImg ( ) ).arg ( m_pSlideshow->countVid ( ) );
 
-  setCaption ( qsTitle );
+  //setCaption ( qsTitle );     //ooo
+  setWindowTitle ( qsTitle );   //xxx
 
   // init Transitions will also call createVidsLength, and createAudioLength
   initTransitions ( );
@@ -224,12 +241,13 @@ void DialogSlideshow::initTransitions ( )
        Render::Manager::m_pSelf = new Render::Manager;
 
   // Disable sorting.
-  m_pListViewTransitions->setSorting ( -1 );
+  //m_pListViewTransitions->setSorting ( -1 );  //oooo
 
   // We need to also init the selected transitions for a Slideshow
   QString qsFilter;
   QStringList::iterator itFilter;
-  QCheckListItem    *pItem = NULL;
+  //Q3CheckListItem    *pItem = NULL;   //ooo
+  QTreeWidgetItem    *pItem = NULL;     //xxx
   QStringList         list = Render::Manager::m_pSelf->getFilterNames ( );
   QStringList::iterator it = list.end ( );
   bool bChecked;
@@ -257,13 +275,17 @@ void DialogSlideshow::initTransitions ( )
   }
 
   QPixmap pix;
-  QImage  img ( QImage::fromMimeSource ( "please_wait.jpg" ) );
-  img  =  img.smoothScale ( 24, 24 );
+  //QImage  img ( QImage::fromMimeSource ( "please_wait.jpg" ) );			//ooo
+  QImage  img ( QImage ( ":/images/please_wait.jpg" ) );				//xxx
+  //img  =  img.smoothScale ( 24, 24 );							//ooo
+  img  =  img.scaled ( 24, 24, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
   pix.convertFromImage  ( img );
   do  {
     qsFilter = *(--it);
-    pItem = new QCheckListItem ( m_pListViewTransitions, qsFilter, QCheckListItem::CheckBoxController );
-    pItem->setPixmap ( 0, pix );
+    //pItem = new Q3CheckListItem ( m_pListViewTransitions, qsFilter, Q3CheckListItem::CheckBoxController );    //ooo
+    pItem = new QTreeWidgetItem ( m_pListViewTransitions );   //xxx
+    //pItem->setPixmap ( 0, pix );  //ooo
+    pItem->setIcon ( 0, pix );      //xxx
     bChecked = false;
     if ( m_pSlideshow->validFilterNames.count ( ) > 0 )  {
       itFilter = m_pSlideshow->validFilterNames.begin ( );
@@ -276,7 +298,7 @@ void DialogSlideshow::initTransitions ( )
     }
     else
       bChecked  =   true;
-    pItem->setOn ( bChecked );
+    //pItem->setOn ( bChecked );    //oooo
   } while ( it != list.begin ( ) );
 
   bChecked = m_pSlideshow->imgBkgImg ( );
@@ -291,12 +313,16 @@ void DialogSlideshow::initTransitions ( )
 
 void DialogSlideshow::slotCreateListViewPix ( )
 {
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );   //xxx
 
   while ( pItem )  {
-    pItem->setPixmap    ( 0, getListViewPix ( pItem->text ( ) ) );
-    qApp->processEvents ( 500 );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    //pItem->setPixmap    ( 0, getListViewPix ( pItem->text ( ) ) );    //ooo
+    pItem->setIcon    ( 0, getListViewPix ( pItem->text ( 0 ) ) );        //xxx
+    //qApp->processEvents ( 500 );				//ooo
+    qApp->processEvents ( QEventLoop::AllEvents, 500 );		//xxx
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);  //xxx
   }
   // After we initialized the pixies, we need to ge vids, and audio lengths
   QTimer::singleShot ( 10,   this, SLOT ( createVidsLength  ( ) ) );
@@ -321,7 +347,8 @@ QPixmap DialogSlideshow::getListViewPix ( QString qsFilterName )
     return pix; // E.g. "Cross Fade"
 
   QImage img  (  qsFileName );
-  img =  img.scale ( 24, 24 );
+  //img =  img.scale ( 24, 24 );							//ooo
+  img  =  img.scaled ( 24, 24, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
   pix.convertFromImage( img );
 
   return pix;
@@ -334,11 +361,13 @@ void DialogSlideshow::createTransitions ( )
   // Note: We need to preserve transitions which the user manually changed.
   QStringList listOfCurrentSelections;
 
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );  //xxx
   while ( pItem )  {
-    if  ( pItem->isOn ( ) )
-      listOfCurrentSelections.append ( pItem->text ( ) );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    /*if  ( pItem->isOn ( ) )
+      listOfCurrentSelections.append ( pItem->text ( ) );*/     //ooo
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);  //xxx
   }
 }
 
@@ -418,8 +447,9 @@ void DialogSlideshow::slotKBParams ( )
          QString qsTitle = "Slideshow [";
          qsTitle += m_pSlideshow->slideshow_name + "] <";
          qsTitle += QString ( "%1 Imgs+ %2 Vids>" ).arg ( m_pSlideshow->countImg ( ) ).arg ( m_pSlideshow->countVid ( ) );
-         setCaption ( qsTitle );
-  }
+         //setCaption ( qsTitle );  //ooo
+         setWindowTitle( qsTitle );	//xxx
+  }   //oooo
 }
 
 void DialogSlideshow::slotKenBurns ( bool bChecked )
@@ -431,7 +461,7 @@ void DialogSlideshow::slotKenBurns ( bool bChecked )
       uint iImgCount = m_pSlideshow->countImg( );
       uint t;
       Utils theUtils;
-      QCursor myCursor ( QCursor::WaitCursor );
+      QCursor myCursor ( Qt::WaitCursor );
       QApplication::setOverrideCursor ( myCursor );
       Cache::Thumbs::ImageEntry *pCache = NULL;
       for ( t=0; t<iImgCount; t++ )  {
@@ -456,7 +486,8 @@ void DialogSlideshow::slotKenBurns ( bool bChecked )
             pImg->width  = img.width  ( );
             pImg->height = img.height ( );
             if ( pImg->pMatrix )  {
-              img = img.xForm ( *pImg->pMatrix );
+              //img = img.xForm ( *pImg->pMatrix ); //ooo
+              img = img.transformed ( *pImg->pMatrix ); //xxx
               pImg->width  = img.width  ( );
               pImg->height = img.height ( );
             }
@@ -517,14 +548,17 @@ void DialogSlideshow::slotAnim ( )
   recreatePix ( );
 }
 
-void DialogSlideshow::slotSelectionChanged ( QListViewItem * )
+//void DialogSlideshow::slotSelectionChanged ( Q3ListViewItem * )   //ooo
+void DialogSlideshow::slotSelectionChanged ( QTreeWidgetItem * )    //xxx
 {
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->selectedItem ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->selectedItem ( );   //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->selectedItems ( )[0];     //xxx
   if ( ! pItem )
     return;
 
   QString qsTransitionPath = Global::qsSystemPath + QString ( "/share/qdvdauthor/slideshow/transitions/alpha/" );
-  QString qsFilterName     = pItem->text ( );
+  //QString qsFilterName     = pItem->text ( ); //ooo
+  QString qsFilterName     = pItem->text ( 0 ); //xxx
   QString qsFileName       = qsTransitionPath + qsFilterName + ".jpg";
 
   QFileInfo fileInfo ( qsFileName );
@@ -540,31 +574,38 @@ void DialogSlideshow::slotSelectionChanged ( QListViewItem * )
     return; // E.g. "Cross Fade"
 
   QImage theImage ( qsFileName );
-  theImage = theImage.smoothScale ( m_pLabelPreview->size ( ) );
+  //theImage = theImage.smoothScale ( m_pLabelPreview->size ( ) );						//ooo
+  theImage = theImage.scaled ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
   QPixmap thePix;
   thePix.convertFromImage ( theImage );
-  m_pLabelPreview->setPaletteBackgroundPixmap ( thePix );
+  //m_pLabelPreview->setPaletteBackgroundPixmap ( thePix ); //ooo
+  QPalette palette;							//xxx
+  palette.setBrush(QPalette::Window, QBrush(thePix));		//xxx
+  m_pLabelPreview->setPalette(palette);					//xxx
 
   recreatePix ( );
 }
 
 void DialogSlideshow::recreatePix ( )
 {
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->selectedItem ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->selectedItem ( );   //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->selectedItems ( )[0]; //xxx
   if ( ( ! pItem ) || ( ! m_pSlideshow ) )
     return;
 
   Utils theUtils;
-  QCursor myCursor     ( QCursor::WaitCursor );
+  QCursor myCursor     ( Qt::WaitCursor );
   QApplication::setOverrideCursor ( myCursor );
 
   QString qsTransitionPath = Global::qsSystemPath + QString ( "/share/qdvdauthor/slideshow/transitions/alpha/" );
-  QString qsFilterName     = qsTransitionPath + pItem->text (   ) + ".jpg";
+  //QString qsFilterName     = qsTransitionPath + pItem->text (   ) + ".jpg";   //ooo
+  QString qsFilterName     = qsTransitionPath + pItem->text ( 0 ) + ".jpg";     //xxx
 
   QFileInfo fileInfo ( qsFilterName );
   if ( ! fileInfo.exists ( ) )  {
     qsTransitionPath = Global::qsSystemPath + QString ( "/share/qdvdauthor/slideshow/transitions/luma/" );
-    qsFilterName     = qsTransitionPath + pItem->text (   ) + ".png";
+    //qsFilterName     = qsTransitionPath + pItem->text (   ) + ".png"; //ooo
+    qsFilterName     = qsTransitionPath + pItem->text ( 0 ) + ".png";   //xxx
   }
 
   if ( m_bAnimated )  {
@@ -577,8 +618,10 @@ void DialogSlideshow::recreatePix ( )
       array[t] = new QPixmap ( m_pLabelPreview->size ( ) );
 
     QImage filter ( qsFilterName );
-    QImage start  = QImage::fromMimeSource ( "default.jpg" );
-    QImage stop   = QImage::fromMimeSource (  "splash.jpg" );
+    //QImage start  = QImage::fromMimeSource ( "default.jpg" );		//ooo
+    QImage start  = QImage ( ":/images/default.jpg" );			//xxx
+    //QImage stop   = QImage::fromMimeSource (  "splash.jpg" );		//ooo
+    QImage stop   = QImage ( ":/images/splash.jpg" );			//xxx
     if ( m_pSlideshow->countImg ( ) >= 2 )  {
       CXmlSlideshow::img_struct *pStart = m_pSlideshow->getImg  ( 0 );
       CXmlSlideshow::img_struct *pStop  = m_pSlideshow->getImg  ( 1 );
@@ -599,12 +642,17 @@ void DialogSlideshow::recreatePix ( )
       }
       iDiff = 15;
     }
-    background = background.smoothScale ( m_pLabelPreview->size ( ) );
+    //background = background.smoothScale ( m_pLabelPreview->size ( ) );    //ooo
+    background = background.scaled ( m_pLabelPreview->size ( ) );           //xxx
 
-    filter = filter.smoothScale ( m_pLabelPreview->size ( ) );
-    start  = start.smoothScale  ( m_pLabelPreview->size ( ) );
-    stop   = stop.smoothScale   ( m_pLabelPreview->size ( ) );
-    result = result.smoothScale ( m_pLabelPreview->size ( ) );
+    //filter = filter.smoothScale ( m_pLabelPreview->size ( ) );						//ooo
+    filter = filter.scaled ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    //start  = start.smoothScale  ( m_pLabelPreview->size ( ) );						//ooo
+    start  = start.scaled  ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    //stop   = stop.smoothScale   ( m_pLabelPreview->size ( ) );						//ooo
+    stop   = stop.scaled   ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
+    //result = result.smoothScale ( m_pLabelPreview->size ( ) );						//ooo
+    result   = result.scaled   ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
     fDelta = 512.0f / ( THUMBNAIL_COUNT - iDiff - 1 );
 
     for ( t=0; t<THUMBNAIL_COUNT; t++ )  {
@@ -625,8 +673,12 @@ void DialogSlideshow::recreatePix ( )
     // Simply display the filter and do not use animation.
     QPixmap pix;
     QImage  filter ( qsFilterName );
-    pix.convertFromImage ( filter.smoothScale   ( m_pLabelPreview->size ( ) ) );
-    m_pLabelPreview->setPaletteBackgroundPixmap ( pix );
+    //pix.convertFromImage ( filter.smoothScale   ( m_pLabelPreview->size ( ) ) );						//ooo
+    pix.convertFromImage ( filter.scaled ( m_pLabelPreview->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );	//xxx
+    //m_pLabelPreview->setPaletteBackgroundPixmap ( pix );  //ooo
+    QPalette palette;							//xxx
+    palette.setBrush(QPalette::Window, QBrush(pix));		//xxx
+    m_pLabelPreview->setPalette(palette);					//xxx
   }
   m_iCurrentPix = 0;
 
@@ -643,51 +695,64 @@ void DialogSlideshow::slotAnimatePix ( )
     m_iCurrentPix = -10; // 1 sec pause between each run ...
     return;
   }
-  m_pLabelPreview->setPaletteBackgroundPixmap ( *m_arrayPix[m_iCurrentPix] );
+  //m_pLabelPreview->setPaletteBackgroundPixmap ( *m_arrayPix[m_iCurrentPix] ); //ooo
+  QPalette palette;							//xxx
+  palette.setBrush(QPalette::Window, QBrush(*m_arrayPix[m_iCurrentPix]));		//xxx
+  m_pLabelPreview->setPalette(palette);					//xxx
 }
 
 void DialogSlideshow::slotSelect ( )
 {
   QStringList listEnabled;
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );  //xxx
   while ( pItem )  {
-    if  ( pItem->isOn ( ) )
-      listEnabled.append ( pItem->text ( ) );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    /*if  ( pItem->isOn ( ) )
+      //listEnabled.append ( pItem->text ( ) ); //ooo
+      listEnabled.append ( pItem->text ( 0 ) ); //xxx*/ //oooo
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);	//xxx
   }
 
-  DialogAlphaTrans filterDialog ( listEnabled, this );
+  /*DialogAlphaTrans filterDialog ( listEnabled, this );
   if ( filterDialog.exec ( )  ==  QDialog::Rejected )
-    return;
+    return;*/   //oooo
 
   QString qsName;
   bool    bChecked;
-  pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( );  //ooo
+  pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );  //xxx
   while ( pItem )  {
-    qsName = pItem->text ( );
+    //qsName = pItem->text ( ); //ooo
+    qsName = pItem->text ( 0 ); //xxx
     bChecked = false;
-    if  ( filterDialog.isChecked ( qsName ) )
-      bChecked = true;
-    pItem->setOn ( bChecked );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    /*if  ( filterDialog.isChecked ( qsName ) )
+      bChecked = true;*/    //oooo
+    //pItem->setOn ( bChecked );    //oooo
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);	//xxx
   }
 }
 
 void DialogSlideshow::slotAll ( )
 {
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );  //xxx
   while ( pItem )  {
-    pItem->setOn ( true );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    //pItem->setOn ( true );    //oooo
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);	//xxx
   }
 }
 
 void DialogSlideshow::slotClear ( )
 {
-  QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+  //Q3CheckListItem *pItem = (Q3CheckListItem *)m_pListViewTransitions->firstChild ( ); //ooo
+  QTreeWidgetItem *pItem = (QTreeWidgetItem *)m_pListViewTransitions->topLevelItem ( 0 )->child ( 0 );  //xxx  
   while ( pItem )  {
-    pItem->setOn ( false );
-    pItem = (QCheckListItem *)pItem->nextSibling ( );
+    //pItem->setOn ( false );   //oooo
+    //pItem = (Q3CheckListItem *)pItem->nextSibling ( );    //ooo
+    pItem = (QTreeWidgetItem *)pItem->parent()->child(pItem->parent()->indexOfChild(pItem)+1);	//xxx
   }
 }
 
@@ -700,14 +765,16 @@ void DialogSlideshow::slotImage ( )
     return;
 
   QFileInfo fileInfo ( qsFileName );
-  Global::qsCurrentPath = fileInfo.dirPath ( TRUE );
+  //Global::qsCurrentPath = fileInfo.dirPath ( TRUE );  //ooo
+  Global::qsCurrentPath = fileInfo.path ( );            //xxx
 
   QImage  theImg ( qsFileName );
   QPixmap thePix;
   if ( theImg.isNull ( ) )
     return;
 
-  thePix.convertFromImage ( theImg.smoothScale ( m_pLabelBackground->size ( ), QImage::ScaleFree ) );
+  //thePix.convertFromImage ( theImg.smoothScale ( m_pLabelBackground->size ( ), Qt::IgnoreAspectRatio ) );				//ooo
+  thePix.convertFromImage ( theImg.scaled ( m_pLabelBackground->size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );		//xxx
   m_pLabelBackground->setPixmap ( thePix );
   m_qsBackground = qsFileName;
 }
@@ -730,7 +797,11 @@ void DialogSlideshow::slotColor ( )
 
   QPixmap emptyPix;
   m_pLabelBackground->setPixmap  ( emptyPix );
-  m_pLabelBackground->setBackgroundColor ( theColor );
+  //m_pLabelBackground->setBackgroundColor ( theColor );    //ooo
+  QPalette palette;										//xxx
+  palette.setBrush(m_pLabelBackground->backgroundRole(), theColor);		//xxx
+  m_pLabelBackground->setPalette(palette);								//xxx
+  
   m_qsBackground = theColor.name ( );
 }
 
@@ -744,7 +815,8 @@ void DialogSlideshow::slotAddAudio ( )
 
   m_listAudio += list;
   QFileInfo fileInfo ( list[0] );
-  Global::qsCurrentPath = fileInfo.dirPath ( TRUE );
+  //Global::qsCurrentPath = fileInfo.dirPath ( TRUE );  //ooo
+  Global::qsCurrentPath = fileInfo.path ( );            //xxx
 
   QString   qsAudio;
   QStringList::iterator it = list.begin ( );
@@ -752,7 +824,8 @@ void DialogSlideshow::slotAddAudio ( )
     qsAudio = *it++;
     fileInfo.setFile ( qsAudio );
     qsAudio = fileInfo.fileName ( );
-    m_pListAudio->insertItem    ( qsAudio );
+    //m_pListAudio->insertItem    ( qsAudio );  //ooo
+    m_pListAudio->insertItem    ( 0, qsAudio ); //xxx
   }
 
   createAudioLength ( );
@@ -760,11 +833,13 @@ void DialogSlideshow::slotAddAudio ( )
 
 void DialogSlideshow::slotDeleteAudio ( )
 {
-  QString qsAudio = m_pListAudio->currentText ( );
+  //QString qsAudio = m_pListAudio->currentText ( );    //ooo
+    QString qsAudio = m_pListAudio->currentItem ( )->text ( );  //xxx
   if ( qsAudio.isEmpty ( ) )
     return;
 
-  m_pListAudio->removeItem ( m_pListAudio->currentItem ( ) );
+  //m_pListAudio->removeItem ( m_pListAudio->currentItem ( ) ); //ooo
+  m_pListAudio->removeItemWidget ( m_pListAudio->currentItem ( ) ); //xxx
 
   // The listBox only holds the file name, and not the whole path
   // thus we need to search for the right entry.
@@ -772,8 +847,10 @@ void DialogSlideshow::slotDeleteAudio ( )
   QStringList::iterator it = m_listAudio.begin ( );
   while ( it != m_listAudio.end ( ) )  {
     qsInList = *it++;
-    if ( qsInList.find   ( qsAudio  ) > -1 ) {
-      m_listAudio.remove ( qsInList );
+    //if ( qsInList.find   ( qsAudio  ) > -1 ) {    //ooo
+    if ( qsInList.indexOf   ( qsAudio  ) > -1 ) {   //xxx
+      //m_listAudio.remove ( qsInList );    //ooo
+      m_listAudio.removeOne ( qsInList );   //xxx
       createAudioLength  ( );
       return;
     }
