@@ -1,28 +1,34 @@
-/****************************************************************************
-** Interface to the GUI.
-**
-**   Created : Wed Feb 18 22:48:00 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    dialogtextfont.h
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
 ****************************************************************************/
 
 #ifndef DIALOGTEXTFONT_H
 #define DIALOGTEXTFONT_H
 
-#include <qfont.h>
-#include <qstring.h>
+//#include <qfont.h>	//ooo
+#include <QFont>
+//#include <qstring.h>	//ooo
+#include <QString>
+//Added by qt3to4:
+#include <QResizeEvent>
+#include <QPaintEvent>
 
 // the designer created GUI.
 #include "rgba.h"
-#include "uidialogtextfont.h"
+//#include "uidialogtextfont.h"		//ooo
+#include "ui_uidialogtextfont.h"	//xxx
 
 class QPaintEvent;
 class TextObject;
 
-class DialogTextFont : public uiDialogTextFont
+//class DialogTextFont : public uiDialogTextFont			//ooo
+class DialogTextFont : public QDialog, public Ui::uiDialogTextFont	//xxx
 {
 	Q_OBJECT
 public:
@@ -56,7 +62,8 @@ protected:
 
 protected slots:
 	virtual void resizeEvent ( QResizeEvent * );
-	virtual void slotFontFamilyChanged ( int  );
+	//virtual void slotFontFamilyChanged ( int  );	//ooo
+	virtual void slotFontFamilyChanged (   );	//xxx
 	virtual void slotFontStyleChanged  ( int  );
 	virtual void slotFontSizeChanged   ( int  );
 	virtual void slotFontSizeChanged   ( const QString & );
