@@ -11,14 +11,23 @@
 #include <qlabel.h>
 #include <qslider.h>
 #include <qdialog.h>
-#include <qlistbox.h>
-#include <qgroupbox.h>
+//#include <q3listbox.h>    //ooo
+#include <QListWidget>  //xxx
+//#include <q3groupbox.h>   //ooo
+#include <QGroupBox> //xxx
 #include <qfileinfo.h>
-#include <qiconview.h>
+//#include <q3iconview.h>   //ooo
+#include <QGraphicsView>        //xxx
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qpushbutton.h>
-#include <qprogressbar.h>
+//#include <q3progressbar.h>    //ooo
+#include <QProgressBar>  //xxx
+//Added by qt3to4:
+#include <QTimerEvent>
+//#include <Q3ValueList>	//oxx
+#include <QPixmap>
+#include <QMessageBox>		//xxx
 
 #include "global.h"
 #include "utils.h"
@@ -34,7 +43,8 @@
 DialogThumbnail::TextAttr  DialogThumbnail::m_textAttr  = TextAttr  ( );
 DialogThumbnail::FrameAttr DialogThumbnail::m_frameAttr = FrameAttr ( );
 
-DialogThumbnail::ThumbnailRequest::ThumbnailRequest ( DialogThumbnail *pDialog, QIconViewItem *pItem, QString qsFile, long iOffset )
+//DialogThumbnail::ThumbnailRequest::ThumbnailRequest ( DialogThumbnail *pDialog, Q3IconViewItem *pItem, QString qsFile, long iOffset ) //ooo
+DialogThumbnail::ThumbnailRequest::ThumbnailRequest ( DialogThumbnail *pDialog, QListWidgetItem *pItem, QString qsFile, long iOffset )   //xxx
   : ExecuteJob ( pDialog )
 {
   pImage          = new QImage;
@@ -62,7 +72,8 @@ bool DialogThumbnail::ThumbnailRequest::response ( )
   return true;
 }
 
-DialogThumbnail::WorkWaiting::WorkWaiting ( QIconViewItem *pViewItem, QImage *pImg, QString qsFile )
+//DialogThumbnail::WorkWaiting::WorkWaiting ( Q3IconViewItem *pViewItem, QImage *pImg, QString qsFile ) //ooo
+DialogThumbnail::WorkWaiting::WorkWaiting ( QListWidgetItem *pViewItem, QImage *pImg, QString qsFile )   //xxx
 {
   pItem      = pViewItem;
   pImage     = pImg;
@@ -76,9 +87,12 @@ DialogThumbnail::WorkWaiting::~WorkWaiting ( )
 };
 
 
-DialogThumbnail::DialogThumbnail ( QDVDAuthor *pDVDAuthor, const char *pName, WFlags f )
-  : uiDialogThumbnail ( pDVDAuthor, pName, f )
+//DialogThumbnail::DialogThumbnail ( QDVDAuthor *pDVDAuthor, const char *pName, Qt::WFlags f )		//ooo
+DialogThumbnail::DialogThumbnail ( QWidget *pParent )							//xxx
+  //: uiDialogThumbnail ( pDVDAuthor, pName, f )	//ooo
+  : QDialog ( pParent )					//xxx
 {
+  setupUi(this);		//xxx
   m_pSourceFileInfo  = NULL;
   m_pSourceFileEntry = NULL;
   m_iCurrentChapter  = 0;
@@ -99,8 +113,10 @@ DialogThumbnail::DialogThumbnail ( QDVDAuthor *pDVDAuthor, const char *pName, WF
   connect ( m_pSliderSize,      SIGNAL ( sliderPressed    ( ) ), this, SLOT ( slotSizePressed   ( ) ) );
   connect ( m_pSliderSize,      SIGNAL ( sliderReleased   ( ) ), this, SLOT ( slotSizeReleased  ( ) ) );
   connect ( m_pSliderSpace,     SIGNAL ( sliderReleased   ( ) ), this, SLOT ( slotSpaceReleased ( ) ) );
-  connect ( m_pListBoxChapters, SIGNAL ( currentChanged   ( QListBoxItem * ) ), 
-	    this, SLOT ( slotChapterChanged( QListBoxItem * ) ) );
+  //connect ( m_pListBoxChapters, SIGNAL ( currentChanged   ( Q3ListBoxItem * ) ),  //ooo
+  connect ( m_pListBoxChapters, SIGNAL ( currentChanged   ( QListWidgetItem * ) ),    //xxx
+	    //this, SLOT ( slotChapterChanged( Q3ListBoxItem * ) ) );  //ooo
+        this, SLOT ( slotChapterChanged( QListWidgetItem * ) ) );
 }
 
 DialogThumbnail::~DialogThumbnail ( )
@@ -110,7 +126,7 @@ DialogThumbnail::~DialogThumbnail ( )
   if ( m_pSourceFileInfo )
     MediaCreator::unregisterFromMediaScanner ( m_pSourceFileInfo );
   if ( m_pSourceFileEntry )  {
-    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
     SourceFileInfo *pInfo;
     while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
       pInfo = *it++;
@@ -132,7 +148,7 @@ int DialogThumbnail::chapterCount ( )
   if ( m_pSourceFileInfo )
    i = m_pSourceFileInfo->listChapters.count ( );
   if ( m_pSourceFileEntry )  {
-    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
     SourceFileInfo *pInfo;
     while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
       pInfo = *it++;
@@ -156,7 +172,7 @@ QString DialogThumbnail::chapter ( int iChapterNumber )
   }
   if ( m_pSourceFileEntry )  {
     int i=0;
-    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
     SourceFileInfo *pInfo;
     while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
       pInfo = *it++;
@@ -176,7 +192,7 @@ SourceFileInfo *DialogThumbnail::getInfoFromChapterNumber ( int iChapterNumber )
     return m_pSourceFileInfo;
   if ( m_pSourceFileEntry )  {
     int i=0;
-    QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+    QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
     SourceFileInfo *pInfo;
     while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
       pInfo = *it++;
@@ -200,7 +216,7 @@ int DialogThumbnail::getChapterNumberFromKey ( QString qsKey )
   QFileInfo fileInfo;
   int t, i=0;
 
-  QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
   SourceFileInfo *pInfo;
   while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {
     pInfo = *it++;
@@ -221,7 +237,8 @@ int DialogThumbnail::getChapterNumberFromKey ( QString qsKey )
 
 void DialogThumbnail::show ( )
 {
-  uiDialogThumbnail::show ( );
+  //uiDialogThumbnail::show ( );	//ooo
+  QDialog::show ( );			//xxx
   if ( Global::pApp ) {
     DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
     DVDMenu *pDVDMenu = Global::pApp->getVMGMenu ( );
@@ -247,7 +264,8 @@ void DialogThumbnail::initSourceFileEntry ( SourceFileEntry *pEntry )
   if ( ! pEntry )
     return;
 
-  setCaption ( QString ( "Thumbnail Dialog : " ) + pEntry->qsDisplayName );
+  //setCaption ( QString ( "Thumbnail Dialog : " ) + pEntry->qsDisplayName );   //ooo
+  setWindowTitle ( QString ( "Thumbnail Dialog : " ) + pEntry->qsDisplayName ); //xxx
   m_pSourceFileInfo  = NULL;
   m_pSourceFileEntry = pEntry;
 
@@ -257,7 +275,7 @@ void DialogThumbnail::initSourceFileEntry ( SourceFileEntry *pEntry )
   QFileInfo fileInfo;
   QString qsChapter;
 
-  QValueList<SourceFileInfo *>::iterator it = pEntry->listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = pEntry->listFileInfos.begin ( );	//oxx
   while ( it != pEntry->listFileInfos.end ( ) )  {
     pInfo = *it++;
     fileInfo.setFile ( pInfo->qsFileName );
@@ -269,8 +287,10 @@ void DialogThumbnail::initSourceFileEntry ( SourceFileEntry *pEntry )
     }
   }
 
-  m_pListBoxChapters->insertStringList ( listChapters );
-  m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 );
+  //m_pListBoxChapters->insertStringList ( listChapters );  //ooo
+  m_pListBoxChapters->insertItems ( 0, listChapters );    //xxx
+  //m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 ); //ooo
+  m_pProgressBar->setMaximum ( pInfo->listChapters.count( ) - 1 );   //xxx
 
   refreshEntry ( true );
 }
@@ -284,12 +304,15 @@ void DialogThumbnail::initSourceFileInfo ( SourceFileInfo *pInfo, QString &qsAct
     return;
 
   QFileInfo   fileInfo ( pInfo->qsFileName );
-  setCaption ( QString ( "Thumbnail Dialog : " ) + fileInfo.fileName ( ) );
+  //setCaption ( QString ( "Thumbnail Dialog : " ) + fileInfo.fileName ( ) );   //ooo
+  setWindowTitle ( QString ( "Thumbnail Dialog : " ) + fileInfo.fileName ( ) ); //xxx
   m_pSourceFileInfo  = pInfo;
   m_pSourceFileEntry = NULL;
   m_qsActionString   = qsAction;
-  m_pListBoxChapters->insertStringList ( pInfo->listChapters );
-  m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 );
+  //m_pListBoxChapters->insertStringList ( pInfo->listChapters );   //ooo
+  m_pListBoxChapters->insertItems ( 0, pInfo->listChapters ); //xxx
+  //m_pProgressBar->setTotalSteps ( pInfo->listChapters.count( ) - 1 ); //ooo
+  m_pProgressBar->setMaximum ( pInfo->listChapters.count( ) - 1 );   //xxx
 
   slotRefresh ( );
 }
@@ -300,7 +323,7 @@ void DialogThumbnail::timerEvent ( QTimerEvent *pEvent )
     if ( pEvent->timerId ( ) == MEDIASCANNER_EVENT + 4 ) {
       int t;
       WorkWaiting *pWork;
-      QValueList<WorkWaiting *> tempList;
+      QList<WorkWaiting *> tempList;		//oxx
       // to decrease threading issues, we quickly remove the used Work objects from the member list.
       for ( t=0;t<(int)m_listOfWorkToDo.count ( ); t++ ) {
         pWork = m_listOfWorkToDo [ t ];
@@ -312,16 +335,21 @@ void DialogThumbnail::timerEvent ( QTimerEvent *pEvent )
         pWork = tempList [ t ];
         updateItem ( pWork->pItem, pWork->pImage, pWork->qsFileName );
         delete pWork;
-        m_pProgressBar->setProgress ( m_iProgress ++ );
+        //m_pProgressBar->setProgress ( m_iProgress ++ );   //ooo
+        m_pProgressBar->setValue ( m_iProgress ++ );    //xxx
       }
-      if ( (int)m_iProgress >= m_pProgressBar->totalSteps ( )-2 )
-        m_pIconViewThumbnails->arrangeItemsInGrid ( TRUE );
+      //if ( (int)m_iProgress >= m_pProgressBar->totalSteps ( )-2 ) //ooo
+      if ( (int)m_iProgress >= m_pProgressBar->maximum ( )-2 )   //xxx
+        //m_pIconViewThumbnails->arrangeItemsInGrid ( TRUE );   //ooo
+        m_pIconViewThumbnails->sortItems ( Qt::AscendingOrder );      //xxx
     }
   }
-  uiDialogThumbnail::timerEvent ( pEvent );
+  //uiDialogThumbnail::timerEvent ( pEvent );	//ooo
+  QDialog::timerEvent ( pEvent );		//xxx
 }
 
-void DialogThumbnail::initWork ( QIconViewItem *pItem, QImage *pImage, QString qsFile )
+//void DialogThumbnail::initWork ( Q3IconViewItem *pItem, QImage *pImage, QString qsFile )  //ooo
+void DialogThumbnail::initWork ( QListWidgetItem *pItem, QImage *pImage, QString qsFile )    //xxx
 {
   WorkWaiting *pNewWork = new WorkWaiting ( pItem, pImage, qsFile );
   m_listOfWorkToDo.append ( pNewWork );
@@ -337,11 +365,13 @@ DialogThumbnail::FrameAttr *DialogThumbnail::frameAttr ( )
   return &m_frameAttr;
 }
 
-QString DialogThumbnail::getChapter ( QIconViewItem *pItem )
+//QString DialogThumbnail::getChapter ( Q3IconViewItem *pItem ) //ooo
+QString DialogThumbnail::getChapter ( QListWidgetItem *pItem )   //xxx
 {
   QString qsChapter;
   if ( pItem )  {
-    QStringList list = QStringList::split ( STRING_SEPARATOR, pItem->key ( ) );
+    //QStringList list = QStringList::split ( STRING_SEPARATOR, pItem->key ( ) );   //ooo
+    QStringList list = pItem->data ( Qt::UserRole ).value<QString>().split ( STRING_SEPARATOR );   //xxx
     if ( list.count ( ) > 0 )
       qsChapter = list[ list.size ( ) - 1 ];
     else
@@ -350,7 +380,8 @@ QString DialogThumbnail::getChapter ( QIconViewItem *pItem )
   return  qsChapter;
 }
 
-bool DialogThumbnail::updateItem ( QIconViewItem *pItem, QImage *pImage, QString qsFile )
+//bool DialogThumbnail::updateItem ( Q3IconViewItem *pItem, QImage *pImage, QString qsFile )    //ooo
+bool DialogThumbnail::updateItem ( QListWidgetItem *pItem, QImage *pImage, QString qsFile )  //xxx
 {
   if ( ! pImage )
     return false;
@@ -373,29 +404,33 @@ bool DialogThumbnail::updateItem ( QIconViewItem *pItem, QImage *pImage, QString
     return false;
 
   QPixmap thePixmap;
-  QImage::ScaleMode scaleMode = QImage::ScaleMin;
+  Qt::AspectRatioMode scaleMode = Qt::KeepAspectRatio;
   if ( m_iThumbnailStretchMode ==  1 )
-    scaleMode = QImage::ScaleMax;
+    scaleMode = Qt::KeepAspectRatioByExpanding;
   if ( m_iThumbnailStretchMode ==  2 )
-    scaleMode = QImage::ScaleFree;  
+    scaleMode = Qt::IgnoreAspectRatio;  
 
-  *pImage = pImage->smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );
+  //*pImage = pImage->smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode ); //ooo
+  *pImage = pImage->scaled ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );   //xxx
   if ( thePixmap.convertFromImage ( *pImage ) )
-    pItem->setPixmap ( thePixmap );
+    //pItem->setPixmap ( thePixmap );   //ooo
+    pItem->setIcon ( thePixmap ); //xxx
 
   return true;
 }
 
 bool DialogThumbnail::getBufferedThumbnail ( )
 {
-  QIconViewItem *pItem = NULL;
+  //Q3IconViewItem *pItem = NULL;   //ooo
+  QListWidgetItem *pItem = NULL; //xxx
 
   while ( (int)m_iCurrentChapter < chapterCount ( ) ) {
     pItem = createCurrentItem ( false );
     if ( ! pItem )
       return true;
 
-    m_pProgressBar->setProgress ( m_iProgress );
+    //m_pProgressBar->setProgress ( m_iProgress );  //ooo
+    m_pProgressBar->setValue ( m_iProgress );    //xxx
     m_iCurrentChapter ++;
   }
   return false;
@@ -421,11 +456,14 @@ void DialogThumbnail::slotFont ( )
 {
   DialogFont fontDialog ( this );
   QString qsText ( "No Text" );
-  if ( m_pComboTextType->currentItem ( ) == 0 )
+  //if ( m_pComboTextType->currentItem ( ) == 0 )   //ooo
+  if ( m_pComboTextType->currentIndex ( ) == 0 ) //xxx
     qsText = "00:00:00.000";
-  else if ( m_pComboTextType->currentItem ( ) == 1 )
+  //else if ( m_pComboTextType->currentItem ( ) == 1 )  //ooo
+  else if ( m_pComboTextType->currentIndex ( ) == 1 )    //xxx
     qsText = "00:00:00";
-  else if ( m_pComboTextType->currentItem ( ) == 2 )
+  //else if ( m_pComboTextType->currentItem ( ) == 2 )  //ooo
+  else if ( m_pComboTextType->currentIndex ( ) == 2 )    //xxx
     qsText = "Chapter 1";
 
   fontDialog.initMe     ( qsText );
@@ -443,14 +481,17 @@ void DialogThumbnail::slotFont ( )
 
 void DialogThumbnail::slotTextType ( int iNewTextType )
 {
-  QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
+  //Q3IconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );   //ooo
+  QListWidgetItem *pItem = m_pIconViewThumbnails->item ( 0 );     //xxx
   while ( pItem ) {
     setItemText ( pItem, iNewTextType );
-    pItem = pItem->nextItem ( );
+    //pItem = pItem->nextItem ( );  //ooo
+    pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem)+1 );  //xxx
   }
 }
 
-void DialogThumbnail::setItemText ( QIconViewItem *pItem, int iTextType )
+//void DialogThumbnail::setItemText ( Q3IconViewItem *pItem, int iTextType )    //ooo
+void DialogThumbnail::setItemText ( QListWidgetItem *pItem, int iTextType )  //xxx
 {
   // we support 4 different tet types
   // 0 == Timestamp          E.g. "00:00:00.000"
@@ -477,7 +518,8 @@ void DialogThumbnail::setItemText ( QIconViewItem *pItem, int iTextType )
       }
     }
     if ( m_pSourceFileEntry )  {
-      int  t = getChapterNumberFromKey ( pItem->key ( ) );
+      //int  t = getChapterNumberFromKey ( pItem->key ( ) );    //ooo
+      int  t = getChapterNumberFromKey ( pItem->data ( Qt::UserRole ).value<QString>() );     //xxx
       qsText = QString (  "Chapter %1" ).arg  ( t + 1 );
     }
   }
@@ -530,7 +572,8 @@ void DialogThumbnail::slotSizeChanged ( int iNewSize )
   m_pEditHeight->setText ( QString ( "%1" ).arg ( (int)fHeight ) );
 }
 
-void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
+//void DialogThumbnail::slotChapterChanged ( Q3ListBoxItem *pListBoxItem )  //ooo
+void DialogThumbnail::slotChapterChanged ( QListWidgetItem *pListBoxItem )    //xxx
 {
   // Called when te user selects items in the ListBox on the left hand side.
   if ( ! pListBoxItem )
@@ -541,15 +584,18 @@ void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
 
   int t;
   QString qsChapter    = pListBoxItem->text ( );
-  QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
+  //Q3IconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );   //ooo
+  QListWidgetItem *pItem = m_pIconViewThumbnails->item ( 0 ); //xxx
   // First we ensure the current item is visible
   while ( pItem ) {
     if  ( getChapter ( pItem ) == qsChapter ) {
       m_pIconViewThumbnails->clearSelection    ( );
-      m_pIconViewThumbnails->ensureItemVisible ( pItem );
+      //m_pIconViewThumbnails->ensureItemVisible ( pItem ); //ooo
+      m_pIconViewThumbnails->scrollToBottom ( );   //xxx
       break;
     }
-    pItem = pItem->nextItem ( );
+    //pItem = pItem->nextItem ( );  //ooo
+    pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem)+1 );  //xxx
   }
 
   // Next we loop through the ListBox and find each 
@@ -561,21 +607,25 @@ void DialogThumbnail::slotChapterChanged ( QListBoxItem *pListBoxItem )
 //printf ( "DialogThumbnail::chapterChanged <%p>\n", pListBoxItem );
       // Okay, and for this selected ListBox item, we find the 
       // associciated IconViewItem and do also sect it.
-      pItem = m_pIconViewThumbnails->firstItem ( );
+      //pItem = m_pIconViewThumbnails->firstItem ( );   //ooo
+      pItem = m_pIconViewThumbnails->item ( 0 );    //xxx
       // First we ensure the current item is visible
       while ( pItem ) {
         if  ( getChapter ( pItem ) == qsChapter ) {
-          m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
+          //m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );   //ooo
+          m_pIconViewThumbnails->setCurrentItem ( pItem );     //xxx
           pItem = NULL;
         }
         else
-          pItem = pItem->nextItem ( );
+          //pItem = pItem->nextItem ( );    //xxx
+          pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem)+1 );  //xxx
       }
     }
   }
 }
 
-void DialogThumbnail::chapterChanged ( QListBoxItem *pListBoxItem )
+//void DialogThumbnail::chapterChanged ( Q3ListBoxItem *pListBoxItem )  //ooo
+void DialogThumbnail::chapterChanged ( QListWidgetItem *pListBoxItem )    //xxx
 {
   // Called when te user selects items in the ListBox on the left hand side.
   if ( ! pListBoxItem )
@@ -583,33 +633,40 @@ void DialogThumbnail::chapterChanged ( QListBoxItem *pListBoxItem )
   // This function handles SourceFileEntries
   // key = 00:00:00.000 : FileName.mpg
 
-  QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );
+  //QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );    //ooo
+  QStringList list = pListBoxItem->text ( ).split ( " : " );    //xxx
   if ( list.count ( ) == 2 )  {
     QString qsChapter, qsFileName, qsSearchKey;
     qsChapter   = list[0];
     qsFileName  = list[1];
     qsSearchKey = QString ( "jump+-+%1+-+%2+-+%3" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( qsFileName ).arg ( qsChapter );
 
-    QIconViewItem *pItem = m_pIconViewThumbnails->firstItem ( );
+    //Q3IconViewItem *pItem = m_pIconViewThumbnails->firstItem ( ); //ooo
+    QListWidgetItem *pItem = m_pIconViewThumbnails->item ( 0 );   //xxx
     // First we ensure the current item is visible
     while ( pItem ) {
-      if  ( pItem->key ( ) == qsSearchKey )  {
+      //if  ( pItem->key ( ) == qsSearchKey )  {    //ooo
+      if  ( pItem->data ( Qt::UserRole ).value<QString>() == qsSearchKey )  {  //xxx
         m_pIconViewThumbnails->clearSelection    ( );
-        m_pIconViewThumbnails->ensureItemVisible ( pItem );
+        //m_pIconViewThumbnails->ensureItemVisible ( pItem );   //ooo
+        m_pIconViewThumbnails->scrollToBottom ( );  //xxx
         //m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
         break;
       }
-      pItem = pItem->nextItem ( );
+      //pItem = pItem->nextItem ( );    //ooo
+      pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem)+1 );  //xxx
     }
   }
 
   // Next we loop through the ListBox and find each 
   // chapter that has been selected (multiple selection)
-  QIconViewItem *pItem = NULL;
+  //Q3IconViewItem *pItem = NULL;   //ooo
+  QListWidgetItem *pItem = NULL; //xxx
   for ( int t=0;t<(int)m_pListBoxChapters->count ( ); t++ ) {
     pListBoxItem = m_pListBoxChapters->item ( t );
     if ( pListBoxItem && pListBoxItem->isSelected ( ) ) {
-      QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );
+      //QStringList list = QStringList::split ( " : ", pListBoxItem->text ( ) );    //ooo
+      QStringList list = pListBoxItem->text ( ).split ( " : " );    //xxx
       if ( list.count ( ) == 2 )  {
         QString qsChapter, qsFileName, qsSearchKey;
         qsChapter   = list[0];
@@ -618,15 +675,19 @@ void DialogThumbnail::chapterChanged ( QListBoxItem *pListBoxItem )
 
         // Okay, and for this selected ListBox item, we find the 
         // associciated IconViewItem and do also sect it.
-        pItem = m_pIconViewThumbnails->firstItem ( );
+        //pItem = m_pIconViewThumbnails->firstItem ( ); //ooo
+        pItem = m_pIconViewThumbnails->item ( 0 );   //xxx
         // First we ensure the current item is visible
         while ( pItem ) {
-          if  ( pItem->key ( ) == qsSearchKey  ) {
-            m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE );
+          //if  ( pItem->key ( ) == qsSearchKey  ) {    //ooo
+          if  ( pItem->data ( Qt::UserRole ).value<QString>() == qsSearchKey  ) {  //xxx
+            //m_pIconViewThumbnails->setSelected ( pItem, TRUE, TRUE ); //ooo
+            m_pIconViewThumbnails->setCurrentItem ( pItem );   //xxx
             pItem = NULL;
           }
           else
-            pItem = pItem->nextItem ( );
+            //pItem = pItem->nextItem ( );  //ooo
+            pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem)+1 );  //xxx
         }
       }
     }
@@ -668,7 +729,8 @@ void DialogThumbnail::refresh ( bool bForceReload )
   if ( ! bOkay )
     m_iThumbnailHeight = 120;
 
-  m_iThumbnailStretchMode = m_pComboStretch->currentItem ( );
+  //m_iThumbnailStretchMode = m_pComboStretch->currentItem ( ); //oooo
+  m_iThumbnailStretchMode = m_pComboStretch->currentIndex ( );   //xxx
 
   while ( (int)m_iCurrentChapter < iChapterCount ) {
     if  ( bForceReload || getBufferedThumbnail ( ) ) {
@@ -679,7 +741,8 @@ void DialogThumbnail::refresh ( bool bForceReload )
 
       Utils theUtils;
       long  iMSecOffset    = theUtils.getMsFromString ( chapter ( m_iCurrentChapter ) );
-      QIconViewItem *pItem = createCurrentItem ( true );
+      //Q3IconViewItem *pItem = createCurrentItem ( true ); //ooo
+      QListWidgetItem *pItem = createCurrentItem ( true );   //xxx
 
       pRequest = new ThumbnailRequest ( this, pItem, pInfo->qsFileName, iMSecOffset );
       MediaCreator::registerWithMediaScanner ( pRequest );
@@ -687,8 +750,10 @@ void DialogThumbnail::refresh ( bool bForceReload )
       m_iCurrentChapter ++; // Also every requested thumbnail should increase the currentCHapter counter.
     }
   }
-  m_pProgressBar->setProgress ( m_iProgress );
-  int iTextType = m_pComboTextType->currentItem ( );
+  //m_pProgressBar->setProgress ( m_iProgress );    //ooo
+  m_pProgressBar->setValue ( m_iProgress );  //xxx
+  //int iTextType = m_pComboTextType->currentItem ( );  //ooo
+  int iTextType = m_pComboTextType->currentIndex ( );    //xxx
   slotTextType ( iTextType );
 }
 
@@ -721,9 +786,10 @@ void DialogThumbnail::refreshEntry ( bool bForceReload )
   if ( ! bOkay )
     m_iThumbnailHeight = 120;
 
-  m_iThumbnailStretchMode = m_pComboStretch->currentItem ( );
+  //m_iThumbnailStretchMode = m_pComboStretch->currentItem ( ); //oooo
+  m_iThumbnailStretchMode = m_pComboStretch->currentIndex ( );   //xxx
 
-  QValueList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = m_pSourceFileEntry->listFileInfos.begin ( );		//oxx
   SourceFileInfo *pInfo;
   while ( it != m_pSourceFileEntry->listFileInfos.end ( ) )  {  //m_iCurrentChapter < iChapterCount ) {
     pInfo = *it++;
@@ -736,7 +802,8 @@ void DialogThumbnail::refreshEntry ( bool bForceReload )
         //pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
 
         long iMSecOffset = theUtils.getMsFromString (               pInfo->listChapters [ t ] );
-        QIconViewItem *pItem = createCurrentItem    (  pInfo, true, pInfo->listChapters [ t ] );
+        //Q3IconViewItem *pItem = createCurrentItem    (  pInfo, true, pInfo->listChapters [ t ] ); //ooo
+        QListWidgetItem *pItem = createCurrentItem    (  pInfo, true, pInfo->listChapters [ t ] );   //xxx
         pRequest = new ThumbnailRequest ( this, pItem, pInfo->qsFileName, iMSecOffset );
         MediaCreator::registerWithMediaScanner ( pRequest );
         m_iProgress --;       // for every requeste thumbnail we decrease the progress.
@@ -744,31 +811,37 @@ void DialogThumbnail::refreshEntry ( bool bForceReload )
       }
     }
   }
-  m_pProgressBar->setProgress ( m_iProgress );
-  int iTextType = m_pComboTextType->currentItem ( );
+  //m_pProgressBar->setProgress ( m_iProgress );    //ooo
+  m_pProgressBar->setValue ( m_iProgress );  //xxx
+  //int iTextType = m_pComboTextType->currentItem ( );  //oooo
+  int iTextType = m_pComboTextType->currentIndex ( );    //xxx
   slotTextType ( iTextType );
 }
 
-QIconViewItem *DialogThumbnail::createCurrentItem ( bool bPleaseWait )
+//Q3IconViewItem *DialogThumbnail::createCurrentItem ( bool bPleaseWait )   //ooo
+QListWidgetItem *DialogThumbnail::createCurrentItem ( bool bPleaseWait ) //xxx
 {
   SourceFileInfo *pInfo = getInfoFromChapterNumber ( m_iCurrentChapter );
   return createCurrentItem ( pInfo, bPleaseWait, chapter ( m_iCurrentChapter ) );
 }
 
-QIconViewItem *DialogThumbnail::createCurrentItem ( SourceFileInfo *pInfo, bool bPleaseWait, QString qsChapter )
+//Q3IconViewItem *DialogThumbnail::createCurrentItem ( SourceFileInfo *pInfo, bool bPleaseWait, QString qsChapter ) //ooo
+QListWidgetItem *DialogThumbnail::createCurrentItem ( SourceFileInfo *pInfo, bool bPleaseWait, QString qsChapter )   //xxx
 {
-  QIconViewItem *pItem   = NULL;
+  //Q3IconViewItem *pItem   = NULL; //ooo
+  QListWidgetItem *pItem   = NULL;   //xxx
   QImage  theImage;
   QString qsActionString = m_qsActionString;
 
-  QImage::ScaleMode scaleMode = QImage::ScaleMin;
+  Qt::AspectRatioMode scaleMode = Qt::KeepAspectRatio;
   if ( m_iThumbnailStretchMode ==  1 )
-    scaleMode = QImage::ScaleMax;
+    scaleMode = Qt::KeepAspectRatioByExpanding;
   if ( m_iThumbnailStretchMode ==  2 )
-    scaleMode = QImage::ScaleFree;
+    scaleMode = Qt::IgnoreAspectRatio;
 
   if ( bPleaseWait )
-    theImage = QImage ( QImage ( ).fromMimeSource ( "please_wait.jpg" ) );
+    //theImage = QImage ( QImage ( ).fromMimeSource ( "please_wait.jpg" ) );	//ooo
+    theImage = QImage ( QImage ( ":/images/please_wait.jpg" ) );		//xxx
   else if ( pInfo )  {
     Utils     theUtils;
     QString   qsFileName, qsBaseName, qsFNChapter;
@@ -792,13 +865,17 @@ QIconViewItem *DialogThumbnail::createCurrentItem ( SourceFileInfo *pInfo, bool
     qsActionString = QString ( "jump+-+%1+-+%2+-+" ).arg ( m_pSourceFileEntry->qsDisplayName ).arg ( fileInfo.fileName ( ) );
   }
 
-  theImage  = theImage.smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );
-  pItem     = new QIconViewItem    ( m_pIconViewThumbnails, qsChapter );
+  //theImage  = theImage.smoothScale ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );  //ooo
+  theImage  = theImage.scaled ( m_iThumbnailWidth, m_iThumbnailHeight, scaleMode );    //xxx
+  //pItem     = new Q3IconViewItem    ( m_pIconViewThumbnails, qsChapter ); //ooo
+  pItem     = new QListWidgetItem    ( qsChapter, m_pIconViewThumbnails );   //xxx
   if ( pItem ) {
     QPixmap thePixmap;
     if ( thePixmap.convertFromImage ( theImage ) ) {
-      pItem->setPixmap ( thePixmap );
-      pItem->setKey    ( qsActionString + qsChapter );
+      //pItem->setPixmap ( thePixmap ); //ooo
+      pItem->setIcon ( thePixmap );   //xxx
+      //pItem->setKey    ( qsActionString + qsChapter );    //oooo
+      pItem->setText    ( qsActionString + qsChapter ); //xxx
     }
   }
   return pItem;
