@@ -15,24 +15,33 @@
 #include <qimage.h>
 
 #include "qplayer/mediascanner.h"
-#include "uidialogthumbnail.h"
+//Added by qt3to4:
+//#include <Q3ValueList>		//oxx
+#include <QTimerEvent>
+#include <QTreeWidget>  //xxx
+#include <QListWidget>  //xxx
+//#include "uidialogthumbnail.h"	//ooo
+#include "ui_uidialogthumbnail.h"	//xxx
 
 class QDVDAuthor;
 class SourceFileInfo;
 class SourceFileEntry;
 
-class DialogThumbnail : public uiDialogThumbnail
+//class DialogThumbnail : public uiDialogThumbnail			//ooo
+class DialogThumbnail : public QDialog, public Ui::uiDialogThumbnail	//xxx
 {
   Q_OBJECT
 
   class ThumbnailRequest : public ExecuteJob {
   public:
-    ThumbnailRequest ( DialogThumbnail *, QIconViewItem *, QString, long );
+    //ThumbnailRequest ( DialogThumbnail *, Q3IconViewItem *, QString, long );  //ooo
+    ThumbnailRequest ( DialogThumbnail *, QListWidgetItem *, QString, long );    //xxx
     virtual ~ThumbnailRequest ( );
 
     virtual bool response ( );
 
-    QIconViewItem   *pOwnerItem;
+    //Q3IconViewItem   *pOwnerItem; //ooo
+    QListWidgetItem   *pOwnerItem;   //xxx
     DialogThumbnail *pParent;
   };
   // When the image is rendered the returned data is temp stored in this struct
@@ -40,10 +49,12 @@ class DialogThumbnail : public uiDialogThumbnail
   class WorkWaiting
   {
   public:
-     WorkWaiting ( QIconViewItem *, QImage *, QString );
+     //WorkWaiting ( Q3IconViewItem *, QImage *, QString ); //ooo
+     WorkWaiting ( QListWidgetItem *, QImage *, QString );
     ~WorkWaiting ( );
 
-    QIconViewItem *pItem;
+    //Q3IconViewItem *pItem;    //ooo
+    QListWidgetItem *pItem;  //xxx
     QImage        *pImage;
     QString        qsFileName;
   };
@@ -72,13 +83,16 @@ class DialogThumbnail : public uiDialogThumbnail
   };
 
 public:
-  DialogThumbnail ( QDVDAuthor *p=NULL, const char *n=0, WFlags f=0 );
+  //DialogThumbnail ( QDVDAuthor *p=NULL, const char *n=0, Qt::WFlags f=0 );	//ooo
+  DialogThumbnail ( QWidget *pParent = 0);					//xxx
   virtual ~DialogThumbnail ( );
 
   void initSourceFileEntry( SourceFileEntry * );
   void initSourceFileInfo ( SourceFileInfo  *, QString & );
-  void initWork           ( QIconViewItem   *, QImage  *, QString );
-  bool updateItem         ( QIconViewItem   *, QImage  *, QString );
+  //void initWork           ( Q3IconViewItem   *, QImage  *, QString ); //ooo
+  void initWork           ( QListWidgetItem   *, QImage  *, QString );//xxx
+  //bool updateItem         ( Q3IconViewItem   *, QImage  *, QString ); //ooo
+  bool updateItem         ( QListWidgetItem   *, QImage  *, QString );   //xxx
   virtual void show           ( );
 
   static TextAttr  *textAttr  ( );
@@ -95,7 +109,8 @@ protected slots:
   virtual void slotTextType      ( int );
   virtual void slotSizeChanged   ( int );
   virtual void slotSpaceChanged  ( int );
-  virtual void slotChapterChanged( QListBoxItem * );
+  //virtual void slotChapterChanged( Q3ListBoxItem * ); //ooo
+  virtual void slotChapterChanged( QListWidgetItem * );   //xxx
 
 protected:
   virtual void timerEvent ( QTimerEvent * );
@@ -103,15 +118,20 @@ protected:
   bool    getBufferedThumbnail        (      );
   void    refresh                     ( bool );
   void    refreshEntry                ( bool );
-  void    setItemText ( QIconViewItem *, int );
-  QString getChapter  ( QIconViewItem *      );
-  QIconViewItem *createCurrentItem    ( bool );
-   QIconViewItem *createCurrentItem    ( SourceFileInfo *, bool, QString );
+  //void    setItemText ( Q3IconViewItem *, int );  //ooo
+  void    setItemText ( QListWidgetItem *, int );    //xxx
+  //QString getChapter  ( Q3IconViewItem *      );  //ooo
+  QString getChapter  ( QListWidgetItem *      );    //xxx
+  //Q3IconViewItem *createCurrentItem    ( bool );  //ooo
+  QListWidgetItem *createCurrentItem    ( bool );    //xxx
+  //Q3IconViewItem *createCurrentItem    ( SourceFileInfo *, bool, QString );   //ooo
+  QListWidgetItem *createCurrentItem    ( SourceFileInfo *, bool, QString ); //xxx
 
   // Replacement for SourceFileInfo / SourceFileEntry vars
   bool    haveSource     ( );
   int     chapterCount   ( );
-  void    chapterChanged ( QListBoxItem * );
+  //void    chapterChanged ( Q3ListBoxItem * ); //ooo
+  void    chapterChanged ( QListWidgetItem * ); //xxx
   QString chapter        ( int );
   SourceFileInfo *getInfoFromChapterNumber ( int );
   int             getChapterNumberFromKey  ( QString );
@@ -132,7 +152,7 @@ private:
 
   int              m_iSliderWidthStart;
   int              m_iSliderHeightStart;
-  QValueList<WorkWaiting *> m_listOfWorkToDo;
+  QList<WorkWaiting *> m_listOfWorkToDo;	//oxx
 };
 
 #endif // __DIALOGTHUMBNAIL_H__
