@@ -1,23 +1,24 @@
-////////////////////////////////////////////////////////////////
-//
-// Class DragNDropContainer
-//
-// This class is only a container class to encapsulate the 
-// variables needed for Drag'n drop support
-//
-//   Created : 
-//        by : Varol Okan
-// Copyright : (c) Varol Okan
-//   License : GPL v 2.0
-//
-////////////////////////////////////////////////////////////////
+/***************************************************************************
+    dragndropcontainer.h
+                             -------------------
+    Class DragNDropContainer
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is only a container class to encapsulate the
+   variables needed for Drag'n drop support
+
+****************************************************************************/
 
 #ifndef DRAGNDROPCONTAINER_H
 #define DRAGNDROPCONTAINER_H
 
-#include <qdatetime.h>
-#include <qsize.h>
-#include <qfont.h>
+#include <QDateTime>
+#include <QSize>
+#include <QFont>
 
 #include "rgba.h"
 
