@@ -1,18 +1,26 @@
-/*****************************************************************************
- ** Class DVDLayout::Gui
- **
- **   Created : April 2'nd 2009
- **        by : Varol Okan
- ** Copyright : (c) Varol Okan
- **   License : GPL v 2.0
- **
- ** This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
- **
- *****************************************************************************/
+/***************************************************************************
+    dvdlayoutarea.cpp
+                             -------------------
+    Class DVDLayout::Gui
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
+    
+****************************************************************************/
 
 #include <qpushbutton.h>
 #include <qpainter.h>
 #include <qlayout.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QPixmap>
+#include <QMouseEvent>
+#include <QMessageBox>		//xxx
+#include <QPalette>         //xxx
 
 #include "global.h"
 #include "dvdmenu.h"
@@ -63,7 +71,7 @@ Area::Container::Connection::Connection ( Connection &theOther )
 
   PieceOfLine *pLine    = NULL;
   PieceOfLine *pNewLine = NULL;
-  QValueList<Area::PieceOfLine *>::iterator it = theOther.lines ( ).begin ( );
+  QList<Area::PieceOfLine *>::iterator it = theOther.lines ( ).begin ( );	//oxx
   while ( it != theOther.lines ( ).end ( ) )  {
     pLine = *it++;
     pNewLine = new PieceOfLine ( pLine->m_startPos, pLine->m_endPos );
@@ -74,20 +82,30 @@ Area::Container::Connection::Connection ( Connection &theOther )
 Area::Container::Connection::~Connection ( )
 {
   PieceOfLine *pLine = NULL;
-  QValueList<PieceOfLine *>::iterator it = m_listLineStipples.begin ( );
+  QList<PieceOfLine *>::iterator it = m_listLineStipples.begin ( );	        //oxx
+  QList<Connection  *>::iterator it_2 = target ( )->sources ( ).end ( );    //xxx
+  QList<Connection  *>::iterator it_3 = source ( )->sources ( ).end ( );    //xxx
+  
   while ( it != m_listLineStipples.end ( ) )  {
     pLine = *it++;
     delete pLine;
   }
-  m_listLineStipples.clear ( );
+
+  m_listLineStipples.clear ( ); 
 
   // Finally remove this connection from the associated Container.
 //  if ( target ( )->sources ( ).size   (      ) > 0 )
-  if ( target ( )->sources ( ).find   ( this ) != target ( )->sources ( ).end ( ) ) 
-       target ( )->sources ( ).remove ( this );
+  //if ( target ( )->sources ( ).find   ( this ) != target ( )->sources ( ).end ( ) )   //oooo
+  //if ( target ( )->sources ( ).indexOf   ( this ) != target ( )->sources ( ).end ( ) )  //xxx
+  if ( target ( )->sources ( ).indexOf   ( this ) != target ( )->sources ( ).indexOf ( *it_2 ) )  //xxx
+    //target ( )->sources ( ).remove ( this );   //ooo
+    target ( )->sources ( ).removeOne ( this );   //xxx
 //  if ( source ( )->targets ( ).size   (      ) > 0 )
-  if ( source ( )->targets ( ).find   ( this ) != source ( )->targets ( ).end ( ) )
-       source ( )->targets ( ).remove ( this );
+  //if ( source ( )->targets ( ).find   ( this ) != source ( )->targets ( ).end ( ) )   //oooo
+  //if ( source ( )->targets ( ).indexOf   ( this ) != source ( )->targets ( ).end ( ) )  //xxx
+  if ( source ( )->targets ( ).indexOf   ( this ) != source ( )->targets ( ).indexOf ( *it_3 ) )  //xxx    
+    //source ( )->targets ( ).remove ( this );   //ooo
+    source ( )->targets ( ).removeOne ( this );   //xxx
 }
 
 Area::enSide Area::Container::Connection::side ( int iIdx )
@@ -117,7 +135,7 @@ Area::Container *Area::Container::Connection::source ( )
 void Area::Container::Connection::clearLines ( )
 {
   PieceOfLine *pLine = NULL;
-  QValueList<Area::PieceOfLine *>::iterator it = m_listLineStipples.begin ( );
+  QList<Area::PieceOfLine *>::iterator it = m_listLineStipples.begin ( );	//oxx
   while ( it != m_listLineStipples.end ( ) )  {
     pLine = *it++;
     delete pLine;
@@ -126,13 +144,13 @@ void Area::Container::Connection::clearLines ( )
   m_listLineStipples.clear ( );
 }
 
-void Area::Container::Connection::setLines ( QValueList<Area::PieceOfLine *> lines )
+void Area::Container::Connection::setLines ( QList<Area::PieceOfLine *> lines )		//oxx
 {
   clearLines ( );
   m_listLineStipples = lines;
 }
 
-QValueList<Area::PieceOfLine *> &Area::Container::Connection::lines ( )
+QList<Area::PieceOfLine *> &Area::Container::Connection::lines ( )	//oxx
 {
   return m_listLineStipples;
 }
@@ -177,7 +195,8 @@ bool Area::ReadObject::readProjectFile  ( QDomNode &xmlNode )
 
   qsAttribute = theElement.attributeNode ( LAYOUT_OBJECT_RECT ).value ( );
   if ( ! qsAttribute.isEmpty ( ) )  {
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );   //ooo
+    QStringList list = qsAttribute.split ( "," );                   //xxx
     if ( list.count ( ) == 4 )  {
       int x, y, w, h;
       x = list[0].toInt ( );
@@ -203,7 +222,8 @@ bool Area::ReadObject::writeProjectFile ( QDomElement &rootElement )
   h = m_rect.height ( );
 
   rootContainer.setAttribute ( LAYOUT_OBJECT_RECT, QString ( "%1, %2, %3, %4" ).arg ( x ).arg ( y ).arg ( w ).arg ( h ) );
-  QDomText text = xmlDoc.createTextNode ( m_qsObjectName.utf8 ( ) );
+  //QDomText text = xmlDoc.createTextNode ( m_qsObjectName.utf8 ( ) );  //ooo
+  QDomText text = xmlDoc.createTextNode ( m_qsObjectName.toUtf8 ( ) );  //xxx
   rootContainer.appendChild ( text );
   rootElement.appendChild   ( rootContainer );
 
@@ -233,7 +253,8 @@ bool Area::Container::writeProjectFile ( QDomElement &rootElement )
   }
 
   rootContainer.setAttribute ( LAYOUT_OBJECT_RECT, QString ( "%1, %2, %3, %4" ).arg ( x ).arg ( y ).arg ( w ).arg ( h ) );
-  QDomText text = xmlDoc.createTextNode ( qsObjectName.utf8 ( ) );
+  //QDomText text = xmlDoc.createTextNode ( qsObjectName.utf8 ( ) );    //ooo
+  QDomText text = xmlDoc.createTextNode ( qsObjectName.toUtf8 ( ) );    //xxx
   rootContainer.appendChild ( text );
   rootElement.appendChild   ( rootContainer );
 
@@ -245,27 +266,27 @@ Object *Area::Container::object ( )
   return m_pObject;
 }
 
-QValueList<Area::Container *> &Area::Container::container ( )
+QList<Area::Container *> &Area::Container::container ( )	//oxx
 {
   return m_listContainer;
 }
 
-QValueList<Area::Container::Connection *> &Area::Container::targets ( )
+QList<Area::Container::Connection *> &Area::Container::targets ( )	//oxx
 {
   return m_listTargets;
 }
 
-QValueList<Area::Container::Connection *> &Area::Container::sources ( )
+QList<Area::Container::Connection *> &Area::Container::sources ( )	//oxx
 {
   return m_listSources;
 }
 
-QValueList<Area::Container::Connection *> Area::Container::side ( enSide side )
+QList<Area::Container::Connection *> Area::Container::side ( enSide side )	//oxx
 {
-  QValueList<Area::Container::Connection *> list;
+  QList<Area::Container::Connection *> list;	//oxx
 
   Connection *pConnection = NULL;
-  QValueList<Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Connection *>::iterator it = m_listTargets.begin ( );		//oxx
   while ( it != m_listTargets.end ( ) )  {
     pConnection = *it++;
     // First we get the connections FROM
@@ -284,12 +305,13 @@ QValueList<Area::Container::Connection *> Area::Container::side ( enSide side )
   return list;
 }
 
-QValueList<Area::Container::Connection *> Area::Container::copy ( )
+
+QList<Area::Container::Connection *> Area::Container::copy ( )		//oxx
 {
-  QValueList<Connection *> list;
+  QList<Connection *> list;		//oxx
 
   Connection *pConnection = NULL;
-  QValueList<Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Connection *>::iterator it = m_listTargets.begin ( );		//oxx
   while ( it != m_listTargets.end ( ) )    {
     pConnection = new Connection  ( **it++ );
     list.append ( pConnection );
@@ -319,7 +341,7 @@ Area::Container::Connection *Area::Container::addTarget ( Area::Container *pTarg
 Area::Container::Connection *Area::Container::getTarget ( Area::Container *pTarget )
 {
   Connection *pProperties = NULL;
-  QValueList<Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Connection *>::iterator it = m_listTargets.begin ( );		//oxx
   while ( it != m_listTargets.end ( ) )  {
     pProperties = *it++;
     if ( pProperties->m_pTarget == pTarget )
@@ -330,9 +352,9 @@ Area::Container::Connection *Area::Container::getTarget ( Area::Container *pTarg
 
 void Area::Container::clearTargets ( )
 {
-  QValueList<Connection *> list = m_listTargets;
+  QList<Connection *> list = m_listTargets;		//oxx
   Connection *pConnection = NULL;
-  QValueList<Connection *>::iterator it = list.begin ( );
+  QList<Connection *>::iterator it = list.begin ( );	//oxx
   while ( it != list.end ( ) )  {
     pConnection = *it++;
     delete pConnection;
@@ -345,9 +367,9 @@ void Area::Container::clearTargets ( )
 
 void Area::Container::clearSources ( )
 {
-  QValueList<Connection *> list = m_listSources;
+  QList<Connection *> list = m_listSources;		//oxx
   Connection *pConnection = NULL;
-  QValueList<Connection *>::iterator it = list.begin ( );
+  QList<Connection *>::iterator it = list.begin ( );	//oxx
   while ( it != list.end ( ) )  {
     pConnection = *it++;
     delete pConnection;
@@ -370,7 +392,7 @@ int Area::Container::getSourceIdx ( Connection *pSource )
 
   Connection *pConnection = NULL;
   Area::enSide whichSide = pSource->side ( 0 );
-  QValueList<Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Connection *>::iterator it = m_listTargets.begin ( );		//oxx
   while (  it  != m_listTargets.end ( ) )  {
     pConnection = *it++;
     if  ( pConnection->side ( 0 ) != whichSide )
@@ -390,7 +412,7 @@ int Area::Container::getTargetIdx ( Connection *pSource )
 
   Connection *pConnection = NULL;
   Area::enSide whichSide = pSource->side ( 1 );
-  QValueList<Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Connection *>::iterator it = m_listTargets.begin ( );		//oxx
   while (  it  != m_listTargets.end ( ) )  {
     pConnection = *it++;
     if  ( pConnection->side ( 0 ) != whichSide )
@@ -413,10 +435,10 @@ int Area::Container::getTargetIdx ( Connection *pSource )
 }
 
 void Area::Container::drawConnections ( QPainter &thePainter, Object *pExcept )
-{
+{    
   Container             *pTarget     = NULL;
   Container::Connection *pConnection = NULL;
-  QValueList<Container::Connection *>::iterator it = m_listTargets.begin ( );
+  QList<Container::Connection *>::iterator it = m_listTargets.begin ( );	//oxx
   Area *pArea = (Area *)object ( )->parent ( );
 
   SimplePainter *pPainter = pArea->getPainter ( );
@@ -436,14 +458,15 @@ void Area::Container::drawConnections ( QPainter &thePainter, Object *pExcept )
     // The routing class will hold different algorithms for routing the connection from point A to point B
     pConnection->setLines ( pRouter->route ( startPos, endPos, pConnection ) );
   }
-  pPainter->draw ( thePainter, this, pExcept );
+  pPainter->draw ( thePainter, this, pExcept );   //ooo
 }
 
 void Area::Container::drawConnection ( QPainter &thePainter, Container::Connection *pConnection )
-{
+{    
   // Target / Source from the point of view of the Connection, not the Container
   Container *pSource, *pTarget;
 //  QValueList<Container::Connection *>::iterator it = m_listSources.begin ( );
+  QList<Container::Connection *>::iterator it = m_listSources.begin ( );	//xxx
   Area *pArea = (Area *)object ( )->parent ( );
 
   SimplePainter *pPainter = pArea->getPainter ( );
@@ -461,14 +484,14 @@ void Area::Container::drawConnection ( QPainter &thePainter, Container::Connecti
 
   // The routing class will hold different algorithms for routing the connection from point A to point B
   pConnection->setLines ( pRouter->route ( startPos, endPos, pConnection ) );
-  pPainter->draw ( thePainter, pConnection );
+  pPainter->draw ( thePainter, pConnection ); //ooo
 }
 
 QPoint Area::Container::getPos ( enSide whichSide, int iWhichNumber )
 {
   QPoint pos;
   // Here we spread out the connections over the available width/height
-  QValueList<Area::Container::Connection *> list = side ( whichSide );
+  QList<Area::Container::Connection *> list = side ( whichSide );		//oxx
   float fDelta = 10.0f;
   int iX, iY, iSize;
   int iTotal = list.size ( ) + 1;
@@ -495,8 +518,10 @@ QPoint Area::Container::getPos ( enSide whichSide, int iWhichNumber )
   return pos;
 }
 
-Area::Area ( QWidget *pParent, const char *pName, WFlags flags )
-  : QIconView ( pParent, pName, flags )
+//Area::Area ( QWidget *pParent, const char *pName, Qt::WFlags flags )      //ooo
+Area::Area ( QWidget *pParent, const char *pName, Qt::WindowFlags flags )   //xxx
+  //: Q3IconView ( pParent, pName, flags )  //ooo
+  : QListView ( pParent )                   //xxx
 {
   m_fZoom       = 1.0;
   m_bGrid       = false;
@@ -505,7 +530,11 @@ Area::Area ( QWidget *pParent, const char *pName, WFlags flags )
   m_iRouterType = 0;
   m_bMouseDown  = false;
   m_pActiveContainer = NULL;
-  setPaletteBackgroundColor ( QColor ( "#BACBE9" ) );
+  //setPaletteBackgroundColor ( QColor ( "#BACBE9" ) );     //oooo
+  QPalette palette;								//xxx
+  //palette.setBrush(QPalette::Base, QBrush(QColor ( "#BACBE9" ) ) );	//xxx
+  palette.setBrush(QPalette::Base, QColor ( "#BACBE9" ) );	//xxx
+  this->setPalette(palette);						//xxx
 }
 
 Area::~Area ( )
@@ -525,7 +554,8 @@ bool Area::readProjectFile ( QDomNode &xmlNode )
 
   qsAttribute = theElement.attributeNode ( LAYOUT_GRID ).value ( );
   if ( ! qsAttribute.isEmpty ( ) )  {
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );   //ooo
+    QStringList list = qsAttribute.split ( "," );                   //xxx
     if ( list.count ( ) == 2 )  {
       m_sizeGrid.setWidth  ( list[0].toInt ( ) );
       m_sizeGrid.setHeight ( list[1].toInt ( ) );
@@ -580,7 +610,7 @@ bool Area::writeProjectFile ( QDomElement &rootElement )
   // but at this time the Container do not yet exist. So instaed be staore the ReadObject list back.
   if ( m_listOfContainer.size ( ) < 1 )  {
     ReadObject *pReadObject = NULL;
-    QValueList<ReadObject *>::iterator it = m_listOfReadObjects.begin ( );
+    QList<ReadObject *>::iterator it = m_listOfReadObjects.begin ( );		//oxx
     while ( it != m_listOfReadObjects.end ( ) )  {
       pReadObject = *it++;
       if ( ! pReadObject->writeProjectFile ( rootDVDLayout) )
@@ -589,7 +619,7 @@ bool Area::writeProjectFile ( QDomElement &rootElement )
   }
   else  {
     Container *pContainer = NULL;
-    QValueList<Container *>::iterator it = m_listOfContainer.begin ( );
+    QList<Container *>::iterator it = m_listOfContainer.begin ( );	//oxx
     while ( it != m_listOfContainer.end ( ) )  {
       pContainer = *it++;
       if ( ! pContainer->writeProjectFile ( rootDVDLayout) )
@@ -601,7 +631,7 @@ bool Area::writeProjectFile ( QDomElement &rootElement )
 }
 
 void Area::refresh  ( )
-{
+{  
   createConnections ( );
   drawConnections   ( );
 }
@@ -615,7 +645,7 @@ void Area::deleteContainer ( Object  *pObject )
 
   if ( m_pActiveContainer == pContainer )  {
     Container::Connection   *pConnection = NULL;
-    QValueList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );
+    QList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );		//oxx
     while ( it != m_listActiveLines.end ( ) )  {
       pConnection = *it++;
       delete pConnection;
@@ -625,7 +655,8 @@ void Area::deleteContainer ( Object  *pObject )
   }
 
   //pContainer->clearConnections  ( );
-  m_listOfContainer.remove ( pContainer );
+  //m_listOfContainer.remove ( pContainer );    //ooo
+  m_listOfContainer.removeOne ( pContainer );   //xxx
   delete pContainer;
 
   // At this point we have removed all Connections plus the offending Container.
@@ -635,7 +666,7 @@ void Area::deleteContainer ( Object  *pObject )
 void Area::setActiveObject ( Object *pObject )
 {
   Container::Connection *pConnection = NULL;
-  QValueList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );
+  QList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );		//oxx
   while ( it != m_listActiveLines.end ( ) )  {
     pConnection = *it++;
     delete pConnection;
@@ -778,7 +809,7 @@ void Area::moveAll ( int iDeltaX, int iDeltaY )
   int x, y;
   Object    *pObject    = NULL;
   Container *pContainer = NULL;
-  QValueList<Container  *>::iterator it = m_listOfContainer.begin ( );
+  QList<Container  *>::iterator it = m_listOfContainer.begin ( );	//oxx
   while ( it != m_listOfContainer.end ( ) )  {
     pContainer = *it++;
     pObject = pContainer->object ( );
@@ -793,7 +824,7 @@ void Area::drawContainer ( QPainter &thePainter, Object *pExcept )
 {
   Container *pContainer = NULL;
   // For each Container
-  QValueList<Container *>::iterator it = m_listOfContainer.begin ( );
+  QList<Container *>::iterator it = m_listOfContainer.begin ( );	//oxx
   while ( it != m_listOfContainer.end ( ) )  {
     pContainer = *it++;
     if ( pExcept && pContainer->object ( ) == pExcept )
@@ -818,14 +849,18 @@ void Area::drawContainer ( Container *pContainer )
     return;
 
   // First we erase the previous temp lines ...
-  QPen     thePen     ( backgroundColor ( ), 2 );
+  //QPen     thePen     ( backgroundColor ( ), 2 ); //oooo
+  //QPen     thePen     ( QColor ( 1, 1, 1 ), 2 );    //xxx
+  QPen     thePen     ( QColor ( 186, 203, 233 ), 2 );    //xxx
   QPainter thePainter ( viewport ( ) );
   thePainter.setPen   ( thePen );
-  thePainter.setBrush ( backgroundColor ( ) );
+  //thePainter.setBrush ( backgroundColor ( ) );    //oooo
+  //thePainter.setBrush ( QColor ( 1, 1, 1 ) );       //xxx
+  thePainter.setBrush ( QColor ( 186, 203, 233 ) );       //xxx
   SimplePainter painter;
 
   Container::Connection *pConnection = NULL;
-  QValueList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );
+  QList<Container::Connection *>::iterator it = m_listActiveLines.begin ( );		//oxx
   while ( it != m_listActiveLines.end ( ) )  {
     pConnection = *it++;
     painter.drawLines ( thePainter, pConnection->lines ( ) );
@@ -848,7 +883,7 @@ void Area::drawContainer ( Container *pContainer )
 void Area::clearContainer ( )
 {
   Container *pContainer = NULL;
-  QValueList <Container *>::iterator it = m_listOfContainer.begin ( );
+  QList <Container *>::iterator it = m_listOfContainer.begin ( );	//oxx
   while ( it != m_listOfContainer.end ( ) )  {
     pContainer = *it++;
     delete pContainer;
@@ -859,7 +894,8 @@ void Area::clearContainer ( )
 void Area::clearPixmap ( )
 {
   m_pixmap = QPixmap ( width ( ), height ( ) );
-  m_pixmap.fill ( paletteBackgroundColor ( ) );
+  //m_pixmap.fill ( paletteBackgroundColor ( ) );   //oooo
+  m_pixmap.fill ( QColor(170,180,255) );   //xxx
 }
 
 void Area::drawConnections ( )
@@ -873,7 +909,11 @@ void Area::drawConnections ( )
   QPainter painter ( &m_pixmap );
   drawGrid         (   painter );
   drawContainer    (   painter, pObject );
-  setPaletteBackgroundPixmap ( m_pixmap );
+  //setPaletteBackgroundPixmap ( m_pixmap );    //oooo
+  QPalette palette;								//xxx
+  //palette.setBrush(QPalette::Window, QBrush(m_pixmap));				//xxx
+  palette.setBrush(QPalette::Base, m_pixmap);				//xxx
+  this->setPalette(palette);					//xxx
 }
 
 void Area::createConnections ( )
@@ -881,8 +921,8 @@ void Area::createConnections ( )
   // This function will recreate the connections of the existing Container
 }
 
-void Area::createConnections ( QValueList<Object *> &list )
-{
+void Area::createConnections ( QList<Object *> &list )		//oxx
+{    
   // This function ( called from Gui::refresh () ) will delete all Container
   // And re-create them to handle the Connections between Objects.
 
@@ -905,15 +945,15 @@ void Area::createConnections ( QValueList<Object *> &list )
   Container *pContainer = NULL;
 
   // First we populate the Container Objects.
-  QValueList<Object *>::iterator it = list.begin ( );
-  while ( it != list.end ( ) ) {
+  QList<Object *>::iterator it = list.begin ( );	//oxx
+  while ( it != list.end ( ) ) { 
     pObject = *it++;
     pContainer = new Container ( pObject );
     m_listOfContainer.append   ( pContainer );
   }
-
+  
   // This run through we determine the X/Y pos of the connection points
-  QValueList<Container *>::iterator itCon = m_listOfContainer.begin ( );
+  QList<Container *>::iterator itCon = m_listOfContainer.begin ( );		//oxx
   while ( itCon != m_listOfContainer.end ( ) )  {
     pContainer = *itCon++;
     if      ( pContainer->object  ( )->type ( ) == Object::TYPE_MOVIE )
@@ -936,15 +976,16 @@ void Area::createConnections ( QValueList<Object *> &list )
         pContainer->container ( ).append ( pTarget );
     }
   }
+
   // The following functin will remove double connection from one container to another.
   // These double connections are of no improtance to the DVDLayout itself.
   cleanListOfContainer ( );
 //for (int x=0;x<m_listOfContainer.count();x++) { if (m_listOfContainer[x]) printf ("%s::%d > %d = cnt<%d>\n",__FILE__,__LINE__,x,m_listOfContainer[x]->container().count()); }
-
+  
   // And finally we go and assign the objects inside the Container objects to Left, Right, and Bottom
   Container *pTarget   = NULL;
-  QValueList<Container *> listContainer;
-  QValueList<Container *>::iterator it2;
+  QList<Container *> listContainer;		//oxx
+  QList<Container *>::iterator it2;		//oxx
   itCon = m_listOfContainer.begin ( );
   while ( itCon != m_listOfContainer.end ( ) )  {
     pContainer    = *itCon++;
@@ -960,7 +1001,7 @@ void Area::createConnections ( QValueList<Object *> &list )
   // Finally after we assigned all sides to all Container
   // we can figure out the idx of the connection on each side.
   Container::Connection *pConnection = NULL;
-  QValueList<Container::Connection *>::iterator it3;
+  QList<Container::Connection *>::iterator it3;		//oxx
   itCon = m_listOfContainer.begin ( );
   while ( itCon != m_listOfContainer.end ( ) )  {
     pContainer   = *itCon++;
@@ -996,15 +1037,16 @@ void Area::cleanListOfContainer ( )
 {
   Container *pContainer = NULL;
   Container *pTarget    = NULL;
-  QValueList<Container *> tempList;
-  QValueList<Container *>::iterator it = m_listOfContainer.end ( );
-  QValueList<Container *>::iterator it2;
+  QList<Container *> tempList;						//oxx
+  QList<Container *>::iterator it = m_listOfContainer.end ( );		//oxx
+  QList<Container *>::iterator it2;					//oxx
   while ( --it != m_listOfContainer.begin ( ) )  {
     pContainer = *it;
     it2 = pContainer->container ( ).begin ( );
     while (  it2 != pContainer->container ( ).end ( ) )  {
       pTarget = *it2++;
-      tempList.remove   ( pTarget );
+      //tempList.remove   ( pTarget );  //ooo
+      tempList.removeOne   ( pTarget ); //xxx
       if ( pTarget  != pContainer )  // Dont want to show connections from one to itself.
         tempList.append ( pTarget );
     }
@@ -1022,9 +1064,10 @@ void Area::createConnections ( Container *pContainer )
   QRgb color = red;
   Container *pTarget   = NULL;
   Container::Connection* pConnection = NULL;
-  QValueList<Container *> listContainer;
-  QValueList<Container *>::iterator it2;
+  QList<Container *> listContainer;		//oxx
+  QList<Container *>::iterator it2;		//oxx
 //  QValueList<Container *>::iterator itCon = m_listOfContainer.begin ( );
+  QList<Container *>::iterator itCon = m_listOfContainer.begin ( );		//xxx
 
   listContainer = pContainer->container ( );
   int iPosX     = pContainer->object    ( )->pos ( ).x ( );
@@ -1085,13 +1128,14 @@ void Area::setReadParams ( Container *pContainer )
     return;
 
   ReadObject *pReadObject = NULL;
-  QValueList<ReadObject *>::iterator it = m_listOfReadObjects.begin ( );
+  QList<ReadObject *>::iterator it = m_listOfReadObjects.begin ( );	//oxx
   while ( it != m_listOfReadObjects.end ( ) )  {
     pReadObject = *it++;
     if ( pReadObject->m_qsObjectName == pObject->getObjectName ( ) )  {
       pObject->setZoom ( m_fZoom );
       pObject->move    ( pReadObject->m_rect.x ( ), pReadObject->m_rect.y ( ) );
-      m_listOfReadObjects.remove (  pReadObject  );
+      //m_listOfReadObjects.remove (  pReadObject  );   //ooo
+      m_listOfReadObjects.removeOne (  pReadObject  );  //xxx
       delete pReadObject;
       return;
     }
@@ -1122,7 +1166,7 @@ void Area::findMovieTargets ( Container *pContainer )
     pContainer->container ( ).append ( pTarget );
 
   SourceFileInfo *pInfo = NULL;
-  QValueList<SourceFileInfo *>::iterator it = pEntry->listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = pEntry->listFileInfos.begin ( );	//oxx
   while ( it != pEntry->listFileInfos.end ( ) )  {
     pInfo   = *it++;
     pTarget = findContainerFromAction ( pInfo->qsPostCommand );
@@ -1131,8 +1175,8 @@ void Area::findMovieTargets ( Container *pContainer )
   }
 }
 
-void Area::findMenuTargets ( Container *pContainer )
-{
+void Area::findMenuTargets ( Container *pContainer )    //ooo-bug
+{    
   if ( ! pContainer )
     return;
   // DVDMenu: qsPre / qsPost
@@ -1146,8 +1190,8 @@ void Area::findMenuTargets ( Container *pContainer )
   Container       *pTarget = NULL;
   SourceFileEntry *pEntry  = NULL;
   DVDMenu *pMenu  = (DVDMenu *) pContainer->object  ( )->getObject ( );
-  QValueList<SourceFileEntry *> list = pMenu->getSourceFileEntries ( false ); // Excluding the PlayMultiple entries
-  QValueList<SourceFileEntry *>::iterator it = list.begin ( );
+  QList<SourceFileEntry *> list = pMenu->getSourceFileEntries ( false ); // Excluding the PlayMultiple entries		//oxx
+  QList<SourceFileEntry *>::iterator it = list.begin ( );								//oxx
   while ( it != list.end ( ) )  {
     pEntry = *it++;
     pTarget = findContainerFromPtr ( pEntry );
@@ -1165,8 +1209,8 @@ void Area::findMenuTargets ( Container *pContainer )
   QString     strMultiple;
   QStringList listMultiple;
   QStringList::iterator itMultiple;
-  QValueList<ButtonObject *> listButtons = pMenu->getButtons ( );
-  QValueList<ButtonObject *>::iterator itButtons = listButtons.begin ( );
+  QList<ButtonObject *> listButtons = pMenu->getButtons ( );			//oxx
+  QList<ButtonObject *>::iterator itButtons = listButtons.begin ( );		//oxx
   while ( itButtons != listButtons.end ( ) )  {
     pButton = *itButtons++;
     listMultiple   = pButton->getPlayMultipleList ( );
@@ -1190,11 +1234,12 @@ void Area::findMenuTargets ( Container *pContainer )
       pCurrentTarget = pTarget;
     }
   }
-
+  
   // Finally we can handle the Button Actions to other Menus.
   itButtons =  listButtons.begin ( );
   while ( itButtons != listButtons.end ( ) )  {
     pButton = *itButtons++;
+
     pOtherMenu = pMenu->getMenuFromButtonAction ( pButton->action ( ) );
     pTarget = findContainerFromPtr ( pOtherMenu );
     if ( pTarget )
@@ -1208,10 +1253,13 @@ Area::Container *Area::findContainerFromAction ( QString &qsAction )
   if ( qsAction.isEmpty ( ) )
     return NULL;
 
-  QStringList stringList = QStringList::split ( STRING_SEPARATOR, qsAction );
+  //QStringList stringList = QStringList::split ( STRING_SEPARATOR, qsAction );     //ooo
+  QStringList stringList = qsAction.split ( STRING_SEPARATOR );                     //xxx
   if ( stringList.count ( ) < 1 )  {  // Maybe something like " call vmgm menu 1; "
-    stringList = QStringList::split ( " ", qsAction );
-    if ( stringList[1].lower ( ) == "vmgm" )
+    //stringList = QStringList::split ( " ", qsAction );    //ooo
+    stringList = qsAction.split ( " " );                    //xxx
+    //if ( stringList[1].lower ( ) == "vmgm" )  //ooo
+    if ( stringList[1].toLower ( ) == "vmgm" )  //xxx
       p = Global::pApp->getVMGMenu ( );
     else
       return NULL;
@@ -1233,7 +1281,7 @@ Area::Container *Area::findContainerFromPtr ( void *p )
 
   Object    *pObject    = NULL;
   Container *pContainer = NULL;
-  QValueList<Container *>::iterator it = m_listOfContainer.begin ( );
+  QList<Container *>::iterator it = m_listOfContainer.begin ( );	//oxx
   while ( it  != m_listOfContainer.end ( ) )  {
     pContainer = *it++;
     pObject    = pContainer->object    ( );
@@ -1249,7 +1297,7 @@ Area::Container *Area::findContainerFromObject ( Object *pObject )
     return NULL;
 
   Container *pContainer = NULL;
-  QValueList<Container *>::iterator itCon = m_listOfContainer.begin ( );
+  QList<Container *>::iterator itCon = m_listOfContainer.begin ( );		//oxx
   while ( itCon !=  m_listOfContainer.end  ( ) )  {
     pContainer   = *itCon++;
     if ( pObject == pContainer->object ( ) )
