@@ -1,14 +1,16 @@
-/*****************************************************************************
- ** Class DVDLayout::Gui
- **
- **   Created :
- **        by : Varol Okan
- ** Copyright : (c) Varol Okan
- **   License : GPL v 2.0
- **
- ** This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
- **
- *****************************************************************************/
+/***************************************************************************
+    dvdlayoutgui.cpp
+                             -------------------
+    Class DVDLayout::Gui
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
+    
+****************************************************************************/
 
 #include <qtimer.h>
 #include <qlayout.h>
@@ -18,15 +20,29 @@
 #include <qcombobox.h>
 #include <qfileinfo.h>
 #include <qlineedit.h>
-#include <qpopupmenu.h>
+//#include <q3popupmenu.h>  //ooo
 #include <qpushbutton.h>
+//Added by qt3to4:
+//#include <Q3HBoxLayout>   //ooo
+#include <QHBoxLayout>      //xxx
+#include <QKeyEvent>
+//#include <Q3ValueList>	//oxx
+#include <QLabel>
+//#include <Q3GridLayout>   //ooo
+#include <QGridLayout>      //xxx
+//#include <Q3Frame>        //ooo
+#include <QFrame>           //xxx
+//#include <q3mimefactory.h>    //ooo
+#include <QMouseEvent>
+#include <QEvent>
+#include <QMessageBox>
 
 #include "global.h"
 #include "dvdmenu.h"
 #include "xml_dvd.h"
 #include "qdvdauthor.h"
 #include "messagebox.h"
-#include "cachethumbs.h"
+#include "cachethumbs.h"  //ooo
 #include "dvdlayoutgui.h"
 #include "dvdlayoutarea.h"
 #include "sourcefileentry.h"
@@ -38,8 +54,10 @@ const int Object::BUTTON_SIZE  =  17;
 const int Object::INITIAL_SIZE = 200;
 const int Gui::REFRESH_MENU    = 123;
 
-Header::Header ( QWidget *pParent, Object *pObject, const char *pName, WFlags flags )
-  : QLabel ( pParent, pName, flags )
+//Header::Header ( QWidget *pParent, Object *pObject, const char *pName, Qt::WFlags flags )     //ooo
+Header::Header ( QWidget *pParent, Object *pObject, const char *pName, Qt::WindowFlags flags )  //xxx
+  //: QLabel ( pParent, pName, flags )  //ooo
+  : QLabel ( pParent )                  //xxx
 {
   m_bMousePressed = false;
   m_pObject       = pObject;
@@ -102,8 +120,10 @@ void Header::mouseDoubleClickEvent ( QMouseEvent * )
 }
 
 
-Object::Object ( QWidget *pParent, const char *pName, WFlags flags )
-  : QFrame ( pParent, pName, flags )
+//Object::Object ( QWidget *pParent, const char *pName, Qt::WFlags flags )      //ooo
+Object::Object ( QWidget *pParent, const char *pName, Qt::WindowFlags flags )   //xxx
+  //: Q3Frame ( pParent, pName, flags ) //ooo
+  : QFrame ( pParent )                 //xxx
 {
   // Okay, to set the style of the PluginFunctionPainter ...
   m_objectSize     = QSize  ( INITIAL_SIZE, INITIAL_SIZE );
@@ -113,41 +133,57 @@ Object::Object ( QWidget *pParent, const char *pName, WFlags flags )
   m_gridSize       = QSize ( 10, 10 );
   m_pArea          = (Area *)pParent;
 
-  setAcceptDrops  ( TRUE );
-  setFrameShape   ( QFrame::NoFrame );
+  //setAcceptDrops  ( TRUE );   //ooo
+  setAcceptDrops  ( true );     //xxx
+  //setFrameShape   ( Q3Frame::NoFrame );   //ooo
+  setFrameShape   ( QFrame::NoFrame );      //xxx
   setLineWidth    ( 2 );
   setMidLineWidth ( 1 );
-  m_pMainLayout = new QHBoxLayout   ( this, 0, 0, "m_pMainLayout" );
+  //m_pMainLayout = new Q3HBoxLayout   ( this, 0, 0, "m_pMainLayout" ); //ooo
+  m_pMainLayout = new QHBoxLayout   ( this );                            //xxx
 
-  m_pInnerFrame = new QFrame        ( this, "m_pInnerFrame" );
-  m_pInnerFrame->setFrameShape      ( QFrame::StyledPanel );
-  m_pInnerFrame->setFrameShadow     ( QFrame::Raised );
+  //m_pInnerFrame = new Q3Frame        ( this, "m_pInnerFrame" );   //ooo
+  m_pInnerFrame = new QFrame        ( this );                       //xxx
+  //m_pInnerFrame->setFrameShape      ( Q3Frame::StyledPanel ); //ooo
+  m_pInnerFrame->setFrameShape      ( QFrame::StyledPanel );    //xxx
+  //m_pInnerFrame->setFrameShadow     ( Q3Frame::Raised );      //ooo
+  m_pInnerFrame->setFrameShadow     ( QFrame::Raised );         //xxx
   m_pInnerFrame->setLineWidth       ( 2 );
   m_pInnerFrame->setMidLineWidth    ( 1 );
   m_pMainLayout->addWidget          ( m_pInnerFrame );
 
-  m_pFrameLayout  = new QGridLayout ( m_pInnerFrame, 1, 1, 3, 2, "m_pFrameLayout" );
-  m_pHeaderLayout = new QHBoxLayout ( 0, 0, 0,       "m_pHeaderLayout"  );
+  //m_pFrameLayout  = new Q3GridLayout ( m_pInnerFrame, 1, 1, 3, 2, "m_pFrameLayout" );     //ooo
+  m_pFrameLayout  = new QGridLayout ( m_pInnerFrame );                                       //xxx
+  //m_pHeaderLayout = new Q3HBoxLayout ( 0, 0, 0,       "m_pHeaderLayout"  );   //ooo
+  m_pHeaderLayout = new QHBoxLayout (   );                                      //xxx
 
   m_pHeader = new Header            ( m_pInnerFrame, this, "m_pLabelHeader" );
   m_pHeader->setMaximumSize         ( QSize  (   32767, BUTTON_SIZE ) );
-  m_pHeader->setPaletteBackgroundColor       ( QColor ( 255, 170, 0 ) );
+  //m_pHeader->setPaletteBackgroundColor       ( QColor ( 255, 170, 0 ) );  //ooo
+  QPalette palette;								                     //xxx
+  palette.setBrush(QPalette::Base, QBrush(QColor ( 255, 170, 0 )));	//xxx
+  m_pHeader->setPalette(palette);						             //xxx
   QFont labelHeader_font            (  m_pHeader->font() );
   labelHeader_font.setFamily        ( "Helvetica" );
   labelHeader_font.setPointSize     ( 6 );
   m_pHeader->setFont                ( labelHeader_font );
-  m_pHeader->setAlignment           ( int( QLabel::AlignCenter ) );
+  //m_pHeader->setAlignment           ( int( Qt::AlignCenter ) );   //ooo
+  m_pHeader->setAlignment           ( Qt::AlignCenter );  //xxx
   m_pHeader->setScaledContents      ( true );
   QSizePolicy sizePol = m_pHeader->sizePolicy ( );
-  sizePol.setHorData                ( QSizePolicy::Ignored );
+  //sizePol.setHorData                ( QSizePolicy::Ignored ); //oooo
   m_pHeader->setSizePolicy          ( sizePol );
   m_pHeaderLayout->addWidget        ( m_pHeader );
   // Connect the header -> this -> ConstructionArea ...
   QObject::connect ( m_pHeader, SIGNAL ( signalRedrawAll ( ) ), this, SLOT ( slotRedrawAll ( ) ) );
 
-  m_pButtonInfo = new QPushButton   ( m_pInnerFrame,   "m_pButtonInfo" );
+  //m_pButtonInfo = new QPushButton   ( m_pInnerFrame,   "m_pButtonInfo" ); //ooo
+  m_pButtonInfo = new QPushButton   ( m_pInnerFrame );                      //xxx
   m_pButtonInfo->setMaximumSize     ( QSize ( BUTTON_SIZE, BUTTON_SIZE ) );
-  m_pButtonInfo->setPaletteBackgroundColor  ( QColor  (  255, 255, 127 ) );
+  //m_pButtonInfo->setPaletteBackgroundColor  ( QColor  (  255, 255, 127 ) );   //ooo
+  QPalette palette2;								//xxx
+  palette2.setBrush(QPalette::Base, QBrush(QColor  (  255, 255, 127 )));	//xxx
+  m_pButtonInfo->setPalette(palette2);						//xxx
   QFont buttonInfo_font             (  m_pButtonInfo->font ( ) );
   buttonInfo_font.setFamily         ( "Helvetica" );
   buttonInfo_font.setPointSize      ( 6 );
@@ -156,9 +192,14 @@ Object::Object ( QWidget *pParent, const char *pName, WFlags flags )
   m_pHeaderLayout->addWidget        ( m_pButtonInfo );
   m_pFrameLayout->addLayout         ( m_pHeaderLayout, 0, 0 );
 
-  m_pInsideWidget = new QLabel      ( m_pInnerFrame, "m_pInsideWidget" );
-  m_pInsideWidget->setPaletteBackgroundColor ( QColor ( 170, 255, 255 ) );
-  m_pInsideWidget->setAlignment     ( int ( QLabel::AlignCenter ) );
+  //m_pInsideWidget = new QLabel      ( m_pInnerFrame, "m_pInsideWidget" ); //ooo
+  m_pInsideWidget = new QLabel      ( m_pInnerFrame );                      //xxx
+  //m_pInsideWidget->setPaletteBackgroundColor ( QColor ( 170, 255, 255 ) );    //ooo
+  QPalette palette3;								//xxx
+  palette3.setBrush(QPalette::Base, QBrush(QColor ( 170, 255, 255 )));	//xxx
+  m_pInsideWidget->setPalette(palette3);						//xxx
+  //m_pInsideWidget->setAlignment     ( int ( Qt::AlignCenter ) );  //ooo
+  m_pInsideWidget->setAlignment     ( Qt::AlignCenter );            //xxx
 
   m_pFrameLayout->addWidget         ( m_pInsideWidget, 1, 0 );
 
@@ -236,7 +277,7 @@ void Object::resizeHeader ( )
 }
 
 void Object::setThumbnail ( )
-{
+{  
   if ( m_thumbnail.isNull ( ) )
     return;
 
@@ -244,7 +285,8 @@ void Object::setThumbnail ( )
   QPixmap thePix;
   QSize   theSize = size ( );
 
-  theImage = m_thumbnail.smoothScale ( theSize, QImage::ScaleMin );
+  //theImage = m_thumbnail.smoothScale ( theSize, Qt::KeepAspectRatio );				//ooo
+  theImage = m_thumbnail.scaled ( theSize, Qt::KeepAspectRatio, Qt::SmoothTransformation );		//xxx
   thePix.convertFromImage    ( theImage );
   m_pInsideWidget->setPixmap (   thePix );
 }
@@ -281,7 +323,7 @@ void Object::leaveEvent ( QEvent * )
 
 void Object::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-  if ( pMouseEvent->button ( ) == LeftButton )  {
+  if ( pMouseEvent->button ( ) == Qt::LeftButton )  {
     m_bMousePressed = true;
     m_pointInitial  = pMouseEvent->pos ( );
     raise ( );
@@ -291,14 +333,14 @@ void Object::mousePressEvent ( QMouseEvent *pMouseEvent )
     if ( type ( ) == TYPE_MOVIE )  {
       SourceFileEntry *pEntry = (SourceFileEntry *)getObject ( );
       QPoint  pos    = pMouseEvent->globalPos (     );
-      Global::pApp->createContextMenu ( pEntry, pos );
+      //Global::pApp->createContextMenu ( pEntry, pos );    //oooo
     }
     else if ( type ( ) == TYPE_MENU )  {
       QPoint      pos   = pMouseEvent->globalPos ( );
       DVDMenu    *pMenu = (DVDMenu *)getObject   ( );
-      QPopupMenu popuMenu ( NULL );
+      /*Q3PopupMenu popuMenu ( NULL );
       popuMenu.insertItem ( tr ( "Proprties ..." ), pMenu, SLOT ( slotEditTimeline ( ) ) );
-      popuMenu.exec ( pos, 2 );
+      popuMenu.exec ( pos, 2 );*/   //oooo
     }
   }
 }
@@ -336,8 +378,14 @@ MovieObject::MovieObject ( QWidget *pParent, SourceFileEntry *pEntry )
   : Object ( pParent )
 {
   // MovieObjects have a slight green tint header
-  m_pHeader->setPaletteBackgroundColor     ( QColor (  0, 170,  0 ) );
-  m_pButtonInfo->setPaletteBackgroundColor ( QColor ( 60, 255, 90 ) );
+  //m_pHeader->setPaletteBackgroundColor     ( QColor (  0, 170,  0 ) );    //ooo
+  QPalette palette;								//xxx
+  palette.setBrush(QPalette::Base, QBrush(QColor (  0, 170,  0 )));	//xxx
+  m_pHeader->setPalette(palette);						//xxx
+  //m_pButtonInfo->setPaletteBackgroundColor ( QColor ( 60, 255, 90 ) );    //ooo
+  QPalette palette2;								//xxx
+  palette2.setBrush(QPalette::Base, QBrush(QColor ( 60, 255, 90 )));	//xxx
+  m_pButtonInfo->setPalette(palette2);						//xxx
   m_pSourceFileEntry = pEntry;
   m_pHeader->setText ( getObjectName ( ) );
   createThumb ();
@@ -400,7 +448,8 @@ void MovieObject::createThumb ( )
     return;
 
   // We only need half the size so we won't have to re-scale the full image all the time.
-  theImage = theImage.smoothScale ( INITIAL_SIZE, INITIAL_SIZE, QImage::ScaleMin );
+  //theImage = theImage.smoothScale ( INITIAL_SIZE, INITIAL_SIZE, Qt::KeepAspectRatio );			//ooo
+  theImage = theImage.scaled ( INITIAL_SIZE, INITIAL_SIZE, Qt::KeepAspectRatio, Qt::SmoothTransformation );	//xxx
   // Next we draw the movieLines.
   m_thumbnail = drawMovieLines ( theImage );
   setSize  ( m_thumbnail.width ( ), m_thumbnail.height ( ) );
@@ -428,7 +477,8 @@ QImage MovieObject::drawMovieLines ( QImage &theImage )
     thePainter.drawRect ( iX, iHeight+iHoleSize+2, iHoleSize-4, iHoleSize-4 );
   }
 
-  QImage finalImage = pix.convertToImage ( );
+  //QImage finalImage = pix.convertToImage ( ); //ooo
+  QImage finalImage = pix.toImage ( );          //xxx
   return finalImage;
 }
 
@@ -470,7 +520,8 @@ void MenuObject::createThumb ( )
     return;
 
   // We only need half the size so we won't have to re-scale the full image all the time.
-  theImage = theImage.smoothScale ( INITIAL_SIZE, INITIAL_SIZE, QImage::ScaleMin );
+  //theImage = theImage.smoothScale ( INITIAL_SIZE, INITIAL_SIZE, Qt::KeepAspectRatio );			//ooo
+  theImage = theImage.scaled ( INITIAL_SIZE, INITIAL_SIZE, Qt::KeepAspectRatio, Qt::SmoothTransformation );	//xxx
   setSize ( theImage.width ( ), theImage.height ( ) );
 
   m_thumbnail = theImage;
@@ -496,19 +547,31 @@ QString MenuObject::getObjectName ( )
 
 // This class handles the controls, such as Zoom slider, menu items etc.
 // It is also the document that keeps the DVDLayout objects
-Gui::Gui ( QWidget *pParent, const char *pName, WFlags flags)
-  : uiDVDLayout  ( pParent, pName, flags )
+//Gui::Gui ( QWidget *pParent, const char *pName, Qt::WFlags flags)	//ooo
+Gui::Gui ( QWidget *pParent )						//xxx
+  //: uiDVDLayout  ( pParent, pName, flags )	//ooo
+  : QWidget ( pParent )				//xxx
 {
-  QHBoxLayout *m_pMainLayout = new QHBoxLayout ( m_pFramePreview, 2, 2, "m_pMainLayout");
+  setupUi(this);	//xxx
+  //Q3HBoxLayout *m_pMainLayout = new Q3HBoxLayout ( m_pFramePreview, 2, 2, "m_pMainLayout");   //ooo
+  QHBoxLayout *m_pMainLayout = new QHBoxLayout ( m_pFramePreview );                             //xxx
   m_pArea      = new  Area ( m_pFramePreview, "DVDLayout::Area" );
   m_pMainLayout->addWidget ( m_pArea );
 
-  QPixmap pix  = QPixmap::fromMimeSource ( "printer.png" );
-  m_pButtonPrinter->setPixmap ( pix );
+  //QPixmap pix  = qPixmapFromMimeSource ( "printer.png" );	//ooo
+  QPixmap pix ( ":/images/printer.png" );			//xxx
+  //QIcon ButtonIcon(pix);    //xxx
+  //QIcon ButtonIcon( ":/images/printer.png" );    //xxx
+  //m_pButtonPrinter->setPixmap ( pix );    //oooo
+  m_pButtonPrinter->setIcon ( pix );    //xxx
+  m_pButtonPrinter->setIconSize(pix.rect().size());    //xxx
+  //m_pButtonPrinter->setIcon ( ButtonIcon );    //xxx
+  //m_pButtonPrinter->setIconSize(pix.rect().size());    //xxx
+  //m_pButtonPrinter->setFixedSize(pix.rect().size());   //xxx
   m_iPreviousSliderValue = -2000;
 
   connect ( m_pButtonPrinter, SIGNAL ( clicked       (     ) ), this, SLOT ( slotPrinter      (     ) ) );
-  connect ( m_pEditZoom,      SIGNAL ( lostFocus     (     ) ), this, SLOT ( slotZoomChanged  (     ) ) );
+  //connect ( m_pEditZoom,      SIGNAL ( lostFocus     (     ) ), this, SLOT ( slotZoomChanged  (     ) ) );    //debian
   connect ( m_pSliderZoom,    SIGNAL ( valueChanged  ( int ) ), this, SLOT ( slotZoomChanged  ( int ) ) );
   connect ( m_pSliderZoom,    SIGNAL ( sliderMoved   ( int ) ), this, SLOT ( slotSliderMoved  ( int ) ) );
   connect ( m_pSliderZoom,    SIGNAL ( sliderReleased(     ) ), this, SLOT ( slotZoomChanged  (     ) ) );
@@ -523,7 +586,7 @@ Gui::~Gui ( )
 void Gui::clear ( )
 {
   Object *pObject = NULL;
-  QValueList<Object *>::iterator it = m_listOfObjects.begin ( );
+  QList<Object *>::iterator it = m_listOfObjects.begin ( );	//oxx
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
     m_pArea->deleteContainer ( pObject );
@@ -552,7 +615,7 @@ void Gui::slotPostRead ( )
   float fAreaZoom = m_pArea->getZoom ( );
   int iZoom;
   QString qsZoom;
-
+  
   if ( fAreaZoom < 0.1f )
        fAreaZoom = 0.1f;
 
@@ -567,16 +630,18 @@ void Gui::slotPostRead ( )
     iZoom = (int)  ( ( fAreaZoom * 100.0f - 100.0f ) * 1000.0f / 900.0f ); // range [ 0 .. +1000 ]
 
   m_pSliderZoom->setValue ( iZoom );
-  m_pComboRouter->setCurrentItem ( m_pArea->routerType ( ) );
+  //m_pComboRouter->setCurrentItem ( m_pArea->routerType ( ) ); //ooo
+  m_pComboRouter->setCurrentIndex ( m_pArea->routerType ( ) );  //xxx
   refresh ( false );
 }
 
 void Gui::slotRecreateThumb ( )
 {
-  QValueList<Object *>::iterator it = m_listRecreateThumbs.begin ( );
+  QList<Object *>::iterator it = m_listRecreateThumbs.begin ( );	//oxx
   while ( it != m_listRecreateThumbs.end ( ) )  {
     Object *pObject = *it++;
-    m_listRecreateThumbs.remove ( pObject );
+    //m_listRecreateThumbs.remove ( pObject );  //ooo
+    m_listRecreateThumbs.removeOne ( pObject ); //xxx
     if ( m_listOfMenus.contains ( pObject ) > 0 )  {
       pObject->createThumb  ( );
       pObject->setThumbnail ( );
@@ -587,11 +652,11 @@ void Gui::slotRecreateThumb ( )
 }
 
 void Gui::refreshMenus ( )
-{
+{  
   // Called after switching main tab to DVDLayout
   m_listRecreateThumbs.clear ( );
 
-  QValueList<Object *>::iterator it = m_listOfMenus.begin ( );
+  QList<Object *>::iterator it = m_listOfMenus.begin ( );	//oxx
   while ( it != m_listOfMenus.end (   )   )
       m_listRecreateThumbs.append ( *it++ );
   QTimer::singleShot ( 100, this, SLOT ( slotRefresh ( ) ) );
@@ -609,27 +674,32 @@ void Gui::refresh ( )
 {
   // Main function, to non-destructively refresh the DVDLayout structure
   Object *pObject = NULL;
-  QValueList<Object *> listTemp = m_listOfVideos;
-  QValueList<Object *>::iterator itTemp;
+  QList<Object *> listTemp = m_listOfVideos;		//oxx
+  QList<Object *>::iterator itTemp;			//oxx
 
   // First we make sure all sources are taken care of.
   SourceFileEntry *pEntry = NULL;
   uint t, iEntries = Global::pApp->sourceFileCount ( );
-  for ( t=0; t<iEntries; t++ )  {
-    pEntry = Global::pApp->sourceFileEntry  ( t );
+  for ( t=0; t<iEntries; t++ )  {   
+    pEntry = Global::pApp->sourceFileEntry  ( t ); 
     if ( ( ! pEntry ) || ( pEntry->bSoundSource ) )
       continue;
 
     pObject = checkEntry ( pEntry );
+ 
     if ( pObject )
-      listTemp.remove ( pObject );
+      //listTemp.remove ( pObject );    //ooo
+      listTemp.removeOne ( pObject );   //xxx
   }
+
   // All objects not found can be deleted.
   itTemp = listTemp.begin ( );
   while ( itTemp != listTemp.end ( ) )   {
     pObject = *itTemp++;
-    m_listOfObjects.remove   ( pObject );
-    m_listOfVideos.remove    ( pObject );
+    //m_listOfObjects.remove   ( pObject );     //ooo
+    m_listOfObjects.removeOne   ( pObject );    //xxx
+    //m_listOfVideos.remove    ( pObject );     //ooo
+    m_listOfVideos.removeOne    ( pObject );    //xxx
     m_pArea->deleteContainer ( pObject );
     delete pObject;
   }
@@ -638,42 +708,48 @@ void Gui::refresh ( )
   listTemp = m_listOfMenus;
   pObject  = checkMenu ( Global::pApp->getVMGMenu ( ) );
   if ( pObject )
-    listTemp.remove ( pObject );
+    //listTemp.remove ( pObject );      //ooo
+    listTemp.removeOne ( pObject );     //xxx
 
   // Next we do the same for all sub menus.
   DVDMenu  *pDVDMenu = NULL;
-  QValueList<DVDMenu *> list = Global::pApp->getSubMenus ( );
-  QValueList<DVDMenu *>::iterator it = list.begin ( );
+  QList<DVDMenu *> list = Global::pApp->getSubMenus ( );	//oxx
+  QList<DVDMenu *>::iterator it = list.begin ( );		//oxx
 
   while ( it != list.end ( ) )  {
     pDVDMenu = *it++;
     pObject = checkMenu ( pDVDMenu );
     if ( pObject )
-      listTemp.remove   ( pObject  );
+      //listTemp.remove   ( pObject  );     //ooo
+      listTemp.removeOne   ( pObject  );    //xxx
   }
+
   // All objects not found can be deleted.
   itTemp = listTemp.begin ( );
   while ( itTemp != listTemp.end ( ) )  {
     pObject = *itTemp++;
-    m_listOfObjects.remove   ( pObject );
-    m_listOfMenus.remove     ( pObject );
+    //m_listOfObjects.remove   ( pObject );     //ooo
+    m_listOfObjects.removeOne   ( pObject );    //xxx
+    //m_listOfMenus.remove     ( pObject );     //ooo
+    m_listOfMenus.removeOne     ( pObject );    //xxx
     m_pArea->deleteContainer ( pObject );
     delete pObject;
   }
 }
 
 void Gui::refresh ( bool /* bAll */ )
-{
+{    
   Object *pObject = NULL;
-  QValueList<Object *>::iterator it = m_listOfObjects.begin ( );
+  QList<Object *>::iterator it = m_listOfObjects.begin ( );	//oxx
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
     pObject->refresh ( );
   }
 
   // After we refreshed all Menus / Movies we had better refresh the Lines too.
-  m_pArea->createConnections ( m_listOfObjects );
-  m_pArea->drawConnections   ( );
+  //m_pArea->createConnections ( m_listOfObjects ); //oooo-bug
+  m_pArea->drawConnections   ( );			//ooo
+  m_pArea->update ( ); //drawConnections   ( );		//xxx
 }
 
 Object *Gui::checkEntry ( SourceFileEntry *pEntry )
@@ -699,7 +775,7 @@ Object *Gui::checkMenu ( DVDMenu *pDVDMenu )
 Object *Gui::findObject ( void *pRealObject, bool bDVDMenu )
 {
   Object *pObject = NULL;
-  QValueList<Object *>::iterator it;
+  QList<Object *>::iterator it;		//oxx
   if ( bDVDMenu )  {
     it = m_listOfMenus.begin ( );
     while ( it != m_listOfMenus.end ( ) )  {
@@ -723,7 +799,7 @@ Object *Gui::findObject ( void *pRealObject, bool bDVDMenu )
 Object *Gui::findObject ( void *pRealObject )
 {
   Object *pObject = NULL;
-  QValueList<Object *>::iterator it = m_listOfObjects.begin ( );
+  QList<Object *>::iterator it = m_listOfObjects.begin ( );	//oxx
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
     if ( pObject->getObject ( ) == pRealObject )
@@ -813,7 +889,7 @@ QPoint Gui::initialPos ( bool bMenu )
   int iMaxVideoY = 0;
   int iMinVideoY = 100000000;
   // To do the right thing we need to get the MaxVideoY
-  QValueList<Object *>::iterator it = m_listOfVideos.begin ( );
+  QList<Object *>::iterator it = m_listOfVideos.begin ( );	//oxx
   while ( it != m_listOfVideos.end ( ) )  {
     MovieObject *pVideo =(MovieObject *)*it++;
     if ( iMaxVideoY < pVideo->pos ( ).y ( ) + pVideo->height ( ) )
@@ -958,7 +1034,7 @@ void Gui::setZoom ( float fZoom )
   // This function will update the zoom of all objects.
   Object *pObject = NULL;
   m_pArea->setZoom ( fZoom );
-  QValueList<Object *>::iterator it = m_listOfObjects.begin ( );
+  QList<Object *>::iterator it = m_listOfObjects.begin ( );	//oxx
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
     pObject->setZoom ( fZoom );
@@ -971,7 +1047,7 @@ void Gui::slotAdjustZoom ( )
   Object *pObject = NULL;
   int iMaxPosX = 0;
   int iMaxPosY = 0;
-  QValueList<Object *>::iterator it = m_listOfObjects.begin ( );
+  QList<Object *>::iterator it = m_listOfObjects.begin ( );	//oxx
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
     if ( iMaxPosX < pObject->pos ( ).x ( ) + pObject->width  ( ) )
@@ -979,6 +1055,7 @@ void Gui::slotAdjustZoom ( )
     if ( iMaxPosY < pObject->pos ( ).y ( ) + pObject->height ( )  )
          iMaxPosY = pObject->pos ( ).y ( ) + pObject->height ( ) ;
   }
+
   float fAreaZoom = m_pArea->getZoom ( );
   iMaxPosX += (int)( 20.0 * fAreaZoom );
   iMaxPosY += (int)( 20.0 * fAreaZoom );
@@ -998,7 +1075,7 @@ void Gui::slotAdjustZoom ( )
 
     if ( fAreaZoom < 0.1f )
          fAreaZoom = 0.1f;
-
+ 
     // Set the Zoom text
     qsZoom.sprintf ( "%0.2f%%", fAreaZoom * 100.0f );
     m_pEditZoom->setText ( qsZoom );
@@ -1008,12 +1085,13 @@ void Gui::slotAdjustZoom ( )
       iZoom = (int)( ( ( fAreaZoom - 1.0f ) * 1000.0f ) / 0.9f ); // range [ 0 .. -1000 ]
     else
       iZoom = (int)( ( fAreaZoom - 1.0f ) * 1000.0f / 900.0f );
-
-    m_pSliderZoom->setValue ( iZoom );
+    
+    m_pSliderZoom->setValue ( iZoom );    //ooo
 
     setZoom ( fAreaZoom );
+ 
     refresh (   false   );
-  }
+  }  
 }
 
 }; // End namespace DVDLayout
