@@ -1,16 +1,23 @@
-/*****************************************************************************
- ** Class DVDLayout::Painter
- **
- **   Created : April 2'nd 2009
- **        by : Varol Okan
- ** Copyright : (c) Varol Okan
- **   License : GPL v 2.0
- **
- ** This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
- **
- *****************************************************************************/
+/***************************************************************************
+    dvdlayoutpainter.cpp
+                             -------------------
+    Class DVDLayout::Painter
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
+    
+****************************************************************************/
 
 #include <qpainter.h>
+//Added by qt3to4:
+//#include <Q3PointArray>   //ooo
+#include <QPolygon>         //xxx
+//#include <Q3ValueList>	//oxx
+#include <QMessageBox>      //xxx
 
 #include "dvdlayoutgui.h"
 #include "dvdlayoutpainter.h"
@@ -27,38 +34,45 @@ SimplePainter::~SimplePainter ( )
 }
 
 void SimplePainter::draw ( QPainter &thePainter, Area::Container *pContainer, Object *pExcept )
-{
+{    
   Area::Container *pTarget = NULL;
   Area::Container::Connection *pConnection = NULL;
-  QValueList<Area::Container::Connection *>::iterator it = pContainer->targets ( ).begin ( );
+  QList<Area::Container::Connection *>::iterator it = pContainer->targets ( ).begin ( );	//oxx
+  //thePainter.setPen(QPen(Qt::black, 3, Qt::DashDotLine, Qt::RoundCap));   //xxx
+  //thePainter.drawLine   (1,1,100,100);   //xxx
   while ( it != pContainer->targets ( ).end ( ) )  {
     pConnection = *it++;
     pTarget     = pConnection->target ( );
     if ( ( ! pTarget ) || ( pTarget->object ( ) == pExcept ) )
       continue;
 
-    QPen thePen ( pConnection->m_color, 2 );
+    //QPen thePen ( pConnection->m_color, 2 );			//ooo
+    QPen thePen ( QBrush(QColor(pConnection->m_color)), 2 );	//xxx
     thePainter.setPen   ( thePen );
-    thePainter.setBrush ( pConnection->m_color );
+    //thePainter.setBrush ( pConnection->m_color );			//ooo
+    thePainter.setBrush ( QBrush(QColor(pConnection->m_color)) );	//xxx
     drawLines ( thePainter, pConnection->lines ( ) );
-  }
+  }   //ooo
 }
 
 void SimplePainter::draw ( QPainter &thePainter, Area::Container::Connection *pConnection )
 {
-  QPen thePen ( pConnection->m_color, 2 );
+  ////QPen thePen ( pConnection->m_color, 2 );			//ooo
+  QPen thePen ( QBrush(QColor(pConnection->m_color)), 2 );	//xxx
   thePainter.setPen   ( thePen );
-  thePainter.setBrush ( pConnection->m_color );
+  //thePainter.setBrush ( pConnection->m_color );			//ooo
+  thePainter.setBrush ( QBrush(QColor(pConnection->m_color)) );		//xxx
   drawLines ( thePainter, pConnection->lines ( ) );
 }
 
-void SimplePainter::drawLines ( QPainter &thePainter, QValueList<Area::PieceOfLine *> &lines )
-{
+void SimplePainter::drawLines ( QPainter &thePainter, QList<Area::PieceOfLine *> &lines )	//oxx
+{    
   Area::PieceOfLine *pLine = NULL;
-  QValueList<Area::PieceOfLine *>::iterator it = lines.begin ( );
+  QList<Area::PieceOfLine *>::iterator it = lines.begin ( );	//oxx
   while ( it != lines.end ( ) )  {
     pLine = *it++;
-    thePainter.drawLine   ( pLine->m_startPos, pLine->m_endPos );
+        
+    thePainter.drawLine   ( pLine->m_startPos, pLine->m_endPos ); //ooo
     if ( it ==  lines.end ( ) )  //m_listLineStipples.end ( ) ) // The last point receives the arrow.
       //thePainter.drawRect ( pLine->m_endPos.x ( ) - 4, pLine->m_endPos.y ( ) - 4, 8, 8 );
       drawArrow ( thePainter, pLine );
@@ -71,7 +85,8 @@ void SimplePainter::drawArrow ( QPainter &thePainter, Area::PieceOfLine *pLine )
 {
   const int iWidth  = 9;
   const int iHeight = 7;
-  QPointArray array ( 3 );
+  //Q3PointArray array ( 3 );   //ooo
+  QPolygon array ( 3 );         //xxx
   int x = pLine->m_endPos.x ( );
   int y = pLine->m_endPos.y ( );
   if ( x > pLine->m_startPos.x ( ) )      // Arrow to the right
@@ -86,6 +101,15 @@ void SimplePainter::drawArrow ( QPainter &thePainter, Area::PieceOfLine *pLine )
   thePainter.drawPolygon ( array );
 }
 
+void SimplePainter::paintEvent (QPaintEvent *pPaint)    //xxx
+{
+   QPixmap temp;    //xxx
+   QPainter thePainter;        //xxx
+   thePainter.begin(&temp);    //xxx
+   thePainter.drawLine(1,1,100,100);   //xxx
+   thePainter.end();    //xxx
+}
+
 ////////////////////////////////////////////////////////////
 //
 //  A bit nicer painter using two colored brush 
@@ -97,9 +121,12 @@ NicePainter::Brush::Brush ( QRgb &theColor )
   m_brushColor = theColor;
 
   // Next we get the 32 * 32 brush template and create the proper colored brush
-  QImage brush = QImage::fromMimeSource ( "brush.png" );
-  m_innerBrush = brush.smoothScale ( 4, 4 );
-  m_outerBrush = brush.smoothScale ( 8, 8 );
+  //QImage brush = QImage::fromMimeSource ( "brush.png" );	//ooo
+  QImage brush = QImage ( ":/images/brush.png" );		//xxx
+  //m_innerBrush = brush.smoothScale ( 4, 4 );  //ooo
+  m_innerBrush = brush.scaled ( 4, 4 );         //xxx
+  //m_outerBrush = brush.smoothScale ( 8, 8 );  //ooo
+  m_outerBrush = brush.scaled ( 8, 8 );         //xxx
   int x, y;
   unsigned char red, green, blue;
   float fFactor;
@@ -154,7 +181,7 @@ void NicePainter::setFastDraw ( bool bFast )
 NicePainter::Brush *NicePainter::getBrush ( QRgb &theColor )
 {
   NicePainter::Brush *pBrush = NULL;
-  QValueList<NicePainter::Brush *>::iterator it = m_listBrush.begin ( );
+  QList<NicePainter::Brush *>::iterator it = m_listBrush.begin ( );	//oxx
   while ( it != m_listBrush.end ( ) )  {
     pBrush = *it++;
     if ( pBrush->m_brushColor == theColor )
@@ -169,16 +196,18 @@ void NicePainter::draw ( QPainter &thePainter, Area::Container *pContainer, Obje
 {
   Area::Container *pTarget = NULL;
   Area::Container::Connection *pConnection = NULL;
-  QValueList<Area::Container::Connection *>::iterator it = pContainer->targets ( ).begin ( );
+  QList<Area::Container::Connection *>::iterator it = pContainer->targets ( ).begin ( );	//oxx
   while ( it != pContainer->targets ( ).end ( ) )  {
     pConnection = *it++;
     pTarget     = pConnection->target ( );
     if ( ( ! pTarget ) || ( pTarget->object ( ) == pExcept ) )
       continue;
 
-    QPen thePen ( pConnection->m_color, 2 );
+    //QPen thePen ( pConnection->m_color, 2 );			//ooo
+    QPen thePen ( QBrush(QColor(pConnection->m_color)), 2 );	//xxx
     thePainter.setPen   ( thePen );
-    thePainter.setBrush ( pConnection->m_color );
+    //thePainter.setBrush ( pConnection->m_color );			//ooo
+    thePainter.setBrush ( QBrush(QColor(pConnection->m_color)) );	//xxx
     m_pCurrentBrush = getBrush ( pConnection->m_color );
 
     drawLines ( thePainter, pConnection->lines ( ) );
@@ -187,9 +216,11 @@ void NicePainter::draw ( QPainter &thePainter, Area::Container *pContainer, Obje
 
 void NicePainter::draw ( QPainter &thePainter, Area::Container::Connection *pConnection )
 {
-  QPen thePen ( pConnection->m_color, 2 );
+  //QPen thePen ( pConnection->m_color, 2 );			//ooo
+  QPen thePen ( QBrush(QColor(pConnection->m_color)), 2 );	//xxx
   thePainter.setPen   ( thePen );
-  thePainter.setBrush ( pConnection->m_color );
+  //thePainter.setBrush ( pConnection->m_color );			//ooo
+  thePainter.setBrush ( QBrush(QColor(pConnection->m_color)) );		//xxx
   m_pCurrentBrush = getBrush ( pConnection->m_color );
 
   drawLines ( thePainter, pConnection->lines ( ) );
@@ -197,10 +228,10 @@ void NicePainter::draw ( QPainter &thePainter, Area::Container::Connection *pCon
 
 #if 0
 // Drawing BSplines .. looks bad though ...
-void NicePainter::drawLines ( QPainter &thePainter, QValueList<Area::PieceOfLine *> &lines )
+void NicePainter::drawLines ( QPainter &thePainter, Q3ValueList<Area::PieceOfLine *> &lines )
 {
   Area::PieceOfLine *pLine = NULL;
-  QValueList<Area::PieceOfLine *>::iterator it = lines.begin ( );
+  Q3ValueList<Area::PieceOfLine *>::iterator it = lines.begin ( );
 
   int iIdx = 0;
   BSpline spline ( 2, lines.size ( )+1 );
@@ -216,10 +247,10 @@ void NicePainter::drawLines ( QPainter &thePainter, QValueList<Area::PieceOfLine
 }
 #else
 // Original, drawing linear lines instead of curved
-void NicePainter::drawLines ( QPainter &thePainter, QValueList<Area::PieceOfLine *> &lines )
+void NicePainter::drawLines ( QPainter &thePainter, QList<Area::PieceOfLine *> &lines )		//oxx
 {
   Area::PieceOfLine *pLine = NULL;
-  QValueList<Area::PieceOfLine *>::iterator it = lines.begin ( );
+  QList<Area::PieceOfLine *>::iterator it = lines.begin ( );		//oxx
   while ( it != lines.end ( ) )  {
     pLine = *it++;
     if ( it ==  lines.end ( ) )  //m_listLineStipples.end ( ) ) // The last point receives the arrow.
@@ -242,7 +273,8 @@ void NicePainter::drawArrow ( QPainter &thePainter, Area::PieceOfLine *pLine, QI
 {
   const int iWidth  = 9;
   const int iHeight = 8;
-  QPointArray array ( 3 );
+  //Q3PointArray array ( 3 );   //ooo
+  QPolygon array ( 3 );         //xxx
   int x = pLine->m_endPos.x ( );
   int y = pLine->m_endPos.y ( );
   QPoint endPos = pLine->m_endPos;
