@@ -1,17 +1,21 @@
-/*****************************************************************************
- ** Class DVDLayout::Gui
- **
- **   Created : April 2'nd 2009
- **        by : Varol Okan
- ** Copyright : (c) Varol Okan
- **   License : GPL v 2.0
- **
- ** This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
- **
- *****************************************************************************/
+/***************************************************************************
+    dvdlayoutrouter.cpp
+                             -------------------
+    Class DVDLayout::Gui
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This is a sub-project to 'Q' DVD-Author to display the current DVD Layout
+   
+****************************************************************************/
 
 #include "dvdlayoutgui.h"
 #include "dvdlayoutrouter.h"
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 namespace DVDLayout
 {
@@ -24,9 +28,9 @@ LinearRouter::~LinearRouter ( )
 {
 }
 
-QValueList<Area::PieceOfLine *> LinearRouter::route ( QPoint startPos, QPoint endPos, Area::Container::Connection *pConnection )
+QList<Area::PieceOfLine *> LinearRouter::route ( QPoint startPos, QPoint endPos, Area::Container::Connection *pConnection )	//oxx
 {
-  QValueList<Area::PieceOfLine *> list;
+  QList<Area::PieceOfLine *> list;	//oxx
   if ( ! pConnection )
     return list;
 
@@ -68,7 +72,7 @@ OthogonalRouter::~OthogonalRouter ( )
 {
 }
 
-QValueList<Area::PieceOfLine *> OthogonalRouter::route ( QPoint startPos, QPoint endPos, Area::Container::Connection *pConnection )
+QList<Area::PieceOfLine *> OthogonalRouter::route ( QPoint startPos, QPoint endPos, Area::Container::Connection *pConnection )	//oxx
 {
   m_listLines.clear ( );
   QPoint pos[2];
