@@ -1,20 +1,25 @@
-/****************************************************************************
-** DVDMenuUndoObject - code
-**
-**   Created : Thursday Jan 2'nd 2003
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    dvdmenuundoobject.cpp
+                             -------------------
+    DVDMenuUndoObject - code
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #include <qpixmap.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QMessageBox>		//xxx
 
 #include "global.h"
 #include "xml_dvd.h"
 #include "dvdmenu.h"
 #include "qdvdauthor.h"
-#include "imageobject.h"
+#include "imageobject.h"	//ooo
 #include "menupreview.h"
 #include "buttonobject.h"
 #include "sourcefileentry.h"
@@ -74,7 +79,7 @@ DVDMenuUndoObject::DVDMenuUndoObject ( enUndoType type, MenuObject *pMenuObject,
   }
 }
 
-DVDMenuUndoObject::DVDMenuUndoObject ( enUndoType type, QValueList<MenuObject *> &list )
+DVDMenuUndoObject::DVDMenuUndoObject ( enUndoType type, QList<MenuObject *> &list )		//oxx
 {
   initMe ( );
   m_enUndoType    = (int)type;
@@ -96,9 +101,9 @@ DVDMenuUndoObject::DVDMenuUndoObject ( enUndoType type, QPixmap &theOldBackgroun
   initMe ( );
   if ( type != NEW_BACKGROUND )
     return;
-
-  m_enUndoType = (int)type;
-  m_backgroundInfo.background = theOldBackground;
+  
+  m_enUndoType = (int)type; 
+  m_backgroundInfo.background = theOldBackground;		//ooo
   m_backgroundInfo.getBackgroundInfo ( pInterface );
 }
 
@@ -161,7 +166,7 @@ DVDMenuUndoObject::~DVDMenuUndoObject ( )
   m_pDVDMenuInterface = NULL;
 
   if ( m_bDeleteObject && m_listOfObjects.count ( ) > 0 )  {
-    QValueList<MenuObject *>::iterator it = m_listOfObjects.begin ( );
+    QList<MenuObject *>::iterator it = m_listOfObjects.begin ( );	//oxx
     while ( it != m_listOfObjects.end ( ) )
       delete *it++;
   }
@@ -335,7 +340,7 @@ void DVDMenuUndoObject::undo ( DVDMenu *pDVDMenu )
   break;
   case NEW_BACKGROUND :
     // First we change the Pixmap
-    tempPix = *pDVDMenu->getMenuPreview()->paletteBackgroundPixmap ();
+    //tempPix = *pDVDMenu->getMenuPreview()->paletteBackgroundPixmap ();	//oooo
     pDVDMenu->getMenuPreview()->setPixmap (m_backgroundInfo.background);
     // STore the prvious Pixmap
     m_backgroundInfo.background = tempPix;
@@ -415,7 +420,7 @@ void DVDMenuUndoObject::redo ( DVDMenu *pDVDMenu )
   break;
   case NEW_BACKGROUND :
     // First we change the Pixmap
-    tempPix = *pDVDMenu->getMenuPreview ( )->paletteBackgroundPixmap  ( );
+    //tempPix = *pDVDMenu->getMenuPreview ( )->paletteBackgroundPixmap  ( );	//oooo
     pDVDMenu->getMenuPreview ( )->setPixmap ( m_backgroundInfo.background );
     // STore the prvious Pixmap
     m_backgroundInfo.background = tempPix;
@@ -510,7 +515,7 @@ void DVDMenuUndoObject::handleObject ( )
       if ( ( m_pMenuObject->objectType ( ) == IMAGE_OBJECT ) ||
            ( m_pMenuObject->objectType ( ) == MOVIE_OBJECT )  )  {
         ImageObject *pImage = (ImageObject *)m_pMenuObject;
-        pImage->updatePixmap ( );
+        pImage->updatePixmap ( );	//oooo
       }
     }
   }
@@ -564,7 +569,7 @@ void DVDMenuUndoObject::handleOverlay ( )
 
 void DVDMenuUndoObject::handleChapters ( DVDMenu *pDVDMenu, bool bUndo )
 {
-  QValueList<MenuObject *>::iterator it = m_listOfObjects.begin ( );
+  QList<MenuObject *>::iterator it = m_listOfObjects.begin ( );		//oxx
   MenuObject *pObject = NULL;
   while ( it != m_listOfObjects.end ( ) )  {
     pObject = *it++;
