@@ -1,17 +1,19 @@
-/****************************************************************************
-** Interface to the GUI.
-**
-**   Created : Thu 21 Sep 12:09:08 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-** 
-** This is a very simple match of Error message to resolve string
-** It works in direct conjunction with execute.cpp's MyDialog::slotAnalyze
-**
-** Note: These error messages are from the used tools and not 
-**       from QDVDAuthor itself.
-**
+/***************************************************************************
+    errormessages.cpp
+                             -------------------
+    Interface to the GUI.
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This is a very simple match of Error message to resolve string
+   It works in direct conjunction with execute.cpp's MyDialog::slotAnalyze
+   
+   Note: These error messages are from the used tools and not
+         from QDVDAuthor itself.
+
 ****************************************************************************/
 
 #include "errormessages.h"
