@@ -1,21 +1,23 @@
-/****************************************************************************
-** Implementation of class Export::DVDAuthor
-**
-**   Created : 
-**        by : Varol Okan using the kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class collects all possible information about
-** the current set stream.
-**
+/***************************************************************************
+    exportdvdauthor.h
+                             -------------------
+    Implementation of class Export::DVDAuthor
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class collects all possible information about
+   the current set stream.
+    
 ****************************************************************************/
 
 #ifndef __EXPORT_DVDAUTHOR_H__
 #define __EXPORT_DVDAUTHOR_H__
 
-#include <qmap.h>
-#include <qvaluelist.h>
+#include <QMap>
+//#include <q3valuelist.h>	//ooo
 
 class SourceFileEntry;
 class CXmlDVDAuthor;
@@ -78,7 +80,8 @@ public:
   SourceFileInfo     *  pTargetInfo;
   DVDMenu            *  pTargetMenu;
   int                   iJumpIndex; // The Jump to the actual menu after we played the transition video
-  QValueList<Source  *> listSource;
+  //Q3ValueList<Source  *> listSource;		//ooo
+  QList<Source  *> listSource;			//xxx
 };
 
 class ExportTitleset
@@ -99,10 +102,10 @@ public:
 	bool                          bSetByUser;
 	QString                       qsFormat;
 	DVDAuthor                  *  pExportDVDAuthor;
-	QValueList<DVDMenu         *> listMenus;              // all menus which fit the format.
-	QValueList<JumpTable       *> listJumpTable;          // the jump table
-	QValueList<SourceFileEntry *> listSourceFileEntries;
-	QValueList<ButtonTransition*> listButtonTransitions;
+	QList<DVDMenu         *> listMenus;              // all menus which fit the format.		//oxx
+	QList<JumpTable       *> listJumpTable;          // the jump table				//oxx
+	QList<SourceFileEntry *> listSourceFileEntries;							//oxx
+	QList<ButtonTransition*> listButtonTransitions;							//oxx
 };
 
 class PlayMultiple
@@ -151,7 +154,7 @@ private:
   void createJumpToMenu        ( SourceFileInfo *, DVDMenu *, uint );
   QString createFormatString   ( SourceFileInfo *, bool  b = false );
   QString createFormatString   ( DVDMenu * );
-  bool cleanUpSourceFileEntries( QValueList<SourceFileEntry *>   & );
+  bool cleanUpSourceFileEntries( QList<SourceFileEntry *>   & );	//oxx
   void cleanSourceFileEntris   ( );
 
   ExportTitleset *addToTitleset(SourceFileEntry *, int, bool b=false      );
@@ -179,16 +182,16 @@ private:
   QString jumpToSubMenu        ( SourceFileEntry  * );
   QString adjustChapterOffset  ( QStringList &, int );
   QString getFromFormat        ( QString &,     int );
-  void getButtonNumberFromName ( QValueList<ButtonObject *> &, QString & );
+  void getButtonNumberFromName ( QList<ButtonObject *> &, QString & );		//oxx
 
   bool m_bOutOfSpecDialog;
   bool m_bMenuZeroDialog;
   bool m_bInsertComments;
   QMap<void *, ButtonTransition *> m_mapTransitionFiles;
-  QValueList<DVDMenu *>            m_listOfAllMenus; 
-  QValueList<PlayMultiple *>       m_listPlayMultiple;
-  QValueList<ExportTitleset *>     m_listTitlesets;
-  QValueList<SourceFileEntry *>    m_listNewEntries;
+  QList<DVDMenu *>            m_listOfAllMenus;		//oxx
+  QList<PlayMultiple *>       m_listPlayMultiple;	//oxx
+  QList<ExportTitleset *>     m_listTitlesets;		//oxx
+  QList<SourceFileEntry *>    m_listNewEntries;		//oxx
   friend class ExportTitleset;
 };
 
@@ -206,7 +209,7 @@ public:
   bool createImageXml ( SourceFileInfo *, Subtitles * );
 
 protected:
-  bool correctOverlappingButtons ( QValueList<QRect> &, int, int );
+  bool correctOverlappingButtons ( QList<QRect> &, int, int );		//oxx
 
 };
 
