@@ -1,21 +1,27 @@
-/****************************************************************************
-** FrameObject class
-**
-**   Created : Tue Feb 02 22:06:51 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class is the encapsulation of the FrameObject.
-**
-** A FrameObject is a visible frame on a DVD menu.  
-**
+/***************************************************************************
+    frameobject.cpp
+                             -------------------
+                             
+    FrameObject class                         
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is the encapsulation of the FrameObject.
+   
+   A FrameObject is a visible frame on a DVD menu.
+    
 ****************************************************************************/
-#include <qpainter.h>
-#include <qwmatrix.h>
-#include <qpixmap.h>
-#include <qpopupmenu.h>
-#include <qlineedit.h>
+
+#include <QPainter>
+#include <QMatrix>
+#include <QPixmap>
+//#include <q3popupmenu.h>	//ooo
+#include <QLineEdit>
+//Added by qt3to4:
+#include <QMouseEvent>
 
 #include "messagebox.h"
 #include "global.h"
@@ -23,7 +29,7 @@
 #include "menuobject.h"
 #include "frameobject.h"
 #include "dialogframe.h"
-#include "dialogmatrix.h"
+#include "dialogmatrix.h"	//ooo
 #include "structuretoolbar.h"
 
 #include "qdvdauthor.h"
@@ -147,30 +153,42 @@ int FrameObject::join ()
   return frameData ( )->m_iFrameJoin;
 }
 
+/*void FrameObject::paintEvent( QPaintEvent* event )    //xxxx
+{
+  //QLabel::paintEvent( event );  
+  QPainter painter;
+  drawContents( &painter ); // ... additional drawing  
+}*/
+
 void FrameObject::drawContents (QPainter *painter)
 {
-        if ( m_pShadow && ! m_bDrawRect )
+    if ( m_pShadow && ! m_bDrawRect )
 	     m_pShadow->drawContents ( painter );
 	if ( frameData ( )->m_colorFrame.alpha ( ) == 0 )
 	  return;
 
-	QWMatrix theMatrix;
+	QMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
-	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
+	//centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));                       //ooo
+    centerPos.setX (rect().x() + static_cast<int>(static_cast<float>(rect().width ()) / 2.0));  //xxx
+	//centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));                       //ooo
+    centerPos.setY (rect().y() + static_cast<int>(static_cast<float>(rect().height()) / 2.0));  //xxx
 	// Here we define the cenetered rect.
-	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+	//QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());                           //ooo
+    QRect theRect (static_cast<int>(-(rect().width()/ 2.0)), static_cast<int>(-(rect().height()/2.0)), rect().width(), rect().height());    //xxx
 
-	QPen thePen (frameData ( )->m_colorFrame.rgb ( ), frameData ( )->m_iFrameWidth, (Qt::PenStyle)frameData ( )->m_iFrameStyle, Qt::FlatCap, (Qt::PenJoinStyle)frameData ( )->m_iFrameJoin);
+	//QPen thePen (frameData ( )->m_colorFrame.rgb ( ), frameData ( )->m_iFrameWidth, (Qt::PenStyle)frameData ( )->m_iFrameStyle, Qt::FlatCap, (Qt::PenJoinStyle)frameData ( )->m_iFrameJoin);		//ooo
+	QPen thePen (QBrush(QColor(frameData ( )->m_colorFrame.rgb())), frameData ( )->m_iFrameWidth, (Qt::PenStyle)frameData ( )->m_iFrameStyle, Qt::FlatCap, (Qt::PenJoinStyle)frameData ( )->m_iFrameJoin);	//xxx
 	// Set the PEN
 	painter->setPen(thePen);
 	// and make sure no Brush is used ...
 	painter->setBrush(Qt::NoBrush);
 
 	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
-
+	//theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());                          //ooo
+    theMatrix.translate (static_cast<double>(centerPos.x()), static_cast<double>(centerPos.y()));   //xxx
+    
 	//. then we apply the other modifications ...
 	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
 	theMatrix.rotate (modifiers()->fRotate);
@@ -178,7 +196,8 @@ void FrameObject::drawContents (QPainter *painter)
 	
 	// Here we draw the rect that encompasses the button (think of rotated)
 	m_boundingRect = theMatrix.mapRect(theRect);
-	if (m_bDrawRect)
+    
+	if (m_bDrawRect) //ooo
 	  drawActiveFrame ( painter );
 
 	painter->setWorldMatrix(theMatrix);
@@ -191,7 +210,7 @@ void FrameObject::drawContents (QPainter *painter)
 void FrameObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
   // Next is to set the AnimationAttributes
-  for ( uint t=0; t<m_listAnimationAttributes.count ( ); t++ )
+  for ( uint t=0; t<(uint)m_listAnimationAttributes.count ( ); t++ )
     m_listAnimationAttributes[t]->setValue(iRenderFrameNumber);
 
   // If start stop have been set then we check the range
@@ -203,7 +222,7 @@ void FrameObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 }
 
 bool FrameObject::mousePressEvent (QMouseEvent *pEvent)
-{
+{   
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
 		QPoint globalPos = pEvent->globalPos();
@@ -226,7 +245,9 @@ bool FrameObject::mouseDoubleClickEvent (QMouseEvent *)
 {
   QString qsAnimation;
   DialogFrame frameDialog ( m_pParent );
+
   frameDialog.initMe ( this );
+
   if ( frameDialog.exec ( ) == QDialog::Rejected )
     return false;
 
@@ -320,9 +341,9 @@ bool FrameObject::writeProjectFile (QDomElement &theElement)
 
 bool FrameObject::createContextMenu (QPoint globalPos)
 {
-        QString qsShadow;
+/*        QString qsShadow;
         QPoint globalPos2 = globalPos;
-	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	Q3PopupMenu *pStackMenu = new Q3PopupMenu(m_pParent);
 	pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
 	pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
 	pStackMenu->insertSeparator();
@@ -338,7 +359,7 @@ bool FrameObject::createContextMenu (QPoint globalPos)
 
 	if (m_pContextMenu)
 		delete m_pContextMenu;
-	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu = new Q3PopupMenu(m_pParent);
 	m_pContextMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit       ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix     ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete     ( ) ) );
@@ -358,7 +379,48 @@ bool FrameObject::createContextMenu (QPoint globalPos)
 	// Here we mark that the user called a menu item thus we don't want the
 	// base classes to continue with the mouse event
 //	if (iReturn != -1)
-		return true;
+		return true;*/	//ooo
+
+  QString qsShadow;
+  QPoint globalPos2 = globalPos;
+ 
+  qsShadow = tr ( "Add Shadow ..." );
+    if ( shadow ( ) )
+  qsShadow = tr ( "Edit Shadow ..." );
+  
+  if (m_pContextMenu)
+    delete m_pContextMenu;
+  
+  QAction *editNewAction = new QAction("Edit ...", this);
+  QAction *matrixNewAction = new QAction("Matrix ...", this);
+  QAction *deleteNewAction = new QAction("Delete", this);
+  QAction *shadowAction = new QAction(qsShadow, this);
+  QAction *defineAsButtonNewAction = new QAction("Define as Button", this);
+  
+  m_pContextMenu = new QMenu (m_pParent);
+  m_pContextMenu->addAction (editNewAction);
+  m_pContextMenu->addAction (matrixNewAction);
+  m_pContextMenu->addAction (deleteNewAction);
+  m_pContextMenu->addSeparator();
+  m_pContextMenu->addAction (shadowAction);
+  m_pContextMenu->addSeparator();
+  m_pContextMenu->addAction(defineAsButtonNewAction);
+  
+  connect(editNewAction,           SIGNAL(triggered()), this, SLOT( slotEdit            ( ) ) );
+  connect(matrixNewAction,         SIGNAL(triggered()), this, SLOT( slotMatrix          ( ) ) );
+  connect(deleteNewAction,         SIGNAL(triggered()), this, SLOT( slotDelete          ( ) ) );
+  connect(shadowAction,            SIGNAL(triggered()), this, SLOT( slotAddShadow       ( ) ) );
+  connect(defineAsButtonNewAction, SIGNAL(triggered()), this, SLOT( slotDefineAsButton  ( ) ) );
+  
+  m_pContextMenu->exec( globalPos2, deleteNewAction );
+  
+  if (m_pContextMenu)
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
+  // Here we mark that the user called a menu item thus we don't want the
+  // base classes to continue with the mouse event
+//	if (iReturn != -1)
+  return true;
 }
 
 StructureItem *FrameObject::createStructure ( StructureItem *pParentItem )
@@ -388,11 +450,14 @@ StructureItem *FrameObject::createStructure ( StructureItem *pParentItem )
   pFrameItem = m_pStructureItem;
   if ( ! pFrameItem ) {
     pFrameItem = new StructureItem ( this, StructureItem::Frame, pParentItem, pParentItem->lastChild ( ), qsName, qsInfo );
-    pFrameItem->setExpandable ( TRUE );
+    //pFrameItem->setExpandable ( TRUE );	//ooo
+    pFrameItem->setExpanded ( false );		//xxx
     m_pStructureItem = pFrameItem;
   }
   else
-    pFrameItem->setText ( qsName, qsInfo );
+    //pFrameItem->setText ( qsName, qsInfo );	//ooo
+    pFrameItem->setText ( 0, qsName );		//xxx
+    pFrameItem->setText ( 1, qsInfo );		//xxx
 
   QString qsArgs;
   qsArgs =  QString ( "%1, %2, %3, %4" ).
@@ -427,7 +492,7 @@ void FrameObject::slotEdit()
 }
 
 void FrameObject::slotMatrix()
-{
+{  
   if ( m_pMatrixDialog )
     return;
 
@@ -488,15 +553,18 @@ AnimationAttribute *FrameObject::getSpecificAttributes (long iMaxNumberOfFrames,
 	AnimationAttribute *pAnimAttr = NULL;
 	if (qsProperty == "color.red")	{
 		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(frameData ( )->m_colorFrame, TYPE_COLOR_RED);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.red(), callMeBack);
+		//pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.Qt::red(), callMeBack);	//ooo
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.red(), callMeBack);		//xxx
 	}
 	else if (qsProperty == "color.green")	{
 		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(frameData ( )->m_colorFrame, TYPE_COLOR_GREEN);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.green(), callMeBack);
+		//pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.Qt::green(), callMeBack);	//ooo
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.green(), callMeBack);		//xxx
 	}
 	else if (qsProperty == "color.blue")	{
 		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(frameData ( )->m_colorFrame, TYPE_COLOR_BLUE);
-		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.blue(), callMeBack);
+		//pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.Qt::blue(), callMeBack);	//ooo
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, frameData ( )->m_colorFrame.blue(), callMeBack);		//xxx
 	}
 	else if (qsProperty == "color.alpha")	{
 		FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(frameData ( )->m_colorFrame, TYPE_COLOR_ALPHA);
