@@ -1,23 +1,28 @@
-/****************************************************************************
-** Global variables
-**
-**   Created : Dec 2003
-**        by : Varol Okan using the kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class collects all possible information about
-** the current set stream.
-**
+/***************************************************************************
+    global.h
+                             -------------------
+    Global variables                         
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class collects all possible information about
+   the current set stream.
+    
 ****************************************************************************/
+
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
-#include <qstring.h>
-#include <qeventloop.h>
-#include <qvaluelist.h>
+//#include <qstring.h>			//ooo
+#include <QString>			//xxx
+//#include <qeventloop.h>		//ooo
+#include <QEventLoop>			//xxx
+#include <QList>
 // Include the logging facilities ...
-#include "utils.h"
+#include "utils.h"			//ooo
 #include "log.h"
 
 // Forward declartion of the Thumbs cache class
@@ -44,7 +49,7 @@ namespace Cache {
 		{"ffmpeg",        "FFMpeg",         "Optional.\n\nThis utility is part of the mplayer utilities. It can be used to convert  video into DVD confoming mpeg2.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nhttp://ffmpeg.mplayerhq.hu"}, \
 		{"png2yuv",       "PNG To YUV",     "Optional. Important.\n\nThis utility is used to create the mpeg2 video stream for Movie Menus.\nNote: without this tool you can not create MovieMenus.\nhttp://netpbm.sf.net"}, \
 		{"oggdec",        "Ogg Dec",        "Optional.\n\nThis utility will help to convert OGG audio files into a DVD conform format.\nThis will be implemented in the next release of 'Q' DVD-Author.\nogg to mp2 > oggdec test.ogg -o - | mp2enc -o test2.mp2"}, \
-		{"mp2enc",        "mp2 Enc",        "Optional !\n\nYou can also use toolame instead.\nThis utility converts a audio file into DVD conforming mp2 format."}, \
+		{"mp2enc",        "mp2 Enc",        "Optional !\n\nYou can also use twolame instead.\nThis utility converts a audio file into DVD conforming mp2 format."}, \
 		{"lame",          "Lame",           "Optional.\n\nNot used in the standard settings ... So why is this tool here ?\nmp3 to mp2 > lame --decode blues.mp3 - | mp2enc -o blues.mp2"}, \
 		{"mplayer",       "MPlayer",        "Optional.\n\nThis program / utility can be used to replace the xine engine.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nmp3 to mp2 > mplayer mymusicfile.mp3 -vo null -ao pcm -aofile menu_audio.pcm ; mp2enc -r 48000 -o menu_audio.mpa < menu_audio.pcm\nhttp://www.mplayerhq.hu"}, \
 		{"jpegtopnm",     "JPG To PNM",     "Optional.\n\nYou can also use jpeg2yuv instead.\nThis utility is used to convert a background image into a mpeg2 movie."}, \
@@ -52,7 +57,7 @@ namespace Cache {
 		{"mpeg2enc",      "MPEG2 Enc",      "Mandatory.\n\nThis utility is used to convert a background image into a mpeg2 movie.\nhttp://mjpeg.sf.net"}, \
 		{"jpeg2yuv",      "JPG To YUV",     "Optional.\n\nYou can also use jpegtopnm.\nThis utility is used to convert a background image into a mpeg2 movie."}, \
 		{"pcm2aiff",      "PCM To AIFF",    "Optional.\n\nNot used in the standard settings ... So why is this tool here ?"}, \
-		{"toolame",       "TooLame",        "Optional.\n\n"}, \
+		{"twolame",       "TwoLame",        "Optional.\n\n"}, \
 		{"mctoolame",     "MC TooLame",     "Optional.\n\n"}, \
 		{"dd",            "dd",             "Optional.\n\n"}, \
 		{"dvd-slideshow", "DVD-Slideshow",  "Optional. Important.\n\nThere is no substiutute for this utility.\nDVD-Slideshow is a bash script which generates the slideshow using the sox, convert, pngtopnm, mpeg2enc, and mp2enc utilities.\nhttp://dvd-slideshow.sf.net"}, \
@@ -163,7 +168,7 @@ public:
 	static MenuObject    *pCopyObject;
 	static SlideDefaults *pSlideDefaults;
 	// Here we store the path to the different tools required.
-	static QValueList<Utils::toolsPaths *> listToolsPaths;
+	static QList<Utils::toolsPaths *> listToolsPaths;	//ooo
 	static Cache::Thumbs *pThumbsCache;
 };
 
