@@ -8,9 +8,13 @@
   *********************************************************/
 #include <qmessagebox.h>
 #include <qstringlist.h>
-#include <qfiledialog.h>
+//#include <q3filedialog.h>   //ooo
+#include <QFileDialog>  //xxx
 #include <qfileinfo.h>
 #include <qimage.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QPainter> //xxx
 
 #include "global.h"
 #include "dvdmenu.h"
@@ -54,16 +58,18 @@ bool DVDAuthor::import ( )
   CXmlDVDAuthor theXmlStructure;
   CXmlSpumux   *pSpumux;
   QStringList   listFileNames, listOfFailures;
-  QValueList<CXmlSpumux *>spumuxList;
+  QList<CXmlSpumux *>spumuxList;	//oxx
   int           t, iResponse;
   bool          bSuccess, bReturn;
   QFileInfo     theFile;
 
   // Read in the dvdauthor file.
-  QString fileName = QFileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr ("dvdauthor XML file ( *.xml *.XML)"));
+  //QString fileName = Q3FileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr ("dvdauthor XML file ( *.xml *.XML)"));   //ooo
+  QString fileName = QFileDialog::getOpenFileName(NULL, QObject::tr("Open Project file dialog"), Global::qsCurrentPath, QObject::tr("dvdauthor XML file ( *.xml *.XML)"));	//xxx
 
   theFile.setFile ( fileName );
-  Global::qsCurrentPath = theFile.dirPath( true );
+  //Global::qsCurrentPath = theFile.dirPath( true );    //ooo
+  Global::qsCurrentPath = theFile.path( );  //xxx
 
   bSuccess = theXmlStructure.readXml ( fileName );
 
@@ -76,10 +82,12 @@ bool DVDAuthor::import ( )
 
   while ( iResponse == QMessageBox::Yes ) {
     listOfFailures.clear ();
-    listFileNames = QFileDialog::getOpenFileNames ( "*.xml", Global::qsCurrentPath, NULL, "OpenDvdauthorXml", "dvdauthor and spumux xml file selection");
+    //listFileNames = Q3FileDialog::getOpenFileNames ( "*.xml", Global::qsCurrentPath, NULL, "OpenDvdauthorXml", "dvdauthor and spumux xml file selection");    //ooo
+    QString fileName = QFileDialog::getOpenFileName(NULL, QObject::tr("OpenDvdauthorXml"), Global::qsCurrentPath, QObject::tr("dvdauthor and spumux xml file selection"));	//xxx
     if ( listFileNames.count() > 0 ) {
       theFile.setFile ( listFileNames[0] );
-      Global::qsCurrentPath = theFile.dirPath ( true );
+      //Global::qsCurrentPath = theFile.dirPath ( true );   //ooo
+      Global::qsCurrentPath = theFile.path ( ); //xxx
 
       for (t=0;t<(int)listFileNames.count();t++) {
 	pSpumux = new CXmlSpumux;
@@ -134,16 +142,16 @@ VMGMenu *DVDAuthor::takeVMGMenu ()
   return pVMGMenu;
 }
 
-QValueList<DVDMenu *> DVDAuthor::takeDVDMenus ()
+QList<DVDMenu *> DVDAuthor::takeDVDMenus ()	//oxx
 {
-  QValueList<DVDMenu *>list = m_listDVDMenus;
+  QList<DVDMenu *>list = m_listDVDMenus;	//oxx
   m_listDVDMenus.clear ();
   return list;
 }
 
-QValueList <SourceFileEntry *> DVDAuthor::takeSourceFileEntries ()
+QList <SourceFileEntry *> DVDAuthor::takeSourceFileEntries ()	//oxx
 {
-  QValueList<SourceFileEntry *>list = m_listSourceFileEntries;
+  QList<SourceFileEntry *>list = m_listSourceFileEntries;	//oxx
   m_listSourceFileEntries.clear ();
   return list;
 }
@@ -153,7 +161,7 @@ QValueList <SourceFileEntry *> DVDAuthor::takeSourceFileEntries ()
 // Private member functions.
 //
 ////////////////////////////////////////////////////////////
-bool DVDAuthor::buildFromDVDAuthorXML ( CXmlDVDAuthor *pDVDAuthor, QValueList<CXmlSpumux *> &spumuxList )
+bool DVDAuthor::buildFromDVDAuthorXML ( CXmlDVDAuthor *pDVDAuthor, QList<CXmlSpumux *> &spumuxList )	//oxx
 {
   if ( ! pDVDAuthor )
     return false;
@@ -299,7 +307,8 @@ bool DVDAuthor::buildMenuFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc, VMGMenu *pVM
       pInterface->listIntroVobs.append ( pPgc->ppArrayVob[ iVob++ ] );
 
     // but the last one becomes our DVDMenu - background.
-    pInterface->listIntroVobs.remove ( pPgc->ppArrayVob[ --iVob ] );
+    //pInterface->listIntroVobs.remove ( pPgc->ppArrayVob[ --iVob ] );  //ooo
+    pInterface->listIntroVobs.removeOne ( pPgc->ppArrayVob[ --iVob ] );  //xxx
     pInterface->qsMovieFileName = pPgc->ppArrayVob [ iVob ]->file;
     pInterface->qsPause = pPgc->ppArrayVob [ iVob ]->pause;
     // remove this VOB object as we got all information we needed from it.
@@ -385,7 +394,8 @@ bool DVDAuthor::buildTitleFromPgc ( CXmlDVDAuthor::pgc_struct *pPgc )
     pVob  = pPgc->ppArrayVob[ iVob++ ];
 
     pInfo->qsFileName   = pVob->file;
-    pInfo->listChapters = QStringList::split ( ',', pVob->chapters );
+    //pInfo->listChapters = QStringList::split ( ',', pVob->chapters ); //ooo
+    pInfo->listChapters = pVob->chapters.split ( ',' );   //xxx
     pInfo->iTitleset    = m_iCurrentTitleset;
     if ( ( pVob->pause == QString ("inf") ) || ( pVob->pause.isEmpty() ) )
       pInfo->iPause     = -1;
@@ -442,7 +452,7 @@ DVDMenu *DVDAuthor::findMenuFromSpu ( CXmlSpumux::spu_struct *pSpu )
   bool bWeHaveAWinner;
   int  iXMLButtons, iMenu = 0;
   CXmlSpumux::button_struct *pXMLButton;
-  QValueList <ButtonObject  *>listOfButtons;
+  QList <ButtonObject  *>listOfButtons;		//oxx
   ButtonObject *pButtonObject;
   DVDMenu *pMenu = m_pVMGMenu;
 
@@ -497,7 +507,7 @@ CXmlSpumux::button_struct *DVDAuthor::findButtonObjectInArray ( CXmlSpumux::butt
   return NULL;
 }
 
-ButtonObject *DVDAuthor::findXMLButtonInList ( QValueList<ButtonObject *> &listOfButtons, CXmlSpumux::button_struct *pXMLButton )
+ButtonObject *DVDAuthor::findXMLButtonInList ( QList<ButtonObject *> &listOfButtons, CXmlSpumux::button_struct *pXMLButton )	//oxx
 {
   uint t;
   ButtonObject *pButtonObject;
@@ -521,7 +531,7 @@ DVDMenu *DVDAuthor::addSpuInfoToMenu ( CXmlSpumux::spu_struct *pSpu, DVDMenu *pM
   // At this point we have the same number of buttons with the corresponding button name
   // So we should extract the button dimensions and also generate the button images / masks.
   CDVDMenuInterface       *pMenuInterface = pMenu->getInterface ();
-  QValueList<ButtonObject *>listOfButtons = pMenu->getButtons   ();
+  QList<ButtonObject *>listOfButtons = pMenu->getButtons   ();	//oxx
   CXmlSpumux::button_struct *pXMLButton;
   ButtonObject *pButtonObject;
   QRect theRect;
@@ -577,7 +587,7 @@ void DVDAuthor::validateButtons ( DVDMenu *pDVDMenu )
   if ( ! pDVDMenu )
     return;
   uint t, iCount, iX, iY, iButtonWidth, iButtonHeight, iDeltaX, iDeltaY, iButtonX, iButtonY;
-  QValueList<ButtonObject *> listOfButtons = pDVDMenu->getButtons ( );
+  QList<ButtonObject *> listOfButtons = pDVDMenu->getButtons ( );	//oxx
   ButtonObject *pButton;
   TextObject   *pText;
   QRect         theRect;
@@ -632,10 +642,16 @@ ImageObject *DVDAuthor::getButtonImageFromLayer ( DVDMenu *pMenu, QRect &theRect
     return NULL;
 
   Utils        theUtil;
-  QImage       theButtonImage ( theRect.width(), theRect.height(), 8, 256); //, theImage.depth() );
+  //QImage       theButtonImage ( theRect.width(), theRect.height(), 8, 256); //, theImage.depth() );   //ooo
+  QImage       theButtonImage ( theRect.width(), theRect.height(), QImage::Format_ARGB32); //, theImage.depth() ); //xxx
   ImageObject *pImage = new ImageObject ( pMenu->getMenuPreview () );
 
-  bitBlt ( &theButtonImage, 0, 0, &theImage, theRect.x(), theRect.y(), theRect.width(), theRect.height(), Qt::CopyROP );
+  //bitBlt ( &theButtonImage, 0, 0, &theImage, theRect.x(), theRect.y(), theRect.width(), theRect.height(), Qt::CopyROP );	//ooo
+  //bitBlt ( &theButtonImage, 0, 0, &theImage, theRect.x(), theRect.y(), theRect.width(), theRect.height() );			//xxx
+  
+  QPainter p( &theButtonImage );    //xxx
+  p.drawImage( 0, 0, theImage, theRect.x(), theRect.y(), theRect.width(), theRect.height() );	//xxx
+  
   qsFileName = theUtil.getUniqueTempFile(DRAGGED_IMAGE_NAME);
   theButtonImage.save (qsFileName, "PNG");
 
