@@ -11,7 +11,7 @@
 #ifndef __IMPORT_DVDAUTHOR_H__
 #define __IMPORT_DVDAUTHOR_H__
 
-#include <qvaluelist.h>
+//#include <q3valuelist.h>	//oxx
 
 class SourceFileEntry;
 class CXmlDVDAuthor;
@@ -31,10 +31,10 @@ public:
   
   bool                          import               ();
   void                          clear          ( bool );
-  QValueList<DVDMenu *>         takeDVDMenus         ();
+  QList<DVDMenu *>         takeDVDMenus         ();				//oxx
   VMGMenu                      *takeVMGMenu          ();
-  QValueList<SourceFileEntry *> takeSourceFileEntries();
-  bool buildFromDVDAuthorXML ( CXmlDVDAuthor *, QValueList<CXmlSpumux *> &);
+  QList<SourceFileEntry *> takeSourceFileEntries();				//oxx
+  bool buildFromDVDAuthorXML ( CXmlDVDAuthor *, QList<CXmlSpumux *> &);		//oxx
 
 private:
   bool buildFromVMGM         ( CXmlDVDAuthor::vmgm_struct     * );
@@ -53,15 +53,15 @@ private:
   DVDMenu *addSpuInfoToMenu  ( CXmlSpumux::spu_struct *, DVDMenu * );
 
   void          validateButtons         ( DVDMenu * );
-  ButtonObject *findXMLButtonInList     ( QValueList<ButtonObject *> &, CXmlSpumux::button_struct * );
+  ButtonObject *findXMLButtonInList     ( QList<ButtonObject *> &, CXmlSpumux::button_struct * );	//oxx
   ImageObject  *getButtonImageFromLayer ( DVDMenu *, QRect &, QString );
   CXmlSpumux::button_struct *findButtonObjectInArray ( CXmlSpumux::button_struct **, ButtonObject * );
 
 private:
   QDVDAuthor                   *m_pDVDAuthor;
-  QValueList<DVDMenu *>         m_listDVDMenus;
+  QList<DVDMenu *>         m_listDVDMenus;		//oxx
   VMGMenu                      *m_pVMGMenu;
-  QValueList<SourceFileEntry *> m_listSourceFileEntries;
+  QList<SourceFileEntry *> m_listSourceFileEntries;	//oxx
   int                           m_iCurrentTitleset;
 };
 
