@@ -1,18 +1,27 @@
-/****************************************************************************
-** importsrt.cpp
-**
-**   Created :
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This file holds the implementation of the import filter for the srt 
-** subtitles file.
-*****************************************************************************/
+/***************************************************************************
+    importsrt.cpp
+                             -------------------
+    ButtonObject class                             
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This file holds the implementation of the import filter for the srt 
+    subtitles file.
+    
+****************************************************************************/
 
 #include <qfile.h>
 #include <qobject.h>
-#include <qfiledialog.h>
+//#include <q3filedialog.h> //ooo
+#include <QFileDialog>      //xxx
+#include <QTime>		//xxx
+//Added by qt3to4:
+//#include <Q3TextStream>   //ooo
+#include <QTextStream>      //xxx
+//#include <Q3ValueList>	//oxx
 
 #include "global.h"
 #include "importsrt.h"
@@ -26,7 +35,8 @@ BaseSubtitle::BaseSubtitle ( )
 
 BaseSubtitle::~BaseSubtitle ( )
 {
-  for (uint t=0;t<m_listOfEntries.count(); t++)
+  //for (uint t=0;t<m_listOfEntries.count(); t++)   //ooo
+  for (uint t=0;t<static_cast<uint> ( m_listOfEntries.count() ); t++)   //ooo
     delete m_listOfEntries[t];
   m_listOfEntries.clear ();
 }
@@ -46,13 +56,16 @@ Srt::~Srt ()
 
 bool Srt::import ( )
 {
-  QString qsImportFile = QFileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr("Subtitle files (*.srt *.SRT)"), NULL, QObject::tr("Open Subtitles File") );
+  //QString qsImportFile = Q3FileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr("Subtitle files (*.srt *.SRT)"), NULL, QObject::tr("Open Subtitles File") );  //ooo
+  QStringList qsImportFile = QFileDialog::getOpenFileNames ( NULL, QObject::tr("Open Subtitles File"), Global::qsCurrentPath, QObject::tr("Subtitle files (*.srt *.SRT)") );    //xxx
 
   // Sanity check .. Did te user choose a new project file ?
-  if (qsImportFile.isNull ())
+  //if (qsImportFile.isNull ()) //ooo
+  if (qsImportFile.isEmpty ())  //xxx
     return false;
 
-  return readFile ( qsImportFile );
+  //return readFile ( qsImportFile );   //ooo
+  return readFile ( qsImportFile[0] );  //xxx
 }
 
 bool Srt::readFile ( QString &fileName )
@@ -64,10 +77,11 @@ bool Srt::readFile ( QString &fileName )
   Subtitles::entry *pEntry;
   QString line, lineIndex, lineTimestamp, lineText;
   QFile projectFile ( fileName );
-  if (!projectFile.open ( IO_ReadOnly ) )
+  if (!projectFile.open ( QIODevice::ReadOnly ) )
     return false;
 
-  QTextStream srtStream( &projectFile );
+  //Q3TextStream srtStream( &projectFile ); //ooo
+  QTextStream srtStream( &projectFile );    //xxx
 
   lineIndex = srtStream.readLine();
   while ( !srtStream.atEnd() ) {
@@ -87,7 +101,8 @@ bool Srt::readFile ( QString &fileName )
   return true;
 }
 
-QString Srt::readEntry ( QTextStream *pStream, Subtitles::entry *pEntry )
+//QString Srt::readEntry ( Q3TextStream *pStream, Subtitles::entry *pEntry )    //ooo
+QString Srt::readEntry ( QTextStream *pStream, Subtitles::entry *pEntry )       //xxx
 {
   int t;
   bool bTrailing = true;
@@ -143,7 +158,8 @@ bool Srt::isTimeStamp ( QString &line )
 {
   line = line;
 
-  if ( ( line.find ("-->") > -1 ) && ( line.contains (':') >= 3) )
+  //if ( ( line.find ("-->") > -1 ) && ( line.contains (':') >= 3) )	//ooo
+  if ( ( line.indexOf ("-->") > -1 ) && ( line.count (':') >= 3) )	//xxx
     return true;
   return false;
 }
@@ -151,14 +167,17 @@ bool Srt::isTimeStamp ( QString &line )
 QString Srt::getTimeRange ( QString &line, bool bStartTime )
 {
   QString qsReturn;
-  int iPos = line.find ( "-->" );
+  //int iPos = line.find ( "-->" );     //ooo
+  int iPos = line.indexOf ( "-->" );    //xxx
 
   if ( iPos < 1 )
     return qsReturn;
   if ( bStartTime )
-    qsReturn = line.left ( iPos ).stripWhiteSpace ( );
+    //qsReturn = line.left ( iPos ).stripWhiteSpace ( );    //ooo
+    qsReturn = line.left ( iPos ).simplified ( );           //xxx
   else
-    qsReturn = line.right ( line.length() - iPos -3 ).stripWhiteSpace ( );
+    //qsReturn = line.right ( line.length() - iPos -3 ).stripWhiteSpace ( );    //ooo
+    qsReturn = line.right ( line.length() - iPos -3 ).simplified ( );           //xxx
 
   return qsReturn;
 }
@@ -172,15 +191,15 @@ long Srt::getTimeFromString ( QString &qsTime )
   return iMSeconds;
 }
 
-QValueList<Subtitles::entry *> Srt::takeSubtitles ( )
+QList<Subtitles::entry *> Srt::takeSubtitles ( )	//oxx
 {
   // and then we pass them on to the caller.
-  QValueList<Subtitles::entry *>list = m_listOfEntries;
+  QList<Subtitles::entry *>list = m_listOfEntries;	//oxx
   m_listOfEntries.clear ( );
   return list;
 }
 
-QValueList<Subtitles::entry *> &Srt::getSubtitles ( )
+QList<Subtitles::entry *> &Srt::getSubtitles ( )	//oxx
 {
   return m_listOfEntries;
 }
