@@ -1,25 +1,31 @@
-/****************************************************************************
-** importssa.cpp
-**
-**   Created :
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This file holds the implementation of the import filter for the
-** saa and ass subtitles file.
-**
-** saa = SubStationAlpha Version 4
-** ass = AdvancedSubStation Verion 4+
-**
-** http://en.wikipedia.org/wiki/SubStation_Alpha
-**
-*****************************************************************************/
+/***************************************************************************
+    importssa.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This file holds the implementation of the import filter for the
+    saa and ass subtitles file.
+
+    saa = SubStationAlpha Version 4
+    ass = AdvancedSubStation Verion 4+
+
+    http://en.wikipedia.org/wiki/SubStation_Alpha
+    
+****************************************************************************/
 
 #include <qfile.h>
 #include <qregexp.h>
 #include <qobject.h>
-#include <qfiledialog.h>
+//#include <q3filedialog.h> //ooo
+#include <QFileDialog>      //xxx
+//Added by qt3to4:
+//#include <Q3TextStream>   //ooo
+#include <QTextStream>      //xxx
+//#include <Q3ValueList>	//oxx
 
 #include "global.h"
 #include "importssa.h"
@@ -85,12 +91,12 @@ Ssa::~Ssa ( )
 {
   clearEntries ( );
 
-  QValueList<Style *>::iterator it = m_listOfStyles.begin ( );
+  QList<Style *>::iterator it = m_listOfStyles.begin ( );	//oxx
   while ( it != m_listOfStyles.end ( ) )
     delete *it++;
   m_listOfStyles.clear ( );
 
-  QValueList<Event *>::iterator it2 = m_listOfEvents.begin ( );
+  QList<Event *>::iterator it2 = m_listOfEvents.begin ( );	//oxx
   while ( it2 != m_listOfEvents.end ( ) )
     delete *it2++;
   m_listOfEvents.clear ( );
@@ -98,13 +104,16 @@ Ssa::~Ssa ( )
 
 bool Ssa::import ()
 {
-  QString qsImportFile = QFileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr("Subtitle files (*.ssa *.ass *.SSA *.ASS)" ), NULL, QObject::tr ( "Open Subtitles File" ) );
+  //QString qsImportFile = Q3FileDialog::getOpenFileName ( Global::qsCurrentPath, QObject::tr("Subtitle files (*.ssa *.ass *.SSA *.ASS)" ), NULL, QObject::tr ( "Open Subtitles File" ) );  //ooo
+  QStringList qsImportFile = QFileDialog::getOpenFileNames ( NULL, QObject::tr ( "Open Subtitles File" ), Global::qsCurrentPath, QObject::tr("Subtitle files (*.ssa *.ass *.SSA *.ASS)" ) );    //xxx
 
   // Sanity check .. Did te user choose a new project file ?
-  if ( qsImportFile.isNull ( ) )
+  //if ( qsImportFile.isNull ( ) )  //ooo
+  if ( qsImportFile.isEmpty ( ) )   //xxx
     return false;
 
-  return readFile ( qsImportFile );
+  //return readFile ( qsImportFile );   //ooo
+  return readFile ( qsImportFile[0] );  //xxx
 }
 
 bool Ssa::readFile ( QString &fileName )
@@ -118,19 +127,23 @@ bool Ssa::readFile ( QString &fileName )
   QRegExp rx ( "\\[script info\\]" );
 
   QFile  projectFile ( fileName );
-  if ( ! projectFile.open ( IO_ReadOnly ) )
+  if ( ! projectFile.open ( QIODevice::ReadOnly ) )
     return false;
 
-  QTextStream ssaStream ( &projectFile );
+  //Q3TextStream ssaStream ( &projectFile );    //ooo
+  QTextStream ssaStream ( &projectFile );       //xxx
   while ( (  !  ssaStream.atEnd ( ) ) && ( ! bExitLoop ) ) {
     line = ssaStream.readLine   ( );
-    temp = line.stripWhiteSpace ( );
+    //temp = line.stripWhiteSpace ( );  //ooo
+    temp = line.simplified ( );         //xxx
     // Filter out commenting lines
     if  ( temp[0] == ';' )
       continue;
-    temp = line.lower ( );
+    //temp = line.lower ( );    //ooo
+    temp = line.toLower ( );    //xxx
     // Find the header
-    if ( temp.find ( rx ) == -1 )
+    //if ( temp.find ( rx ) == -1 )     //ooo
+    if ( temp.indexOf ( rx ) == -1 )    //xxx
       continue;
 
     // If we get here, we have found the [Script Info] - header
@@ -142,7 +155,8 @@ bool Ssa::readFile ( QString &fileName )
   return true;
 }
 
-bool Ssa::readScriptInfo ( QTextStream &ssaStream )
+//bool Ssa::readScriptInfo ( Q3TextStream &ssaStream )  //ooo
+bool Ssa::readScriptInfo ( QTextStream &ssaStream )     //xxx
 {
   QStringList list;
   QString line, temp;
@@ -151,30 +165,38 @@ bool Ssa::readScriptInfo ( QTextStream &ssaStream )
 
   while ( ! ssaStream.atEnd ( ) )  {
     line = ssaStream.readLine ( );
-    temp = line.stripWhiteSpace ( );
+    //temp = line.stripWhiteSpace ( );  //ooo
+    temp = line.simplified ( );         //xxx
     // Filter out commenting lines
     if  ( temp[0] == ';' )
       continue;
 
-    list = QStringList::split ( ":", line );
+    //list = QStringList::split ( ":", line );  //ooo
+    list = line.split ( ":" );                  //xxx
     if ( list.count ( ) == 2 )  {
       // Here we extract the variables for the Script class.
-      if ( list[0].find ( "PlayResX" ) > -1 )
+      //if ( list[0].find ( "PlayResX" ) > -1 )     //ooo
+      if ( list[0].indexOf ( "PlayResX" ) > -1 )    //xxx
         m_script.m_iPlayResX = list[1].toInt ( );
-      else if ( list[0].find ( "PlayResY" ) > -1 )
+      //else if ( list[0].find ( "PlayResY" ) > -1 )    //ooo
+      else if ( list[0].indexOf ( "PlayResY" ) > -1 )   //xxx
         m_script.m_iPlayResY = list[1].toInt ( );
-      else if ( list[0].find ( "Timer" ) > -1 )  {
+      //else if ( list[0].find ( "Timer" ) > -1 )  {    //ooo
+      else if ( list[0].indexOf ( "Timer" ) > -1 )  {   //xxx
         // Convert 100,0000 to 100.0f
         list[1].replace ( ",", "." );
         m_script.m_fTimerMultiply = list[1].toFloat ( );
       }
     }
     else  {
-      temp = line.lower ( );
+      //temp = line.lower ( );  //ooo
+      temp = line.toLower ( );  //xxx
       // Find the header
-      if ( temp.find ( rxSSA ) != -1 )
+      //if ( temp.find ( rxSSA ) != -1 )    //ooo
+      if ( temp.indexOf ( rxSSA ) != -1 )   //xxx
         return readSSAStyles ( ssaStream );
-      else if ( temp.find( rxASS ) != -1 )
+      //else if ( temp.find( rxASS ) != -1 )    //ooo
+      else if ( temp.indexOf( rxASS ) != -1 )   //xxx
         return readASSStyles ( ssaStream );
     }
   }
@@ -183,7 +205,8 @@ bool Ssa::readScriptInfo ( QTextStream &ssaStream )
 }
 
 // [V4 Styles]
-bool Ssa::readSSAStyles ( QTextStream &ssaStream )
+//bool Ssa::readSSAStyles ( Q3TextStream &ssaStream )   //ooo
+bool Ssa::readSSAStyles ( QTextStream &ssaStream )      //xxx
 {
 // [V4 Styles]
 // Format: Name, Fontname, Fontsize, PrimaryColour, SecondaryColour, TertiaryColour, BackColour, Bold, Italic, BorderStyle, Outline, Shadow, Alignment, MarginL, MarginR, MarginV, AlphaLevel, Encoding
@@ -194,7 +217,8 @@ bool Ssa::readSSAStyles ( QTextStream &ssaStream )
 }
 
 // [V4+ Styles]
-bool Ssa::readASSStyles ( QTextStream &ssaStream )
+//bool Ssa::readASSStyles ( Q3TextStream &ssaStream )   //ooo
+bool Ssa::readASSStyles ( QTextStream &ssaStream )      //xxx
 {
 // [V4+ Styles]
 // Format: Name, Fontname, Fontsize, PrimaryColour, SecondaryColour, OutlineColour, BackColour, Bold, Italic, Underline, StrikeOut, ScaleX, ScaleY, Spacing, Angle, BorderStyle, Outline, Shadow, Alignment, MarginL, MarginR, MarginV, Encoding
@@ -208,26 +232,32 @@ bool Ssa::readASSStyles ( QTextStream &ssaStream )
 
   while ( ! ssaStream.atEnd ( ) )  {
     line = ssaStream.readLine ( );
-    temp = line.stripWhiteSpace ( );
+    //temp = line.stripWhiteSpace ( );  //ooo
+    temp = line.simplified ( );         //xxx
     // Filter out commenting lines
     if  ( temp[0] == ';' )
       continue;
 
-    temp = line.lower ( );
+    //temp = line.lower ( );    //ooo
+    temp = line.toLower ( );    //xxx
     // Find the header
-    if ( temp.find ( rxEvents ) !=  -1 )
+    //if ( temp.find ( rxEvents ) !=  -1 )  //ooo
+    if ( temp.indexOf ( rxEvents ) !=  -1 ) //xxx
       return readEvents ( ssaStream );
 
-    list = QStringList::split ( ":", line );
+    //list = QStringList::split ( ":", line );  //ooo
+    list = line.split ( ":" );                  //xxx
     if ( list.count ( ) < 2 )
       continue;
 
     if ( list[0] == "Format" )  {
-      format = QStringList::split ( ",", list[1].remove ( " " ) );
+      //format = QStringList::split ( ",", list[1].remove ( " " ) );    //ooo
+      format = list[1].remove ( " " ).split ( "," );                    //xxx
       continue;
     }
 
-    style = QStringList::split ( ",", list[1], true );
+    //style = QStringList::split ( ",", list[1], true );    //ooo
+    style = list[1].split ( "," );                          //xxx
     if ( style.count ( ) != format.count ( ) )
       continue;
 
@@ -288,13 +318,14 @@ bool Ssa::readASSStyles ( QTextStream &ssaStream )
   return false;
 }
 
-bool Ssa::readEvents ( QTextStream &ssaStream )
+//bool Ssa::readEvents ( Q3TextStream &ssaStream )  //ooo
+bool Ssa::readEvents ( QTextStream &ssaStream )     //xxx
 {
 // [Events]
 // Format: Layer, Start, End, Style, Name, MarginL, MarginR, MarginV, Effect, Text
 // Dialogue: 0,0:00:30.52,0:00:32.96,*Default,,0000,0000,0000,,I first went to\NRussia in 1938
 
-  QValueList<Style *>::iterator it;
+  QList<Style *>::iterator it;		//oxx
   QStringList list, format, event;
   Event *pEvent = NULL;
   Style *pStyle = NULL;
@@ -304,22 +335,26 @@ bool Ssa::readEvents ( QTextStream &ssaStream )
 
   while ( ! ssaStream.atEnd ( ) )  {
     line = ssaStream.readLine ( );
-    temp = line.stripWhiteSpace ( );
+    //temp = line.stripWhiteSpace ( );  //ooo
+    temp = line.simplified ( );         //xxx
     // Filter out commenting lines
     if  ( temp[0] == ';' )
       continue;
 
-    list = QStringList::split ( ":", line );
+    //list = QStringList::split ( ":", line );  //ooo
+    list = line.split ( ":" );                  //xxx
     if ( list.count ( ) < 2 )
       continue;
 
     if ( list[0] == "Format" )  {
-      format = QStringList::split ( ",", list[1].remove ( " " ) );
+      //format = QStringList::split ( ",", list[1].remove ( " " ) );    //ooo
+      format = list[1].remove ( " " ).split ( "," );                    //xxx
       continue;
     }
     else if ( list[0] == "Dialogue" )  {
       line = line.right  ( line.length ( ) - 9 );
-      event = QStringList::split   ( ",", line, true );
+      //event = QStringList::split   ( ",", line, true );   //ooo
+      event = line.split   ( "," );                         //xxx
       if ( event.count ( ) != format.count ( ) )
         continue;
 
@@ -390,7 +425,7 @@ Rgba Ssa::toRgba ( QString &qsClr )
 
 void Ssa::clearEntries ( )
 {
-  QValueList<Subtitles::entry *>::iterator it = m_listOfEntries.begin ( );
+  QList<Subtitles::entry *>::iterator it = m_listOfEntries.begin ( );	//oxx
   while ( it != m_listOfEntries.end ( ) )
     delete *it++;
   m_listOfEntries.clear ( );
@@ -416,7 +451,7 @@ void Ssa::toSubtitles ( )
   int     iPos, iIndex = 0;
   long    iStartTime, iEndTime;
   Subtitles::entry *pEntry = NULL;
-  QValueList<Event *>::iterator it = m_listOfEvents.begin ( );
+  QList<Event *>::iterator it = m_listOfEvents.begin ( );	//oxx
   while ( it != m_listOfEvents.end ( ) )  {
     pEvent = *it++;
 
@@ -449,28 +484,32 @@ void Ssa::toSubtitles ( )
     qsText.replace ( "\\s0", "</s>" );
 
     iPos = 0;
-    while ( ( iPos = rxFontSize.search ( qsText, iPos ) ) != -1 ) {
+    //while ( ( iPos = rxFontSize.search ( qsText, iPos ) ) != -1 ) {   //ooo
+    while ( ( iPos = rxFontSize.indexIn ( qsText, iPos ) ) != -1 ) {    //xxx
 //    if ( rxFontSize.search ( ) > -1 )  {
       QString qsFontSize = rxFontSize.cap ( 1 );
       qsFontSize = QString ( "<font size=\"%1\">" ).arg ( qsFontSize );
       qsText.replace ( rxFontSize, qsFontSize );
     }
     iPos = 0;
-    while ( ( iPos = rxFontSize2.search ( qsText, iPos ) ) != -1 ) {
+    //while ( ( iPos = rxFontSize2.search ( qsText, iPos ) ) != -1 ) {  //ooo
+    while ( ( iPos = rxFontSize2.indexIn ( qsText, iPos ) ) != -1 ) {   //xxx
 //    if ( rxFontSize2.search ( ) > -1 )  { // font size without curly brackets
       QString qsFontSize = rxFontSize2.cap ( 1 );
       qsFontSize = QString ( "<font size=\"%1\">" ).arg ( qsFontSize );
       qsText.replace ( rxFontSize2, qsFontSize );
     }
     iPos = 0;
-    while ( ( iPos = rxFontName.search ( qsText, iPos ) ) != -1 ) {
+    //while ( ( iPos = rxFontName.search ( qsText, iPos ) ) != -1 ) {   //ooo
+    while ( ( iPos = rxFontName.indexIn ( qsText, iPos ) ) != -1 ) {    //xxx
 //    if ( rxFontName.search ( ) > -1 )  {
       QString qsFontName = rxFontName.cap ( 1 );
       qsFontName = QString ( "<font face=\"%1\">" ).arg ( qsFontName );
       qsText.replace ( rxFontName, qsFontName );
     }
     iPos = 0;
-    while ( ( iPos = rxFontName2.search ( qsText, iPos ) ) != -1 ) {
+    //while ( ( iPos = rxFontName2.search ( qsText, iPos ) ) != -1 ) {  //ooo
+    while ( ( iPos = rxFontName2.indexIn ( qsText, iPos ) ) != -1 ) {   //xxx
 //    if ( rxFontName2.search ( ) > -1 )  { // Font name without curly brackets
       QString qsFontName = rxFontName.cap ( 1 );
       qsFontName = QString ( "<font face=\"%1\">" ).arg ( qsFontName );
@@ -491,18 +530,18 @@ void Ssa::toSubtitles ( )
 //printf ( "%s::%d > entries<%d> events<%d> styles<%d>\n", __FILE__, __LINE__, (int)m_listOfEntries.count ( ), (int)m_listOfEvents.count ( ), (int)m_listOfStyles.count ( ) );
 }
 
-QValueList<Subtitles::entry *> Ssa::takeSubtitles ( )
+QList<Subtitles::entry *> Ssa::takeSubtitles ( )	//oxx
 {
   // First we create the Subtitles
   toSubtitles ( );
 
   // and then we pass them on to the caller.
-  QValueList<Subtitles::entry *>list = m_listOfEntries;
+  QList<Subtitles::entry *>list = m_listOfEntries;	//oxx
   m_listOfEntries.clear ( );
   return list;
 }
 
-QValueList<Subtitles::entry *> &Ssa::getSubtitles ( )
+QList<Subtitles::entry *> &Ssa::getSubtitles ( )	//oxx
 {
   // First we create the Subtitles
   toSubtitles ( );
