@@ -1,18 +1,24 @@
-/****************************************************************************
-** Keyword - class
-**
-**   Created : Fri Dec 09 22:06:51 2005
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class will replace a given token in a string with the set value.
-** This class is currently only used in QDVDAuthorInit to help generate
-** the correct commands.
-**
+/***************************************************************************
+    keyword.cpp
+                             -------------------
+    Keyword - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class will replace a given token in a string with the set value.
+   This class is currently only used in QDVDAuthorInit to help generate
+   the correct commands.
+    
 ****************************************************************************/
 
 #include "qdvdauthorinit.h"
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QMessageBox>		//xxx
+
 #include "keyword.h"
 
 Keyword::Keyword ()
@@ -145,27 +151,28 @@ bool Keyword::setValue ( int iWhichKeyset, int iWhichKey, QString qsValue )
   return true;
 }
 
-void Keyword::setKeywords ( int iWhichKeys, QValueList<QString> listKeywords )
+void Keyword::setKeywords ( int iWhichKeys, QList<QString> listKeywords )	//oxx
 {
   uint t;
   clear ( iWhichKeys );
-  for ( t=0;t<listKeywords.count();t++)
+  for ( t=0;t<(uint)listKeywords.count();t++)
     setValue ( iWhichKeys, t, listKeywords[t] );
 }
 
 QString Keyword::resolvString ( int iWhichKeyset, QString qsInput)
-{
+{ 
   // This function resolves the variables in the stored commands / comments / names like
   // +MENU_NAME+, +WIDTH+, +BACKGROUND_FILE_NAME+ etc.
   QString qsOutput = qsInput;
   uint t;
 
-  for (t=0;t<m_listOfPair[iWhichKeyset].count();t++)	{
+  for (t=0;t<(uint)m_listOfPair[iWhichKeyset].count();t++)	{
     // Here we replace the actual keyword with the real string.
     if ( (m_listOfPair[iWhichKeyset][t]->qsValue.isNull()) || (m_listOfPair[iWhichKeyset][t]->qsValue.isEmpty()) )
       continue;
     qsOutput.replace ( m_listOfPair[iWhichKeyset][t]->qsKey, m_listOfPair[iWhichKeyset][t]->qsValue );
   }
+
   return qsOutput;
 }
 
@@ -192,7 +199,7 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
   QString qsAudioBitrate, qsVideoBitrate;
   long iAudioBitrate, iVideoBitrate, iStartingAt, iEndingAt, iDuration;
 
-  for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
+  for (t=0;t<(uint)m_listOfPair[TransKeys].count();t++)	{
     qsValue = value ( TransKeys, t );
     stringArray[t] = qsValue;
   }
@@ -232,7 +239,8 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
 
   qsValue = stringArray[ TransAudioType ];
   // default it to mp2 and only allow ac3, and pcm
-  qsValue = qsValue.lower ( );
+  //qsValue = qsValue.lower ( );	//ooo
+  qsValue = qsValue.toLower ( );	//xxx
   if ( ( qsValue != "mp2" ) && ( qsValue != "pcm" ) )
          qsValue  = "ac3";
   stringArray[ TransAudioType ] = qsValue;
@@ -245,7 +253,8 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
        iVideoBitrate = 1856;	// Note: How to handle no audio (0) ?
   stringArray[ TransVideoBitrate ] = QString ("%1").arg( iVideoBitrate );
 
-  if (qsConversionTool.find ( SUB_BLOCK_TRANSCODE ) > -1 )	{
+  //if (qsConversionTool.find ( SUB_BLOCK_TRANSCODE ) > -1 )	{	//ooo
+  if (qsConversionTool.indexOf ( SUB_BLOCK_TRANSCODE ) > -1 )	{	//xxx
     qsRatio = stringArray[ TransRatio ];
     if ( qsRatio == QString ("1:1"))
       qsRatio = QString ("1");
@@ -259,7 +268,8 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsRatio = QString ("2");
     stringArray[ TransRatio ] = qsRatio;
   }
-  else if (qsConversionTool.find ( SUB_BLOCK_MENCODER ) > -1 )	{
+  //else if (qsConversionTool.find ( SUB_BLOCK_MENCODER ) > -1 )	{	//ooo
+  else if (qsConversionTool.indexOf ( SUB_BLOCK_MENCODER ) > -1 )	{	//xxx
     bool bOkay;
     QString qsSampleRate = stringArray[ TransSampleRate ];
     int iSampleRate      = qsSampleRate.toInt ( &bOkay );
@@ -298,7 +308,8 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsFrameRate = "25";
     stringArray[ TransFrameRate ] = qsFrameRate;
   }
-  else if (qsConversionTool.find ( SUB_BLOCK_FFMPEG ) > -1 )	{
+  //else if (qsConversionTool.find ( SUB_BLOCK_FFMPEG ) > -1 )	{	//ooo
+  else if (qsConversionTool.indexOf ( SUB_BLOCK_FFMPEG ) > -1 )	{	//xxx
     bool bOkay;
     QString qsSampleRate = stringArray[ TransSampleRate ];
     int iSampleRate      = qsSampleRate.toInt ( &bOkay );
@@ -326,13 +337,14 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
          iVideoBitrate = 1856000;  // Minimum video Bitrate = 2800kbps
     stringArray[ TransVideoBitrate ] = QString ("%1").arg( iVideoBitrate );
   }
-  else if (qsConversionTool.find ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{
+  //else if (qsConversionTool.find ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{	//ooo
+  else if (qsConversionTool.indexOf ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{	//xxx
     qsRatio = stringArray[ TransRatio ]; // only 4:3 and 16:9 are valid
     if ( ( qsRatio != QString ("4:3") ) && ( qsRatio != QString ("16:9") ) )
       stringArray[ TransRatio ] = QString ( "4:3" );
   }
 
-  for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
+  for (t=0;t<(uint)m_listOfPair[TransKeys].count();t++)	{
     qsValue = stringArray[ t ];
     qsKey   = key   ( TransKeys, t );
     // Here we replace the actual keyword with the real string.
@@ -352,6 +364,7 @@ void Keyword::printf ( int iWhichKeyset )
 
   for (t=0;t<(int)m_listOfPair[iWhichKeyset].count();t++) {
     pEntry = m_listOfPair[iWhichKeyset][t];
-    ::printf ("%d > index=<%d> : Key=<%s> value=<%s>\n", t, pEntry->iIndex, pEntry->qsKey.ascii(), pEntry->qsValue.ascii() );
+    //::printf ("%d > index=<%d> : Key=<%s> value=<%s>\n", t, pEntry->iIndex, pEntry->qsKey.ascii(), pEntry->qsValue.ascii() );				//ooo
+    ::printf ("%d > index=<%d> : Key=<%s> value=<%s>\n", t, pEntry->iIndex, pEntry->qsKey.toLatin1().data(), pEntry->qsValue.toLatin1().data() );	//xxx
   }
 }
