@@ -1,23 +1,29 @@
-/****************************************************************************
-** ShadowObject class
-**
-**   Created : Wed Oct 31 22:06:51 2007
-**        by : Varol Okan using vi
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class creates a ButtonMask for an associated ImageObject.
-**
+/***************************************************************************
+    maskobject.cpp
+                             -------------------
+    ShadowObject class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class creates a ButtonMask for an associated ImageObject.
+    
 ****************************************************************************/
 
 #include <math.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
+//#include <q3popupmenu.h>	/ooo
 #include <qcolordialog.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QMouseEvent>
 
 #include "global.h"
 #include "xml_dvd.h"
-#include "movieobject.h"
+//#include "movieobject.h"	//ooo
+#include  "imageobject.h"	//xxx
 #include "structuretoolbar.h"
 
 #include "buttonobject.h"
@@ -117,7 +123,7 @@ void MaskObject::createMask ( )
 
     // Now that we have the object to draw we should create the QImage - object ...
     theImage = pImageObject->image ( ).copy ( );  // Copy is required otherwise the orig image is changed.
-    theImage.setAlphaBuffer ( true );
+    //theImage.setAlphaBuffer ( true );		//oooo
     //    http://bullwinkle.toonzone.net/rbplan.wav
     // Lastly we should filter out color keys if present (MovieObject, and Imagebject only)
 
@@ -129,11 +135,11 @@ void MaskObject::createMask ( )
 bool MaskObject::filterColorKeys ( QImage &theShadow )
 {
   ImageObject tempImage, *pImageObject;
-  MovieObject tempMovie;
+  /*MovieObject tempMovie;
   // Only Image, or Movie objects of interest for color keying.
   if ( ( m_pMenuObject->objectType ( ) != tempImage.objectType ( ) ) &&
        ( m_pMenuObject->objectType ( ) != tempMovie.objectType ( ) ) )
-    return false;
+    return false;*/	//oooo
 
   // Note MovieObject is derived off ImageObject.
   pImageObject = (ImageObject *)m_pMenuObject;
@@ -160,8 +166,8 @@ bool MaskObject::filterColorKeys ( QImage &theShadow )
   // Next we create the min/max Color keys, to check if we ought to filter the pixel out or not
   ImageManipulator *pManipulator = &pImageObject->manipulator ( );
   QImage theImage   = pImageObject->image ( );
-  QValueList<QColor *>listColorKeyMin;
-  QValueList<QColor *>listColorKeyMax;
+  QList<QColor *>listColorKeyMin;	//oxx
+  QList<QColor *>listColorKeyMax;	//oxx
   QColor *pColorMin, *pColorMax, theColor, targetColor;
   QRgb thePixel, *pLine, *pShadowLine;
 
@@ -217,7 +223,7 @@ bool MaskObject::filterColorKeys ( QImage &theShadow )
 }
 
 // Same as ImageObject::filterColorKey.
-bool MaskObject::filterColorKey ( QColor *pColor, int iColorKeyCount, QValueList<QColor *> *pListColorMin, QValueList<QColor *>*pListColorMax )
+bool MaskObject::filterColorKey ( QColor *pColor, int iColorKeyCount, QList<QColor *> *pListColorMin, QList<QColor *>*pListColorMax )	//oxx
 {
   int iRed, iGreen, iBlue, t;
 
@@ -231,11 +237,15 @@ bool MaskObject::filterColorKey ( QColor *pColor, int iColorKeyCount, QValueList
        ( *pColor == QColor ( 0, 0, 0 ) ) )
     return true;
 
-  iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();
+  //iRed = pColor->Qt::red(); iGreen = pColor->Qt::green(); iBlue = pColor->Qt::blue ();	//ooo
+  iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();			//xxx
   for (t=0;t<iColorKeyCount;t++)	{
-    if ( (iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) && 
-	 (iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&
-	 (iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )
+    //if ( (iRed   >= (*pListColorMin)[t]->Qt::red  () && iRed   <= (*pListColorMax)[t]->Qt::red  ()) &&	//ooo
+    if ( (iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) &&			//xxx
+	 //(iGreen >= (*pListColorMin)[t]->Qt::green() && iGreen <= (*pListColorMax)[t]->Qt::green()) &&	//ooo
+         (iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&			//xxx
+	 //(iBlue  >= (*pListColorMin)[t]->Qt::blue () && iBlue  <= (*pListColorMax)[t]->Qt::blue ()) )		//ooo
+	 (iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )			//xxx
       return true;
   }
   return false;
@@ -290,7 +300,8 @@ StructureItem *MaskObject::createStructure ( StructureItem *pParentItem )
 
   if ( ! m_pStructureItem ) {
     m_pStructureItem = new StructureItem ( this, StructureItem::Unknown, pParentItem, "Mask Object" );
-    m_pStructureItem->setExpandable ( FALSE );
+    //m_pStructureItem->setExpandable ( FALSE );	//ooo
+    m_pStructureItem->setExpanded ( false );		//xxx
   }
   return m_pStructureItem;
 }
