@@ -1,21 +1,26 @@
-/****************************************************************************
-** Shadow object 
-**
-**   Created : Wed Oct 31 21:45:00 2007 (Halloween)
-**        by : Varol Okan using vi
-** Copyright : (c) Varol Okan
-** License   : GPL v 2.0
-**
-**  This class will create a buttonmask for the associated MenuObject.
-**  Thus far masks were only Rectangles. This class will create a mask
-**  according to the associated imageObject ( similar to a ShadowObject)
-**
+/***************************************************************************
+    maskobject.h
+                             -------------------
+    Shadow object
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class will create a buttonmask for the associated MenuObject.
+    Thus far masks were only Rectangles. This class will create a mask
+    according to the associated imageObject ( similar to a ShadowObject)
+    
 ****************************************************************************/
 
 #ifndef MASKOBJECT_H
 #define MASKOBJECT_H
 
 #include <qimage.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+//#include <Q3ValueList>	//oxx
 
 #include "menuobject.h"
 
@@ -56,7 +61,7 @@ protected slots:
   virtual void slotChangeColor ( );
 
 private:
-  bool filterColorKey ( QColor *, int, QValueList<QColor *> *, QValueList<QColor *>* );
+  bool filterColorKey ( QColor *, int, QList<QColor *> *, QList<QColor *>* );	//oxx
   void createMask     ( );
   //void filterColor    ( QImage &, QColor );
 
