@@ -1,37 +1,35 @@
-/****************************************************************************
-** MenuOject class
-**
-**   Created : Tue Feb 02 22:06:51 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class is the encapsulation of the MenuObject.
-**
-** A MenuObject is the base class for any visible object in a DVD menu.
-** A MenuObject itself is not visible and not used in itself. Only derived
-** classes are used in the DVD Menu.
-**
-** Current objects include :
-** TextObject, ImageObject, MovieObject, FrameObject, ButtonObject
-** ShadowObject, MaskObject, ObjectCollection, and MenuObject
-**
+/***************************************************************************
+    menuobject.cpp
+                             -------------------
+    MenuOject class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+  This class is the encapsulation of the MenuObject.
+
+  A MenuObject is the base class for any visible object in a DVD menu.
+  A MenuObject itself is not visible and not used in itself. Only derived
+  classes are used in the DVD Menu.
+
+  Current objects include :
+  TextObject, ImageObject, MovieObject, FrameObject, ButtonObject
+  ShadowObject, MaskObject, ObjectCollection, and MenuObject
+    
 ****************************************************************************/
 
-#include <qfile.h>
-#include <qtimer.h>
-#include <qpainter.h>
-#include <qpopupmenu.h>
-
-#include "global.h"
+#include <QTimer>
+#include <QPainter>
+#include <QMessageBox>
+#include <QMouseEvent>
+#include <QTextStream>
 
 #include "xml_dvd.h"
 #include "menuobject.h"
-#include "qdvdauthor.h"
 #include "shadowobject.h"
-#include "overlayobject.h"
 #include "structuretoolbar.h"
-#include "dvdmenuundoobject.h"
 #include "dialogmatrix.h"
 
 MenuObject::Data::Data ( )
@@ -78,10 +76,10 @@ MenuObject::MenuObject (QWidget *pParent)
   m_pContextMenu   = NULL;
   m_pShadow        = NULL;
   m_pOverlay       = NULL;
-  m_pStructureItem = NULL;
-  m_pMatrixDialog  = NULL;
+  m_pStructureItem = NULL;	//ooo
+  m_pMatrixDialog  = NULL;	//ooo
   m_objectState    = StateUnknown;
-  m_pData          = new Data;
+  m_pData          = new Data;  
 }
 
 MenuObject::~MenuObject ( )
@@ -90,10 +88,10 @@ MenuObject::~MenuObject ( )
   if ( m_pContextMenu )
     delete m_pContextMenu;
   m_pContextMenu = NULL;
-  for ( t=0; t<m_listAnimationAttributes.count ( ); t++ )
-    delete m_listAnimationAttributes[t];
+  for ( t=0; t<(uint)m_listAnimationAttributes.count ( ); t++ )
+    delete m_listAnimationAttributes[t];	//oooo
 
-  m_listAnimationAttributes.clear ( );
+  m_listAnimationAttributes.clear ( );	//oooo
 
   resetStructureItem ( );
   if ( m_pShadow )
@@ -233,11 +231,11 @@ bool MenuObject::readProjectFile  (QDomNode &theNode)
 		  if ( ! m_pShadow->readProjectFile ( xmlMenuObject ) )
 		    return false;
 		}
-		else if ( tagName == OVERLAY_OBJECT )  {
+/*		else if ( tagName == OVERLAY_OBJECT )  {
 		  m_pOverlay = new OverlayObject ( this );
 		  if ( ! m_pOverlay->readProjectFile ( xmlMenuObject ) )
 		    return false;
-		}
+		}*/	//oooo
 		// So lets get the next sibling ... until we hit hte end of DVDMenu ...
 		xmlMenuObject = xmlMenuObject.nextSibling();
 	}
@@ -315,8 +313,10 @@ void MenuObject::update ( )
 {
   QPainter thePainter ( parent ( ) );
   QRect theRect = boundingRect ( );
-  theRect.addCoords ( -5, -5, 5, 5 );
-  parent()->repaint ( theRect, FALSE );
+  //theRect.addCoords ( -5, -5, 5, 5 );		//ooo
+  theRect.adjust ( -5, -5, 5, 5 );		//xxx
+  //parent()->repaint ( theRect, FALSE );	//ooo
+  parent()->repaint ( theRect );		//xxx
   drawContents ( &thePainter );
 }
 
@@ -395,7 +395,8 @@ bool MenuObject::mouseMoveEvent ( QMouseEvent *pEvent )
   case MenuObject::StateScaleTRXY:
   case MenuObject::StateScaleBLXY:
   case MenuObject::StateScaleBRXY: {
-    double fZoom   = (double)( iPos / 100.0 );
+    //double fZoom   = (double)( iPos / 100.0 );                //ooo
+    double fZoom   = static_cast<double> ( iPos / 100.0 );      //xxx
     if (fZoom > 1.0)
       fZoom = fZoom * 2.0 - 1.0;
 
@@ -409,7 +410,8 @@ bool MenuObject::mouseMoveEvent ( QMouseEvent *pEvent )
   break;
   case MenuObject::StateScaleLeftX: 
   case MenuObject::StateScaleRightX: {
-    double fZoom   = (double)( iPos / 100.0 );
+    //double fZoom   = (double)( iPos / 100.0 );                //ooo
+    double fZoom   = static_cast<double> ( iPos / 100.0 );      //xxx
     if (fZoom > 1.0)
       fZoom = fZoom * 2.0 - 1.0;
 
@@ -423,7 +425,8 @@ bool MenuObject::mouseMoveEvent ( QMouseEvent *pEvent )
   case MenuObject::StateScaleTopY:
   case MenuObject::StateScaleBottomY: {
     iPos = pEvent->pos().y() - m_currentMousePos.y();
-    double fZoom   = (double)( iPos / 100.0 );
+    //double fZoom   = (double)( iPos / 100.0 );            //ooo
+    double fZoom   = static_cast<double> ( iPos / 100.0 );  //xxx
     if ( fZoom > 1.0 )
          fZoom = fZoom * 2.0 - 1.0;
 
@@ -434,7 +437,8 @@ bool MenuObject::mouseMoveEvent ( QMouseEvent *pEvent )
   }
   break;
   case MenuObject::StateRotate: {
-    double fRotate = (double)iPos;
+    //double fRotate = (double)iPos;                    //ooo
+    double fRotate = static_cast<double> ( iPos );      //xxx
     modifiers( )->fRotate += fRotate;
     update   ( );
   }
@@ -468,7 +472,8 @@ void MenuObject::setObjectState ( enState newState )
 // the state of the mouse operation.
 // This function checks wether the mouse was pressed above a hot spot 
 // Resize / rotate etc. or not.
-MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState theState )
+//MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState theState )	//oooo
+MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::MouseButton theState )	//xxx
 {
   m_objectState = StateMoveObject;
   int iHeight2, iWidth2, iX, iY;
@@ -476,8 +481,10 @@ MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState th
 
   iX = pos.x( );
   iY = pos.y( );
-  iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );
-  iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );
+  //iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );                            //ooo
+  iWidth2  = theRect.x( ) + static_cast<int> ( static_cast<float> ( theRect.width  ( ) ) / 2.0 );   //xxx
+  //iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );                            //ooo
+  iHeight2 = theRect.y( ) + static_cast<int> ( static_cast<float> ( theRect.height ( ) ) / 2.0 );   //xxx
   if ( iX < theRect.x() + HANDLE_WIDTH ) { // left side
     if ( iY < theRect.y() + HANDLE_HEIGHT )
       m_objectState = StateScaleTLXY; // upper left corner
@@ -506,7 +513,7 @@ MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState th
   }
   //  else if ( ( iX > iWidth2  - HANDLE_WIDTH  ) && ( iX < iWidth2  + HANDLE_WIDTH  ) &&
   //	    ( iY > iHeight2 - HANDLE_HEIGHT ) && ( iY < iHeight2 + HANDLE_HEIGHT ) ) {
-  else if ( theState == Qt::ControlButton ) {
+  else if ( theState == Qt::ControlModifier ) {
     m_objectState = StateRotate;
   }
   return m_objectState;
@@ -514,12 +521,14 @@ MenuObject::enState MenuObject::setObjectState ( QPoint &pos, Qt::ButtonState th
 
 void MenuObject::drawActiveFrame ( QPainter *pPainter )
 {
-  QBrush theBrush ( yellow );
+  QBrush theBrush ( Qt::yellow );
   QRect theRect = m_boundingRect;
   int iHeight2, iWidth2, iRight, iBottom;
 
-  iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );
-  iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );
+  //iWidth2  = theRect.x( ) + (int)((float) theRect.width  ( )  / 2.0 );                            //ooo
+  iWidth2  = theRect.x( ) + static_cast<int> ( static_cast<float> ( theRect.width  ( ) ) / 2.0 );  //xxx
+  //iHeight2 = theRect.y( ) + (int)((float) theRect.height ( )  / 2.0 );                            //ooo
+  iHeight2 = theRect.y( ) + static_cast<int> ( static_cast <float> ( theRect.height ( ) ) / 2.0 );  //xxx
   iRight   = theRect.x( ) + theRect.width  ( ) - HANDLE_WIDTH;
   iBottom  = theRect.y( ) + theRect.height ( ) - HANDLE_HEIGHT;
 
@@ -529,23 +538,28 @@ void MenuObject::drawActiveFrame ( QPainter *pPainter )
   // top right
   pPainter->fillRect ( iRight, theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
   // top center
-  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  //pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );             //ooo
+  pPainter->fillRect ( iWidth2 - static_cast<int> (HANDLE_WIDTH / 2.0), theRect.y(), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );   //xxx
 
   // bottom left
   pPainter->fillRect ( theRect.x(), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
   // bottom right
   pPainter->fillRect ( iRight, iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
   // bottom center
-  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  //pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );             //ooo
+  pPainter->fillRect ( iWidth2 - static_cast<int> (HANDLE_WIDTH / 2.0), iBottom, HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );   //xxx
 
   // left center
-  pPainter->fillRect ( theRect.x(), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  //pPainter->fillRect ( theRect.x(), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );   //ooo
+  pPainter->fillRect ( theRect.x(), iHeight2 - static_cast<int> (HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush ); //xxx
   // right center
-  pPainter->fillRect ( iRight, iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
+  //pPainter->fillRect ( iRight, iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );            //ooo
+  pPainter->fillRect ( iRight, iHeight2 - static_cast<int> (HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );  //xxx
 
   // center
   //  pPainter->fillRect ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT, theBrush );
-  pPainter->drawEllipse ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT );
+  //pPainter->drawEllipse ( iWidth2 - (int)(HANDLE_WIDTH / 2.0), iHeight2 - (int)(HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT );              //ooo
+  pPainter->drawEllipse ( iWidth2 - static_cast<int> (HANDLE_WIDTH / 2.0), iHeight2 - static_cast<int> (HANDLE_HEIGHT / 2.0), HANDLE_WIDTH, HANDLE_HEIGHT );    //xxx
 }
 
 // called from ButtonPreview::releaseMouseEvent, to reset active object.
@@ -612,7 +626,7 @@ void MenuObject::setData ( MenuObject::Data *pData )
   if ( m_pData && pData )
       *m_pData = *pData;
   if ( m_pMatrixDialog  )
-       m_pMatrixDialog->initMe ( this );
+       m_pMatrixDialog->initMe ( this );	//oooo
 }
 
 QPoint MenuObject::position ( )
@@ -651,13 +665,14 @@ void MenuObject::setPosition ( QPoint &position )
   m_boundingRect = QRect ( iX, iY, iWidth, iHeight );
 }
 
+
 void MenuObject::setCurrentMousePos ( QPoint &pos )
 {
   m_currentMousePos = pos;
 }
 
 void MenuObject::setParent ( QWidget *pParent )
-{
+{  
   m_pParent = pParent;
 }
 
@@ -666,11 +681,6 @@ QWidget *MenuObject::parent ( )
   return m_pParent;
 }
 
-bool MenuObject::drawRect ( )
-{
-  return m_bDrawRect;
-}
-
 MenuObject *MenuObject::clone( QWidget *, MenuObject * )
 {
   return NULL;
@@ -708,67 +718,12 @@ void MenuObject::slotAddShadow ( )
   emit ( signalShadowMe ( this ) );
 }
 
-void MenuObject::slotDeleteShadow ( )
-{
-  UndoBuffer *pUndo = Global::pApp->getUndoBuffer ( );
-  if ( pUndo )
-       pUndo->push ( new DVDMenuUndoObject ( DVDMenuUndoObject::DELETED_SHADOW, this, shadow ( ) ) );
-
-  setShadow ( NULL );
-  emit ( signalUpdatePixmap ( ) );
-}
-
 void MenuObject::slotAddOverlay ( )
 {
   // Send request back to be handled in MenuPreview ..
   emit ( signalOverlayMe ( this ) );
 }
 
-void MenuObject::slotDeleteOverlay ( )
-{
-  UndoBuffer *pUndo = Global::pApp->getUndoBuffer ( );
-  if ( pUndo )
-       pUndo->push ( new DVDMenuUndoObject ( DVDMenuUndoObject::DELETED_OVERLAY, this, overlay ( ) ) );
-
-  setOverlay ( NULL );
-  emit ( signalUpdatePixmap ( ) );
-}
-
-void MenuObject::slotCut ( )
-{
-  slotCopy       ( );
-  slotEmitDelete ( );
-}
-
-void MenuObject::slotCopy ( )
-{
-  if ( Global::pCopyObject )
-    delete Global::pCopyObject;
-  Global::pCopyObject = clone ( );
-
-  if ( m_pContextMenu )
-    delete m_pContextMenu;
-  m_pContextMenu = NULL;
-}
-
-void MenuObject::slotToFront ( )
-{
-	// Send it all the way to the front
-	emit (signalMoveOnStack (this, 1000));
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = NULL;
-}
-
-void MenuObject::slotToBack ()
-{
-	// Send it all the way to the back
-	emit (signalMoveOnStack (this, -1000));
-	if (m_pContextMenu)
-		delete m_pContextMenu;
-	m_pContextMenu = NULL;
-}
-
 void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames)
 {
   // Called from MenuPreview::createAnimationData
@@ -782,7 +737,7 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
   // of the object.
   // Once rendering is done the original values are re-set.
   QFile file (qsFileName);
-  file.open ( IO_ReadOnly );
+  file.open ( QIODevice::ReadOnly );
   QTextStream stream( &file );
   QString line;
   uint t;
@@ -791,7 +746,7 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
   bool bFound;
   QString qsProperty, qsValue;
 
-  for (t=0;t<m_listAnimationAttributes.count();t++)	{
+  for (t=0;t<(uint)m_listAnimationAttributes.count();t++)	{
     delete m_listAnimationAttributes[t];
   }
   m_listAnimationAttributes.clear();
@@ -799,8 +754,10 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
 
   while ( !stream.atEnd() ) {
     line = stream.readLine(); // line of text excluding '\n'
-    iPos = line.find ("::");
-    iPos2 = line.find ("=");
+    //iPos = line.find ("::");		//ooo
+    iPos = line.indexOf ("::");		//xxx
+    //iPos2 = line.find ("=");		//ooo
+    iPos2 = line.indexOf ("=");		//xxx
     if ( (iPos == -1) || (iPos2 == -1) )
       continue;
     qsProperty   = QString ("");
@@ -831,7 +788,7 @@ void MenuObject::loadAnimationData (QString &qsFileName, long iMaxNumberOfFrames
     //printf ("MenuObject::loadAnimationData - load <%d> <%s>=<%s>\n", iFrameNumber, (const char *)qsProperty, (const char *)qsValue);
 
     // This loop will check if this property is already taken care of and we have a array of values waiting.
-    for (t=0;t<m_listAnimationAttributes.count ();t++)	{
+    for (t=0;t<(uint)m_listAnimationAttributes.count ();t++)	{
       pAnimAttr = m_listAnimationAttributes[t];
       if (pAnimAttr->name() == qsProperty)	{
 	pAnimAttr->append (iFrameNumber, qsValue);
