@@ -1,20 +1,23 @@
-/****************************************************************************
-** Modifiers / ImageManipulator class implementation.
-**
-**   Created : ?
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
-**
-**
+/***************************************************************************
+    modifiers.cpp
+                             -------------------
+    Modifiers / ImageManipulator class implementation.
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
+#include <QMessageBox>
+
 #include "structuretoolbar.h"
 #include "modifiers.h"
 #include "xml_dvd.h"
 #include "rgba.h"
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -178,7 +181,9 @@ StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, Structur
 
     if ( ! m_pStructureItem )  {
       m_pStructureItem = new StructureItem ( pMenuObject, StructureItem::Modifiers, pParentItem, pPreviousItem, qsModifiers, NULL );
-      m_pStructureItem->setExpandable ( TRUE );
+      m_pStructureItem->setText ( 0, qsModifiers );	//xxx
+      //m_pStructureItem->setExpandable ( TRUE );	//ooo
+      m_pStructureItem->setExpanded ( true );		//xxx
     }
 
     // Comming here we are guaranteed to have a StructureItem - object.
@@ -246,7 +251,7 @@ ImageManipulator::~ImageManipulator()
 {
 	uint t;
 	if (listColorKeys.count())	{
-		for (t=0;t<listColorKeys.count();t++)
+		for (t=0;t<(uint)listColorKeys.count();t++)
 			delete listColorKeys[t];
 		listColorKeys.clear();
 	}
@@ -336,7 +341,7 @@ bool ImageManipulator::readProjectFile (QDomNode &theNode)
 	if ( fKenBurnsY2 >  1.0 )
 	     fKenBurnsY2 = -1.0;
 
-	for (uint t=0;t<listColorKeys.count();t++)
+	for (uint t=0;t<(uint)listColorKeys.count();t++)
 		delete listColorKeys[t];
 	listColorKeys.clear ();
 	QDomNode    manipulatorNodes = theNode.firstChild();
@@ -424,8 +429,8 @@ bool ImageManipulator::operator == ( ImageManipulator &other )
   if ( ! bReturn )
     return false;
 
-  QValueList<colorKeying *>::iterator it1 =       listColorKeys.begin ( );
-  QValueList<colorKeying *>::iterator it2 = other.listColorKeys.begin ( );
+  QList<colorKeying *>::iterator it1 =       listColorKeys.begin ( );		//oxx
+  QList<colorKeying *>::iterator it2 = other.listColorKeys.begin ( );		//oxx
 
   while ( it1 != listColorKeys.end ( ) )  {
     if  ( ! ( *(*it1++) == *(*it2++) ) )
@@ -476,7 +481,7 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
       manipulatorNode.setAttribute( MANIPULATOR_BLUE, QString ("%1").arg(fBlue) );
     if (fBrightness != initialValues.fBrightness)
       manipulatorNode.setAttribute( MANIPULATOR_BRIGHTNESS, QString ("%1").arg(fBrightness) );
-    for (uint t=0;t<listColorKeys.count ();t++)	{
+    for (uint t=0;t<(uint)listColorKeys.count ();t++)	{
       QDomElement colorKeyNode = xmlDoc.createElement ( MANIPULATOR_COLOR_KEY );
       Rgba        theColor ( listColorKeys[t]->theColor );
       if ( listColorKeys[t]->fDeltaColor != 0.0 )
@@ -520,39 +525,53 @@ StructureItem *ImageManipulator::createStructure ( StructureItem *pParentItem, S
 	  ( iStartFrame   == initialValues.iStartFrame)   &&
 	  ( iStopFrame    == initialValues.iStopFrame)    &&
 	  ( listColorKeys.count() > 0) ) )  {
-
+ 
     StructureItem *pTemp=NULL;
-    if ( ! m_pStructureItem ) {
+    if ( ! m_pStructureItem ) { 
       MenuObject *pMenuObject = pParentItem->getMenuObject ( );
       m_pStructureItem = new StructureItem ( pMenuObject, StructureItem::Modifiers, pParentItem, pPreviousItem, QObject::tr ( "Modifiers" ), NULL );
-      pParentItem->setExpandable ( TRUE );
+      //m_pStructureItem->setText ( 0, QObject::tr ( "Modifiers" ) );	//xxx
+      //pParentItem->setExpandable ( TRUE );	//ooo
+      pParentItem->setExpanded ( false );	//xxx
     }
 
-    pTemp   = (StructureItem *)m_pStructureItem->firstChild ( );
+    //pTemp   = (StructureItem *)m_pStructureItem->firstChild ( );	//ooo
+    pTemp   = (StructureItem *)m_pStructureItem->child ( 0 );
+ 
     while  ( pTemp ) {
       delete pTemp;
-      pTemp = (StructureItem *)m_pStructureItem->firstChild ( );
+
+      //pTemp = (StructureItem *)m_pStructureItem->firstChild ( );	//ooo
+      pTemp = (StructureItem *)m_pStructureItem->child ( 0 );		//xxx
     }
+	//oooo  
 
     if ( ( fRed   != initialValues.fRed   ) ||
 	 ( fGreen != initialValues.fGreen ) ||
 	 ( fBlue  != initialValues.fBlue  ) )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Color Adjust"),  QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
+
     if ( fBrightness    != initialValues.fBrightness )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Brightness"),    QString ("%1").arg(fBrightness));
+
     if ( fTransparency  != initialValues.fTransparency )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Transparency"),  QString ("%1").arg(fTransparency));
+  
     if ( ( fShearX      != initialValues.fShearX ) || ( fShearY  != initialValues.fShearY)  )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Shear (x, y)"),  QString ("%1, %2").arg(fShearX).arg(fShearY));
+
     if ( ( iStartFrame  != initialValues.iStartFrame ) || ( iStopFrame  != initialValues.iStopFrame) )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("VisibleFromTo"), QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
+
     if ( fZoom  != initialValues.fZoom )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ( "Zoom" ), QString ("%1").arg ( fZoom ) );
+  
     if ( fRotate  != initialValues.fRotate )
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Rotate"), QString ("%1 deg").arg ( fRotate ) );
+
     if ( listColorKeys.count ( ) > 0 )  {
       QString qsColorKeys ( "|" );
-      for ( uint t=0; t<listColorKeys.count ( ); t++ )
+      for ( uint t=0; t<(uint)listColorKeys.count ( ); t++ )
 	qsColorKeys += QString ( "0x%1|" ).arg ( listColorKeys[t]->theColor, 16 );
       new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ( "ColorKey" ), qsColorKeys );
     }
@@ -603,11 +622,11 @@ ImageManipulator& ImageManipulator::operator = (ImageManipulator &theOther)
   fBrightness         = theOther.fBrightness;
   fTransparency       = theOther.fTransparency;
   if (listColorKeys.count())	{
-    for (t=0;t<listColorKeys.count();t++)
+    for (t=0;t<(uint)listColorKeys.count();t++)
       delete listColorKeys[t];
     listColorKeys.clear();
   }
-  for (t=0;t<theOther.listColorKeys.count();t++)
+  for (t=0;t<(uint)theOther.listColorKeys.count();t++)
     listColorKeys.append(new colorKeying (theOther.listColorKeys[t]));
 
   return *this;
