@@ -1,23 +1,24 @@
-/****************************************************************************
-  ** Modifiers / ImageManpulator - classes
-  **
-  **   Created : 
-  **        by : Varol Okan using kate editor
-  ** Copyright : (c) Varol Okan
-  **   License : GPL v 2.0
-  **
-  **
-  ****************************************************************************/
+/***************************************************************************
+    modifiers.h
+                             -------------------
+    Modifiers / ImageManpulator - classes
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+****************************************************************************/
 
 #ifndef MODIFIERS_H
 #define MODIFIERS_H
 
-#include <qdom.h>
-#include <qcolor.h>
-#include <qvaluelist.h>
+//#include <qdom.h>		//ooo
+#include <QDomNode>		//xxx
+//#include <qcolor.h>		//ooo
+#include <QColor>		//xxx
+//#include <q3valuelist.h>	//oxx
 
-class QListViewItem;
-class StructureItem;
 class StructureItem;
 
 class Modifiers
@@ -111,7 +112,7 @@ public:
 	float	fAspectRatio; // E.g. 4:3 used to resize view
 	int	iXRes;        // 720 Currently not used
 	int	iYRes;        // 480 currently not used
-	QValueList<colorKeying *> listColorKeys;
+	QList<colorKeying *> listColorKeys;	//oxx
 
 	friend class ImageObject;
 };
