@@ -1,17 +1,18 @@
-/****************************************************************************
-** MovieObject class
-**
-**   Created : Tue Feb 02 22:06:51 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class is the encapsulation of the MovieObject.
-**
-** The MovieObject is a DVD Menu object which displays a short animation/
-** sequence of the movie to be played.
-**
-**
+/***************************************************************************
+    movieobject.cpp
+                             -------------------
+    MovieObject class                             
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class is the encapsulation of the MovieObject.
+    
+    The MovieObject is a DVD Menu object which displays a short animation/
+    sequence of the movie to be played.
+    
 ****************************************************************************/
 #include <stdlib.h>
 
@@ -19,8 +20,12 @@
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qpainter.h>
-#include <qtimer.h>
+//#include <qtimer.h>   //ooo
+#include <QTimer>   //xxx
 #include <qdir.h>
+//Added by qt3to4:
+#include <QTimerEvent>
+#include <QPixmap>
 
 #include "global.h"
 #include "xml_dvd.h"
@@ -154,11 +159,15 @@ void MovieObject::createExtractionPath ( )
 {
   QString   qsExtractionPath, qsOffset;
   QFileInfo fileInfo ( fileName ( ) );
-  QTime     zeroTime;
+  //QTime     zeroTime; //ooo
+  QTime     zeroTime(0,0,0,0);    //xxx
   char      cBuffer[15];
 
-  qsExtractionPath = fileInfo.baseName ( true );
-  qsOffset         = movieData ( )->m_timeOffset.toString ( "hhmmsszzz"  );
+  //qsExtractionPath = fileInfo.baseName ( true );	//ooo
+  qsExtractionPath = fileInfo.baseName ( );		//xxx
+  //qsOffset         = movieData ( )->m_timeOffset.toString ( "hhmmsszzz"  );   //ooo
+  qsOffset         = offset ( ).toString ( "hhmmsszzz"  );   //xxx
+  
   int iDuration    = zeroTime.msecsTo      ( duration ( ) );
   sprintf ( cBuffer, "-%07d", iDuration );
   qsExtractionPath += "-"+qsOffset + cBuffer;
@@ -191,13 +200,19 @@ void MovieObject::setMSecPreview ( long iMSecPreview )
 
 QTime &MovieObject::offset    ()
 {
-	return movieData ( )->m_timeOffset;
+  if (movieData ( )->m_timeOffset.isNull() && movieData ( )->m_bMenuLength && dvdMenu ( ) ) {  //xxx
+    return dvdMenu ( )->getInterface ( )->timeOffset;
+  }
+    
+  return movieData ( )->m_timeOffset;
 }
 
 QTime &MovieObject::duration  ( )
 {
-  if ( movieData ( )->m_bMenuLength && dvdMenu ( ) )
+  if ( movieData ( )->m_bMenuLength && dvdMenu ( ) ) {
     return dvdMenu ( )->getInterface ( )->timeDuration;
+  }
+
   return movieData ( )->m_timeDuration;
 }
 
@@ -259,8 +274,10 @@ QImage *MovieObject::previewImage ()
 void MovieObject::setPixmap ( QPixmap &thePixmap )
 {
   if ( ! thePixmap.isNull ( ) )  {
-    m_image        = thePixmap.convertToImage ( );
-    m_imagePreview = thePixmap.convertToImage ( );
+    //m_image        = thePixmap.convertToImage ( );	//ooo
+    m_image        = thePixmap.toImage ( );		//xxx
+    //m_imagePreview = thePixmap.convertToImage ( );	//ooo
+    m_imagePreview = thePixmap.toImage ( );		//xxx
     return;
   }
   // Here we set the temp image for now but in order to see it in the right size,
@@ -271,11 +288,14 @@ void MovieObject::setPixmap ( QPixmap &thePixmap )
   // Note that the real imagePreview is generated in a background thread and later on passed into this object
   // in order to have the GUI active.
   QString qsFileName = fileName ();
-  m_imagePreview = QImage (QImage().fromMimeSource("please_wait.jpg"));
+  //m_imagePreview = QImage (QImage().fromMimeSource("please_wait.jpg"));	//ooo
+  m_imagePreview = QImage ( ":/imagres/please_wait.jpg" );			//xxx
   if ( (movieSize().width() > 5) && (movieSize().height() > 5) )
-    m_imagePreview = m_imagePreview.smoothScale (movieSize(), QImage::ScaleFree);
+    //m_imagePreview = m_imagePreview.smoothScale (movieSize(), Qt::IgnoreAspectRatio);		//ooo
+    m_imagePreview = m_imagePreview.scaled (movieSize(), Qt::IgnoreAspectRatio);		//xxx
   else
-    m_imagePreview = m_imagePreview.smoothScale (rect().size(), QImage::ScaleFree);
+    //m_imagePreview = m_imagePreview.smoothScale (rect().size(), Qt::IgnoreAspectRatio);	//ooo
+    m_imagePreview = m_imagePreview.scaled (rect().size(), Qt::IgnoreAspectRatio);		//xxx
 
   updatePixmap (); 
   MediaCreator::registerWithMediaScanner (this, qsFileName, &m_imagePreview, movieData ( )->m_iMSecPreview );
@@ -289,20 +309,21 @@ void MovieObject::slotSetThumbnail ( long iMSecPreview )
 
 void MovieObject::timerEvent(QTimerEvent *pTimerEvent)
 {
-	// Called after the background thread has generated the preview ...
-	QSize theSize;
-	switch ( pTimerEvent->timerId ( ) )	{
-	case MEDIASCANNER_EVENT + 2: // ExecuteJob::TYPE_IMAGE
-		float fZoom = ((float)rect ( ).width ( ) / m_imagePreview.width ( ) );
-		theSize = m_imagePreview.size ( );
-		setZoom      ( fZoom );
-		setMovieSize ( theSize );
-		updatePixmap ( );
-		updateShadow ( );
-		if (  shadow ( ) ) // need a refresh to do the shadow correctly.
-		      emit   ( signalUpdatePixmap ( ) );
-	break;
-	}
+  // Called after the background thread has generated the preview ...
+  QSize theSize;
+  switch ( pTimerEvent->timerId ( ) )	{
+  case MEDIASCANNER_EVENT + 2: // ExecuteJob::TYPE_IMAGE
+    float fZoom = ((float)rect ( ).width ( ) / m_imagePreview.width ( ) );
+    theSize = m_imagePreview.size ( );
+    setZoom      ( fZoom );
+    setMovieSize ( theSize );
+    updatePixmap ( );
+    updateShadow ( );
+    if (  shadow ( ) ) // need a refresh to do the shadow correctly.
+      emit   ( signalUpdatePixmap ( ) );
+    break;
+  }
+		//oooo
 }
 
 void MovieObject::updatePixmap()
@@ -318,7 +339,7 @@ void MovieObject::updatePixmap()
 	float fAdjust = 0.0;
 	QColor theColor;
 	QRgb thePix;	// QRgb defined as :  0xAARRGGBB;
-	QWMatrix theMatrix;
+	QMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 
@@ -328,19 +349,25 @@ void MovieObject::updatePixmap()
 	QImage theImage = m_imagePreview;
 	if (theImage.isNull())
 		return;
-	theImage = theImage.smoothScale ( rect ().width(), rect().height(), QImage::ScaleFree);
+	//theImage = theImage.smoothScale ( rect ().width(), rect().height(), Qt::IgnoreAspectRatio);	//ooo
+	theImage = theImage.scaled ( rect ().width(), rect().height(), Qt::IgnoreAspectRatio);		//xxx
 
-	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
+	//centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));                          //ooo
+        centerPos.setX (rect().x() + static_cast<int>(static_cast<float>(rect().width ()) / 2.0));     //xxx
+	//centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));                           //ooo
+        centerPos.setY (rect().y() + static_cast<int>(static_cast<float>(rect().height()) / 2.0));      //xxx
 	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
+	//theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());                          //ooo
+        theMatrix.translate (static_cast<double>(centerPos.x()), static_cast<double>(centerPos.y()));   //xxx
 	// then we apply the other modifications ...
 	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
 	// Here we create the scaled image ...
-	theImage = theImage.xForm ( theMatrix );
+	//theImage = theImage.xForm ( theMatrix );	//ooo
+	theImage = theImage.transformed ( theMatrix );	//xxx
 
 	// create empty image.
-	QImage imageColored = QImage (theImage.width(), theImage.height(), theImage.depth());
+	//QImage imageColored = QImage (theImage.width(), theImage.height(), theImage.depth());		//ooo
+	QImage imageColored = QImage (theImage.width(), theImage.height(), QImage::Format_ARGB32);	//xxx
 	if (manipulator().fBrightness > 0.0)	{
 		bLighter = true;
 		fAdjust = 100 + manipulator().fBrightness * 300;
@@ -372,7 +399,8 @@ void MovieObject::updatePixmap()
 	// and plug in the remaining operations ...
 	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	m_image = imageColored.xForm ( theMatrix );
+	//m_image = imageColored.xForm ( theMatrix );		//ooo
+	m_image = imageColored.transformed ( theMatrix );	//xxx
 	emit    ( signalUpdatePixmap ( ) );
 }
 
@@ -395,24 +423,35 @@ void MovieObject::slotProperties ()
   if ( m_pConvertTimer )
        m_pConvertTimer->stop ( );
 
-  DialogMovie movieDialog (NULL);
-  connect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
-  movieDialog.initMe ( this ); 
-  if ( movieDialog.exec ( ) == QDialog::Accepted )  {
+  //DialogMovie movieDialog (NULL); //ooo
+  DialogMovie *movieDialog = new DialogMovie ( NULL );  //xxx
+  
+  //connect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) ); //ooo
+  connect ( movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );    //xxx
+  
+  //movieDialog.initMe ( this );    //ooo
+  movieDialog->initMe ( this );     //xxx
+  
+  //if ( movieDialog.exec ( ) == QDialog::Accepted )  { //ooo
+  if ( movieDialog->exec ( ) == QDialog::Accepted )  {  //xxx
 
     DVDMenuUndoObject *pUndo = new DVDMenuUndoObject ( this, MenuObject::StateUnknown );
     int iX, iY, iWidth, iHeight;
-    iX      = movieDialog.m_pEditX->text ( ).toInt ( );
-    iY      = movieDialog.m_pEditY->text ( ).toInt ( );
-    iWidth  = movieDialog.m_pEditWidth ->text ( ).toInt ( );
-    iHeight = movieDialog.m_pEditHeight->text ( ).toInt ( );
+    iX      = movieDialog->m_pEditX->text ( ).toInt ( );    //oxx
+    iY      = movieDialog->m_pEditY->text ( ).toInt ( );    //oxx
+    iWidth  = movieDialog->m_pEditWidth ->text ( ).toInt ( );   //oxx
+    iHeight = movieDialog->m_pEditHeight->text ( ).toInt ( );   //oxx
     QRect rect ( iX, iY, iWidth, iHeight );
     setRect    ( rect );
     // Next we hande the start/stop time.
     QString qsFormat ("hh:mm:ss.zzz");
     QTime startingTime, endingTime, duration;
-    startingTime = QTime::fromString ( movieDialog.m_pEditStarting2->text ( ) );
-    endingTime   = QTime::fromString ( movieDialog.m_pEditEnding2  ->text ( ) );
+    //startingTime = QTime::fromString ( movieDialog.m_pEditStarting2->text ( ) );  //ooo
+    startingTime = QTime::fromString ( movieDialog->m_pEditStarting2->text ( ), qsFormat );    //xxx
+    
+    //endingTime   = QTime::fromString ( movieDialog.m_pEditEnding2  ->text ( ) );  //ooo
+    endingTime   = QTime::fromString ( movieDialog->m_pEditEnding2  ->text ( ), qsFormat );    //xxx
+    
     if ( startingTime.isValid ( ) )  {
       setOffset ( startingTime );
       if (endingTime.isValid ( ) )  {
@@ -421,11 +460,11 @@ void MovieObject::slotProperties ()
         setDuration ( duration );
       }
     }
-    setMenuLength ( movieDialog.m_pCheckSameAsMenuLength->isChecked  ( ) );
+    setMenuLength ( movieDialog->m_pCheckSameAsMenuLength->isChecked  ( ) );    //oxx
     setLoop ( Loop );
-    if ( movieDialog.m_pButtonLoop->text ( ) == "Stretch" )
+    if ( movieDialog->m_pButtonLoop->text ( ) == "Stretch" )    //oxx
          setLoop ( Stretch );
-    if ( movieDialog.m_pButtonLoop->text ( ) == "Stop" )
+    if ( movieDialog->m_pButtonLoop->text ( ) == "Stop" )   //oxx
          setLoop ( Stop );
 
     emit ( signalUpdatePixmap ( ) );
@@ -438,7 +477,11 @@ void MovieObject::slotProperties ()
     else
       delete pUndo;
   }
-  disconnect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
+  
+  //disconnect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );  //ooo
+  disconnect ( movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) ); //xxx
+  
+  //delete movieDialog;   //xxx
 
   // And finally we re-start the timer (or start a new time to extract the propper images.
   // Note: this can be done bacause I will check a status file first before extracting the frames, 
@@ -454,7 +497,8 @@ void MovieObject::registerToRender ()
 		m_pConvertTimer = new QTimer (this);
 		connect( m_pConvertTimer, SIGNAL(timeout()), this, SLOT(slotStartConverting()) );
 	}
-	m_pConvertTimer->start( 30000, TRUE ); // 30 seconds single-shot timer
+	//m_pConvertTimer->start( 30000, TRUE ); // 30 seconds single-shot timer	//ooo
+	m_pConvertTimer->start( 30000 ); // 30 seconds single-shot timer		//xxx
 }
 
 void MovieObject::slotStartConverting ()
@@ -466,7 +510,8 @@ void MovieObject::startConverting ( bool bAllowDialogs )
 {
 	QString qsCommand, qsFullPath, qsMenuName, qsFormat;
 	QFileInfo fileInfo;
-	QTime zeroTime;
+	//QTime zeroTime;  //ooo
+    QTime zeroTime(0,0,0,0);    //xxx
 	QDir theTempDir;
 	qsFormat = QString ("hh:mm:ss.zzz");
 
@@ -489,16 +534,18 @@ void MovieObject::startConverting ( bool bAllowDialogs )
 	qsMenuName = QString ( "NoMenuError" );
 	if ( m_pDVDMenu )
 		qsMenuName = m_pDVDMenu->getInterface()->qsMenuName;
-
+    
 	// Make sure we have the latest and greates path.
 	createExtractionPath ( );
 
 	qsFullPath = QFile::encodeName ( QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( extractionPath ( ) ) );
 	qsCommand  = QString ( "mkdir -p '%1'" ).arg ( qsFullPath );
-	if ( system ((const char *)qsCommand) == -1 )
+	//if ( system ((const char *)qsCommand) == -1 )		//ooo
+	if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 		return;
 	// and now we check that the path has been created succesfully
-	theTempDir.setPath ( QFile::decodeName ( qsFullPath.latin1 ( ) ) );
+	//theTempDir.setPath ( QFile::decodeName ( qsFullPath.latin1 ( ) ) );		//ooo
+	theTempDir.setPath ( QFile::decodeName ( qsFullPath.toLatin1 ( ).data() ) );	//xxx
 	if ( ! theTempDir.exists ( ) )  {
 	  if ( bAllowDialogs )
 	    MessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
@@ -548,7 +595,8 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 		QString qsAttribute = attribute.value();
 		QSize theSize;
 		// In the form of WIDTHxHEIGHT
-		int iPos = qsAttribute.find (QString("x"));
+		//int iPos = qsAttribute.find (QString("x"));	//ooo
+		int iPos = qsAttribute.indexOf (QString("x"));	//xxx
 		if (iPos > -1)	{
 			theSize.setWidth (qsAttribute.left (iPos).toInt());
 			theSize.setHeight(qsAttribute.right(qsAttribute.length()-iPos-1).toInt());
@@ -590,8 +638,10 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 	}
 	// Here we create the Pixmap in the right scale
 	QPixmap nullPixmap; 
-	QImage theImage = QImage().fromMimeSource("please_wait.jpg");
-	theImage = theImage.smoothScale(rect().width(), rect().height(), QImage::ScaleFree);
+	//QImage theImage = QImage().fromMimeSource("please_wait.jpg");		//ooo
+	QImage theImage = QImage ( ":/images/please_wait.jpg" );		//xxx
+	//theImage = theImage.smoothScale(rect().width(), rect().height(), Qt::IgnoreAspectRatio);	//ooo
+	theImage = theImage.scaled(rect().width(), rect().height(), Qt::IgnoreAspectRatio);		//xxx
 	nullPixmap.convertFromImage(theImage);
 	setPixmap (nullPixmap);
 	return true;
@@ -610,7 +660,10 @@ bool MovieObject::writeProjectFile (QDomElement &theElement)
 	  qsType = "Stop";
 	if (!m_qsFileName.isNull())
 		movieNode.setAttribute( MOVIE_OBJECT_FILE_NAME, m_qsFileName );
-	movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   movieData ( )->m_timeOffset.toString   (qsFormat) );
+    
+    //movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   movieData ( )->m_timeOffset.toString   (qsFormat) );   //ooo
+    movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   offset().toString   (qsFormat) );   //xxx  
+
 	movieNode.setAttribute( MOVIE_OBJECT_DURATION, movieData ( )->m_timeDuration.toString (qsFormat) );
 	movieNode.setAttribute( MOVIE_OBJECT_MENU_LENGTH,  movieData ( )->m_bMenuLength ? "true" : "false" );
 	movieNode.setAttribute( MOVIE_OBJECT_LOOP,         qsType );
@@ -635,6 +688,7 @@ StructureItem *MovieObject::createStructure ( StructureItem *pParentItem )
   StructureItem *pTemp=NULL;
   QFileInfo fileInfo ( m_qsFileName );
   QString qsName;
+  QString qsFormat ("hhmmsszzz");    //xxx
 
   if ( ! pParentItem )  {
     if ( m_pOverlay  )
@@ -650,7 +704,8 @@ StructureItem *MovieObject::createStructure ( StructureItem *pParentItem )
 
   if ( ! m_pStructureItem ) {
     m_pStructureItem = new StructureItem ( this, StructureItem::Video, pParentItem, pParentItem->lastChild ( ), qsName, fileInfo.fileName ( ) );
-    m_pStructureItem->setExpandable      ( TRUE );
+    //m_pStructureItem->setExpandable      ( TRUE );	//ooo
+    m_pStructureItem->setExpanded      ( true );	//xxx
   }
 
   ImageObject initialValues;
@@ -659,8 +714,10 @@ StructureItem *MovieObject::createStructure ( StructureItem *pParentItem )
                                          QString ( "%1, %2, %3, %4" ).arg ( rect ( ).x ( ) ).arg ( rect ( ).y ( ) ).
                                          arg ( rect ( ).width ( ) ).arg( rect ( ).height ( ) ) );
 
-  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Duration"), duration ( ).toString ( ) );
-  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Offset"), movieData ( )->m_timeOffset.toString   ( ) );
+  //pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Duration"), duration ( ).toString ( ) );   //ooo
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Duration"), duration ( ).toString ( qsFormat ) );    //xxx
+  //pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Offset"), movieData ( )->m_timeOffset.toString   ( ) );    //ooo
+  pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Offset"), movieData ( )->m_timeOffset.toString   ( qsFormat ) ); //xxx
 
   if ( m_pOverlay )
     pTemp = m_pOverlay->createStructure ( m_pStructureItem );
@@ -725,7 +782,7 @@ void MovieObject::loadPixmap(QString qsFileName)
 	float fAdjust = 0.0;
 	QColor theColor;
 	QRgb thePix;	// QRgb defined as :  0xAARRGGBB;
-	QWMatrix theMatrix;
+	QMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 
@@ -746,10 +803,12 @@ void MovieObject::loadPixmap(QString qsFileName)
 	// then we apply the other modifications ...
 	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
 	// Here we create the scaled image ...
-	theImage = theImage.xForm ( theMatrix );
+	//theImage = theImage.xForm ( theMatrix );	//ooo
+	theImage = theImage.transformed ( theMatrix );	//xxx
 
 	// create empty image.
-	QImage imageColored = QImage (theImage.width(), theImage.height(), theImage.depth());
+	//QImage imageColored = QImage (theImage.width(), theImage.height(), theImage.depth());		//ooo
+	QImage imageColored = QImage (theImage.width(), theImage.height(), QImage::Format_ARGB32);	//xxx
 	if (manipulator().fBrightness > 0.0)	{
 		bLighter = true;
 		fAdjust = 100 + manipulator().fBrightness * 300;
@@ -781,11 +840,12 @@ void MovieObject::loadPixmap(QString qsFileName)
 	// and plug in the remaining operations ...
 	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	m_image = imageColored.xForm( theMatrix );
+	//m_image = imageColored.xForm( theMatrix );		//ooo
+	m_image = imageColored.transformed( theMatrix );	//xxx
 }
 
 void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int iTotalFramesToRender)
-{
+{   
   if ( m_pOverlay )  {
        m_pOverlay->drawContents ( pPainter, iRenderFrameNumber, iTotalFramesToRender );
        return;
@@ -797,8 +857,10 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
   // Okay first step is get the fileName of the frame
   qsMenuName = dvdMenu ( )->getInterface ( )->qsMenuName;
   qsFullPath = QString ( "%1/%2/%3/%4" ).arg ( Global::qsTempPath ).arg ( Global::qsProjectName ) .arg ( qsMenuName ).arg ( extractionPath ( ) );
+
   QDir theDir ( qsFullPath );
-  theDir.setNameFilter ( "0*.jpg" );
+  //theDir.setNameFilter ( "0*.jpg" );				//ooo
+  theDir.setNameFilters ( QStringList(QString("0*.jpg")) );	//xxx
   int iDirCount = theDir.count  ( );
 
 //	// Next is to set the AnimationAttributes
@@ -812,7 +874,14 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
     iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
   else if ( movieData ( )->m_enLoop == Stop )
     iCurrentClipFile = ( iRenderFrameNumber > iDirCount ) ? iDirCount-1 : iRenderFrameNumber;
-  qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);
+
+  //qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);   //ooo
+  
+  if ( iDirCount > 0 )  //xxx
+    qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);   //xxx
+  else  //xxx  
+    qsFileName = QString ("%1/").arg(qsFullPath); //xxx
+
   //printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
   loadPixmap (qsFileName);
   // if we have an animation, then the shadow is updated in the imageobject ...
