@@ -1,13 +1,14 @@
-/****************************************************************************
-** Interface to the GUI.
-**
-**   Created : Sun Feb 23 21:45:00 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**  pure virtual class as base for the three button types.
-**
+/***************************************************************************
+    movieobject.h
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+  pure virtual class as base for the three button types.
+    
 ****************************************************************************/
 
 #ifndef MOVIEOBJECT_H
@@ -16,6 +17,9 @@
 #include <qimage.h>
 #include <qdatetime.h>
 #include <qsize.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QTimerEvent>
 
 #include "imageobject.h"
 
