@@ -1,18 +1,22 @@
-/****************************************************************************
-** ShadowObject class
-**
-**   Created : Tue Aug 08 22:06:51 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class 
-**
+/***************************************************************************
+    overlayobject.cpp
+                             -------------------
+    ShadowObject class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class
+    
 ****************************************************************************/
 
 #include <qimage.h>
 #include <qpainter.h>
 #include <qfileinfo.h>
+//Added by qt3to4:
+#include <QMouseEvent>
 
 #include "xml_dvd.h"
 #include "structuretoolbar.h"
@@ -143,7 +147,8 @@ bool OverlayObject::readProjectFile ( QDomNode &theNode )
   attribute = theElement.attributeNode ( OVERLAY_OBJECT_OFFSET );
   if ( ! attribute.isNull ( ) )  {
     QPoint theOffset;
-    QStringList list = QStringList::split ( ",", attribute.value ( ) );
+    //QStringList list = QStringList::split ( ",", attribute.value ( ) );	//ooo
+    QStringList list = attribute.value ( ).split ( "," );			//xxx
     if ( list.count ( ) == 2 )
          theOffset = QPoint ( list[0].toInt ( ), list[1].toInt ( ) );
     setOffset ( theOffset );
@@ -299,7 +304,7 @@ bool OverlayObject::fastDraw ( )
 QImage &OverlayObject::image ( QImage &image )
 {
   m_image = image.copy   ( );
-  m_image.setAlphaBuffer ( true );
+  //m_image.setAlphaBuffer ( true );	//oooo
 
   if ( m_imageOverlay.isNull ( ) )
     return m_image;
@@ -316,15 +321,18 @@ QImage &OverlayObject::image ( QImage &image )
 
   if ( ( m_imageScaled.width ( ) != iScaledWidth ) || ( m_imageScaled.height ( ) != iScaledHeight ) )  {
     if ( fastDraw ( ) )
-         m_imageScaled = m_imageOverlay.scale ( iScaledWidth, iScaledHeight );
+         //m_imageScaled = m_imageOverlay.scale ( iScaledWidth, iScaledHeight );	//ooo
+         m_imageScaled = m_imageOverlay.scaled ( iScaledWidth, iScaledHeight );		//xxx
     else
-         m_imageScaled = m_imageOverlay.smoothScale ( iScaledWidth, iScaledHeight );
+         //m_imageScaled = m_imageOverlay.smoothScale ( iScaledWidth, iScaledHeight );							//ooo
+         m_imageScaled = m_imageOverlay.scaled ( iScaledWidth, iScaledHeight, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );	//xxx
   }
   if ( ( rotate ( ) != 0.0f ) || ( shearX ( ) != 1.0f) || ( shearY ( ) != 1.0f ) ) {
-    QWMatrix theMatrix;
+    QMatrix theMatrix;
     theMatrix.rotate ( rotate ( ) );
     theMatrix.shear  ( shearX ( ), shearY ( ) );
-    m_imageScaled = m_imageScaled.xForm  ( theMatrix );
+    //m_imageScaled = m_imageScaled.xForm  ( theMatrix );	//ooo
+    m_imageScaled = m_imageScaled.transformed  ( theMatrix );	//xxx
     iScaledWidth  = m_imageScaled.width  ( );
     iScaledHeight = m_imageScaled.height ( );
     iMaxX         = iScaledWidth  - 1;
@@ -395,7 +403,7 @@ void OverlayObject::drawContents ( QPainter *, int iRenderFrameNumber, int )
     return;
 
   // Next is to set the AnimationAttributes
-  for ( uint t=0; t<m_listAnimationAttributes.count ( ) ;t++ )
+  for ( uint t=0; t<(uint)m_listAnimationAttributes.count ( ) ;t++ )
     m_listAnimationAttributes[t]->setValue ( iRenderFrameNumber );
 
   // And then we ought to refresh the pixmap ...
@@ -434,11 +442,15 @@ StructureItem *OverlayObject::createStructure ( StructureItem *pParentItem )
   pOverlayItem = m_pStructureItem;
   if ( ! pOverlayItem ) {
     pOverlayItem = new StructureItem ( this, StructureItem::Modifiers, pParentItem, pParentItem->lastChild ( ), qsItem, qsInfo );
-    pOverlayItem->setExpandable ( TRUE );
+    //pOverlayItem->setExpandable ( TRUE );	//ooo
+    pOverlayItem->setExpanded ( true );		//xxx
     m_pStructureItem = pOverlayItem;
   }
-  else
-    pOverlayItem->setText ( qsItem, qsInfo );
+  else {
+    //pOverlayItem->setText ( qsItem, qsInfo );		//ooo
+    pOverlayItem->setText ( 0, qsItem );		//xxx
+    pOverlayItem->setText ( 1, qsInfo );		//xxx
+  }
 
   pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Offset"), QString ( "%1, %2" ).arg ( offset ( ).x ( ) ).arg ( offset ( ).y ( ) ) );
   pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Rotate"), QString ( "%1" ).arg ( rotate ( ) ) );
@@ -481,15 +493,18 @@ AnimationAttribute *OverlayObject::getSpecificAttributes ( long iMaxNumberOfFram
   }
   else if ( qsProperty == "color.red" )  {
     callMeBack2 = new FunctionCallback<Rgba> ( m_color, TYPE_COLOR_RED );
-    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.red(), callMeBack2 );
+    //pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.Qt::red(), callMeBack2 );	//ooo
+    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.red(), callMeBack2 );		//xxx
   }
   else if ( qsProperty == "color.green" )   {
     callMeBack2 = new FunctionCallback<Rgba> ( m_color, TYPE_COLOR_GREEN );
-    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.green(), callMeBack2 );
+    //pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.Qt::green(), callMeBack2 );	//ooo
+    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.green(), callMeBack2 );	//xxx
   }
   else if ( qsProperty ==  "color.blue" )   {
     callMeBack2 = new FunctionCallback<Rgba> ( m_color, TYPE_COLOR_BLUE );
-    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.blue(), callMeBack2 );
+    //pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.Qt::blue(), callMeBack2 );	//ooo
+    pAnimAttr  = new AnimationAttribute ( iMaxNumberOfFrames, qsProperty, m_color.blue(), callMeBack2 );	//xxx
   }
   else if ( qsProperty == "color.alpha" )   {
     callMeBack2 = new FunctionCallback<Rgba> ( m_color, TYPE_COLOR_ALPHA );
