@@ -33,6 +33,8 @@
 #include <qobject.h>
 #include <qdatetime.h>
 #include <qstringlist.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 #include "sourcegroups.h"
 
@@ -53,7 +55,7 @@ class Interface : public QObject
   public:
     Interface ( ) { m_enType=SourceGroup::NTSC; m_qsProjectName="Unnamed"; m_qsTempPath="/tmp"; };
     virtual ~Interface ( ) {
-      QValueList<SourceGroup *>::iterator it=m_listOfGroups.begin ( );
+      QList<SourceGroup *>::iterator it=m_listOfGroups.begin ( );	//oxx
       while ( it != m_listOfGroups.end ( ) )
         delete *it++;
     };
@@ -81,7 +83,7 @@ class Interface : public QObject
     QString m_qsProjectName;
     QString m_qsTempPath;
 
-    QValueList<SourceGroup *> m_listOfGroups;
+    QList<SourceGroup *> m_listOfGroups;	//oxx
 }; // end class Interface
 
 }; // end namespace Plugin
