@@ -4,15 +4,20 @@
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qcursor.h>
-#include <qlistbox.h>
+//#include <q3listbox.h>    //ooo
+#include <QListWidget>      //xxx
 #include <qpainter.h>
 #include <qfileinfo.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qpushbutton.h>
-#include <qfiledialog.h>
+//#include <q3filedialog.h> //ooo
+#include <QFileDialog>
 #include <qradiobutton.h>
 #include <qapplication.h>
+//Added by qt3to4:
+#include <QTimerEvent>
+#include <QMessageBox>  //xxx
 
 #include "../../win32.h"
 #include "../../CONFIG.h" // get PREFIX_DIRECTORY
@@ -21,15 +26,16 @@
 namespace Plugin
 {
 
-MenuSlideInterface::MenuSlideInterface ( )
+MenuSlideInterface::MenuSlideInterface ( )    //ooo
+//MenuSlideInterface::MenuSlideInterface ( QWidget *pParent ) //xxx
   : Interface ( ),
-    MenuSlide ( )
+    MenuSlide ( ) //ooo
+    //MenuSlide ( pParent )   //xxx
 {
-
 }
 
 bool MenuSlideInterface::execute  ( )
-{
+{    
   MenuSlide::show ( );
   return true;
 };
@@ -47,9 +53,13 @@ MenuSlide::ImageContainer::ImageContainer ( QString &qsFile )
   qsBaseName = fileInfo.fileName ( );
 }
 
-MenuSlide::MenuSlide( QWidget *pParent, const char *pName, bool bModal, WFlags fl )
-    : uiDialogMenuSlide ( pParent, pName, bModal, fl )
+//MenuSlide::MenuSlide( QWidget *pParent, const char *pName, bool bModal, Qt::WFlags fl )	//ooo
+MenuSlide::MenuSlide( QWidget *pParent )							//xxx
+    //: uiDialogMenuSlide ( pParent, pName, bModal, fl )	//ooo
+    : QDialog ( pParent )					//xxx
 {
+  setupUi(this);	//xxx
+  
   m_iMaxWidth  = 200;
   m_iMaxHeight = 200;
   m_iConcurrentImages = 3;
@@ -66,7 +76,11 @@ MenuSlide::MenuSlide( QWidget *pParent, const char *pName, bool bModal, WFlags f
   connect ( m_pButtonBackground,   SIGNAL ( clicked ( ) ), SLOT ( slotBackground ( ) ) );
   connect ( m_pRadioImageDuration, SIGNAL ( toggled ( bool ) ), SLOT ( slotToggledID ( bool ) ) );
   connect ( m_pRadioTotalDuration, SIGNAL ( toggled ( bool ) ), SLOT ( slotToggledTD ( bool ) ) );
-  connect ( m_pListBoxImages,      SIGNAL ( selectionChanged ( QListBoxItem * ) ), SLOT ( slotImageChanged ( QListBoxItem * ) ) );
+  //connect ( m_pListBoxImages,      SIGNAL ( selectionChanged ( Q3ListBoxItem * ) ), SLOT ( slotImageChanged ( Q3ListBoxItem * ) ) );  //ooo
+  connect ( m_pListBoxImages,      SIGNAL ( itemClicked ( QListWidgetItem * ) ), SLOT ( slotImageChanged ( QListWidgetItem * ) ) );    //xxx
+  
+  //connect ( buttonOk,              SIGNAL ( clicked ( ) ), SLOT ( accept         ( ) ) );   //xxx
+  
 }
 
 MenuSlide::~MenuSlide ( )
@@ -75,21 +89,28 @@ MenuSlide::~MenuSlide ( )
 
 void MenuSlide::polish ( )
 {
-  uiDialogMenuSlide::polish ( );
+  //uiDialogMenuSlide::polish ( );	//ooo
+  //QDialog::polish ( );			//xxx
   loadBackgroundImage ( );
 }
 
 void MenuSlide::loadBackgroundImage ( )
-{
+{    
   QString qsFileName = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/menuslide/background/background00000.jpg";
+  
   QPixmap thePixmap;
   QImage  theImage ( qsFileName );
   if ( theImage.isNull ( ) )
     return;
 
-  theImage = theImage.smoothScale ( m_pFrame->width ( ) - 10, m_pFrame->height ( ) - 10, QImage::ScaleMin );
+  //theImage = theImage.smoothScale ( m_pFrame->width ( ) - 10, m_pFrame->height ( ) - 10, Qt::KeepAspectRatio );   //ooo
+  theImage = theImage.scaled ( m_pFrame->width ( ) - 10, m_pFrame->height ( ) - 10, Qt::KeepAspectRatio );  //xxx
   thePixmap.convertFromImage      ( theImage );
-  m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );
+  //m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );  //ooo
+  QPalette palette;								//xxx
+  //palette.setBrush(QPalette::Base, QBrush(thePixmap));				//xxx
+  palette.setBrush(m_pFramePreview->backgroundRole(), QBrush(thePixmap));				//xxx
+  m_pFramePreview->setPalette(palette);					//xxx
   m_pFramePreview->setFixedSize   ( thePixmap.size ( ) );
   m_backgroundPixmap = thePixmap;
 }
@@ -143,13 +164,14 @@ void MenuSlide::slotToggledTD   ( bool bToggled )
   m_pEditTotalDuration->setEnabled (   bToggled );
 }
 
-void MenuSlide::slotImageChanged ( QListBoxItem *pItem )
+//void MenuSlide::slotImageChanged ( Q3ListBoxItem *pItem ) //ooo
+void MenuSlide::slotImageChanged ( QListWidgetItem *pItem ) //xxx
 {
   // Called when the user selects an image in the ListBox to the left ...
   int t;
   QString qsImage = pItem->text ( );
 
-  QCursor myCursor     ( QCursor::WaitCursor );
+  QCursor myCursor     ( Qt::WaitCursor );
   QApplication::setOverrideCursor ( myCursor );
 
   for ( t=0; t<(int)m_listImages.count ( ); t++ ) {
@@ -160,10 +182,14 @@ void MenuSlide::slotImageChanged ( QListBoxItem *pItem )
 	int iWidth  = m_pFrame->width  ( ) - 10;
 	int iHeight = m_pFrame->height ( ) - 10;
 	*pImage = QImage ( m_listImages[t]->qsFileName );
-	*pImage = pImage->smoothScale ( iWidth, iHeight, QImage::ScaleMin );
+	//*pImage = pImage->smoothScale ( iWidth, iHeight, Qt::KeepAspectRatio );  //ooo
+    *pImage = pImage->scaled ( iWidth, iHeight, Qt::KeepAspectRatio );  //xxx
       }
       thePixmap.convertFromImage ( *pImage );
-      m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );
+      //m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );  //ooo
+      QPalette palette;								//xxx
+      palette.setBrush(QPalette::Window, QBrush(thePixmap));				//xxx
+      m_pFramePreview->setPalette(palette);					//xxx
       m_pFramePreview->setFixedSize ( thePixmap.size (      ) );
       QApplication::restoreOverrideCursor ( );
       return;
@@ -185,14 +211,16 @@ void MenuSlide::slotAddImages ( )
     qsHomeDir = QString ( pHomeDir );
 
   //QStringList list = FilePreviewDialog::getOpenFileNames ( qsHomeDir, qsFilter, this, "FileOpenDialog", uiDialogMenuSlide::tr ( "Add Images to list." ) );
-  QStringList list = QFileDialog::getOpenFileNames ( qsFilter, qsHomeDir, this, "FileOpenDialog", tr ( "Add Images to list." ) );
+  //QStringList list = Q3FileDialog::getOpenFileNames ( qsFilter, qsHomeDir, this, "FileOpenDialog", tr ( "Add Images to list." ) );    //xxx
+  QStringList list = QFileDialog::getOpenFileNames ( this, "FileOpenDialog", qsHomeDir, qsFilter ); //xxx
 
   if ( list.count ( ) < 1 )
     return;
 
   for ( t=0; t<(int)list.count  ( ); t++ ) {
     pImage = new ImageContainer ( list[t] );
-    m_pListBoxImages->insertItem( pImage->qsBaseName );
+    //m_pListBoxImages->insertItem( pImage->qsBaseName );   //ooo
+    m_pListBoxImages->addItem( pImage->qsBaseName );   //xxx
     m_listImages.append ( pImage );
   }
 
@@ -259,7 +287,8 @@ void MenuSlide::createAnimationData ( bool bCreateThumbs )
 
   QString qsValue;
   float   fFPS = 25.0; // PAL
-  if ( m_pComboFormat->currentItem ( ) == 0 )
+  //if ( m_pComboFormat->currentItem ( ) == 0 ) //ooo
+  if ( m_pComboFormat->currentIndex ( ) == 0 )  //xxx
     fFPS = 29.97; // NTSC
 
   m_iTotalFrames   = (unsigned long)( fFPS * fTotalLength );
@@ -275,7 +304,7 @@ void MenuSlide::createAnimationData ( bool bCreateThumbs )
   }
   
   if ( bCreateThumbs ) {
-    QCursor myCursor     ( QCursor::WaitCursor );
+    QCursor myCursor     ( Qt::WaitCursor );
     QApplication::setOverrideCursor ( myCursor );
 
     // preloading all images
@@ -288,7 +317,8 @@ void MenuSlide::createAnimationData ( bool bCreateThumbs )
       pContainer = m_listImages[t];
       if ( pContainer->thumbnail.isNull ( ) ) {
 	pContainer->thumbnail = QImage ( pContainer->qsFileName );
-	pContainer->thumbnail = pContainer->thumbnail.smoothScale ( iWidth, iHeight, QImage::ScaleMin );
+	//pContainer->thumbnail = pContainer->thumbnail.smoothScale ( iWidth, iHeight, Qt::KeepAspectRatio );  //ooo
+    pContainer->thumbnail = pContainer->thumbnail.scaled ( iWidth, iHeight, Qt::KeepAspectRatio );  //xxx
       }
     }
     QApplication::restoreOverrideCursor ( );
@@ -331,7 +361,8 @@ void MenuSlide::animate ( unsigned long iFrameNumber )
   iWidth  = m_pFrame->width  ( ) - 10;
   iHeight = m_pFrame->height ( ) - 10;
 
-  if ( m_pComboFormat->currentItem ( ) == 0 ) {
+  //if ( m_pComboFormat->currentItem ( ) == 0 ) {   //ooo
+  if ( m_pComboFormat->currentIndex ( ) == 0 ) {    //xxx
     fFPS = 29.97f; // NTSC
     //iTotalHeight = 480;
   }
@@ -351,14 +382,18 @@ void MenuSlide::animate ( unsigned long iFrameNumber )
       printf ( "Image<%d>=<%0.3f=%0.3f> ", t, fDeltaZoom, fDeltaZoom * iFrameNumber);
 //      iImageWidth  = (int)( fDeltaZoom * iFrameNumber * iWidth  );
 //      iImageHeight = (int)( fDeltaZoom * iFrameNumber * iHeight );
-      theImage     = m_listImages[t]->thumbnail.smoothScale ( iWidth, iHeight, QImage::ScaleMin );
+      //theImage     = m_listImages[t]->thumbnail.smoothScale ( iWidth, iHeight, Qt::KeepAspectRatio ); //ooo
+      theImage     = m_listImages[t]->thumbnail.scaled ( iWidth, iHeight, Qt::KeepAspectRatio );    //xxx
 
       thePainter.drawImage ( 20, 20, theImage );
     }
   }
   printf ( "\n" );
   // Finally we copy over the created image.
-  m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );
+  //m_pFramePreview->setPaletteBackgroundPixmap ( thePixmap );  //ooo
+  QPalette palette;								//xxx
+  palette.setBrush(QPalette::Window, QBrush(thePixmap));				//xxx
+  m_pFramePreview->setPalette(palette);					//xxx
   m_pFramePreview->setFixedSize ( thePixmap.size (      ) );    
 }
 /*
@@ -402,25 +437,28 @@ void MenuSlide::timerEvent ( QTimerEvent *pEvent )
 ///////////////////////////////////////////////////////////////////////
 
 void MenuSlide::accept ( )
-{
+{    
   srandom  ( 0 );
   //QString qsText = testMenu ( );
   QString qsText = getMenuXml ( );
   QString qsMenuName ( "MenuSlide" );
 
   Plugin::SourceGroup::type theType = Plugin::SourceGroup::NTSC;
-  if ( m_pComboFormat->currentItem ( ) > 0 )
+  //if ( m_pComboFormat->currentItem ( ) > 0 )  //ooo
+  if ( m_pComboFormat->currentIndex ( ) > 0 )   //xxx
     theType = Plugin::SourceGroup::PAL;
 
   doEmit ( theType, qsMenuName, qsText );
   //printf ( "Accepted <%s>\n", qsText.ascii( ) );
 
-  uiDialogMenuSlide::accept ( );
+  //uiDialogMenuSlide::accept ( );	//ooo
+  QDialog::accept ( );			//xxx
 }
 
 QString MenuSlide::getMenuXml ( )
 {
-  QTime   theDuration;
+  //QTime   theDuration;	//ooo
+  QTime   theDuration(0,0,0);	//xxx
   QString qsDuration, qsFormat = ( "hh:mm:ss.zzz" );
 
   int   iTotalImages = m_listImages.count ( );
@@ -521,7 +559,8 @@ QString MenuSlide::buildAnimation ( int iImageNumber )
 
   fFPS = 25.0; // PAL
   iTotalHeight = 576;
-  if ( m_pComboFormat->currentItem ( ) == 0 ) {
+  //if ( m_pComboFormat->currentItem ( ) == 0 ) {   //ooo
+  if ( m_pComboFormat->currentIndex ( ) == 0 ) {    //xxx
     fFPS = 29.97; // NTSC
     iTotalHeight = 480;
   }
