@@ -13,16 +13,20 @@
 
 #include <qimage.h>
 #include <qpixmap.h>
-#include <qvaluelist.h>
+//#include <q3valuelist.h>	//oxx
+//Added by qt3to4:
+#include <QTimerEvent>
 
 #include "../interface.h"
 
-#include "uimenuslide.h"
+//#include "uimenuslide.h"	//ooo
+#include "ui_uimenuslide.h"	//xxx
 
 namespace Plugin
 {
 
-class MenuSlide : public uiDialogMenuSlide
+//class MenuSlide : public uiDialogMenuSlide				//ooo
+class MenuSlide : public QDialog, public Ui::uiDialogMenuSlide		//xxx
 {
   Q_OBJECT
 
@@ -35,7 +39,8 @@ class MenuSlide : public uiDialogMenuSlide
   };
 
 public:
-           MenuSlide  ( QWidget *p=NULL, const char *n=NULL, bool m=FALSE, WFlags f=0 );
+           //MenuSlide  ( QWidget *p=NULL, const char *n=NULL, bool m=FALSE, Qt::WFlags f=0 );		//ooo
+	   MenuSlide  ( QWidget *pParent=NULL );							//xxx
   virtual ~MenuSlide  ( );
   virtual void accept ( );
 
@@ -58,7 +63,8 @@ protected slots:
   virtual void slotBackground   ( );
   virtual void slotToggledID    ( bool );
   virtual void slotToggledTD    ( bool );
-  virtual void slotImageChanged ( QListBoxItem * );
+  //virtual void slotImageChanged ( Q3ListBoxItem * );  //ooo
+  virtual void slotImageChanged ( QListWidgetItem * );  //xxx
 
 protected:
   void timerEvent ( QTimerEvent * );
@@ -74,7 +80,7 @@ private:
   int m_iMaxHeight;
   int m_iConcurrentImages;
   QString testMenu ( );
-  QValueList<ImageContainer *> m_listImages;
+  QList<ImageContainer *> m_listImages;		//oxx
 
   int m_iAnimationTimerID;
   unsigned long m_iCurrentFrame;
@@ -87,7 +93,8 @@ private:
 class MenuSlideInterface : public Interface, public MenuSlide
 {
 public:
-  MenuSlideInterface    ( );
+  MenuSlideInterface    ( );  //ooo
+  //MenuSlideInterface    ( QWidget * );  //xxx
   virtual ~MenuSlideInterface   ( ) { };
 //  virtual float version ( ) { return 0.1f; };
   virtual QWidget *getConfigWidget ( QWidget * ) { return 0; };
