@@ -1,13 +1,16 @@
 
 // This is the implementation of the SimpleDVD plugin for QDVDAuthor.
 
-#include <qprogressdialog.h>
+//#include <q3progressdialog.h> //ooo
+#include <QProgressDialog> //xxx
 #include <qapplication.h>
 #include <qpushbutton.h>
 #include <qfileinfo.h>
 #include <qimage.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
-#include "uisimpledvd.h"
+//#include "uisimpledvd.h"  //ooo
 #include "simpledvd.h"
 
 // The class factories
@@ -47,7 +50,7 @@ bool SimpleDVD::execute ( )
 {
   int iButtonsPerMenu = 6;
   // Here we create the DVD Structure for the given input arameters
-  QValueList<SourceGroup *>::iterator it = m_listOfGroups.begin ( );
+  QList<SourceGroup *>::iterator it = m_listOfGroups.begin ( );	//oxx
   SourceGroup *pGroup = NULL;
   int iMenuNumber, iCount;
   iMenuNumber = iCount = 0;
@@ -63,14 +66,17 @@ bool SimpleDVD::execute ( )
   m_iNrOfMenus    = (int)( ( m_listOfGroups.count ( ) + iButtonsPerMenu - 1 ) / iButtonsPerMenu );
   int iProgress   = 0;
   int iSlideCount = 1;
-  QProgressDialog progressDialog ( NULL );
-  progressDialog.setTotalSteps   ( m_iNrOfMenus );
+  //Q3ProgressDialog progressDialog ( NULL );   //ooo
+  QProgressDialog progressDialog ( NULL );  //xxx
+  //progressDialog.setTotalSteps   ( m_iNrOfMenus );    //ooo
   progressDialog.resize          ( QSize(550, 80) ); //.expandedTo ( progressDialog.minimumSizeHint ( ) ) );
   progressDialog.show            (    );
-  progressDialog.setProgress     ( iProgress++ );
-  qApp->processEvents            ( 10 );
+  //progressDialog.setProgress     ( iProgress++ ); //ooo
+  progressDialog.setValue     ( iProgress++ );  //xxx
+  //qApp->processEvents            ( 10 );  //ooo
+  qApp->processEvents            ( );   //xxx
 
-  QValueList<SourceGroup *> listGroups;
+  QList<SourceGroup *> listGroups;	//oxx
   it = m_listOfGroups.begin ( );
   while ( it != m_listOfGroups.end ( ) )  {
     pGroup = *it++;
@@ -83,15 +89,18 @@ bool SimpleDVD::execute ( )
       listGroups.clear ( );
 
       QString qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber );
-      progressDialog.setCaption ( tr ( "Creating [%1]" ).arg ( qsMenuName ) );
+      //progressDialog.setCaption ( tr ( "Creating [%1]" ).arg ( qsMenuName ) );    //ooo
+      progressDialog.setWindowTitle ( tr ( "Creating [%1]" ).arg ( qsMenuName ) );  //xxx
 
       // Create the DVDMenu
       //printf ( "%s\n\n\n", qsMenuXML.ascii ( ) );
       emit ( signalNewMenuResponse ( theType, qsMenuName, qsMenuXML ) );
       iCount = 0;
     }
-    progressDialog.setProgress ( iProgress++ );
-    qApp->processEvents        (     10 );
+    //progressDialog.setProgress ( iProgress++ );   //ooo
+    progressDialog.setValue ( iProgress++ ); //xxx
+    //qApp->processEvents        (     10 );    //ooo
+    qApp->processEvents        (     ); //xxx
   }
   if ( iCount > 0 )  {
       SourceGroup::type theType = pGroup->enType;
@@ -108,7 +117,7 @@ bool SimpleDVD::execute ( )
   return true;
 }
 
-QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber, int &iSlideCount )
+QString SimpleDVD::getMenuXML ( QList<SourceGroup *> &list, int iMenuNumber, int &iSlideCount )	//oxx
 {
   QFileInfo fileInfo;
   QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName, qsGroupName;
@@ -150,7 +159,7 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
   qsMenuXML += "   </TextObject>\n";
 
   // Next we take care of the Buttons ...
-  QValueList<SourceGroup *>::iterator it;
+  QList<SourceGroup *>::iterator it;	//oxx
   it = list.begin ( );
   while ( it != list.end ( ) )  {
     pGroup = *it++;
@@ -161,7 +170,8 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
     qsGroupName = pGroup->qsGroupName;
     qsFileName  = "";
     if ( pGroup->bSlideshow )  {
-      qsGroupName.sprintf ( "[%02d] - %s", iSlideCount++, (const char *)pGroup->qsGroupName.utf8 ( ) );
+      //qsGroupName.sprintf ( "[%02d] - %s", iSlideCount++, (const char *)pGroup->qsGroupName.utf8 ( ) );   //ooo
+      qsGroupName.sprintf ( "[%02d] - %s", iSlideCount++, (const char *)pGroup->qsGroupName.toUtf8 ( ) ); //xxx  
       qsFileName  = pGroup->qsGroupName + ".vob+-+00:00:00.000";
     }
     else if ( pGroup->listFiles.size ( ) > 0 )  {
