@@ -1,3 +1,5 @@
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 #ifndef __PLUGIN_SOURCE_GROUPS_H__
 #define __PLUGIN_SOURCE_GROUPS_H__
@@ -21,7 +23,7 @@ class SourceGroup
     };
              SourceGroup ( ) { enType=NTSC; bSlideshow=false; bCreateChapterMenu=false; iFlags=2; };
     virtual ~SourceGroup ( ) {
-      QValueList<SourceEntry *>::iterator it=listFiles.begin ( );
+      QList<SourceEntry *>::iterator it=listFiles.begin ( );	//oxx
       while ( it != listFiles.end ( ) )
         delete *it++;
     };
@@ -34,7 +36,7 @@ class SourceGroup
     QDateTime     dateStart;   // The starting date of the Slideshow / Videos
     QDateTime     dateEnd;     // The ending date of the Slideshow  / Videos
 
-    QValueList<SourceEntry *> listFiles;
+    QList<SourceEntry *> listFiles;		//oxx
     QString     qsScreenshot;
     bool        bSlideshow;
     int         iFilterLength;
