@@ -9,7 +9,10 @@ v** DummyWidget - class
 ** MediaInterface's (XineWidget, KaffeinesWidget, MPlayerWidget VLCWidget)
 ** 
 ****************************************************************************/
-#include <qimage.h>
+//#include <qimage.h>		//ooo
+#include <QImage>		//xxx
+//Added by qt3to4:
+#include <QPixmap>
 
 #include "dummywidget.h"
 #include "mplayerinfo.h"
@@ -20,7 +23,8 @@ QImage DummyInfo::getScreenshot( long )
 }
 
 DummyWidget::DummyWidget(QWidget *parent, const char *pName, void *)
-	: QWidget(parent, pName), MediaInterface()
+	//: QWidget(parent, pName), MediaInterface()	//ooo
+	: QWidget(parent), MediaInterface()		//xxx
 {
 	m_pMediaInfo = new DummyInfo;
 }
