@@ -13,7 +13,10 @@
 #ifndef DUMMYWIDGET_H
 #define DUMMYWIDGET_H
 
-#include <qwidget.h>
+//#include <qwidget.h>		//ooo
+#include <QWidget>		//xxx
+//Added by qt3to4:
+#include <QPixmap>
 
 #include "mediainfo.h"
 #include "mediainterface.h"
