@@ -22,6 +22,17 @@
 #ifndef KXINEWIDGET_H
 #define KXINEWIDGET_H
 
+#include <QWidget>		//xxx
+#include <QTimerEvent>		//xxx
+#include <QMouseEvent>		//xxx
+#include <QWheelEvent>		//xxx
+#include <QTime>		//xxx
+#include <QTimer>		//xxx
+#include <QString>		//xxx
+#include <QStringList>		//xxx
+#include <X11/Xlib.h>		//xxx
+#include <xine.h>		//xxx
+
 /* define this if you want to use QT only - disables post plugin support (except visualization)! */
 #define USE_QT_ONLY 1
 
@@ -39,23 +50,33 @@
 #endif
 
 /* forward declaration */
-class QString;
-class QMouseEvent;
-class QTimerEvent;
-class QTime;
+//class QString;		//ooo
+//class QMouseEvent;		//ooo
+//class QTimerEvent;		//ooo
+//class QTime;			//ooo
 
-#include <qtimer.h>
-#include <qptrlist.h>
-#include <X11/Xlib.h>
-#include <xine.h>
+//#include <qtimer.h>		//ooo
+//#include <QTimer>		//xxx
+//#include <q3ptrlist.h>	//ooo
+//#include <QList>		//xxx
+//#include <X11/Xlib.h>		//ooo
+//#include <xine.h>		//ooo
+
+//Added by qt3to4:
+//#include <QTimerEvent>
+//#include <QMouseEvent>
+//#include <QWheelEvent>
 
 #ifndef USE_QT_ONLY
 #include "postfilter.h"
 #else
 typedef int PostFilter; /* dummy type */
-#include <qwidget.h>
-#include <qstringlist.h>
-#include <qdatetime.h>
+//#include <qwidget.h>		//ooo
+//#include <QWidget>		//xxx
+//#include <qstringlist.h>	//ooo
+//#include <QStringList>		//xxx
+//#include <qdatetime.h>	//ooo
+//#include <QDateTime>		//xxx
 #endif
 
 #define SUPPORTED_PROTOCOLS "file,http,mms,mmst,rtsp,rtp,tcp,pnm,cdda,vcd,vcdo,dvd,dvb,pvr,v4l,net,vdr,smb"
@@ -195,7 +216,7 @@ signals:
 	void signalXineReady();
 	void signalXinePlaying();
 
-	void signalHasChapters(bool);
+	//void signalHasChapters(bool);		//ooo
 	void signalPlaybackFinished();
 	void signalNewChannels(const QStringList& audio, const QStringList& sub, int currentAudio, int currentSub);
 	void signalNewPosition(int, const QTime&);
@@ -234,10 +255,13 @@ public slots:
 	void slotSeekToPosition(int pos);
 	void slotSeekToTime(const QTime&);
 	void slotStopSeeking();
-	void slotEnableVideoFilters(bool enable);
-	void slotEnableAudioFilters(bool enable);
+	//void slotEnableVideoFilters(bool enable);	//ooo
+	void slotEnableVideoFilters(int enable);	//xxx
+	//void slotEnableAudioFilters(bool enable);	//ooo
+	void slotEnableAudioFilters(int enable);	//xxx
 	void slotEject();
-	void slotEnableAutoresize(bool enable);
+	//void slotEnableAutoresize(bool enable);	//ooo
+	void slotEnableAutoresize(int enable);		//xxx
 	void slotAspectRatioAuto();
 	void slotAspectRatio4_3();
 	void slotAspectRatioAnamorphic(); /* 16:9 */
@@ -276,7 +300,8 @@ public slots:
 	void slotSetEq4k(int val);
 	void slotSetEq8k(int val);
 	void slotSetEq16k(int val);
-	void slotSetVolumeGain(bool gain);
+	//void slotSetVolumeGain(bool gain);	//ooo
+	void slotSetVolumeGain(int gain);	//xxx
 
 	/* DVD Menus */
 	void slotMenuToggle();
@@ -397,9 +422,9 @@ protected:
 
 #ifndef USE_QT_ONLY
 	/*postfilter*/
-	QPtrList<PostFilter> m_videoFilterList;
+	Q3PtrList<PostFilter> m_videoFilterList;
 	bool m_videoFiltersEnabled;
-	QPtrList<PostFilter> m_audioFilterList;
+	Q3PtrList<PostFilter> m_audioFilterList;
 	bool m_audioFiltersEnabled;
 	PostFilter* m_deinterlaceFilter;
 	bool m_deinterlaceEnabled;
@@ -476,8 +501,10 @@ public:
 public slots:
 	void setDvb( const QString &pipeName, const QString &chanName, int haveVideo );
 	void setDvbCurrentNext( const QString &channelName, const QStringList &list );
-	bool openDvb();
-	bool playDvb();
+	//bool openDvb();	//ooo
+	int openDvb();		//xxx
+	//bool playDvb();	//ooo
+	int playDvb();		//xxx
 	void slotPlayTimeShift();
 	void dvbShowOSD();
 	void dvbHideOSD();
