@@ -15,13 +15,17 @@
 #include <unistd.h>
 #endif
 
-#include <qprocess.h>
+//#include <q3process.h>	//ooo
+#include <QProcess>		//xxx
 #include <qregexp.h>
 #include <qtimer.h>
 #include <qmutex.h>
 #include <qimage.h>
+#include <QTime>	//xxx
+#include <QFile>	//xxx
+#include <QFileInfo>	//xxx
 
-#include "../../win32.h"
+//#include "../../win32.h"	//ooo
 #include "../../global.h"
 #include "mplayerinfo.h"
 
@@ -38,11 +42,14 @@
 #endif
 
 MPlayerInfoProcess::MPlayerInfoProcess ( MPlayerInfo *pParent )
-  : QProcess ( )
+  //: Q3Process ( )	//ooo
+  : QProcess ( )	//xxx
 {
   m_pParent       = pParent;
   m_bHasExited    = false;
-  connect ( this, SIGNAL ( processExited ( ) ), this, SLOT ( slotHasExited ( ) ) );
+  //connect ( this, SIGNAL ( processExited ( ) ), this, SLOT ( slotHasExited ( ) ) );   //ooo
+  connect ( this, SIGNAL ( finished (int, QProcess::ExitStatus) ), this, SLOT ( slotHasExited ( ) ) );          //xxx
+  //connect ( this, SIGNAL ( readChannelFinished ( ) ), this, SLOT ( slotHasExited ( ) ) );          //xxx
 }
 
 MPlayerInfoProcess::~MPlayerInfoProcess ( )
@@ -92,7 +99,8 @@ MPlayerInfo::~MPlayerInfo ( )
 
 void MPlayerInfo::initMe ( )
 {
-  m_pMutex         = new QMutex ( TRUE );
+  //m_pMutex         = new QMutex ( TRUE );	//ooo
+  m_pMutex         = new QMutex ( );		//xxx
   m_bAcquireLock   = false;
   m_pSlaveProcess  = NULL;
   m_iRetryCounter  = 200;
@@ -125,7 +133,8 @@ void MPlayerInfo::slotRetryQuery ( )
   if ( bTryToLockFailed == true ) {
     debug_out ( " Hard Out !\n" );
     delete m_pMutex;
-    m_pMutex = new QMutex ( TRUE );
+    //m_pMutex = new QMutex ( TRUE );		//ooo
+    m_pMutex = new QMutex ( );			//xxx
     // Hard lock the mutex, Could starve here ...
     Lock ( );
   }
@@ -138,10 +147,12 @@ void MPlayerInfo::deleteSlaveProcess ( )
 {
   if ( m_pSlaveProcess ) {
     if ( ! m_pSlaveProcess->hasExited ( ) ) {
-      m_pSlaveProcess->tryTerminate ( );
-      usleep ( 20000 ); // sleep for a bit ( 20 ms )
+      //m_pSlaveProcess->tryTerminate ( );				//ooo
+      //usleep ( 20000 ); // sleep for a bit ( 20 ms )			//ooo
+      SleeperThread::msleep ( 20 ); // sleep for a bit ( 20 ms )	//xxx
       m_pSlaveProcess->kill ( );
-      usleep ( 20000 ); // sleep for a bit ( 20 ms )
+      //usleep ( 20000 ); // sleep for a bit ( 20 ms )			//ooo
+      SleeperThread::msleep ( 20 ); // sleep for a bit ( 20 ms )	//xxx
       debug_out ( "kill / delete <%p>\n", m_pSlaveProcess );
     }
     delete m_pSlaveProcess;
@@ -176,7 +187,8 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
   QFileInfo fileInfo ( QFile::encodeName ( m_qsFileName ) );
   QString qsAudioExtensions = getExtensions ( false );
   int  iIsVideo = 1;
-  if ( qsAudioExtensions.find ( fileInfo.extension ( FALSE ) ) > -1 )
+  //if ( qsAudioExtensions.find ( fileInfo.extension ( FALSE ) ) > -1 )		//ooo
+  if ( qsAudioExtensions.indexOf ( fileInfo.suffix ( ) ) > -1 )			//xxx
        iIsVideo = 0;
 
   m_pSlaveProcess = new MPlayerInfoProcess ( this );
@@ -194,9 +206,10 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
   listCommand.append ( QString ( "--"          ) );
   listCommand.append ( QString ( "%1" ).arg ( m_qsFileName ) );
 
-  connect ( m_pSlaveProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadStdout ( ) ) );
+  //connect ( m_pSlaveProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadStdout ( ) ) );         //ooo
+  connect ( m_pSlaveProcess, SIGNAL ( readyReadStandardOutput ( ) ), this, SLOT ( slotReadStdout ( ) ) );   //xxx
 
-  m_pSlaveProcess->clearArguments ( );
+  //m_pSlaveProcess->clearArguments ( );		//ooo
   m_pSlaveProcess->setArguments   ( listCommand );
 
 //  QString test ( " " );
@@ -204,7 +217,8 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
 //  printf ( "MPLayerInfo::queryValues () <%s>\n", test.ascii ( ) );
 
   QTimer::singleShot ( 0, this, SLOT ( slotStart ( ) ) );
-  usleep ( 10 );
+  //usleep ( 10 );			//ooo
+  SleeperThread::msleep ( 10 );		//xxx
 //  m_pSlaveProcess->start ( ); 
   Unlock ( );
 
@@ -234,7 +248,8 @@ debug_out ( "this<%p> slave<%p> iCount<%d>\n", this, m_pSlaveProcess, iMaxCounte
       Lock ( );
       if ( m_pSlaveProcess && ! m_pSlaveProcess->hasExited ( ) && ( iMaxCounter > 0 ) ) {
         Unlock ( );
-        usleep ( 50000 ); // 50 ms = 0.05sec
+        //usleep ( 50000 ); // 50 ms = 0.05sec			//ooo
+	SleeperThread::msleep ( 50 ); // 50 ms = 0.05sec	//xxx
         iMaxCounter --;
       }
       else {
@@ -257,7 +272,8 @@ void MPlayerInfo::slotReadStdout ()
 //printf ("MPlayerInfo::slotReadStdout\n");
   QString qsWidth, qsHeight, qsWindowWidth, qsWindowHeight;
   QString qsLength, qsBuffer, qsAspect;
-  QString qsStdout ( m_pSlaveProcess->readStdout ( ) );
+  //QString qsStdout ( m_pSlaveProcess->readStdout ( ) );		//ooo
+  QString qsStdout ( m_pSlaveProcess->readAllStandardOutput ( ) );	//xxx
   float fAspect = 0.0f;
   int iPos;
 
@@ -270,15 +286,18 @@ void MPlayerInfo::slotReadStdout ()
   //m_pMutex->unlock ( );
 
 //printf ("    %s\n", (const char *)qsStdout);
+printf ("***    %s\n", qsStdout.toLatin1().data());    //xxx
 	// Okay and here we process the received data.
 	// VO: [xv] 352x240 => 352x264 Planar YV12
 	QRegExp	regSize ("ID_VIDEO_WIDTH=([0-9]+)");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		qsWidth   = regSize.cap(1);
 		m_iResolutionWidth  = qsWidth. toInt();
 	}
 	regSize = QRegExp ("ID_VIDEO_HEIGHT=([0-9]+)");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		qsHeight   = regSize.cap(1);
 		m_iResolutionHeight = qsHeight.toInt();
 	}
@@ -289,23 +308,27 @@ void MPlayerInfo::slotReadStdout ()
 		m_qsResolution  = QString ("%1x%2").arg(m_iResolutionWidth).arg(m_iResolutionHeight);
 	}
 	regSize = QRegExp ("ID_VIDEO_FPS=([0-9\\.]+)");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_fFPS  = regSize.cap(1).toFloat();
 		m_qsFPS = regSize.cap(1);
 	}
 	regSize = QRegExp ("ID_VIDEO_BITRATE=([0-9]+)");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_iVideoBPS  = regSize.cap(1).toInt();
 		m_qsVideoBPS = regSize.cap(1);
 	}
 	regSize = QRegExp ("AO:.*");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_bAudioHandled = true;
 	}
 	// Movie-Aspect is 1.33:1 - prescaling to correct movie aspect.
 	regSize = QRegExp ("Movie-Aspect is (\\S+).*"); //  1.33:1 OR undefined ...
 	iPos = 0;
-	while ( ( iPos = regSize.search ( qsStdout, iPos ) ) != -1 )  {
+	//while ( ( iPos = regSize.search ( qsStdout, iPos ) ) != -1 )  {	//ooo
+	while ( ( iPos = regSize.indexIn ( qsStdout, iPos ) ) != -1 )  {	//xxx
 	  iPos += regSize.matchedLength ( );
 	  if ( fAspect == 0.0 )  {
 	    qsAspect = regSize.cap    ( 1 );
@@ -322,7 +345,8 @@ void MPlayerInfo::slotReadStdout ()
 	}
 	regSize = QRegExp ("ID_VIDEO_ASPECT=([0123456789.]*)"); //  1.33:1 OR undefined ...
 	iPos = 0;
-	while ( ( iPos = regSize.search ( qsStdout, iPos ) ) != -1 )  {
+	//while ( ( iPos = regSize.search ( qsStdout, iPos ) ) != -1 )  {	//ooo
+	while ( ( iPos = regSize.indexIn ( qsStdout, iPos ) ) != -1 )  {	//xxx
 	  iPos += regSize.matchedLength ( );
 	  if ( fAspect == 0.0 )  {
 	    qsAspect = regSize.cap    ( 1 );
@@ -339,12 +363,14 @@ void MPlayerInfo::slotReadStdout ()
 	}
 	// Selected video codec: [mpeg12] vfm:libmpeg2 (MPEG 1 or 2 (libmpeg2))
 	regSize = QRegExp ("ID_VIDEO_FORMAT=(\\S*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		if (regSize.cap(1)[0] != '0')	// discard in case we get some cryptic 0x10000002 style of info ...
 			m_qsVideoCodec = regSize.cap(1);
 	}
 	regSize = QRegExp ("Selected video codec:\\s*(\\S*)\\s*(\\S*).*");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		if (m_qsVideoCodec.isEmpty())
 			m_qsVideoCodec = regSize.cap(1) + QString (" ") + regSize.cap(2);
 		m_bHasVideo = true;
@@ -352,13 +378,15 @@ void MPlayerInfo::slotReadStdout ()
 	}
 	// Selected audio codec: [mp3] afm:mp3lib (mp3lib MPEG layer-2, layer-3)
 	regSize = QRegExp ("Selected audio codec:\\s*(\\S*)\\s*(\\S*).*");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_bHasAudio = true;
 		m_bAudioHandled = true;
 	}
 	// AUDIO: 44100 Hz, 2 ch, 16 bit (0x10), ratio: 28000->176400 (224.0 kbit)
 	regSize = QRegExp ("ID_AUDIO_CODEC=(\\S*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_qsAudioCodec = regSize.cap(1);
 		m_bHasAudio = true;
 	}
@@ -369,20 +397,23 @@ void MPlayerInfo::slotReadStdout ()
 	//		m_bHasAudio = true;
 	//	}
 	regSize = QRegExp ("ID_AUDIO_BITRATE=([0-9]*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_iAudioBPS  = regSize.cap(1).toInt();
 		m_qsAudioBPS = regSize.cap(1);
 		m_bHasAudio = true;
 	}
 	
 	regSize = QRegExp ("ID_AUDIO_RATE=([0-9]*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_iSample  = regSize.cap(1).toInt();
 		m_qsSample = regSize.cap(1);
 		m_bHasAudio = true;
 	}
 	regSize = QRegExp ("ID_AUDIO_NCH=([0-9]*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		int iChannels = regSize.cap(1).toInt();
 		m_qsAudioFormat = QString ("Undef.");
 		if (iChannels == 2)
@@ -392,21 +423,24 @@ void MPlayerInfo::slotReadStdout ()
 		m_bHasAudio = true;
 	}
 	regSize = QRegExp ("ID_AUDIO_BITRATE=([0-9]*)");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		m_iAudioBPS  = regSize.cap(1).toInt();
 		m_qsAudioBPS = regSize.cap(1);
 		m_bHasAudio = true;
 	}
 	// AUDIO: 44100 Hz, 2 ch, 16 bit (0x10), ratio: 28000->176400 (224.0 kbit)
 	regSize = QRegExp ("AUDIO:\\s*([0-9]+\\s*Hz),\\s([0-9]+\\s*ch),\\s([0-9]+\\s*bit).*([0-9\\.]+\\skbit).");
-	if (regSize.searchRev(qsStdout) > -1)	{
+	//if (regSize.searchRev(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		QString qsBits = regSize.cap(3);
 		m_iBits        = qsBits.left(qsBits.length() - 4).toInt();
 		m_bHasAudio = true;
 	}
 	// Das ist das absolut letzte !!!
 	regSize = QRegExp ("ID_LENGTH=([0-9]*)");
-	if (regSize.search(qsStdout) > -1)	{
+	//if (regSize.search(qsStdout) > -1)	{	//ooo
+	if (regSize.indexIn(qsStdout) > -1)	{	//xxx
 		qsLength   = regSize.cap(1);
 		m_iLength  = qsLength.toInt() * 1000;
 		m_qsLength = QString ("00:00:00");
@@ -458,41 +492,52 @@ QImage MPlayerInfo::getScreenshot( long iMSecOffset )
 
 	qsTempPath = QFile::encodeName ( QString ( "%1/%2" ).arg ( m_qsTempPathName ).arg ( fileInfo.baseName ( ) ) );
 	qsCommand  = QString ( "mkdir -p \"%1\"" ).arg ( qsTempPath );
-	iRet = system ( qsCommand.utf8 ( ) ); iRet = iRet;
+	//iRet = system ( qsCommand.utf8 ( ) ); iRet = iRet;	//ooo
+	iRet = system ( qsCommand.toUtf8 ( ) ); iRet = iRet;	//xxx
 	
 	m_qsScreenshotName  = QString ("%1/00000001.jpg").arg ( qsTempPath );
 	if (iMSecOffset != 0)	// For some reasons Mplayer produces always the first image from start
 		m_qsScreenshotName  = QString ( "%1/00000002.jpg" ).arg ( qsTempPath );
 
 	// Next we verify that the file has been created.
-	fileInfo.setFile ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );
+	//fileInfo.setFile ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );	//ooo
+	fileInfo.setFile ( QFile::decodeName ( m_qsScreenshotName.toUtf8 ( ) ) );	//xxx
 	if ( fileInfo.exists ( ) )  {
 		qsCommand = QString ( "rm -f \"%1\"" ).arg ( m_qsScreenshotName );
-		iRet = system ( qsCommand.utf8 ( ) );
+		//iRet = system ( qsCommand.utf8 ( ) );		//ooo
+		iRet = system ( qsCommand.toUtf8 ( ) );		//xxx
 	}
 	// Here we generate the screenshot ...
 //	qsCommand = QString("mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf spp,scale -frames 2 -quiet \"%2\" &>/dev/null").arg(qsTempPath).arg(getFileName());
-	if ( iMSecOffset == 0 )
-		qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -frames 2 -quiet \"%2\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( QFile::encodeName ( qsFileName.utf8 ( ) ) );
-	else
-		qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -ss %2 -forceidx -frames 3 -quiet \"%3\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( timeOffset.toString ( ) ).arg ( QFile::encodeName ( qsFileName.utf8 ( ) ) );
-
-	iRet = system ( qsCommand.utf8 ( ) );
+	if ( iMSecOffset == 0 ) {
+		//qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -frames 2 -quiet \"%2\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( QFile::encodeName ( qsFileName.utf8 ( ) ) );		//ooo
+		qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -frames 2 -quiet \"%2\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( qsFileName );						//xxx
+	} else {
+		//qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -ss %2 -forceidx -frames 3 -quiet \"%3\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( timeOffset.toString ( ) ).arg ( QFile::encodeName ( qsFileName.utf8 ( ) ) );		//ooo
+		qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -ss %2 -forceidx -frames 3 -quiet \"%3\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( timeOffset.toString ( ) ).arg ( qsFileName );						//xxx
+	}
+	//iRet = system ( qsCommand.utf8 ( ) );		//ooo
+	iRet = system ( qsCommand.toUtf8 ( ) );		//xxx
 	// printf ("MPlayerInfo::getScreenshot iRet<%d> = <%s>\n", iRet,(const char *)qsCommand);
 
 	int iMaxWait = 0;
-	usleep ( 100000 ); // wait 100 MS because the command was executed in the background
+	//usleep ( 100000 ); // wait 100 MS because the command was executed in the background			//ooo
+	SleeperThread::msleep ( 100 ); // wait 100 MS because the command was executed in the background	//xxx
 	while ( iMaxWait++ < 8 )  {
 		{       // Note: Need to create a new object each time, else the 'exist' info will be buffered. This is No Good here ...
-			QFileInfo fileInfo ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );
+			//QFileInfo fileInfo ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );	//ooo
+			QFileInfo fileInfo ( QFile::decodeName ( m_qsScreenshotName.toUtf8 ( ) ) );	//xxx
 			if ( fileInfo.exists  ( ) )  {
-				if ( ! theImage.load ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) ) )  {
-					debug_out ( "Could not load preview from file <%s>\n", (const char *)m_qsScreenshotName.utf8 ( ) );
+				//if ( ! theImage.load ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) ) )  {	//ooo
+				if ( ! theImage.load ( QFile::decodeName ( m_qsScreenshotName.toUtf8 ( ) ) ) )  {	//xxx
+					//debug_out ( "Could not load preview from file <%s>\n", (const char *)m_qsScreenshotName.utf8 ( ) );	//ooo
+					debug_out ( "Could not load preview from file <%s>\n", (const char *)m_qsScreenshotName.toUtf8 ( ) );	//xxx
 				}
 				if ( theImage.width ( ) > 0 )
 					return theImage;
 			}
-			sleep ( 1 );
+			//sleep ( 1 );				//ooo
+			SleeperThread::msleep ( 1 );		//xxx
 		}
 	}
 
