@@ -13,12 +13,15 @@
 #define MPLAYERWIDGET_H
 
 #include "qmplayerwidget.h"
+//Added by qt3to4:
+#include <QPixmap>
 #include "mediainterface.h"
 
 class MPlayerWidget : protected QMPlayerWidget, public MediaInterface
 {
 public:
-	MPlayerWidget(QWidget *p=0, const char *n=0, void *p2=NULL);
+	MPlayerWidget(QWidget *p=0, const char *n=0, void *p2=NULL);		//ooo
+	//MPlayerWidget(QWidget *p=0);						//xxx
 	virtual ~MPlayerWidget();
 
 	// Here are the implementation of the mandatory MediaInterface - class
