@@ -13,20 +13,29 @@
 
 #include <qstringlist.h>
 #include <qfileinfo.h>
-#include <qprocess.h>
+//#include <q3process.h>	//ooo
+#include <QProcess>		//xxx
+#include <QTextStream>		//xxx
 #include <qstring.h>
 #include <qwidget.h>
 #include <qtimer.h>
 #include <qfile.h>
 #include <qdir.h>
-#include <qdom.h>
+//#include <qdom.h>		//ooo
+#include <QtXml/QDomDocument>	//xxx
+#include <QtXml/QDomElement>	//xxx
+#include <QtXml/QDomNode>	//xxx
 
 #include "xml_mplayer.h"
-#include "qplayer_global.h"
+//#include "qplayer_global.h"	//ooo
+#include "../qplayer_global.h"	//xxx
 #include "qmplayerwidget.h"
 
-QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlags)
-	: QWidget (pParent, pName, iFlags)
+//QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, Qt::WFlags iFlags)	//ooo
+//QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, Qt::WindowFlags iFlags)	//xxx
+QMPlayerWidget::QMPlayerWidget(QWidget *pParent)						//xxx
+	//: QWidget (pParent, pName, iFlags)	//ooo
+	: QWidget (pParent)			//xxx
 {
 	m_iExitError = -1;
 	m_iSeekValue =  5;					
@@ -34,7 +43,8 @@ QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlag
 	m_qsScreenshotName = QString (MPLAYER_TEMP_FILE);
 
 	m_bInPauseMode = false;
-	m_pMasterProcess = new QProcess ( this );
+	//m_pMasterProcess = new Q3Process ( this );	//ooo
+	m_pMasterProcess = new QProcess ( this );	//xxx
 
 	m_rxParseElapsedTime = QRegExp ("V:(.*[0-9]) ");
 	m_rxParseElapsedTime.setMinimal(true);
@@ -45,9 +55,12 @@ QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlag
 	m_listPluginOptions.append (QString("alsa"));
 	m_listPluginOptions.append (QString(""));
 
-	QObject::connect (m_pMasterProcess, SIGNAL(readyReadStdout()), this, SLOT (slotReadStdout     ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(readyReadStderr()), this, SLOT (slotReadStderr     ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(processExited  ()), this, SLOT (slotProcessExited  ()));
+	//QObject::connect (m_pMasterProcess, SIGNAL(readyReadStdout()), this, SLOT (slotReadStdout     ()));          //ooo
+    QObject::connect (m_pMasterProcess, SIGNAL(readyReadStandardOutput()), this, SLOT (slotReadStdout     ()));     //xxx
+	//QObject::connect (m_pMasterProcess, SIGNAL(readyReadStderr()), this, SLOT (slotReadStderr     ()));          //ooo
+    QObject::connect (m_pMasterProcess, SIGNAL(readyReadStandardError()), this, SLOT (slotReadStderr     ()));      //xxx
+	//QObject::connect (m_pMasterProcess, SIGNAL(processExited  ()), this, SLOT (slotProcessExited  ()));          //ooo
+    QObject::connect (m_pMasterProcess, SIGNAL(finished  (int, QProcess::ExitStatus)), this, SLOT (slotProcessExited  (int, QProcess::ExitStatus))); //xxx
 	QObject::connect (m_pMasterProcess, SIGNAL(wroteToStdin   ()), this, SLOT (slotWroteToStdin   ()));
 	QObject::connect (m_pMasterProcess, SIGNAL(launchFinished ()), this, SLOT (slotLaunchFinished ()));
 	QObject::connect (m_pMasterProcess, SIGNAL(destroyed      ()), m_pMasterProcess, SLOT (kill   ()));
@@ -59,12 +72,16 @@ QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlag
 QMPlayerWidget::~QMPlayerWidget ( )
 {
   if ( m_pMasterProcess ) {
-    if ( m_pMasterProcess->processIdentifier ( ) > 0 ) {
+    //if ( m_pMasterProcess->processIdentifier ( ) > 0 ) {	//ooo
+    if ( m_pMasterProcess->pid ( ) > 0 ) {			//xxx
       QString qsCommand = QString ( "kill -9 `ps -ef | grep -e mplayer -e %1 | awk '{print $2}'`" ).arg ( winId ( ) ); 
-      int iRet = system ( qsCommand.utf8 ( ) );
+      //int iRet = system ( qsCommand.utf8 ( ) );	//ooo
+      int iRet = system ( qsCommand.toUtf8 ( ) );	//xxx
       iRet = iRet;
     }
-    if ( m_pMasterProcess->isRunning ( ) )
+    //if ( m_pMasterProcess->isRunning ( ) )	//ooo
+    //if ( !m_pMasterProcess->atEnd ( ) )		//xxx
+    if (m_pMasterProcess->state() == QProcess::Running)	//xxx    
       m_pMasterProcess->kill   ( );
     delete  m_pMasterProcess;
   }
@@ -73,60 +90,91 @@ QMPlayerWidget::~QMPlayerWidget ( )
 bool QMPlayerWidget::start(QStringList *pEnvironment)
 {
 	m_bInPauseMode = false;
-	if (m_pMasterProcess->isRunning())
+	//if (m_pMasterProcess->isRunning())	//ooo
+	//if (m_pMasterProcess->atEnd())		//xxx
+    if (m_pMasterProcess->state() == QProcess::Running)	//xxx
 		return false;
-	QStringList listCommand;
-	m_pMasterProcess->clearArguments();
-	listCommand.append(QString("mplayer")); 
-	listCommand.append(QString("-zoom"));	// Automatically adjust to window size
-	listCommand.append(QString("-noautosub"));
-	listCommand.append(QString("-cache"));
-	listCommand.append(QString("1024"));
-	listCommand.append(QString("-double"));
+	QStringList listCommand;	//ooo
+	//QStringList *listCommand;	//xxx
+	//m_pMasterProcess->clearArguments();		//ooo
+	//listCommand.append(QString("mplayer")); 	//ooo
+	listCommand.append(QString("-zoom"));	// Automatically adjust to window size	//ooo
+	//listCommand->append(QString("-zoom"));	// Automatically adjust to window size	//xxx
+	listCommand.append(QString("-noautosub"));	//ooo
+	//listCommand->append(QString("-noautosub"));	//xxx
+	listCommand.append(QString("-cache"));	//ooo
+	//listCommand->append(QString("-cache"));		//xxx
+	listCommand.append(QString("1024"));		//ooo
+	//listCommand->append(QString("1024"));		//xxx
+	listCommand.append(QString("-double"));	//ooo
+	//listCommand->append(QString("-double"));	//xxx
 //	listCommand.append(QString("-quiet"));
-	listCommand.append(QString("-noquiet"));
-	listCommand.append(QString("-ontop"));
+	listCommand.append(QString("-noquiet"));	//ooo
+	//listCommand->append(QString("-noquiet"));	//xxx
+	listCommand.append(QString("-ontop"));	//ooo
+	//listCommand->append(QString("-ontop"));		//xxx
 
-	listCommand.append(QString("-wid"));
-	listCommand.append(QString("%1").arg((long)winId()));
-	listCommand.append(QString("-slave"));
+	listCommand.append(QString("-wid"));		//ooo
+	//listCommand->append(QString("-wid"));		//xxx
+	listCommand.append(QString("%1").arg((long)winId()));		//ooo
+	//listCommand->append(QString("%1").arg((long)winId()));		//xxx
+	listCommand.append(QString("-slave"));	//ooo
+	//listCommand->append(QString("-slave"));		//xxx
 	if (!m_listPluginOptions[QMPlayerWidget::AudioPlugin].isEmpty())	{
-		listCommand.append(QString("-ao"));
-		listCommand.append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::AudioPlugin]).arg(m_listPluginOptions[QMPlayerWidget::AudioPluginOptions]));
+		listCommand.append(QString("-ao"));	//ooo
+		//listCommand->append(QString("-ao"));	//xxx
+		listCommand.append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::AudioPlugin]).arg(m_listPluginOptions[QMPlayerWidget::AudioPluginOptions]));	//ooo
+		//listCommand->append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::AudioPlugin]).arg(m_listPluginOptions[QMPlayerWidget::AudioPluginOptions]));	//xxx
 	}
-	listCommand.append(QString("-vo"));
+	listCommand.append(QString("-vo"));	//ooo
+	//listCommand->append(QString("-vo"));	//xxx
 	if (m_listPluginOptions[QMPlayerWidget::VideoPlugin].isEmpty())	
-		listCommand.append(QString("x11"));
+		listCommand.append(QString("x11"));	//ooo
+		//listCommand->append(QString("x11"));	//xxx
 	else
-		listCommand.append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::VideoPlugin]).arg(m_listPluginOptions[QMPlayerWidget::VideoPluginOptions]));
+		listCommand.append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::VideoPlugin]).arg(m_listPluginOptions[QMPlayerWidget::VideoPluginOptions]));	//ooo
+		//listCommand->append(QString("%1%2").arg(m_listPluginOptions[QMPlayerWidget::VideoPlugin]).arg(m_listPluginOptions[QMPlayerWidget::VideoPluginOptions]));	//xxx
 
-	listCommand.append(QString("-xy"));	// Scales it by keeping aspect ratio
-	listCommand.append(QString("%1").arg(width()));
+	listCommand.append(QString("-xy"));	// Scales it by keeping aspect ratio	//ooo
+	//listCommand->append(QString("-xy"));	// Scales it by keeping aspect ratio	//xxx
+	listCommand.append(QString("%1").arg(width()));	//ooo
+	//listCommand->append(QString("%1").arg(width()));	//xxx
 
-	listCommand.append(QString("-identify"));
-	listCommand.append(QString("-framedrop"));
+	listCommand.append(QString("-identify"));	//ooo
+	//listCommand->append(QString("-identify"));	//xxx
+	listCommand.append(QString("-framedrop"));	//ooo
+	//listCommand->append(QString("-framedrop"));	//xxx
 
 	//listCommand.append ( ">/dev/null" );
         //listCommand.append ( "2>&1" );
 
-	if ( m_qsFileName.find ( "dvd://" ) > -1 ) {
+	//if ( m_qsFileName.find ( "dvd://" ) > -1 ) {		//ooo
+	if ( m_qsFileName.indexOf ( "dvd://" ) > -1 ) {		//xxx
 	  QString qsTemp = m_qsFileName;
 	  qsTemp.remove ( "dvd:/" );
 	  QFileInfo fileInfo ( qsTemp );
 	  if ( fileInfo.isDir  ( ) ) {
-	    listCommand.append ( "-dvd-device" );
-	    listCommand.append ( qsTemp );
-	    listCommand.append ( QString  ( "--" ) );
-	    listCommand.append ( "dvd://1" );
+	    listCommand.append ( "-dvd-device" );	//ooo
+	    //listCommand->append ( "-dvd-device" );	//xxx
+	    listCommand.append ( qsTemp );		//ooo
+	    //listCommand->append ( qsTemp );		//xxx
+	    listCommand.append ( QString  ( "--" ) );	//ooo
+	    //listCommand->append ( QString  ( "--" ) );	//xxx
+	    listCommand.append ( "dvd://1" );		//ooo
+	    //listCommand->append ( "dvd://1" );		//xxx
 	  }
 	  else if ( fileInfo.exists ( ) ) {
-	    listCommand.append ( QString  ( "--" ) );
-	    listCommand.append ( qsTemp );
+	    listCommand.append ( QString  ( "--" ) );	//ooo
+	    //listCommand->append ( QString  ( "--" ) );	//xxx
+	    listCommand.append ( qsTemp );		//ooo
+	    //listCommand->append ( qsTemp );		//xxx
 	  }
 	}
 	else {
-	  listCommand.append ( QString ( "--" ) );
-	  listCommand.append ( m_qsFileName ); //QString("%1").arg(m_qsFileName));
+	  listCommand.append ( QString ( "--" ) );	//ooo
+	  //listCommand->append ( QString ( "--" ) );	//xxx
+	  listCommand.append ( m_qsFileName ); //QString("%1").arg(m_qsFileName));	//ooo
+	  //listCommand->append ( m_qsFileName ); //QString("%1").arg(m_qsFileName));	//xxx
 	}
 //	listCommand.append ( ">/dev/null" );
 //	listCommand.append ( "2>&1" );
@@ -134,22 +182,26 @@ bool QMPlayerWidget::start(QStringList *pEnvironment)
 	// -ss 01:10:00 seeks to 1 hour 10 min
 	m_fLength = 0.0;
 	//printf ( "<%p>command < %s >\n", m_pMasterProcess, listCommand.join ( " " ).ascii ( ) );
-
+    
 	m_pMasterProcess->setArguments ( listCommand  );
 	emit (signalMPlayerStarted());
-	return m_pMasterProcess->start ( pEnvironment );
+	//return m_pMasterProcess->start ( pEnvironment );				//ooo
+	m_pMasterProcess->start ( QString("%1").arg("mplayer"), listCommand );	//xxx
+	return m_pMasterProcess->waitForStarted();					//xxx
+
 }
 
 void QMPlayerWidget::loadInitFile ()
 {
 	QFileInfo fileInfo;
 	QString qsPlayerIniFile;
-	qsPlayerIniFile = QDir::homeDirPath();
+	//qsPlayerIniFile = QDir::homeDirPath();	//ooo
+	qsPlayerIniFile = QDir::homePath();		//xxx
 	qsPlayerIniFile.append(MPLAYER_INIT_FILE);
 
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_ReadOnly))
+	if (!iniFile.open(QIODevice::ReadOnly))
 		return;
 	// Try to get the right xml contents ...
 	QDomDocument xmlDoc( XML_DOCTYPE_MPLAYER );
@@ -157,7 +209,8 @@ void QMPlayerWidget::loadInitFile ()
 		// Error handling ...
 		iniFile.close ( );
 		QString qsOut = QObject::tr ( "MPlayer xml init file <%1> seems to be defective. Re-setting values.\n" ).arg( qsPlayerIniFile );
-		printf ( "%s", qsOut.ascii ( ) );
+		//printf ( "%s", qsOut.ascii ( ) );		//ooo
+		printf ( "%s", qsOut.toLatin1().data() );	//xxx
  		saveInitFile ( );
 		return;
 	}
@@ -184,7 +237,8 @@ void QMPlayerWidget::loadInitFile ()
 			}
 			else
 				printf ("Warning: MPlayer::loadHistory -=> wrong XML Node <%s>\nContinuing ...\n",
-						(const char *)searchXMLTree.tagName());
+						//(const char *)searchXMLTree.tagName());		//ooo
+						 searchXMLTree.tagName().toLatin1().data());		//xxx
 			// Go to the next node ...
 			xmlNode = xmlNode.nextSibling();
 		}
@@ -196,7 +250,8 @@ void QMPlayerWidget::saveInitFile ()
 {
 	QFileInfo fileInfo;
 	QString qsPlayerIniFile;
-	qsPlayerIniFile = QDir::homeDirPath();
+	//qsPlayerIniFile = QDir::homeDirPath();	//ooo
+	qsPlayerIniFile = QDir::homePath();		//xxx
 	qsPlayerIniFile.append(MPLAYER_INIT_FILE);
 
 	// First we create the document, ...
@@ -222,11 +277,14 @@ void QMPlayerWidget::saveInitFile ()
 
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_WriteOnly))
+	if (!iniFile.open(QIODevice::WriteOnly))
 		return;
 
 	QString xml = xmlDoc.toString();
-	iniFile.writeBlock(xml, qstrlen (xml));
+	//iniFile.writeBlock(xml, qstrlen (xml));					//ooo
+	iniFile.write(xml.toLatin1().data(), qstrlen (xml.toLatin1().data()));	//xxx
+	QTextStream out(&iniFile);		//xxx
+	out << xml.toLatin1().data();		//xxx
 	iniFile.close();
 }
 
@@ -236,7 +294,10 @@ void QMPlayerWidget::setFilename(const QString &qsFileName)
 	// Here we set the global file name.
 	m_qsFileName = qsFileName;
 
-	if (m_pMasterProcess->isRunning ())	{
+	//if (m_pMasterProcess->isRunning ())	{	//ooo
+	//if (!m_pMasterProcess->atEnd ())	{	//xxx
+    //if (m_pMasterProcess->Running ())	{	//xxx
+    if (m_pMasterProcess->state() == QProcess::Running) {	//xxx    
 		qsBuffer = QString ("loadfile %1\n").arg(qsFileName);
 		writeToStdin (qsBuffer);
 		m_fLength = 0.0;
@@ -245,41 +306,52 @@ void QMPlayerWidget::setFilename(const QString &qsFileName)
 
 void QMPlayerWidget::slotReadStdout     ()
 {
-	QString qsStdout(m_pMasterProcess->readStdout());
+	//QString qsStdout(m_pMasterProcess->readStdout());		//ooo
+	QString qsStdout(m_pMasterProcess->readAllStandardOutput());	//xxx
 	if (qsStdout.length() == 0)
 		return;
 
 	int iTemp, iElapsedTime, iElapsedLength, iSec, iMin, iHour;
 	QString qsElapsedTime;
-	iTemp = m_rxParseElapsedTime.match(qsStdout);
+	//iTemp = m_rxParseElapsedTime.match(qsStdout);		//ooo
+	iTemp = m_rxParseElapsedTime.indexIn(qsStdout);		//xxx
 	iElapsedLength = 0;
 	if (iTemp != -1)	{
 		float fElapsedTime = m_rxParseElapsedTime.cap(1).toFloat();
 		iElapsedTime = (int)fElapsedTime;
 		if ( m_fLength > 0.0 )
-		  iElapsedLength = (int)(fElapsedTime / m_fLength * 65535.0 );
-		iHour = (int) (fElapsedTime / 3600.0); //(iElapsedTime - iSec - iMin*60)%3600;
-		iMin  = (int)((fElapsedTime-iHour*3600)/60.0);
-		iSec  = (int) (fElapsedTime-iHour*3600-iMin*60);
-		qsElapsedTime = qsElapsedTime.sprintf ("%02d:%02d:%02d.%03d", iHour, iMin, iSec, (uint)((fElapsedTime - iElapsedTime)*1000.0));
+		  //iElapsedLength = (int)(fElapsedTime / m_fLength * 65535.0 );  //ooo
+          iElapsedLength = static_cast<int>(fElapsedTime / m_fLength * 65535.0 );   //xxx
+		//iHour = (int) (fElapsedTime / 3600.0); //(iElapsedTime - iSec - iMin*60)%3600;  //ooo
+        iHour = static_cast<int> (fElapsedTime / 3600.0); //(iElapsedTime - iSec - iMin*60)%3600;   //xxx
+		//iMin  = (int)((fElapsedTime-iHour*3600)/60.0);  //ooo
+        iMin  = static_cast<int>((fElapsedTime-iHour*3600)/60.0);   //xxx
+		//iSec  = (int) (fElapsedTime-iHour*3600-iMin*60);    //ooo
+        iSec  = static_cast<int> (fElapsedTime-iHour*3600-iMin*60); //xxxx
+		//qsElapsedTime = qsElapsedTime.sprintf ("%02d:%02d:%02d.%03d", iHour, iMin, iSec, (uint)((fElapsedTime - iElapsedTime)*1000.0)); //ooo
+        qsElapsedTime = qsElapsedTime.sprintf ("%02d:%02d:%02d.%03d", iHour, iMin, iSec, static_cast<uint>((fElapsedTime - iElapsedTime)*1000.0));  //xxx
 		emit (signalNewPosition ( iElapsedLength, qsElapsedTime ) );
 		emit (signalNewPosition ( (int)(fElapsedTime * 1000.0) ) );
 	}
 
-	if ( m_rxParseLength.search(qsStdout) > -1 )
+	//if ( m_rxParseLength.search(qsStdout) > -1 )		//ooo
+	if ( m_rxParseLength.indexIn(qsStdout) > -1 )		//xxx
 	  m_fLength = m_rxParseLength.cap (1).toFloat ();
 }
 
 void QMPlayerWidget::slotReadStderr     ()
 {
-	QString qsStderr(m_pMasterProcess->readStdout());
+	//QString qsStderr(m_pMasterProcess->readStdout());		//ooo
+	QString qsStderr(m_pMasterProcess->readAllStandardOutput());	//xxx
 	if (qsStderr.length() == 0)
 		return;
 }
 
-void QMPlayerWidget::slotProcessExited  ()
+//void QMPlayerWidget::slotProcessExited  ()    //ooo
+void QMPlayerWidget::slotProcessExited  (int, QProcess::ExitStatus) //xxx
 {
-	if (m_pMasterProcess->normalExit())
+	//if (m_pMasterProcess->normalExit())	//ooo
+	if (m_pMasterProcess->NormalExit)	//xxx
 		m_iExitError = m_pMasterProcess->exitStatus();
 	emit (signalMPlayerExited(m_iExitError));
 	emit (signalPlaybackFinished ());
@@ -319,7 +391,8 @@ void QMPlayerWidget::slotNavigate ( int nav )
 
 void QMPlayerWidget::slotMenu ( int menu )
 {
-  if ( m_qsFileName.find ( "dvd://" ) > -1 ) {
+  //if ( m_qsFileName.find ( "dvd://" ) > -1 ) {	//ooo
+  if ( m_qsFileName.indexOf ( "dvd://" ) > -1 ) {	//xxx
     QString qsFile = m_qsFileName;
     qsFile = qsFile.remove ( "dvd:/" );
     qsFile += "/VIDEO_TS.VOB";
@@ -327,7 +400,8 @@ void QMPlayerWidget::slotMenu ( int menu )
     if ( fileInfo.exists ( ) )
       m_qsFileName = qsFile;
   }
-  if ( m_qsFileName.find ( "VIDEO_TS.VOB" ) > -1 ) {
+  //if ( m_qsFileName.find ( "VIDEO_TS.VOB" ) > -1 ) {		//ooo
+  if ( m_qsFileName.indexOf ( "VIDEO_TS.VOB" ) > -1 ) {		//xxx
     slotStop ( );
     QTimer::singleShot ( 100, this, SLOT ( slotPlay ( ) ) );
     return;
@@ -357,7 +431,8 @@ void QMPlayerWidget::slotAudioTrack ( int iTrackNumber )
 
 void QMPlayerWidget::writeToStdin(QString &qsBuffer)
 {
-	m_pMasterProcess->writeToStdin(qsBuffer.latin1());
+	//m_pMasterProcess->writeToStdin(qsBuffer.latin1());	//ooo
+	m_pMasterProcess->write(qsBuffer.toLatin1().data());		//xxx
 }
 
 void QMPlayerWidget::slotForward()
@@ -374,7 +449,9 @@ void QMPlayerWidget::slotPlay()
 {
 	if (m_bInPauseMode)
 		slotPause ();
-	if (m_pMasterProcess->isRunning())
+	//if (m_pMasterProcess->isRunning())	//ooo
+	//if (!m_pMasterProcess->atEnd())		//xxx
+    if (m_pMasterProcess->state() == QProcess::Running)	//xxx
 		return;
 	start();
 }
@@ -390,7 +467,9 @@ void QMPlayerWidget::slotStop()
 {
 	if (m_bInPauseMode)
 		slotPause ();
-	if (m_pMasterProcess->isRunning())	{
+	//if (m_pMasterProcess->isRunning())	{	//ooo
+	//if (!m_pMasterProcess->atEnd())	{		//xxx
+    if (m_pMasterProcess->state() == QProcess::Running) {	//xxx
 		QString qsBuffer="quit\n";
 		writeToStdin (qsBuffer);
 	}
@@ -433,7 +512,8 @@ void QMPlayerWidget::slotSetVolume(float fValue)
 void QMPlayerWidget::slotScreenshot ( )
 {
 	QString qsCommand = QString ( "rm -f %1" ).arg ( m_qsScreenshotName );
-	int iRet = system ( qsCommand.utf8 ( ) );
+	//int iRet = system ( qsCommand.utf8 ( ) );	//ooo
+	int iRet = system ( qsCommand.toUtf8 ( ) );	//xxx
 	iRet = iRet;
 	QString qsBuffer = QString ( "screenshot %1\n").arg ( m_qsScreenshotName );
 	writeToStdin ( qsBuffer );
@@ -498,7 +578,12 @@ void QMPlayerWidget::setAspectRatio (uint iAspectRatio)
 
 bool QMPlayerWidget::isPlaying()
 {
-	return m_pMasterProcess->isRunning();
+	//return m_pMasterProcess->isRunning();		//ooo
+	//return !m_pMasterProcess->atEnd();		//xxx
+    if (m_pMasterProcess->state() == QProcess::Running)	//xxx
+        return true;
+    else
+        return false;
 }
 
 void QMPlayerWidget::playChapter (int iChapter)
