@@ -12,33 +12,45 @@
 #include <stdlib.h>
 
 #include <qstringlist.h>
-#include <qprocess.h>
-#include <qwidget.h>
-#include <qregexp.h>
-#include <qstring.h>
+//#include <q3process.h>	//ooo
+
+//#include <qwidget.h>		//ooo
+#include <QWidget>		//xxx
+//#include <qregexp.h>		//ooo
+#include <QRegExp>		//xxx
+//#include <qstring.h>		//ooo
+#include <QString>		//xxx
+#include <QFileInfo>		//xxx
 
 #include <vlc/vlc.h>
 
 #include "qplayer_global.h"
 #include "qvlcwidget.h"
 
-QVLCWidget::QVLCWidget(QWidget *pParent, const char *pName, WFlags iFlags)
-	: QWidget (pParent, pName, iFlags)
+//QVLCWidget::QVLCWidget(QWidget *pParent, const char *pName, Qt::WFlags iFlags)	//ooo
+QVLCWidget::QVLCWidget(QWidget *pParent)						//xxx
+	//: QWidget (pParent, pName, iFlags)	//ooo
+	: QWidget (pParent)			//xxx
 {
 	m_iExitError = -1;
 	m_iSeekValue =  5;
 	m_qsScreenshotName = QString ("/tmp/mplayer_screenshot.jpg");
 
 	m_bInPauseMode = false;
-	m_pMasterProcess = new QProcess;
+	//m_pMasterProcess = new Q3Process;	//ooo
+	m_pMasterProcess = new QProcess;	//xxx
 
-	QObject::connect (m_pMasterProcess, SIGNAL(readyReadStdout()), this, SLOT (slotReadStdout     ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(readyReadStderr()), this, SLOT (slotReadStderr     ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(processExited  ()), this, SLOT (slotProcessExited  ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(wroteToStdin   ()), this, SLOT (slotWroteToStdin   ()));
-	QObject::connect (m_pMasterProcess, SIGNAL(launchFinished ()), this, SLOT (slotLaunchFinished ()));
+	//QObject::connect (m_pMasterProcess, SIGNAL(readyReadStdout()), this, SLOT (slotReadStdout     ()));          //ooo
+	QObject::connect (m_pMasterProcess, SIGNAL(readyReadStandardOutput()), this, SLOT (slotReadStdout     ()));    //xxx
+	//QObject::connect (m_pMasterProcess, SIGNAL(readyReadStderr()), this, SLOT (slotReadStderr     ()));          //ooo
+    QObject::connect (m_pMasterProcess, SIGNAL(readyReadStandardError()), this, SLOT (slotReadStderr     ()));      //xxx
+	//QObject::connect (m_pMasterProcess, SIGNAL(processExited  ()), this, SLOT (slotProcessExited  ()));          //ooo
+    //QObject::connect (m_pMasterProcess, SIGNAL(finished  ()), this, SLOT (slotProcessExited  ()));                  //xxx
+    QObject::connect ( m_pMasterProcess, SIGNAL( finished  ( int, QProcess::ExitStatus) ), this, SLOT ( slotProcessExited  ( int, QProcess::ExitStatus ) ) );  //xxx
+	//QObject::connect (m_pMasterProcess, SIGNAL(wroteToStdin   ()), this, SLOT (slotWroteToStdin   ()));  //ooo
+	//QObject::connect (m_pMasterProcess, SIGNAL(launchFinished ()), this, SLOT (slotLaunchFinished ()));  //ooo
 	
-	const char *pString =  VLC_Version ();
+	//const char *pString =  VLC_Version ();			//ooo
 //	printf ("QVLCWidget::QVLCWidget <%s>\n", pString);
 }
 
@@ -51,11 +63,12 @@ QVLCWidget::~QVLCWidget()
 bool QVLCWidget::start(QStringList *pEnvironment)
 {
 	m_bInPauseMode = false;
-	if (m_pMasterProcess->isRunning())
+	//if (m_pMasterProcess->isRunning())	//ooo
+	if (m_pMasterProcess->atEnd ())		//xxx
 		return false;
 	QStringList listCommand;
 	m_qsStdoutBuffer="";
-	m_pMasterProcess->clearArguments();
+	//m_pMasterProcess->clearArguments();	//ooo
 	listCommand.append(QString("mplayer")); 
 	listCommand.append(QString("-zoom"));
 	listCommand.append(QString("-noautosub"));
@@ -86,7 +99,8 @@ bool QVLCWidget::start(QStringList *pEnvironment)
 
 	m_pMasterProcess->setArguments (listCommand);
 	emit (signalMPlayerStarted());
-	return m_pMasterProcess->start(pEnvironment);
+	//return m_pMasterProcess->start(pEnvironment);		//ooo
+	return m_pMasterProcess->waitForStarted();		//xxx
 }
 
 void QVLCWidget::setFilename(const QString &qsFileName)
@@ -95,7 +109,8 @@ void QVLCWidget::setFilename(const QString &qsFileName)
 	// Here we set the global file name.
 	m_qsFileName = qsFileName;
 
-	if (m_pMasterProcess->isRunning ())	{
+	//if (m_pMasterProcess->isRunning ())	{	//ooo
+	if (m_pMasterProcess->atEnd ())	{		//xxx
 		qsBuffer = QString ("loadfile %1\n").arg(qsFileName);
 		writeToStdin (qsBuffer);
 	}
@@ -103,7 +118,8 @@ void QVLCWidget::setFilename(const QString &qsFileName)
 
 void QVLCWidget::slotReadStdout     ()
 {
-	QString qsStdout(m_pMasterProcess->readStdout());
+	//QString qsStdout(m_pMasterProcess->readStdout());		//ooo
+	QString qsStdout(m_pMasterProcess->readAllStandardOutput());	//xxx
 	if (qsStdout.length() == 0)
 		return;
 
@@ -112,7 +128,8 @@ void QVLCWidget::slotReadStdout     ()
 
 void QVLCWidget::slotReadStderr     ()
 {
-	QString qsStderr(m_pMasterProcess->readStdout());
+	//QString qsStderr(m_pMasterProcess->readStdout());		//ooo
+	QString qsStderr(m_pMasterProcess->readAllStandardOutput());	//xxx
 	if (qsStderr.length() == 0)
 		return;
 
@@ -120,9 +137,11 @@ void QVLCWidget::slotReadStderr     ()
 	parseStderr(qsStderr);
 }
 
-void QVLCWidget::slotProcessExited  ()
+//void QVLCWidget::slotProcessExited  ()    //ooo
+void QVLCWidget::slotProcessExited  (int, QProcess::ExitStatus) //xxx
 {
-	if (m_pMasterProcess->normalExit())
+	//if (m_pMasterProcess->normalExit())		//ooo
+	if (m_pMasterProcess->NormalExit)		//xxx
 		m_iExitError = m_pMasterProcess->exitStatus();
 	emit (signalMPlayerExited(m_iExitError));
 }
@@ -135,17 +154,20 @@ void QVLCWidget::slotLaunchFinished ()
 {
 }
 
-void QVLCWidget::writeToStdin(QString &qsBuffer)
+void QVLCWidget::writeToStdin ( QString &qsBuffer )
 {
-	m_pMasterProcess->writeToStdin(qsBuffer.latin1());
+	//m_pMasterProcess->writeToStdin(qsBuffer.latin1());	//ooo
+	//m_pMasterProcess->writeToStdin ( qsBuffer );		//xxx
+	m_pMasterProcess->write ( qsBuffer.toLatin1() );	//xxx
 }
 
-void QVLCWidget::parseStderr(QString &qsBuffer)
+void QVLCWidget::parseStderr ( QString &qsBuffer )
 {
 	QRegExp rx("V:(.*[0-9]) ");
 	int iTemp;
 	rx.setMinimal(true);
-	iTemp=rx.match(qsBuffer);
+	//iTemp=rx.match(qsBuffer);	//ooo
+	iTemp=rx.indexIn(qsBuffer);	//xxx
 	if (iTemp != -1)
 	{
 		iTemp= (int)(rx.cap(1)).toFloat();
@@ -167,7 +189,8 @@ void QVLCWidget::slotPlay()
 {
 	if (m_bInPauseMode)
 		slotPause ();
-	if (m_pMasterProcess->isRunning())
+	//if (m_pMasterProcess->isRunning())	//ooo
+	if (m_pMasterProcess->atEnd())		//xxx
 		return;
 	start();
 }
@@ -183,7 +206,8 @@ void QVLCWidget::slotStop()
 {
 	if (m_bInPauseMode)
 		slotPause ();
-	if (m_pMasterProcess->isRunning())	{
+	//if (m_pMasterProcess->isRunning())	{	//ooo
+	if (m_pMasterProcess->atEnd())	{		//xxx
 		QString qsBuffer="quit\n";
 		writeToStdin (qsBuffer);
 	}
@@ -204,7 +228,8 @@ void QVLCWidget::slotSetVolume(float fValue)
 
 void QVLCWidget::slotScreenshot()
 {
-	system (QString("rm %1").arg(m_qsScreenshotName));
+	//system (QString("rm %1").arg(m_qsScreenshotName));			//ooo
+	system (QString("rm %1").arg(m_qsScreenshotName).toLatin1().data());	//xxx
 	QString qsBuffer = QString("screenshot %1\n").arg(m_qsScreenshotName);
 	writeToStdin (qsBuffer);
 	// Next we verify that the file has been created.
@@ -259,7 +284,7 @@ void QVLCWidget::slotSetSeek(int iNewValue)
 }
 
 // Non mandatory functions.
-void QVLCWidget::setAspectRatio (uint iAspectRatio)
+void QVLCWidget::setAspectRatio ( uint iAspectRatio )
 {
 	// Can be ASPECT_AUTO, ASPECT_34, ASPECT_169, or ASPECT_SQUARE
 	QString qsBuffer;
@@ -285,6 +310,7 @@ void QVLCWidget::setAspectRatio (uint iAspectRatio)
 
 bool QVLCWidget::isPlaying()
 {
-	return m_pMasterProcess->isRunning();
+	//return m_pMasterProcess->isRunning();		//ooo
+	return m_pMasterProcess->atEnd();		//xxx
 }
 
