@@ -39,6 +39,12 @@
 #include <qdir.h>
 #include <qcursor.h>
 #include <qimage.h>
+//Added by qt3to4:
+#include <QTimerEvent>
+#include <QMouseEvent>
+#include <QKeyEvent>
+#include <QEvent>
+#include <QMessageBox>		//xxx
 
 #include <string.h>
 #include <stdlib.h>
@@ -68,9 +74,29 @@
 #define TIMER_EVENT_RESTART_PLAYBACK  200
 #define TIMER_EVENT_RESIZE_PARENT     300
 
+QXineWidget::MyThread::MyThread ( QXineWidget *pParent )	//xxx
+  : QThread ( )
+  , m_pParent ( pParent )
+{
+}
+
+QXineWidget::MyThread::~MyThread ( )	//xxx
+{
+}
+
+void QXineWidget::MyThread::run ( )	//xxx
+{
+	// Executed in separate thread
+	if ( m_pParent )
+		m_pParent->run ( );
+	exec ( );
+}
+
 
 QXineWidget::QXineWidget(QWidget *parent, void *pXineEngine, const char *name, const QString& prefAudio, const QString& prefVideo, bool verbose, bool startManual)
-             : QWidget(parent,name), QThread()
+             //: QWidget(parent,name), QThread()	//ooo
+             : QWidget(parent)				//xxx
+	     , m_workerThread  ( this )			//xxx
 {
 	initMe (prefAudio, prefVideo, verbose, startManual);
 	if (pXineEngine)	{
@@ -80,7 +106,9 @@ QXineWidget::QXineWidget(QWidget *parent, void *pXineEngine, const char *name, c
 }
 
 QXineWidget::QXineWidget(QWidget *parent, const char *name, const QString& prefAudio, const QString& prefVideo, bool verbose, bool startManual)
-             : QWidget(parent,name), QThread()
+             //: QWidget(parent,name), QThread()	//ooo
+             : QWidget(parent)				//xxx
+	     , m_workerThread  ( this )			//xxx
 {
 	initMe (prefAudio, prefVideo, verbose, startManual);
 }
@@ -109,7 +137,7 @@ void QXineWidget::initMe (const QString& prefAudio, const QString& prefVideo, bo
   preferedAudio = prefAudio;
   preferedVideo = prefVideo;
 
-  setPaletteBackgroundColor(QColor(0,0,0));
+  //setPaletteBackgroundColor(QColor(0,0,0));		//ooo
 
   playMode = NORMAL_PLAY;
 
@@ -139,7 +167,8 @@ QXineWidget::~QXineWidget()
     xine_close(xineStream);
   }
 
-  if (running())
+  //if (running())				//ooo
+  if ( m_workerThread.isRunning ( ) )		//xxx
   {
 
     XEvent ev;
@@ -152,13 +181,15 @@ QXineWidget::~QXineWidget()
     ev.xexpose.height = height();
     ev.xexpose.count = 0;
 
-    XSendEvent( x11Display(), winId(), False, ExposureMask, &ev );  /* send a fake expose event */
-    XFlush( x11Display() );
+    //XSendEvent( x11Display(), winId(), False, ExposureMask, &ev );  /* send a fake expose event */	//ooo
+    //XFlush( x11Display() );										//ooo
 
-    if( !wait(1000) )  /* wait a second for thread exiting */
+    //if( !wait(1000) )  /* wait a second for thread exiting */		//ooo
+    if( ! m_workerThread.wait ( 1000 ) )				//xxx
     {
        warningOut("XEvent thread don't exit. Terminating it...");
-       terminate();
+       //terminate();				//ooo
+       m_workerThread.terminate ( );		//xxx
     }
   }
 
@@ -271,27 +302,31 @@ void QXineWidget::SaveXineConfig()
     xine_config_lookup_entry (xineEngine, "input.cdda_device", &config);
     if ( devicePath == config.str_value )
     {
-      config.str_value = (char*)cachedCDPath.latin1();
+      //config.str_value = (char*)cachedCDPath.latin1();	//ooo
+      config.str_value = cachedCDPath.toLatin1().data();	//xxx
       xine_config_update_entry (xineEngine, &config);
     }
 
     xine_config_lookup_entry (xineEngine, "input.vcd_device", &config);
     if ( devicePath == config.str_value )
     {
-      config.str_value = (char*)cachedVCDPath.latin1();
+      //config.str_value = (char*)cachedVCDPath.latin1();	//ooo
+      config.str_value = cachedVCDPath.toLatin1().data();	//xxx
       xine_config_update_entry (xineEngine, &config);
     }  
 
     xine_config_lookup_entry (xineEngine, "input.dvd_device", &config);
     if ( devicePath == config.str_value )
     {
-      config.str_value = (char*)cachedDVDPath.latin1();
+      //config.str_value = (char*)cachedDVDPath.latin1();	//ooo
+      config.str_value = cachedDVDPath.toLatin1().data();	//xxx
       xine_config_update_entry (xineEngine, &config);
     }  
   }  
     
   debugOut(QString("Save %1\n").arg(configFile));
-  xine_config_save(xineEngine, configFile);
+  //xine_config_save(xineEngine, configFile);			//ooo
+  xine_config_save(xineEngine, configFile.toLatin1().data());	//xxx
 }  
 
 
@@ -391,7 +426,8 @@ void QXineWidget::XineEventListener(void *p, const xine_event_t* xineEvent)
         vw->subCh.clear();
 
         /*** get audio channels  ***/
-        channels = QMAX(6, xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL));
+        //channels = QMAX(6, xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL));		//ooo
+	channels = xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL)+1;			//xxx
         for(i = 0; i < channels; i++)
         {
           if (xine_get_audio_lang(vw->xineStream, i, lang))
@@ -402,7 +438,8 @@ void QXineWidget::XineEventListener(void *p, const xine_event_t* xineEvent)
 
         /*** get subtitle channels ***/
     
-        channels = QMAX(6, xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_SPU_CHANNEL));
+        //channels = QMAX(6, xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_SPU_CHANNEL));		//ooo
+	channels = xine_get_stream_info(vw->xineStream, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL)+1;			//xxx
         for(j = 0; j < channels; j++)
         {
           if (xine_get_spu_lang(vw->xineStream, j, lang))
@@ -766,7 +803,8 @@ void QXineWidget::VideoDriverChangedCallback(void* p, xine_cfg_entry_t* entry)
      vw->postEvent( vw, new QTimerEvent( TIMER_EVENT_NEW_INFO ) );
      playing = false;
      vw->videoDriver = xine_open_video_driver(vw->xineEngine,
-                           vw->videoDriverName, XINE_VISUAL_TYPE_X11,
+                           //vw->videoDriverName, XINE_VISUAL_TYPE_X11,				//ooo
+			   vw->videoDriverName.toLatin1().data(), XINE_VISUAL_TYPE_X11,		//xxx
                            (void *) &(vw->visual));
   }
   else
@@ -829,7 +867,8 @@ void QXineWidget::AudioDriverChangedCallback(void* p, xine_cfg_entry_t* entry)
      vw->trackInfoRow = vw->i18n("Error: Can't init new Audio Driver %1 - using %2!").arg(entry->enum_values[entry->num_value]).arg(vw->audioDriverName);
      vw->postEvent( vw, new QTimerEvent( TIMER_EVENT_NEW_INFO ) );
      playing = false;
-     vw->audioDriver = xine_open_audio_driver(vw->xineEngine, vw->audioDriverName, NULL);
+     //vw->audioDriver = xine_open_audio_driver(vw->xineEngine, vw->audioDriverName, NULL);			//ooo
+     vw->audioDriver = xine_open_audio_driver(vw->xineEngine, vw->audioDriverName.toLatin1().data(), NULL);	//xxx
   }
   else
   {
@@ -938,7 +977,8 @@ bool QXineWidget::InitXine()
   double resVer = DisplayHeight( xineDisplay, xineScreen )*1000 / DisplayHeightMM( xineDisplay, xineScreen );
 
   displayRatio = resVer / resHor;
-  if (QABS( displayRatio - 1.0 ) < 0.01) displayRatio   = 1.0;
+  //if (QABS( displayRatio - 1.0 ) < 0.01) displayRatio   = 1.0;	//ooo
+  if (qAbs( displayRatio - 1.0 ) < 0.01) displayRatio   = 1.0;		//xxx
 
   debugOut(QString("Display aspect ratio (v/h): %1\n").arg(displayRatio));
   XUnlockDisplay( xineDisplay );
@@ -965,12 +1005,14 @@ bool QXineWidget::InitXine()
 
 	/* load configuration */
 
-	  configFile = QDir::homeDirPath();
+	  //configFile = QDir::homeDirPath();		//ooo
+	  configFile = QDir::homePath();		//xxx
 	  configFile.append("/.qdvdauthor/xine_config.ini");
 
 	  bool bSave = false;
 	  if (QFile::exists(configFile))
-		xine_config_load (xineEngine, configFile);
+		//xine_config_load (xineEngine, configFile);			//ooo
+		xine_config_load (xineEngine, configFile.toLatin1().data());	//xxx
 	  else
 		bSave = true;
 
@@ -980,14 +1022,17 @@ bool QXineWidget::InitXine()
 	  if (bSave)	{
 	    warningOut(QString ("No config file found, will create \n%1\n").arg(configFile));
 		// First we check if the directory exists or if we should create it first ...
-		QString qsDirPath = QDir::homeDirPath() + QString ("/.qdvdauthor");
+		//QString qsDirPath = QDir::homeDirPath() + QString ("/.qdvdauthor");		//ooo
+		QString qsDirPath = QDir::homePath() + QString ("/.qdvdauthor");		//xxx
 		QDir theDir(qsDirPath);
 		if (!theDir.exists())
 			theDir.mkdir (qsDirPath);
-		xine_config_save  (xineEngine, configFile);
+		//xine_config_save  (xineEngine, configFile);			//ooo
+		xine_config_save  (xineEngine, configFile.toLatin1().data());	//xxx
 		}
     }
-    start ();	/* Start the initialisation thread */
+    //start ();	/* Start the initialisation thread */		//ooo
+    m_workerThread.start ( );					//xxx
     return true;
 }
 
@@ -1013,6 +1058,7 @@ bool QXineWidget::taskInitXine()
   //audioChoices = new char*[15];
   for(i = 0; i < 15; i++) audioChoices[i] = new char[10];
   audioChoices[0] = const_cast<char*>("auto");
+
   i = 0;
   while(drivers[i])
   {
@@ -1024,7 +1070,8 @@ bool QXineWidget::taskInitXine()
   if (preferedAudio == "auto") cmdlAudioEnum = true;
   
   char* audioInfo = new char[200];
-  strcpy(audioInfo, i18n("Audiodriver to use (default: auto)").local8Bit() );
+  //strcpy(audioInfo, i18n("Audiodriver to use (default: auto)").local8Bit() );		//ooo
+  strcpy(audioInfo, i18n("Audiodriver to use (default: auto)").toLocal8Bit().data() );		//xxx
   i = xine_config_register_enum(xineEngine, "gui.audiodriver", 0,
                    audioChoices, audioInfo, NULL, 10, &QXineWidget::AudioDriverChangedCallback, this);
 
@@ -1036,7 +1083,8 @@ bool QXineWidget::taskInitXine()
   debugOut(QString("Use audio driver %1\n").arg(audioDriverName));
 
   i = 0;
-  char* videoChoices[15]; // = NULL;
+  //char* videoChoices[15]; // = NULL;	//ooo
+  char* videoChoices[16];		//xxx
   drivers = xine_list_video_output_plugins (xineEngine);
 //  videoChoices = new char*[15];
   for(i = 0; i < 15; i++) videoChoices[i] = new char[10];
@@ -1052,7 +1100,8 @@ bool QXineWidget::taskInitXine()
   if (preferedVideo == "auto") cmdlVideoEnum = true;
 
   char* videoInfo = new char[200];
-  strcpy( videoInfo, i18n("Videodriver to use (default: auto)").local8Bit() );
+  //strcpy( videoInfo, i18n("Videodriver to use (default: auto)").local8Bit() );	//ooo
+  strcpy( videoInfo, i18n("Videodriver to use (default: auto)").toLocal8Bit().data() );	//xxx
   i = xine_config_register_enum(xineEngine, "gui.videodriver", 0,
                    videoChoices, videoInfo, NULL, 10, &QXineWidget::VideoDriverChangedCallback, this);
 
@@ -1074,7 +1123,8 @@ bool QXineWidget::taskInitXine()
   debugOut("Init video driver\n");
 
   videoDriver = xine_open_video_driver(xineEngine,
-               videoDriverName,  XINE_VISUAL_TYPE_X11,
+               //videoDriverName,  XINE_VISUAL_TYPE_X11,			//ooo
+		videoDriverName.toLatin1().data(),  XINE_VISUAL_TYPE_X11,	//xxx
                (void *) &(visual));
   if (!videoDriver)
   {
@@ -1086,7 +1136,8 @@ bool QXineWidget::taskInitXine()
 /* init audio driver */  
   debugOut("Init audio driver\n");
   
-  audioDriver = xine_open_audio_driver (xineEngine, audioDriverName, NULL);
+  //audioDriver = xine_open_audio_driver (xineEngine, audioDriverName, NULL);				//ooo
+  audioDriver = xine_open_audio_driver (xineEngine, audioDriverName.toLatin1().data(), NULL);		//xxx
   if (!audioDriver)
   {
     QApplication::beep();
@@ -1161,7 +1212,8 @@ bool QXineWidget::PlayMRL(const QString& mrl, const QString& title, bool returnI
   extraInfo = QString::null;
   QString ref;
   
-  for (int i = 1; i <= mrl.contains('#'); i++)
+  //for (int i = 1; i <= mrl.contains('#'); i++)	//ooo
+  for (int i = 1; i <= mrl.indexOf('#'); i++)		//xxx
   {
     ref = mrl.section('#', i, i);
     if (ref.section(':', 0, 0) == "subtitle")
@@ -1170,9 +1222,11 @@ bool QXineWidget::PlayMRL(const QString& mrl, const QString& title, bool returnI
       extraInfo = extraInfo + " ** " + i18n("Save as: ") + ref.section(':', 1);
   }
  
-  debugOut(QString("Playing: %1").arg(currentMRL.local8Bit()));
+  //debugOut(QString("Playing: %1").arg(currentMRL.local8Bit()));	//ooo
+  debugOut(QString("Playing: %1").arg(currentMRL.toLocal8Bit().data()));			//xxx
 
-  if (!xine_open(xineStream, currentMRL.local8Bit() )) /** pass mrl local 8Bit encoded **/
+  //if (!xine_open(xineStream, currentMRL.local8Bit() )) /** pass mrl local 8Bit encoded **/	//ooo
+  if (!xine_open(xineStream, currentMRL.toLocal8Bit().data() )) /** pass mrl local 8Bit encoded **/	//xxx
   {
     SendXineError( returnInfo );
     setCursor(QCursor(Qt::ArrowCursor));
@@ -1185,10 +1239,12 @@ bool QXineWidget::PlayMRL(const QString& mrl, const QString& title, bool returnI
        (!xine_get_stream_info (xineStream, XINE_STREAM_INFO_HAS_VIDEO)) )
   {
 
-    if (visualPluginName && (!xinePost))
+    //if (visualPluginName && (!xinePost))			//ooo
+    if ( ! visualPluginName.isEmpty ( ) && (!xinePost))		//xxx
     {
       debugOut(QString("Init visual plugin: %1").arg(visualPluginName));
-      xinePost = xine_post_init (xineEngine, visualPluginName, 0,
+      //xinePost = xine_post_init (xineEngine, visualPluginName, 0,			//ooo
+      xinePost = xine_post_init (xineEngine, visualPluginName.toLatin1().data(), 0,	//xxx
           &audioDriver,
           &videoDriver);
 
@@ -1232,7 +1288,9 @@ bool QXineWidget::PlayMRL(const QString& mrl, const QString& title, bool returnI
   if ( (title.contains('.')) || (title.contains(":/")) ) /* tags was still read? */
   {
     QString metaTitle = QString::fromLocal8Bit( xine_get_meta_info(xineStream, XINE_META_INFO_TITLE) );
-    if ( (metaTitle) && (!metaTitle.isEmpty()) )  //usable meta info
+    //if ( (metaTitle) && (!metaTitle.isEmpty()) )  //usable meta info		//ooo
+    //if  ( ! metaTitle.isEmpty ( ) )						//xxx
+    if ( (!metaTitle.isNull()) && (!metaTitle.isEmpty()) )    //xxx
     {
       QString metaArtist = QString::fromLocal8Bit(xine_get_meta_info(xineStream, XINE_META_INFO_ARTIST));
       QString metaAlbum = QString::fromLocal8Bit(xine_get_meta_info(xineStream, XINE_META_INFO_ALBUM));
@@ -1370,10 +1428,12 @@ void QXineWidget::SetVisualPlugin(const QString& visual)
 
 
   if ( (xine_get_status( xineStream ) == XINE_STATUS_PLAY)
-       && (!xine_get_stream_info(xineStream, XINE_STREAM_INFO_HAS_VIDEO)) && (visualPluginName) )
+       //&& (!xine_get_stream_info(xineStream, XINE_STREAM_INFO_HAS_VIDEO)) && (visualPluginName) )				//ooo
+       && ( ! xine_get_stream_info ( xineStream, XINE_STREAM_INFO_HAS_VIDEO)) && ( ! visualPluginName.isEmpty ( ) ) )		//xxx
   {
 
-    xinePost = xine_post_init (xineEngine, visualPluginName, 0, &audioDriver, &videoDriver);
+    //xinePost = xine_post_init (xineEngine, visualPluginName, 0, &audioDriver, &videoDriver);				//ooo
+    xinePost = xine_post_init (xineEngine, visualPluginName.toLatin1().data(), 0, &audioDriver, &videoDriver);		//xxx
     postAudioSource = xine_get_audio_source(xineStream);
     postInput = (xine_post_in_t*)xine_post_input(xinePost, const_cast<char*>("audio in"));
     xine_post_wire( postAudioSource, postInput );
@@ -1407,7 +1467,8 @@ bool QXineWidget::GetAutoplayPluginMrl(const QString& plugin, QStringList& list)
   int num;
   int i = 0;
 
-  mrls = xine_get_autoplay_mrls(xineEngine, plugin, &num);
+  //mrls = xine_get_autoplay_mrls(xineEngine, plugin, &num);						//ooo
+  mrls = const_cast<char **>(xine_get_autoplay_mrls(xineEngine, plugin.toLatin1().data(), &num));	//xxx
 
   if (mrls)
   {
@@ -1565,17 +1626,20 @@ void QXineWidget::SetDevice(const QString& device)
 
   xine_config_lookup_entry (xineEngine, "input.cdda_device", &config);
   cachedCDPath = config.str_value;
-  config.str_value = (char*)device.latin1();
+  //config.str_value = (char*)device.latin1();		//ooo
+  config.str_value = device.toLatin1().data();		//xxx
   xine_config_update_entry (xineEngine, &config);
 
   xine_config_lookup_entry (xineEngine, "input.vcd_device", &config);
   cachedVCDPath = config.str_value;
-  config.str_value = (char*)device.latin1();
+  //config.str_value = (char*)device.latin1();		//ooo
+  config.str_value = device.toLatin1().data();		//xxx
   xine_config_update_entry (xineEngine, &config);
 
   xine_config_lookup_entry (xineEngine, "input.dvd_device", &config);
   cachedDVDPath = config.str_value;
-  config.str_value = (char*)device.latin1();
+  //config.str_value = (char*)device.latin1();		//ooo
+  config.str_value = device.toLatin1().data();		//xxx
   xine_config_update_entry (xineEngine, &config);
 }
 
@@ -1587,7 +1651,8 @@ void QXineWidget::SetStreamSaveDir(const QString& dir)
   if (!xine_config_lookup_entry (xineEngine, "misc.save_dir", &config)) return; /* older xine-lib */
 
   debugOut(QString("Set misc.save_dir to: %1").arg(dir));
-  config.str_value = (char*)dir.latin1();
+  //config.str_value = (char*)dir.latin1();	//ooo
+  config.str_value = dir.toLatin1().data();	//xxx
   xine_config_update_entry (xineEngine, &config);
 }  
 
@@ -1794,7 +1859,8 @@ void QXineWidget::slotChangePosition(int pos)
   {
     posTimer.stop();
     xine_play(xineStream, pos, 0);
-    posTimer.start(500,false);
+    //posTimer.start(500,false);	//ooo
+    posTimer.start(500);		//xxx
   }
   
   if (pause)
@@ -1810,7 +1876,8 @@ void QXineWidget::slotChangePositionByTime(int pos)
   {
     posTimer.stop();
     xine_play(xineStream,0, pos);// in MSec
-    posTimer.start(500,false);
+    //posTimer.start(500,false);	//ooo
+    posTimer.start(500);		//xxx
   }
 
   if (pause)
@@ -1822,7 +1889,8 @@ void QXineWidget::slotEject()
   xine_eject(xineStream);
 }
 
-void QXineWidget::slotEnableAutoresize(bool enable)
+//void QXineWidget::slotEnableAutoresize(bool enable)	//ooo
+void QXineWidget::slotEnableAutoresize(int enable)	//xxx
 {
   autoresizeEnabled = enable;
   if (!autoresizeEnabled)
@@ -1942,6 +2010,7 @@ QString QXineWidget::GetLengthInfo()
 void QXineWidget::slotEmitLengthInfo()
 {
   QString length = GetLengthInfo();
+  
   if (!length.isNull())
   {
     lengthInfoTimer.stop();
@@ -2381,14 +2450,16 @@ QString QXineWidget::msToTimeString( int iMSec )
     hours = msec/3600;
     my_msec -= hours*3600*1000;
     t = t.setNum(hours);
-    t = t.rightJustify (2, '0');
+    //t = t.rightJustify (2, '0');	//ooo
+    t = t.rightJustified (2, '0');	//xxx
     t.append(":");
 
     msec = msec - (hours*3600);
     min = msec / 60;
     my_msec -= min*60*1000;
     tmp = tmp.setNum(min);
-    tmp = tmp.rightJustify(2, '0');
+    //tmp = tmp.rightJustify(2, '0');	//ooo
+    tmp = tmp.rightJustified(2, '0');	//xxx
     t.append(tmp);
     t.append(":");
 
@@ -2397,13 +2468,15 @@ QString QXineWidget::msToTimeString( int iMSec )
 //    if(my_msec > 500)
 //    	sec++;
     tmp = tmp.setNum(sec);
-    tmp = tmp.rightJustify(2, '0');
+    //tmp = tmp.rightJustify(2, '0');	//ooo
+    tmp = tmp.rightJustified(2, '0');	//xxx
     t.append(tmp);
     t.append(".");
     
     msec = (int)(iMSec/1000.0) * 1000;  //sec
     tmp = tmp.setNum(iMSec - msec);
-    tmp = tmp.rightJustify(3, '0');
+    //tmp = tmp.rightJustify(3, '0');	//ooo
+    tmp = tmp.rightJustified(3, '0');	//xxx
     t.append (tmp);
     
    return t;
@@ -2412,7 +2485,8 @@ QString QXineWidget::msToTimeString( int iMSec )
 int QXineWidget::timeStringToMs( QString timeString )
 {
   int sec = 0;
-  QStringList tokens = QStringList::split(':',timeString);
+  //QStringList tokens = QStringList::split(':',timeString);	//ooo
+  QStringList tokens = timeString.split(':');			//xxx
   
   sec += tokens[0].toInt()*3600; //hours
   sec += tokens[1].toInt()*60; //minutes
