@@ -10,13 +10,17 @@
 ****************************************************************************/
 
 #include <qimage.h>
+//Added by qt3to4:
+#include <QPixmap>
 
-#include "mediainfo.h"
+//#include "mediainfo.h"	//ooo
+#include "../mediainfo.h"	//xxx
 #include "qvlcwidget.h"
 #include "vlcwidget.h"
 
 VLCWidget::VLCWidget(QWidget *pParent, const char *pName, void *pExistingEngine)
-	: QVLCWidget(pParent, pName=0), MediaInterface ()
+	//: QVLCWidget(pParent, pName=0), MediaInterface ()	//ooo
+	: QVLCWidget(pParent), MediaInterface ()		//xxx
 {
 	pExistingEngine = pExistingEngine;
 }
@@ -76,6 +80,22 @@ void VLCWidget::stop ()
 {
 }
 
+void VLCWidget::setNavigate ( enNavigate nav )			//xxx
+{
+}
+
+void VLCWidget::setMenu ( enMenu menu )				//xxx
+{
+}
+
+void VLCWidget::setSubtitleTrack ( int iTrackNumber )		//xxx
+{
+}
+
+void VLCWidget::setAudioTrack ( int iTrackNumber )		//xxx
+{
+}
+
 void VLCWidget::setSpeed(float fValue)
 {
 	fValue = fValue;
@@ -128,6 +148,18 @@ QImage VLCWidget::getScreenshot(float)
 	return screenShot;
 }
 
+bool VLCWidget::setScreenshot ( long iMSecOffset )
+{
+
+  return false;
+}
+
+bool VLCWidget::setScreenshot ( QPixmap &pix )
+{
+
+  return false;
+}
+
 // Non mandatory functions.
 void VLCWidget::setAspectRatio (uint)
 {
