@@ -12,9 +12,12 @@
 #include <unistd.h>
 
 #include <qobject.h>
-#include <qimage.h>
+//#include <qimage.h>   //ooo
+#include <QImage>       //xxx
 #include <qfile.h>
 #include <qdir.h>
+#include <QMessageBox>	//xxx
+#include <QUrl> //xxx
 
 #include "xineinfo.h"
 
@@ -28,10 +31,12 @@ XineInfo::XineInfo  ( void *pVoid )
 	m_bOwnXineEngine = false;
 	if ( ! pVoid )	{
 		m_pMediaEngine = (void *)xine_new ( );
-		QString configFile = QDir::homeDirPath ( );
+		//QString configFile = QDir::homeDirPath ( );		//ooo
+		QString configFile = QDir::homePath ( );		//xxx
 		configFile.append ( "/.qdvdauthor/xine_config.ini" );
 		if ( QFile::exists ( configFile ) )
-			xine_config_load ( (xine_t *)m_pMediaEngine, (const char *)configFile );
+			//xine_config_load ( (xine_t *)m_pMediaEngine, (const char *)configFile );	//ooo
+			xine_config_load ( (xine_t *)m_pMediaEngine, configFile.toLatin1().data() );	//xxx
 		xine_init ( (xine_t *)m_pMediaEngine );
 		m_bOwnXineEngine = true;
 	}
@@ -159,150 +164,153 @@ void XineInfo::frameOutputCb ( void * /*pUserData*/, int /*iVideoWidth*/, int /*
 
 void XineInfo::queryValues ()
 {
-	int iReturn, iPosStream, iPosTime, iLengthTime;
+  int iReturn, iPosStream, iPosTime, iLengthTime;
 
-	// Sanity check ...
-	if ( ! xine_open ( m_pXineStream, m_qsFileName.ascii ( ) ) ||
-	     ! xine_play ( m_pXineStream, 0, 0 ) ) {
-		printf ( "Unable to open mrl\n" );
-		return;
-	}
-	// this is the main function, to query all values
-	if ( ! m_pXineStream )
-		return;
-	m_bHasAudio = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_HAS_AUDIO);
-	m_bHasVideo = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_HAS_VIDEO);
+  // Sanity check ...
+  //if ( ! xine_open ( m_pXineStream, m_qsFileName.ascii ( ) ) ||		//ooo
+  if ( ! xine_open ( m_pXineStream, m_qsFileName.toLatin1().data() ) ||	//xxx
+       ! xine_play ( m_pXineStream, 0, 0 ) ) {
+    printf ( "Unable to open mrl\n" );
+    return;
+  }	//oooo
 
-	m_bAudioHandled = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_HANDLED);
-	m_bVideoHandled = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_HANDLED);
-	
-	//F.J.Cruz 18-12-04
-        m_bIsSeekeable = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_SEEKABLE);
+  // this is the main function, to query all values
+  if ( ! m_pXineStream )
+    return;
 
-	// Here we check if the status is Ok (I.e. if audio avail and we can play the audio, then it is ok (same with video)
-	if ( ( (m_bHasAudio) && (m_bAudioHandled) ) || ( (m_bHasVideo) && (m_bVideoHandled) ) )
-		m_qsStatus = QObject::tr ("Ok");
-	else
-		m_qsStatus = QObject::tr ("Not Ok");
+  m_bHasAudio = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_HAS_AUDIO);
+  m_bHasVideo = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_HAS_VIDEO);
 
-	iReturn      = 0;
-	int iCounter = 0;
-	while ( ( iReturn == 0 ) && ( iCounter++ < 3 ) )  {
-		usleep ( 1000 );
-		// Note: Xine is prone to returning wrong length information ( 2008 - 12 - 21 )
-		iReturn = xine_get_pos_length (m_pXineStream, &iPosStream, &iPosTime, &iLengthTime );
-	}
-	if (iReturn == 1)	{	// success
-		m_iLength  = iLengthTime;
-		m_qsLength = msToTimeString ( iLengthTime );
-	}
-	else
-		m_qsLength = QString ("0:00:00");
+  m_bAudioHandled = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_HANDLED);
+  m_bVideoHandled = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_HANDLED);
 
-	if (m_bHasVideo)	{
-		m_iResolutionWidth  = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_WIDTH);
-		m_iResolutionHeight = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_HEIGHT);
-		m_qsResolution = QString ("%1x%2").arg(m_iResolutionWidth).arg(m_iResolutionHeight);
-		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_FRAME_DURATION);
-		m_fFPS = 90000.0 / (float)iReturn;
-		m_qsFPS = QString ("%1").arg(m_fFPS);		// E.g. 25
+  //F.J.Cruz 18-12-04
+  m_bIsSeekeable = (bool)xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_SEEKABLE);
 
-		m_qsVideoFormat = getVideoFormat (m_iResolutionWidth, m_iResolutionHeight);
+  // Here we check if the status is Ok (I.e. if audio avail and we can play the audio, then it is ok (same with video)
+  if ( ( (m_bHasAudio) && (m_bAudioHandled) ) || ( (m_bHasVideo) && (m_bVideoHandled) ) )
+    m_qsStatus = QObject::tr ("Ok");
+  else
+    m_qsStatus = QObject::tr ("Not Ok");
 
-/*		iReturn = xine_get_param (m_pXineStream, XINE_PARAM_VO_ASPECT_RATIO);
-		if (iReturn == XINE_VO_ASPECT_AUTO)
-			m_qsRatio = QString ("auto");
-		else if (iReturn == XINE_VO_ASPECT_SQUARE)
-			m_qsRatio = QString ("1:1");
-		else if (iReturn == XINE_VO_ASPECT_4_3)
-			m_qsRatio = QString ("4:3");
-		else if (iReturn == XINE_VO_ASPECT_ANAMORPHIC)
-			m_qsRatio = QString ("16:9");
-		else if (iReturn ==  XINE_VO_ASPECT_DVB)
-			m_qsRatio = QString ("2.11:1");
-		else
-			m_qsRatio = QString ("<%1>").arg(iReturn);
+  iReturn      = 0;
+  int iCounter = 0;
+  while ( ( iReturn == 0 ) && ( iCounter++ < 3 ) )  {
+    usleep ( 1000 );
+    // Note: Xine is prone to returning wrong length information ( 2008 - 12 - 21 )
+    iReturn = xine_get_pos_length (m_pXineStream, &iPosStream, &iPosTime, &iLengthTime );
+  }
+  if (iReturn == 1)	{	// success
+    m_iLength  = iLengthTime;
+    m_qsLength = msToTimeString ( iLengthTime );
+  }
+  else
+    m_qsLength = QString ("0:00:00");
+
+  if (m_bHasVideo)	{
+    m_iResolutionWidth  = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_WIDTH);
+    m_iResolutionHeight = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_HEIGHT);
+    m_qsResolution = QString ("%1x%2").arg(m_iResolutionWidth).arg(m_iResolutionHeight);
+    iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_FRAME_DURATION);
+    m_fFPS = 90000.0 / (float)iReturn;
+    m_qsFPS = QString ("%1").arg(m_fFPS);		// E.g. 25
+
+    m_qsVideoFormat = getVideoFormat (m_iResolutionWidth, m_iResolutionHeight);
+
+/*    iReturn = xine_get_param (m_pXineStream, XINE_PARAM_VO_ASPECT_RATIO);
+    if (iReturn == XINE_VO_ASPECT_AUTO)
+      m_qsRatio = QString ("auto");
+    else if (iReturn == XINE_VO_ASPECT_SQUARE)
+      m_qsRatio = QString ("1:1");
+    else if (iReturn == XINE_VO_ASPECT_4_3)
+      m_qsRatio = QString ("4:3");
+    else if (iReturn == XINE_VO_ASPECT_ANAMORPHIC)
+      m_qsRatio = QString ("16:9");
+    else if (iReturn ==  XINE_VO_ASPECT_DVB)
+      m_qsRatio = QString ("2.11:1");
+    else
+      m_qsRatio = QString ("<%1>").arg(iReturn);
 */
 
-		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_RATIO);
-		m_qsRatio.sprintf ( "%4.2f:1", (double)iReturn/10000.0);
+    iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_RATIO);
+    m_qsRatio.sprintf ( "%4.2f:1", (double)iReturn/10000.0);
 
-/*		if (iReturn == 1)
-			m_qsRatio = QString ("1:1");
-		else if (iReturn == (int)(16.0/9.0*10000))
-			m_qsRatio = QString ("16:9");
-		else if (iReturn == (int)(4.0/3.0*10000))
-			m_qsRatio = QString ("4:3");
-		else if (iReturn == (int)(2.11*10000))
-			m_qsRatio = QString ("2.11:1");
-		else if (iReturn == (int)(21.0/9.0*10000))
-			m_qsRatio = QString ("21:9");
-		else if (iReturn == (int)(29.0/9.0*10000))
-			m_qsRatio = QString ("29:9");
-		else
-			m_qsRatio = QString ("%1:1").arg((float)iReturn/10000);
+/*    if (iReturn == 1)
+      m_qsRatio = QString ("1:1");
+    else if (iReturn == (int)(16.0/9.0*10000))
+      m_qsRatio = QString ("16:9");
+    else if (iReturn == (int)(4.0/3.0*10000))
+      m_qsRatio = QString ("4:3");
+    else if (iReturn == (int)(2.11*10000))
+      m_qsRatio = QString ("2.11:1");
+    else if (iReturn == (int)(21.0/9.0*10000))
+      m_qsRatio = QString ("21:9");
+    else if (iReturn == (int)(29.0/9.0*10000))
+      m_qsRatio = QString ("29:9");
+    else
+      m_qsRatio = QString ("%1:1").arg((float)iReturn/10000);
 */
 
-		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_FOURCC);
-		if (iReturn)
-			m_qsVideoCodec = QString(QString ("<%1 = %2>").arg(iReturn).arg(get_fourcc_string (iReturn)));
-		else
-			m_qsVideoCodec = QString(xine_get_meta_info (m_pXineStream, XINE_META_INFO_VIDEOCODEC));
-		
-		m_iVideoBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_BITRATE);
-		if (m_iVideoBPS < 1)	{ 
-			// Here we construct the video bitrate in case it is set to zero by xine.
-			m_iVideoBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_BITRATE);
-			m_iAudioBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITRATE);
-			if ((m_iVideoBPS > 0) && (m_iAudioBPS > 0) )
-				m_iVideoBPS -= m_iAudioBPS;
-		}
-		if (m_iVideoBPS < 1)
-			m_qsVideoBPS = QString ("? bps");
-		if (m_iVideoBPS < 1000)
-			m_qsVideoBPS = QString ("%1 bps").arg(m_iVideoBPS);
-		else if (m_iVideoBPS < 1000000)
-			m_qsVideoBPS = QString ("%1kbps").arg((float)m_iVideoBPS/1000);
-		else
-			m_qsVideoBPS = QString ("%1Mbps").arg((float)m_iVideoBPS/1000000);
-	}
-	if (m_bHasAudio)	{
-		m_iBits = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITS);
-		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_FOURCC);
-		if (iReturn)
-			m_qsAudioCodec = QString(QString ("<%1 = %2>").arg(iReturn).arg(get_fourcc_string (iReturn)));
-		else
-			m_qsAudioCodec = QString(xine_get_meta_info (m_pXineStream, XINE_META_INFO_AUDIOCODEC));
+    iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_FOURCC);
+    if (iReturn)
+      m_qsVideoCodec = QString(QString ("<%1 = %2>").arg(iReturn).arg(get_fourcc_string (iReturn)));
+    else
+      m_qsVideoCodec = QString(xine_get_meta_info (m_pXineStream, XINE_META_INFO_VIDEOCODEC));
 
-		iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_CHANNELS);
-		if (iReturn == 0)
-			m_qsAudioFormat = QString ("");
-		else if (iReturn == 1)
-			m_qsAudioFormat = QObject::tr ("mono");
-		else if (iReturn == 2)
-			m_qsAudioFormat = QObject::tr ("stereo");
-		else if (iReturn == 4)
-			m_qsAudioFormat = QObject::tr ("quad");
-		else
-			m_qsAudioFormat = QObject::tr ("%1 channels").arg(iReturn);
+    m_iVideoBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_VIDEO_BITRATE);
+    if (m_iVideoBPS < 1)	{ 
+      // Here we construct the video bitrate in case it is set to zero by xine.
+      m_iVideoBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_BITRATE);
+      m_iAudioBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITRATE);
+      if ((m_iVideoBPS > 0) && (m_iAudioBPS > 0) )
+        m_iVideoBPS -= m_iAudioBPS;
+    }
+    if (m_iVideoBPS < 1)
+      m_qsVideoBPS = QString ("? bps");
+    if (m_iVideoBPS < 1000)
+      m_qsVideoBPS = QString ("%1 bps").arg(m_iVideoBPS);
+    else if (m_iVideoBPS < 1000000)
+      m_qsVideoBPS = QString ("%1kbps").arg((float)m_iVideoBPS/1000);
+    else
+      m_qsVideoBPS = QString ("%1Mbps").arg((float)m_iVideoBPS/1000000);
+  }
+  if (m_bHasAudio)	{
+    m_iBits = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITS);
+    iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_FOURCC);
+    if (iReturn)
+      m_qsAudioCodec = QString(QString ("<%1 = %2>").arg(iReturn).arg(get_fourcc_string (iReturn)));
+    else
+      m_qsAudioCodec = QString(xine_get_meta_info (m_pXineStream, XINE_META_INFO_AUDIOCODEC));
 
-		m_iSample = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_SAMPLERATE);
-		if (m_iSample < 1000)
-			m_qsSample = QString ("%1 Hz").arg(m_iSample);
-		else if (m_iSample < 1000000)
-			m_qsSample = QString ("%1kHz").arg(m_iSample/1000);
-		else
-			m_qsSample = QString ("%1MHz").arg(m_iSample/1000000);
+    iReturn = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_CHANNELS);
+    if (iReturn == 0)
+      m_qsAudioFormat = QString ("");
+    else if (iReturn == 1)
+      m_qsAudioFormat = QObject::tr ("mono");
+    else if (iReturn == 2)
+      m_qsAudioFormat = QObject::tr ("stereo");
+    else if (iReturn == 4)
+      m_qsAudioFormat = QObject::tr ("quad");
+    else
+      m_qsAudioFormat = QObject::tr ("%1 channels").arg(iReturn);
 
-		m_iAudioBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITRATE);
-		if (m_iAudioBPS < 1000)
-			m_qsAudioBPS = QString ("%1 bps").arg(m_iAudioBPS);
-		else if (m_iAudioBPS < 1000000)
-			m_qsAudioBPS = QString ("%1kbps").arg((float)m_iAudioBPS/1000);
-		else
-			m_qsAudioBPS = QString ("%1Mbps").arg((float)m_iAudioBPS/1000000);
-	}
-	/*
+    m_iSample = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_SAMPLERATE);
+    if (m_iSample < 1000)
+      m_qsSample = QString ("%1 Hz").arg(m_iSample);
+    else if (m_iSample < 1000000)
+      m_qsSample = QString ("%1kHz").arg(m_iSample/1000);
+    else
+      m_qsSample = QString ("%1MHz").arg(m_iSample/1000000);
+
+    m_iAudioBPS = xine_get_stream_info (m_pXineStream, XINE_STREAM_INFO_AUDIO_BITRATE);
+    if (m_iAudioBPS < 1000)
+      m_qsAudioBPS = QString ("%1 bps").arg(m_iAudioBPS);
+    else if (m_iAudioBPS < 1000000)
+      m_qsAudioBPS = QString ("%1kbps").arg((float)m_iAudioBPS/1000);
+    else
+      m_qsAudioBPS = QString ("%1Mbps").arg((float)m_iAudioBPS/1000000);
+  }
+/*
 uint t;
 int iAudioArray[] = {XINE_STREAM_INFO_HAS_AUDIO, XINE_STREAM_INFO_IGNORE_AUDIO, XINE_STREAM_INFO_BITRATE, XINE_STREAM_INFO_AUDIO_CHANNELS, XINE_STREAM_INFO_AUDIO_BITS, XINE_STREAM_INFO_AUDIO_SAMPLERATE, XINE_STREAM_INFO_AUDIO_BITRATE, XINE_STREAM_INFO_AUDIO_FOURCC, XINE_STREAM_INFO_AUDIO_HANDLED, XINE_STREAM_INFO_MAX_AUDIO_CHANNEL, XINE_STREAM_INFO_AUDIO_MODE};
 
@@ -316,7 +324,7 @@ for (t=0;t<15;t++)
 	printf ("<%d = %d> ", iVideoArray[t], xine_get_stream_info (m_pXineStream, iVideoArray[t]));
 printf ("\n\n");
 */
-	xine_close(m_pXineStream);
+  xine_close(m_pXineStream);
 }
 
 // Function borrowed from kaffeine ...
@@ -340,7 +348,8 @@ QString XineInfo::msToTimeString(unsigned long int iMSec)
     min = iMSec / 60;
     my_msec -= min*60*1000;
     tmp = tmp.setNum(min);
-    tmp = tmp.rightJustify(2, '0');
+    //tmp = tmp.rightJustify(2, '0');	//ooo
+    tmp = tmp.rightJustified(2, '0');	//xxx
     t.append(tmp);
     t.append(":");
 
@@ -348,7 +357,8 @@ QString XineInfo::msToTimeString(unsigned long int iMSec)
     my_msec -= sec*1000;
     
     tmp = tmp.setNum(sec);
-    tmp = tmp.rightJustify(2, '0');
+    //tmp = tmp.rightJustify(2, '0');	//ooo
+    tmp = tmp.rightJustified(2, '0');	//xxx
     t.append(tmp);
 
    return t;
@@ -385,17 +395,22 @@ xine_stream_t *XineInfo::getXineStream ()
 
 QImage XineInfo::getScreenshot ( long iMSecOffset )
 {
-  if ( ! xine_open ( m_pXineStream, (const char *)m_qsFileName ) )
+  //if ( ! xine_open ( m_pXineStream, (const char *)m_qsFileName ) )	//ooo
+  if ( ! xine_open ( m_pXineStream, m_qsFileName.toLatin1().data() ) )	//xxx
     return getScreenshot ( m_qsFileName );
 
   xine_play ( m_pXineStream, 0, iMSecOffset );
   xine_stop ( m_pXineStream );
 
-  QImage theScreenshot = getScreenshot ( m_qsFileName );
-  
+  QImage theScreenshot = getScreenshot ( m_qsFileName );  //ooo
+  //QImage *theScreenshot;    //xxx
+  //theScreenshot = new QImage (getScreenshot ( m_qsFileName ));  //xxx
+  //QImage theScreenshot(getScreenshot ( m_qsFileName ));     //xxx
+
   xine_close ( m_pXineStream );
 
-  return theScreenshot;
+  return theScreenshot;   //ooo
+  //return *theScreenshot;    //xxx
 }
 
 QImage XineInfo::getScreenshot(QString)
@@ -408,24 +423,36 @@ QImage XineInfo::getScreenshot(QString)
 	
 	if (!pRgbPile)
 		return QImage();
-	QImage screenShot(pRgbPile, iWidth, iHeight, 32, 0, 0, QImage::IgnoreEndian);
-
+	//QImage screenShot(pRgbPile, iWidth, iHeight, 32, 0, 0, QImage::IgnoreEndian);	//ooo
+	//QImage screenShot(pRgbPile, iWidth, iHeight, QImage::Format_ARGB32_Premultiplied, 0, 0);	//xxx
+    QImage screenShot(pRgbPile, iWidth, iHeight, QImage::Format_RGB32, 0, 0);	//xxx
+    //QImage screenShot(pRgbPile, iWidth, iHeight, QImage::Format_ARGB32);	//xxx
+    //screenShot.setColorCount(32);   //xxx
+    
+    //QImage image = screenShot;  //xxx
+    
 	// not neccesary since this woul scale to the window extend which we don't want.
 //	if (fScaleFactor >= 1.0)
 //		iWidth = (int)((double) iWidth * fScaleFactor);
 //	else
 //		iHeight = (int) ((double) iHeight / fScaleFactor);
-
+    
 	// need this step to copy the data over and beeing able
 	// to delete the temp data (pRgbPile) without the application crashing.
-	screenShot = screenShot.smoothScale(iWidth, iHeight);
-
+	//screenShot = screenShot.smoothScale(iWidth, iHeight);		//ooo
+	//screenShot = screenShot.scaled(iWidth, iHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);		//xxx
+    screenShot = screenShot.copy(0, 0, iWidth, iHeight);		//xxx
+    //screenShot = screenShot.copy();		//xxx
+    //screenShot = screenShot.scaled(150, 150);		//xxx
+    //QImage screenShot_ = screenShot;		//xxx
+    
 	delete []pRgbPile;	
-	return screenShot;
+	return screenShot;	//ooo
+    //return screenShot_;	//xxx
 }
 
 void XineInfo::GetScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHeight, double& scaleFactor)
-{
+{    
   uint8_t   *yuv = NULL, *y = NULL, *u = NULL, *v =NULL;
   
   int        width, height, ratio, format;
@@ -442,7 +469,7 @@ void XineInfo::GetScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHe
     }  
 
   xine_get_current_frame (m_pXineStream, &width, &height, &ratio, &format, yuv);
-
+  
   videoWidth = width;
   videoHeight = height;
 
@@ -491,8 +518,8 @@ void XineInfo::GetScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHe
   rgb32BitData = yv12ToRgb (y, u, v, width, height);
 
 
-  image_ratio = (double) width / (double) height;
-
+  image_ratio = (double) width / (double) height; //ooo
+  //image_ratio = static_cast<double> ( width ) / static_cast<double> ( height );   //xxx
 
   switch (ratio) {
   case XINE_VO_ASPECT_ANAMORPHIC:  // * anamorphic  * /
@@ -574,7 +601,6 @@ void XineInfo::yuy2Toyv12 (uint8_t *y, uint8_t *u, uint8_t *v, uint8_t *input,
 uchar *XineInfo::yv12ToRgb (uint8_t *src_y, uint8_t *src_u, uint8_t *src_v,
            int width, int height)
 {
-
   int     i, j;
 
   int     y, u, v;
@@ -633,10 +659,13 @@ uchar *XineInfo::yv12ToRgb (uint8_t *src_y, uint8_t *src_u, uint8_t *src_v,
       u = src_u[(sub_i_uv * uv_width) + sub_j_uv] - 128;
       v = src_v[(sub_i_uv * uv_width) + sub_j_uv] - 128;
 
-      r = (int)((1.1644 * (double)y) + (1.5960 * (double)v));
-      g = (int)((1.1644 * (double)y) - (0.3918 * (double)u) - (0.8130 * (double)v));
-      b = (int)((1.1644 * (double)y) + (2.0172 * (double)u));
-
+      //r = (int)((1.1644 * (double)y) + (1.5960 * (double)v)); //ooo
+      r = static_cast<int>((1.1644 * static_cast<double>(y)) + (1.5960 * static_cast<double>(v)));  //xxx
+      //g = (int)((1.1644 * (double)y) - (0.3918 * (double)u) - (0.8130 * (double)v));  //ooo
+      g = static_cast<int>((1.1644 * static_cast<double>(y)) - (0.3918 * static_cast<double>(u)) - (0.8130 * static_cast<double>(v)));   //xxx
+      //b = (int)((1.1644 * (double)y) + (2.0172 * (double)u)); //ooo
+      b = static_cast<int>((1.1644 * static_cast<double>(y)) + (2.0172 * static_cast<double>(u)));  //xxx
+      
       clip_8_bit (r);
       clip_8_bit (g);
       clip_8_bit (b);
@@ -647,7 +676,7 @@ uchar *XineInfo::yv12ToRgb (uint8_t *src_y, uint8_t *src_u, uint8_t *src_v,
       rgb[(i * width + j) * 4 + 3] = 0;
 
     }
-  }
+  }  
   return rgb;
 }
 
