@@ -1,14 +1,16 @@
-/****************************************************************************
-** Implementation of class MediaInfo
-**
-**   Created : Tue Nov 9 07:53:05 2004
-**        by : Varol Okan using the kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class collects all possible information about
-** the current set stream.
-**
+/***************************************************************************
+    mediainfo.cpp
+                             -------------------
+    Implementation of class MediaInfo
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class collects all possible information about
+    the current set stream.
+    
 ****************************************************************************/
 
 #include <qfileinfo.h>
@@ -63,7 +65,7 @@ void MediaInfo::setUseEventLoop ( bool bUseEventLoop )
 
 void *MediaInfo::getMediaEngine ()
 {
-	return m_pMediaEngine;
+  return m_pMediaEngine;
 }
 	
 void MediaInfo::setMediaEngine  (void *pMediaEngine)
@@ -75,7 +77,8 @@ void MediaInfo::setMediaEngine  (void *pMediaEngine)
 void MediaInfo::setFileName ( QString qsStream, bool bQueryValues )
 {
   // First we chack if we want to play a DVD, no info avail at this point in time ...
-  if ( qsStream.find ( "dvd://" ) > -1 )
+  //if ( qsStream.find ( "dvd://" ) > -1 )				//ooo
+  if ( qsStream.indexOf ( "dvd://", Qt::CaseInsensitive ) > -1 )	//xxx
     return;
 
   // Next we check if the file exists ...
@@ -168,7 +171,8 @@ QString MediaInfo::getRatio ()
     return m_qsRatio;
 
   QString qsRatio = m_qsRatio;
-  int iPos = qsRatio.find ( ":" );
+  //int iPos = qsRatio.find ( ":" );				//ooo
+  int iPos = qsRatio.indexOf ( ":", Qt::CaseSensitive );	//xxx
   float fValue = 0.0;
 
   if ( iPos ) {
@@ -203,7 +207,7 @@ int MediaInfo::getBits ()
 }
 
 QString MediaInfo::getFormat (bool bVideo)
-{
+{ 
 	if (bVideo)
 		return m_qsVideoFormat;
 	return m_qsAudioFormat;
@@ -301,18 +305,29 @@ bool MediaInfo::videoHandled ()
 
 void MediaInfo::test_print ()
 {
-	printf ("FileName : %s\n", (const char *)getFileName ());
-	printf ("Length   : %d <%s>\n", (uint)getLength (), (const char *)getLengthString ());
-	printf ("Ratio    : %s\n", (const char *)getRatio ());
-	printf ("Format   : Video<%s> Audio<%s>\n", (const char *)getFormat  (true), (const char *)getFormat (false));
-	printf ("Codec    : Video<%s> Audio<%s>\n", (const char *)getCodec (true), (const char *)getCodec (false));
-	printf ("Size     : %d <%s>\n", getSize (), (const char *) getSizeString ());
-	printf ("Resolution : %d - %d <%s>\n", getResolution (true),  getResolution (false), (const char *) getResolutionString ());
+	//printf ("FileName : %s\n", (const char *)getFileName ());									//ooo
+	printf ("FileName : %s\n", getFileName ().toLatin1().data());									//xxx
+	//printf ("Length   : %d <%s>\n", (uint)getLength (), (const char *)getLengthString ());					//ooo
+	printf ("Length   : %d <%s>\n", (uint)getLength (), getLengthString ().toLatin1().data());					//xxx
+	//printf ("Ratio    : %s\n", (const char *)getRatio ());									//ooo
+	printf ("Ratio    : %s\n", getRatio ().toLatin1().data());									//xxx
+	//printf ("Format   : Video<%s> Audio<%s>\n", (const char *)getFormat  (true), (const char *)getFormat (false));		//ooo
+	printf ("Format   : Video<%s> Audio<%s>\n", getFormat  (true).toLatin1().data(), getFormat (false).toLatin1().data());		//xxx
+	//printf ("Codec    : Video<%s> Audio<%s>\n", (const char *)getCodec (true), (const char *)getCodec (false));			//ooo
+	printf ("Codec    : Video<%s> Audio<%s>\n", getCodec (true).toLatin1().data(), getCodec (false).toLatin1().data());		//xxx
+	//printf ("Size     : %d <%s>\n", getSize (), (const char *) getSizeString ());							//ooo
+	printf ("Size     : %d <%s>\n", getSize (), getSizeString ().toLatin1().data());						//xxx
+	//printf ("Resolution : %d - %d <%s>\n", getResolution (true),  getResolution (false), (const char *) getResolutionString ());	//ooo
+	printf ("Resolution : %d - %d <%s>\n", getResolution (true),  getResolution (false), getResolutionString ().toLatin1().data());	//xxx
 	printf ("FPS        : %f\n", getFPS ());
-	printf ("Status     : %s\n", (const char *)getStatus ());
-	printf ("Sample     : %d <%s>\n", getSample (), (const char *)getSampleString ());
-	printf ("BPS (Video): %d <%s>\n", getBPS (true), (const char *)getBPSString (true));
-	printf ("BPS (Audio): %d <%s>\n", getBPS (false), (const char *)getBPSString (false));
+	//printf ("Status     : %s\n", (const char *)getStatus ());									//ooo
+	printf ("Status     : %s\n", getStatus ().toLatin1().data());									//xxx
+	//printf ("Sample     : %d <%s>\n", getSample (), (const char *)getSampleString ());						//ooo
+	printf ("Sample     : %d <%s>\n", getSample (), getSampleString ().toLatin1().data());						//xxx
+	//printf ("BPS (Video): %d <%s>\n", getBPS (true), (const char *)getBPSString (true));						//ooo
+	printf ("BPS (Video): %d <%s>\n", getBPS (true), getBPSString (true).toLatin1().data());					//xxx
+	//printf ("BPS (Audio): %d <%s>\n", getBPS (false), (const char *)getBPSString (false));					//ooo
+	printf ("BPS (Audio): %d <%s>\n", getBPS (false), getBPSString (false).toLatin1().data());					//xxx
 	printf ("Bits       : %d\n", getBits ());
 	printf ("Has Video  : %s Supported %s\n", hasVideo () ? "true" : "false", videoHandled () ? "true" : "false");
 	printf ("Has Audio  : %s Supported %s\n", hasAudio () ? "true" : "false", audioHandled () ? "true" : "false");
