@@ -1,14 +1,16 @@
-/****************************************************************************
-** MediaInfo - class
-**
-**   Created : Tue Nov 9 12:09:08 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class will use the Media Engine (Xine, MPlayer, or VLC), to obtain 
-** information about the stream currently set by this engine.
-**
+/***************************************************************************
+    mediainfo.h
+                             -------------------
+    MediaInfo - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
+    This class will use the Media Engine (Xine, MPlayer, or VLC), to obtain 
+    information about the stream currently set by this engine.
+
 ****************************************************************************/
 
 #ifndef MEDIAINFO_H
