@@ -1,27 +1,43 @@
-/****************************************************************************
-** PreviewThread class
-**
-** Created: Tue Jan 02 22:06:51 2004
-**      by: Varol Okan using Kate
-**
-** This class spinns off a new thread and generate a Preview of the Job 
-** which was set through MediaCreator::registerWithPreviewThread.
-** 
-** Once the preview is generated we will call the update function in 
-** the main thread ( Currently MovieObject::updatePixmap () )
-**
-** if after 5 seconds after termination of the thread there are no new 
-** requests in the queue then the thread will be termintaed to free 
-** some memory.
-**
+/***************************************************************************
+    mediascanner.h
+                             -------------------
+    PreviewThread class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
+    This class spinns off a new thread and generate a Preview of the Job 
+    which was set through MediaCreator::registerWithPreviewThread.
+ 
+    Once the preview is generated we will call the update function in 
+    the main thread ( Currently MovieObject::updatePixmap () )
+
+    if after 5 seconds after termination of the thread there are no new 
+    requests in the queue then the thread will be termintaed to free 
+    some memory.
+
 ****************************************************************************/
 
 #ifndef MEDIASCANNER_H
 #define MEDIASCANNER_H
 
-#include <qvaluelist.h>
+//#include <q3valuelist.h>	//oxx
 #include <qthread.h>
 #include <qmutex.h>
+#include <QMutex>	//xxx
+#include <QImage>	//xxx
+#include <QThread>	//xxx
+
+class SleeperThread9 : public QThread	//xxx
+{
+public:
+    static void msleep(unsigned long int msecs)
+    {
+        QThread::msleep(msecs);
+    }
+};
 
 class MediaInfo;
 class Subtitles;
@@ -130,7 +146,7 @@ private:
 	QMutex                  *m_pMutex;
 	MediaInfo               *m_pMediaInfo;
 	volatile int             m_iWaitCounter;
-	QValueList<ExecuteJob *> m_listExecuteFifo;
+	QList<ExecuteJob *> m_listExecuteFifo;	//oxx
 };
 
 #endif	// MEDIASCANNER_H
