@@ -16,25 +16,37 @@
 ****************************************************************************/
 #include <unistd.h>
 
-#include <qdatetimeedit.h>
+//#include <q3datetimeedit.h>   //ooo
+#include <QDateTimeEdit>        //xxx
 #include <qapplication.h>
 #include <qmessagebox.h>
 #include <qtranslator.h>
 #include <qpushbutton.h>
 #include <qpushbutton.h>
-#include <qfiledialog.h>
-#include <qpopupmenu.h>
+//#include <q3filedialog.h> //ooo
+#include <QFileDialog>		//xxx
+//#include <q3popupmenu.h>  //ooo
+#include <QMenu>            //xxx
 #include <qcombobox.h>
 #include <qdatetime.h>
-#include <qtoolbar.h>
+//#include <q3toolbar.h>    //ooo
+#include <QToolBar>         //xxx
 #include <qslider.h>
 #include <qaction.h>
 #include <qlayout.h>
-#include <qframe.h>
+//#include <q3frame.h>  //ooo
+#include <QFrame>       //xxx
 #include <qlabel.h>
 #include <qimage.h>
-#include <qdom.h>
+//#include <qdom.h>     //ooo
+#include <QtXml/QDomElement>	//xxx
 #include <qdir.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+//#include <Q3GridLayout>   //ooo
+#include <QGridLayout>		//xxx
+#include <QPixmap>
+//#include <q3mimefactory.h>    //ooo
 
 #include "../utils.h"
 #include "../CONFIG.h"
@@ -49,9 +61,13 @@
 
 #include "mediainfo.h"
 
-QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
-    : uiQPlayer ( parent, name, fl )
+//QPlayer::QPlayer( QWidget* parent, const char* name, Qt::WFlags fl )		//ooo
+QPlayer::QPlayer( QWidget* pParent )						//xxx
+    //: uiQPlayer ( parent, name, fl )		//ooo
+    //: Q3MainWindow ( pParent )			//xxx
+    : QMainWindow ( pParent )			//xxx
 {
+        setupUi(this);		//xxx
 	MediaCreator::setPreferredEngine (QString ("DummyWidget"));
 	m_iIsPlaying = STATE_STOPPED;
 	m_iSubtitleTrack   = -1;
@@ -62,26 +78,89 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 	m_pLanguagePopup   = NULL;
 	m_pTranslator      = NULL;
 	initLanguages();
-	m_pToolBarPrevious  = new QToolBar (QString("Previous"), this, DockTop);
-	m_pToolBarPrevious->setHorizontalStretchable ( true );
-	m_pComboPrevious = new QComboBox (m_pToolBarPrevious);
+    
+    toolBar->addAction( fileOpenAction );  //xxx
+    toolBar->addAction( fileOpenPrevious );  //xxx
+    toolBar->addAction( fileExitAction );  //xxx
+    toolBar->addAction( m_pActionScreenshot );  //xxx
+    toolBar->addAction( m_pActionAbout );  //xxx
+    toolBar->addSeparator();    //xxx
+    
+	//m_pToolBarPrevious  = new Q3ToolBar (QString("Previous"), this, DockTop);	//ooo
+	//m_pToolBarPrevious  = new Q3ToolBar (QString("Previous"), this, Qt::DockTop);	//xxx
+    //m_pToolBarPrevious  = new QToolBar (QString("Previous"), this);	//xxx
+	//m_pToolBarPrevious->setHorizontalStretchable ( true );   //ooo
+	//m_pComboPrevious = new QComboBox (m_pToolBarPrevious);   //ooo
+    //m_pComboPrevious = new QComboBox (toolBar);   //xxx
+    m_pComboPrevious = new QComboBox (this);   //xxx
+    toolBar->addWidget(m_pComboPrevious);   //xxx
 	loadHistory ();
+
+    //Qt::WindowFlags iFlags = 0;	//xxx
+    
+    QGridLayout   *pLayout = new QGridLayout (m_pFrameImage);  //xxx
+    //m_pImagePreview = new ImagePreview ( m_pFrameImage, "m_pPreview", iFlags );   //xxx
+    m_pImagePreview = new QLabel(m_pFrameImage); //xxx
+    m_pImagePreview->setAutoFillBackground(true);   //xxx
+    pLayout->addWidget( m_pImagePreview, 0, 0 );   //xxx
+    QPalette palette;							//xxx
+    //palette.setBrush(QPalette::Window, QBrush(QImage(":/images/qplayer_logo.png")));		//xxx
+    palette.setBrush(QPalette::Window, QPixmap(":/images/qplayer_logo.png"));		//xxx
+    //palette.setBrush(QPalette::Base, QBrush(":/images/qplayer_logo.png"));		//xxx
+    //palette.setBrush(m_pImagePreview->backgroundRole(), QBrush(":/images/qplayer_logo.png"));		//xxx
+    //palette.setBrush(m_pImagePreview->backgroundRole(), QColor("#aab4ff"));		//xxx
+    //palette.setBrush(QPalette::Window, QColor("#aab4ff"));		//xxx
+    //palette.setBrush(m_pImagePreview->backgroundRole(), QBrush(QColor(170,180,255)));		//xxx
+    //palette.setBrush(QPalette::Window, QColor(170,180,255));		//xxx
+    //palette.setBrush(QPalette::Base, QColor(0,0,0));		//xxx
+    m_pImagePreview->setPalette(palette);				//xxx
+    //m_pFrameImage->setPalette(palette);				//xxx
+    
+    palette.setBrush(QPalette::Window, QColor(170,170,255));		//xxx
+    m_pLabelHeader->setAutoFillBackground(true);   //xxx
+    m_pLabelHeader->setPalette(palette);				//xxx
+    
+    palette.setBrush(QPalette::Window, QColor(128,145,238));		//xxx
+    frame4->setAutoFillBackground(true);   //xxx
+    frame4->setPalette(palette);				//xxx
+    
+    palette.setBrush(QPalette::Window, QColor(238,145,235));		//xxx
+    frame5->setAutoFillBackground(true);   //xxx
+    frame5->setPalette(palette);				//xxx
+    
 	// First we should create the XineWidget ...
 	if (MediaCreator::preferredEngine () == QString ("DummyWidget"))	{
 		if (QMessageBox::information (this, tr("Dummy set"), tr("The Media Backend is set to the DummyWidget,\nwhich does not have any functionality.\nDo you want to change the Media backend now ?"), QMessageBox::Yes, QMessageBox::No)	== QMessageBox::Yes)
 			slotConfigure ();
 	}
-	m_pMediaInterface = MediaCreator::createPreferredWidget (m_pFramePreview, "MediaWidget");
+	//m_pMediaInterface = MediaCreator::createPreferredWidget (m_pFramePreview, "MediaWidget");    //ooo
+	m_pMediaInterface = MediaCreator::createPreferredWidget (m_pFramePreview, "MediaWidget", NULL);    //xxx
 
 	// Error !!! Lets pull the break on it ...
-	m_pVideoLayout = new QGridLayout( m_pFramePreview, 1, 1, 4, 6, "XineMainLayout");
+	//m_pVideoLayout = new Q3GridLayout( m_pFramePreview, 1, 1, 4, 6, "XineMainLayout");   //ooo
+    m_pVideoLayout = new QGridLayout( m_pFramePreview );   //xxx
 	m_pVideoLayout->addWidget (m_pMediaInterface->getWidget(), 0, 0);
-
-	fileOpenAction->addTo      ( toolBar );
-	fileOpenPrevious->addTo    ( toolBar );
-	fileExitAction->addTo      ( toolBar );
-	m_pActionScreenshot->addTo ( toolBar );
-	m_pActionAbout->addTo      ( toolBar );
+    
+	//fileOpenAction->addTo      ( toolBar );  //ooo
+    //toolBar->addAction( fileOpenAction );  //xxx
+	//fileOpenPrevious->addTo    ( toolBar );  //ooo
+    //toolBar->addAction( fileOpenPrevious );  //xxx
+	//fileExitAction->addTo      ( toolBar );  //ooo
+    //toolBar->addAction( fileExitAction );  //xxx
+	//m_pActionScreenshot->addTo ( toolBar );  //ooo
+    //toolBar->addAction( m_pActionScreenshot );  //xxx
+	//m_pActionAbout->addTo      ( toolBar );  //ooo
+    //toolBar->addAction( m_pActionAbout );  //xxx
+    
+    connect ( fileOpenAction,            SIGNAL ( triggered ( ) ), this, SLOT ( fileOpen            ( ) ) );    //xxx
+    connect ( actionOpen_Previous,       SIGNAL ( triggered ( ) ), this, SLOT ( fileOpenRecent      ( ) ) );    //xxx
+    connect ( fileExitAction,            SIGNAL ( triggered ( ) ), this, SLOT ( fileExit            ( ) ) );    //xxx
+    
+    connect ( m_pActionConfigure,        SIGNAL ( triggered ( ) ), this, SLOT ( slotConfigure       ( ) ) );    //xxx
+    connect ( m_pActionSetup,            SIGNAL ( triggered ( ) ), this, SLOT ( slotSetup           ( ) ) );    //xxx
+    connect ( m_pActionMediaInfo,        SIGNAL ( triggered ( ) ), this, SLOT ( slotMediaInfo       ( ) ) );    //xxx
+    //connect ( helpContentsAction,        SIGNAL ( triggered ( ) ), this, SLOT ( helpAbout           ( ) ) );    //xxx
+    connect ( m_pActionAbout,            SIGNAL ( triggered ( ) ), this, SLOT ( helpAbout           ( ) ) );    //xxx
 
 	m_pSliderTime->setRange (0, 65535);
 	m_fSpeed = 1.0;
@@ -89,30 +168,72 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 	m_pSliderVolume->setRange(0, 100);
 	m_pSliderVolume->setValue(-80);
 
-	m_pButtonPrev      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
-	m_pButtonNext      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
-	m_pButtonStop      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_SELECTED));
-	m_pButtonPlay      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
-	m_pButtonSpeedPlus ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
-	m_pButtonSpeedMinus->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
+    //QPalette palette;		//xxx
+	//m_pButtonPrev      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));    //ooo
+    palette.setBrush(QPalette::Base, QColor( COLOR_QUICK_NORMAL ));	//xxx
+    m_pButtonPrev->setPalette(palette);	//xxx
+	//m_pButtonNext      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));    //ooo
+    m_pButtonNext->setPalette(palette);	//xxx
+	//m_pButtonStop      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_SELECTED));    //ooo
+    palette.setBrush(QPalette::Base, QColor( COLOR_QUICK_SELECTED ));	//xxx
+    m_pButtonStop->setPalette(palette);	//xxx
+	//m_pButtonPlay      ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));    //ooo
+    palette.setBrush(QPalette::Base, QColor( COLOR_QUICK_NORMAL ));	//xxx
+    m_pButtonPlay->setPalette(palette);	//xxx
+	//m_pButtonSpeedPlus ->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));    //ooo
+    m_pButtonSpeedPlus->setPalette(palette);	//xxx
+	//m_pButtonSpeedMinus->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));    //ooo
+    m_pButtonSpeedMinus->setPalette(palette);	//xxx
 
-	m_pButtonPrev      ->setPixmap (QPixmap().fromMimeSource( "prev_chapter.png" ));
-	m_pButtonNext      ->setPixmap (QPixmap().fromMimeSource( "next_chapter.png" ));
-	m_pButtonStop      ->setPixmap (QPixmap().fromMimeSource( "stop.png" ));
-	m_pButtonPlay      ->setPixmap (QPixmap().fromMimeSource( "play.png" ));
-	m_pButtonSpeedPlus ->setPixmap (QPixmap().fromMimeSource( "faster.png" ));
-	m_pButtonSpeedMinus->setPixmap (QPixmap().fromMimeSource( "slower.png" ));
+	//m_pButtonPrev      ->setPixmap (QPixmap().fromMimeSource( "prev_chapter.png" ));	//ooo
+	//m_pButtonPrev      ->setPixmap (QPixmap( ":/images/prev_chapter.png" ));		//xxx
+    m_pButtonPrev      ->setIcon (QIcon( ":/images/prev_chapter.png" ));		//xxx
+	//m_pButtonNext      ->setPixmap (QPixmap().fromMimeSource( "next_chapter.png" ));	//ooo
+	//m_pButtonNext      ->setPixmap (QPixmap( ":/images/next_chapter.png" ));		//xxx
+    m_pButtonNext      ->setIcon (QIcon( ":/images/next_chapter.png" ));		//xxx
+	//m_pButtonStop      ->setPixmap (QPixmap().fromMimeSource( "stop.png" ));		//ooo
+	//m_pButtonStop      ->setPixmap (QPixmap( ":/images/stop.png" ));			//xxx
+    m_pButtonStop      ->setIcon (QIcon( ":/images/stop.png" ));			//xxx
+	//m_pButtonPlay      ->setPixmap (QPixmap().fromMimeSource( "play.png" ));		//ooo
+	//m_pButtonPlay      ->setPixmap (QPixmap( ":/images/play.png" ));			//xxx
+    m_pButtonPlay      ->setIcon (QIcon( ":/images/play.png" ));			//xxx
+	//m_pButtonSpeedPlus ->setPixmap (QPixmap().fromMimeSource( "faster.png" ));		//ooo
+	//m_pButtonSpeedPlus ->setPixmap (QPixmap( ":/images/faster.png" ));			//xxx
+    m_pButtonSpeedPlus ->setIcon (QIcon( ":/images/faster.png" ));			//xxx
+	//m_pButtonSpeedMinus->setPixmap (QPixmap().fromMimeSource( "slower.png" ));		//ooo
+	//m_pButtonSpeedMinus->setPixmap (QPixmap( ":/images/slower.png" ));			//xxx
+    m_pButtonSpeedMinus->setIcon (QIcon( ":/images/slower.png" ));			//xxx
 
-	editCopyAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editcopy" ) ) );
-	fileExitAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "exit.png" ) ) );
-	fileOpenPrevious->setIconSet( QIconSet( QPixmap::fromMimeSource( "new.png" ) ) );
-	fileOpenAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "open.png" ) ) );
-	fileSaveAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "save.png" ) ) );
-	editRedoAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "redo" ) ) );
-	editCutAction   ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editcut" ) ) );
-	editPasteAction ->setIconSet( QIconSet( QPixmap::fromMimeSource( "editpaste" ) ) );
-	editFindAction  ->setIconSet( QIconSet( QPixmap::fromMimeSource( "searchfind" ) ) );
-	m_pActionScreenshot->setIconSet( QIconSet( QPixmap::fromMimeSource( "desktop.png" ) ) );
+	//editCopyAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "editcopy" ) ) );		//ooo
+	//editCopyAction  ->setIconSet( QIcon( ":/images/editcopy" ) );				//xxx
+    editCopyAction  ->setIcon( QIcon( ":/images/editcopy" ) );				//xxx
+	//fileExitAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "exit.png" ) ) );		//ooo
+	//fileExitAction  ->setIconSet( QIcon( ":/images/exit.png" ) );				//xxx
+    fileExitAction  ->setIcon( QIcon( ":/images/exit.png" ) );				//xxx
+	//fileOpenPrevious->setIconSet( QIcon( qPixmapFromMimeSource( "new.png" ) ) );		//ooo
+	//fileOpenPrevious->setIconSet( QIcon( ":/images/new.png" ) );				//xxx
+    fileOpenPrevious->setIcon( QIcon( ":/images/new.png" ) );				//xxx
+	//fileOpenAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "open.png" ) ) );		//ooo
+	//fileOpenAction  ->setIconSet( QIcon( ":/images/open.png" ) );				//xxx
+    fileOpenAction  ->setIcon( QIcon( ":/images/open.png" ) );				//xxx
+	//fileSaveAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "save.png" ) ) );		//ooo
+	//fileSaveAction  ->setIconSet( QIcon( ":/images/save.png" ) );				//xxx
+    fileSaveAction  ->setIcon( QIcon( ":/images/save.png" ) );				//xxx
+	//editRedoAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "redo" ) ) );		//ooo
+	//editRedoAction  ->setIconSet( QIcon( ":/images/redo" ) );				//xxx
+    editRedoAction  ->setIcon( QIcon( ":/images/redo" ) );				//xxx
+	//editCutAction   ->setIconSet( QIcon( qPixmapFromMimeSource( "editcut" ) ) );		//ooo
+	//editCutAction   ->setIconSet( QIcon( ":/images/editcut" ) );				//xxx
+    editCutAction   ->setIcon( QIcon( ":/images/editcut" ) );				//xxx
+	//editPasteAction ->setIconSet( QIcon( qPixmapFromMimeSource( "editpaste" ) ) );	//ooo
+	//editPasteAction ->setIconSet( QIcon( ":/images/editpaste" ) );				//xxx
+    editPasteAction ->setIcon( QIcon( ":/images/editpaste" ) );				//xxx
+	//editFindAction  ->setIconSet( QIcon( qPixmapFromMimeSource( "searchfind" ) ) );	//ooo
+	//editFindAction  ->setIconSet( QIcon( ":/images/searchfind" ) );				//xxx
+    editFindAction  ->setIcon( QIcon( ":/images/searchfind" ) );				//xxx
+	//m_pActionScreenshot->setIconSet( QIcon( qPixmapFromMimeSource( "desktop.png" ) ) );	//ooo
+	//m_pActionScreenshot->setIconSet( QIcon( ":/desktop.png" ) );				//xxx
+    m_pActionScreenshot->setIcon( QIcon( ":/desktop.png" ) );				//xxx
 	
 	// The buttons fro the DVD menu guidance.
 	connect ( m_pButtonUp,            SIGNAL ( clicked ( ) ), this, SLOT ( slotUp            ( ) ) );
@@ -130,7 +251,8 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 	connect (m_pButtonPrev,       SIGNAL(clicked()), this, SLOT(slotPrev()));
 	connect (m_pButtonNext,       SIGNAL(clicked()), this, SLOT(slotNext()));
 	connect (m_pButtonStop,       SIGNAL(clicked()), this, SLOT(slotStop()));
-	connect (m_pButtonPlay,       SIGNAL(clicked()), this, SLOT(slotPlay()));
+	connect (m_pButtonPlay,       SIGNAL(clicked()), this, SLOT(slotPlay()));    //ooo
+    //connect (m_pButtonPlay,       SIGNAL(activated()), this, SLOT(slotPlay()));     //xxx
 	connect (m_pButtonSpeedPlus,  SIGNAL(clicked()), this, SLOT(slotSpeedPlus()));
 	connect (m_pButtonSpeedMinus, SIGNAL(clicked()), this, SLOT(slotSpeedMinus()));
 	connect (m_pSliderVolume,     SIGNAL(valueChanged(int)), this, SLOT(slotSetVolume(int)));
@@ -150,6 +272,7 @@ QPlayer::QPlayer( QWidget* parent, const char* name, WFlags fl )
 QPlayer::~QPlayer()
 {
 	saveHistory();
+    delete m_pImagePreview; //xxx
 }
 
 void QPlayer::initLanguages()
@@ -161,26 +284,36 @@ void QPlayer::initLanguages()
 //	QDir theFiles = QDir::home();
 	QDir theFiles (PREFIX_DIRECTORY); // e.g. /usr/local
 	theFiles.cd (PREFIX_DIRECTORY"/share/qdvdauthor");
-	theFiles.setNameFilter ("qplayer_*.qm");
+	//theFiles.setNameFilter ("qplayer_*.qm"); //ooo
+    theFiles.setNameFilters ( QStringList( QString("qplayer_*.qm") ) );  //xxx
 	QStringList listFiles = theFiles.entryList ();
 	
 	// Here we create the sub-menu for the additional languafges ...
 	if (m_pLanguagePopup)
 		delete m_pLanguagePopup;
-	m_pLanguagePopup = new QPopupMenu ( this );
+	//m_pLanguagePopup = new Q3PopupMenu ( this ); //ooo
+    m_pLanguagePopup = new QMenu ( this );  //xxx
 //	editMenu->insertItem( toolsLanguagesAction->iconSet(), tr( "Languages" ), m_pLanguagePopup );
-	Tools->insertItem( tr( "Languages" ), m_pLanguagePopup );
-	QAction *pActionLanguage = new QAction (this, "languageEnglish");
+	//Tools->insertItem( tr( "Languages" ), m_pLanguagePopup );    //ooo
+    m_pLanguagePopup->setTitle("Languages"); //xxx
+    Tools->addMenu( m_pLanguagePopup ); //xxx
+	//QAction *pActionLanguage = new QAction (this, "languageEnglish");    //ooo
+    QAction *pActionLanguage = new QAction (this);  //xxx
 	pActionLanguage->setText( "English" );
-	pActionLanguage->setMenuText( "English" );
-	pActionLanguage->addTo( m_pLanguagePopup );
+	//pActionLanguage->setMenuText( "English" );   //ooo
+    //pActionLanguage->setText( "English" );  //xxx
+	//pActionLanguage->addTo( m_pLanguagePopup );  //ooo
+    m_pLanguagePopup->addAction(pActionLanguage);   //xxx
 
 	for (t=0;t<listFiles.count();t++)	{
 		// Frist we try to extract the language ...
-		pActionLanguage = new QAction (this, QString ("language%1").arg(t));
+		//pActionLanguage = new QAction (this, QString ("language%1").arg(t));    //ooo
+        pActionLanguage = new QAction (this);  //xxx
 		pActionLanguage->setText( theUtils.iso639(listFiles[t]) );
-		pActionLanguage->setMenuText( theUtils.iso639(listFiles[t].mid (listFiles[t].length()-5,2)) );
-		pActionLanguage->addTo( m_pLanguagePopup );
+		//pActionLanguage->setMenuText( theUtils.iso639(listFiles[t].mid (listFiles[t].length()-5,2)) );  //ooo
+        //pActionLanguage->setText( theUtils.iso639(listFiles[t].mid (listFiles[t].length()-5,2)) );  //xxx
+		//pActionLanguage->addTo( m_pLanguagePopup ); //ooo
+        m_pLanguagePopup->addAction(pActionLanguage);   //xxx
 	}
 	connect( m_pLanguagePopup, SIGNAL( activated(int) ), this, SLOT( slotChangeLanguage(int) ) );
 }
@@ -188,10 +321,11 @@ void QPlayer::initLanguages()
 void QPlayer::slotChangeLanguage (int iID)
 {
 	// The first thing is to co-relate the ID to the language ...
-	QString qsID ("en");	// Default = english
+	/*QString qsID ("en");	// Default = english
 	QDir theFiles (PREFIX_DIRECTORY); // e.g. /usr/local
 	theFiles.cd (PREFIX_DIRECTORY"/share/qdvdauthor");
-	theFiles.setNameFilter ("qplayer_*.qm");
+	//theFiles.setNameFilter ("qplayer_*.qm");   //ooo
+    theFiles.setNameFilters ( QStringList( QString("qplayer_*.qm") ) );  //xxx
 	QStringList listFiles = theFiles.entryList ();
 	// Now that we have the file list in the same order as they were generated, we can find the right one ...
 	int iIndexOfID = m_pLanguagePopup->indexOf(iID);
@@ -210,7 +344,7 @@ void QPlayer::slotChangeLanguage (int iID)
 	pTrans->load( qsLang );
 	m_pTranslator = pTrans;
 	qApp->installTranslator( m_pTranslator );
-	languageChange();
+	languageChange();*/    //oooo
 }
 
 void QPlayer::loadHistory ()
@@ -218,7 +352,8 @@ void QPlayer::loadHistory ()
 	int t;
 	QFileInfo fileInfo;
 	QString qsPlayerIniFile;
-	qsPlayerIniFile = QDir::homeDirPath();
+	//qsPlayerIniFile = QDir::homeDirPath();   //ooo
+    qsPlayerIniFile = QDir::homePath( );		//xxx
 	qsPlayerIniFile.append(QPLAYER_INIT_DIR);
 
 	// First we check for the existance of the settings directory ...
@@ -229,7 +364,7 @@ void QPlayer::loadHistory ()
 	qsPlayerIniFile.append(QPLAYER_INIT_FILE);
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_ReadOnly))
+	if (!iniFile.open(QIODevice::ReadOnly))
 		return;
 	// Try to get the right xml contents ...
 	QDomDocument xmlDoc( XML_DOCTYPE_QPLAYER );
@@ -237,7 +372,8 @@ void QPlayer::loadHistory ()
 		// Error handling ...
 		iniFile.close();
 		QString qsOut = tr ( "QPlayer xml init file <%1> seems to be defective. Re-setting values.\n" ).arg ( qsPlayerIniFile );
-		printf ( "%s", qsOut.ascii ( ) );
+		//printf ( "%s", qsOut.ascii ( ) );   //ooo
+        printf ( "%s", qsOut.toLatin1 ( ).data ( ) );   //xxx
 		return;
 	}
 
@@ -267,7 +403,8 @@ void QPlayer::loadHistory ()
 				MediaCreator::setPreferredEngine (domText);
 			else
 				printf ("Warning: QPlayer::loadHistory -=> wrong XML Node <%s>\nContinuing ...\n",
-						(const char *)searchXMLTree.tagName());
+						//(const char *)searchXMLTree.tagName()); //ooo
+                        searchXMLTree.tagName().toLatin1().data()); //xxx
 			// Go to the next node ...
 			xmlNode = xmlNode.nextSibling();
 		}
@@ -275,12 +412,14 @@ void QPlayer::loadHistory ()
 	iniFile.close();
 //printf ("QPlayer::laodHistory \n%s\n\n", (const char *)xmlDoc.toString());
 	// Remove all empty entries ...
-	m_listHistory.remove (QString ());
+	//m_listHistory.remove (QString ());   //ooo
+    m_listHistory.removeOne (QString ());   //xxx
 	// And finally we insert them into the combo box
 	if (m_listHistory.count() > 0)	{
 		for (t=m_listHistory.count()-1; t >= 0;t--)	{
 			fileInfo.setFile (m_listHistory[t]);
-			m_pComboPrevious->insertItem (fileInfo.fileName());
+			//m_pComboPrevious->insertItem (fileInfo.fileName());    //ooo
+            m_pComboPrevious->addItem (fileInfo.fileName());    //xxx
 		}
 		m_qsFileName = m_listHistory[m_listHistory.count()-1];
 	}
@@ -291,7 +430,8 @@ void QPlayer::saveHistory ()
 	uint t;
 	QFileInfo fileInfo;
 	QString qsPlayerIniFile;
-	qsPlayerIniFile = QDir::homeDirPath();
+	//qsPlayerIniFile = QDir::homeDirPath();   //ooo
+    qsPlayerIniFile = QDir::homePath(); //xxx
 	qsPlayerIniFile.append(QPLAYER_INIT_DIR);
 	qsPlayerIniFile.append(QPLAYER_INIT_FILE);
 
@@ -318,13 +458,14 @@ void QPlayer::saveHistory ()
 
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_WriteOnly))
+	if (!iniFile.open(QIODevice::WriteOnly))
 		return;
 
 	QString xml = xmlDoc.toString();
 //printf ("QPlayer::saveHistory\n%s\n\n", (const char *)xml);
 
-	iniFile.writeBlock(xml, qstrlen (xml));
+	//iniFile.writeBlock(xml, qstrlen (xml));  //ooo
+    iniFile.write(xml.toLatin1().data(), qstrlen (xml.toLatin1().data())); //xxx
 	iniFile.close();
 }
 
@@ -350,7 +491,8 @@ void QPlayer::fileOpen()
 
   if ( qsFileName.isEmpty ( ) )
     return;
-  setFileName ( qsFileName );
+  //setFileName ( qsFileName ); //ooo
+  setFileName ( qsFileName, false );    //xxx
 
 /*
 	// Here we open the MovieDialog.
@@ -376,13 +518,15 @@ void QPlayer::fileOpen()
 void QPlayer::setFileName (QString qsFileName, bool bAddCurrentPath)
 {
 	m_qsFileName = qsFileName;
+
 	if (bAddCurrentPath)
-		addFileToHistory(QDir::currentDirPath() + QString ("/") + m_qsFileName);
+		//addFileToHistory(QDir::currentDirPath() + QString ("/") + m_qsFileName);    //ooo
+        addFileToHistory(QDir::currentPath() + QString ("/") + m_qsFileName);   //xxx
 	else
 		addFileToHistory(m_qsFileName);
 }
 
-void QPlayer::setFileList (QValueList<QString> listVideos, bool bAddCurrentPath)
+void QPlayer::setFileList (QList<QString> listVideos, bool bAddCurrentPath)	//oxx
 {
 	uint t;
 	for (t=0;t<listVideos.count (); t++)
@@ -397,11 +541,13 @@ void QPlayer::addFileToHistory(QString qsNewFile)
 	// This function will add the newly selected file name to the history combo box...
 
 	// This line will remove any double names of the history
-	m_listHistory.remove(qsNewFile);
+	//m_listHistory.remove(qsNewFile); //ooo
+    m_listHistory.removeOne(qsNewFile); //xxx
 	// The we check if we reached the max history number
 	if (m_listHistory.count() >= MAX_HISTORY_FILES)	{
 		QString qsFileToRemove = m_listHistory[0];
-		m_listHistory.remove (qsFileToRemove);
+		//m_listHistory.remove (qsFileToRemove);  //ooo
+        m_listHistory.removeOne (qsFileToRemove);   //xxx
 	}
 	// and finally we add the current file to the top of the pop ...
 	m_listHistory.append(qsNewFile);
@@ -415,15 +561,18 @@ void QPlayer::addFileToHistory(QString qsNewFile)
 		// Next we check if we are playing e.g. a DVD a la dvd:/path/VIDEO_TS/
 		// in which case we extract dvd:/path
 		if (fileInfo.fileName().isEmpty())	{
-			int iPos = m_listHistory[iHistoryCount - t].find ("/VIDEO_TS/");
+			//int iPos = m_listHistory[iHistoryCount - t].find ("/VIDEO_TS/");   //ooo
+            int iPos = m_listHistory[iHistoryCount - t].indexOf ("/VIDEO_TS/"); //xxx
 			if (iPos != -1)
 				qsFileName = m_listHistory[iHistoryCount - t].left (iPos);
 		}
 //		m_pComboPrevious->insertItem(qsFileName);
-		m_pComboPrevious->insertItem(fileInfo.fileName());
+		//m_pComboPrevious->insertItem(fileInfo.fileName());  //ooo
+		m_pComboPrevious->addItem(fileInfo.fileName());   //xxx
 	}
 	// Okay, we have now the information for the new Movie file to display.
-	m_pLabelHeader->setText(QString("<p align=\"center\">%1</p>").arg(m_pComboPrevious->text(0)));
+	//m_pLabelHeader->setText(QString("<p align=\"center\">%1</p>").arg(m_pComboPrevious->text(0)));   //ooo
+	m_pLabelHeader->setText(QString("<p align=\"center\">%1</p>").arg(m_pComboPrevious->currentText()));   //xxx
 	// And finally we generate a first image ...
 	getImage ();
 }
@@ -437,7 +586,7 @@ void QPlayer::getImage(uint /* iFrameNumber */)
 
 void QPlayer::polish ()
 {
-	QWidget::polish ();
+	//QWidget::polish ();  //ooo
 	
 	if (m_pMediaInterface)	{
 		m_pMediaInterface->initMediaEngine ();
@@ -547,7 +696,9 @@ void QPlayer::slotStop ()
 {
 	m_pMediaInterface->stop();
 	colorMovieButtons (m_pButtonStop);
-	m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));
+	//m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));	//ooo
+	//m_pButtonPlay->setPixmap (QPixmap ( ":/images/play.png" ) );		//xxx
+    m_pButtonPlay->setIcon (QIcon ( ":/images/play.png" ) );		//xxx
 	m_iIsPlaying = STATE_STOPPED;
 	m_pSliderTime->setValue ( 0 );
 }
@@ -560,19 +711,25 @@ void QPlayer::slotPlay ()
 	if (m_iIsPlaying == STATE_PLAYING)	{
 		m_iIsPlaying = STATE_PAUSED;
 		m_pMediaInterface->pause();
-		m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));
+		//m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));	//ooo
+		//m_pButtonPlay->setPixmap (QPixmap ( ":/images/play.png" ) );		//xxx
+        m_pButtonPlay->setIcon (QIcon ( ":/images/play.png" ) );		//xxx
 	}
 	else if (m_iIsPlaying == STATE_PAUSED)	{
 		m_iIsPlaying = STATE_PLAYING;
 		m_pMediaInterface->play();
-		m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("pause.png"));
+		//m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("pause.png"));	//ooo
+		//m_pButtonPlay->setPixmap (QPixmap ( ":/imagespause.png" ) );		//xxx
+        m_pButtonPlay->setIcon (QIcon ( ":/imagespause.png" ) );		//xxx
 	}
 	else 	{		
 		QString qsFileName = m_qsFileName;
 		m_pMediaInterface->playMRL(qsFileName);
 		m_fSpeed = 1.0;
 		colorMovieButtons (m_pButtonPlay);
-		m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("pause.png"));
+		//m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("pause.png"));	//ooo
+		//m_pButtonPlay->setPixmap (QPixmap ( ":/images/pause.png" ) );		//xxx
+        m_pButtonPlay->setIcon (QIcon ( ":/images/pause.png" ) );		//xxx
 		m_iIsPlaying = STATE_PLAYING;
 	}
 }
@@ -618,17 +775,24 @@ void QPlayer::slotSpeedMinus ()
 void QPlayer::slotPlaybackFinished ()
 {
 	colorMovieButtons (m_pButtonStop);
-	m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));
+	//m_pButtonPlay->setPixmap (QPixmap ().fromMimeSource("play.png"));	//ooo
+	//m_pButtonPlay->setPixmap (QPixmap ( ":/imagesplay.png" ) );		//xxx
+    m_pButtonPlay->setIcon (QIcon ( ":/imagesplay.png" ) );		//xxx
 	m_pSliderTime->setValue ( 0 );
 	m_iIsPlaying = STATE_STOPPED;
 }
 
 void QPlayer::colorMovieButtons (void *pButton)
 {
+    QPalette palette;		//xxx
 	static QPushButton *pPreviousButton = m_pButtonStop;
-	pPreviousButton->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));
+	//pPreviousButton->setPaletteBackgroundColor (QColor (COLOR_QUICK_NORMAL));  //ooo
+    palette.setBrush(QPalette::Base, QColor( COLOR_QUICK_NORMAL ));	//xxx
+    pPreviousButton->setPalette(palette);   //xxx
 	pPreviousButton = (QPushButton *)pButton;
-	pPreviousButton->setPaletteBackgroundColor (QColor (COLOR_QUICK_SELECTED));
+	//pPreviousButton->setPaletteBackgroundColor (QColor (COLOR_QUICK_SELECTED));    //ooo
+    palette.setBrush(QPalette::Base, QColor( COLOR_QUICK_SELECTED ));	//xxx
+    pPreviousButton->setPalette(palette);	//xxx
 }
 
 void QPlayer::slotNewPosition (int iPos, const QString& qsTime)
@@ -649,7 +813,8 @@ void QPlayer::slotSetup ()
 void QPlayer::slotConfigure ()
 {
 	// Note since MediaCreator is static we don't need to pass infos here :)
-	ConfigureDialog *pDialog = new ConfigureDialog ();
+	//ConfigureDialog *pDialog = new ConfigureDialog ();	//ooo
+	DialogConfigure *pDialog = new DialogConfigure ();	//xxx
 	pDialog->m_pMediaInterface = m_pMediaInterface;
 	pDialog->exec();
 }
@@ -740,11 +905,13 @@ void QPlayer::slotScreenshot()
 	Utils theUtils;
 	long iMsecOffset  = 0;
 	QString qsCurrent = m_pLabelTime->text (); //QString("<p align=\"center\">%1</p>").arg(qsTime));
-printf ( "<%s> ", qsCurrent.ascii () );
+//printf ( "<%s> ", qsCurrent.ascii () );   //ooo
+printf ( "<%s> ", qsCurrent.toLatin1 ().data () );  //xxx
 	qsCurrent.remove ( "<p align=\"center\">" );
 	qsCurrent.remove ( "</p>" );
 	iMsecOffset = theUtils.getMsFromString ( qsCurrent );
-printf ( "%ld %s\n", iMsecOffset, qsCurrent.ascii() );
+//printf ( "%ld %s\n", iMsecOffset, qsCurrent.ascii() );    //ooo
+printf ( "%ld %s\n", iMsecOffset, qsCurrent.toLatin1().data() );    //xxx
 //	MediaInfo *pMediaInfo = m_pMediaInterface->getMediaInfo ( );
 
 	QImage screenShot;
@@ -758,20 +925,26 @@ printf ( "%ld %s\n", iMsecOffset, qsCurrent.ascii() );
 	  return;
 	}
 	
-	QString qsFileName = QFileDialog::getSaveFileName("./", tr("Images (*.png *.xpm *.jpg)"), this, tr("save file Dialog"), tr("Save Screenshot under ..."));
+	//QString qsFileName = Q3FileDialog::getSaveFileName("./", tr("Images (*.png *.xpm *.jpg)"), this, tr("save file Dialog"), tr("Save Screenshot under ..."));   //ooo
+	QString qsFileName = QFileDialog::getSaveFileName(this, tr("save file Dialog"), "./", tr("Images (*.png *.xpm *.jpg)")); //xxx
 
 	if (qsFileName.isEmpty())
 		return;
 	QFileInfo fileInfo (qsFileName);
-	QString qsExtension = fileInfo.extension();
-	qsExtension = qsExtension.upper();
-	screenShot.save (qsFileName, qsExtension);
+	//QString qsExtension = fileInfo.extension();  //ooo
+    QString qsExtension = fileInfo.suffix();    //xxx
+	//qsExtension = qsExtension.upper();   //ooo
+    qsExtension = qsExtension.toUpper();    //xxx
+	//screenShot.save (qsFileName, qsExtension);   //ooo
+    screenShot.save (qsFileName, qsExtension.toLatin1().data());    //xxx
 }
 
 void QPlayer::helpAbout()
 {
-	AboutQPlayer *pDialog = new AboutQPlayer (this);
-	pDialog->m_pLabelTux->setPixmap (QPixmap().fromMimeSource ("babytux.png"));
+	//AboutQPlayer *pDialog = new AboutQPlayer (this);					//ooo
+	DialogAboutQPlayer *pDialog = new DialogAboutQPlayer (this);				//xxx
+	//pDialog->m_pLabelTux->setPixmap (QPixmap().fromMimeSource ("babytux.png"));		//ooo
+	pDialog->m_pLabelTux->setPixmap (QPixmap( ":/images/babytux.png" ) );			//xxx
 	pDialog->show();
 }
 
