@@ -22,6 +22,7 @@
 #include <qfile.h>
 #include <qstring.h>
 #include <qfileinfo.h>
+#include <QTextStream>  //xxx
 
 #include "qrender.h"
 #include "xml_qrender.h"
@@ -61,7 +62,7 @@ printf ("QRender::QRender \n");
 QRender::~QRender()
 {
 	uint t;
-	for (t=0;t<m_listInputOptions.count();t++)
+    for (t=0;t<static_cast<uint>(m_listInputOptions.count());t++)   //oxx
 		delete m_listInputOptions[t];
 	delete m_pOutputOptions;
 }
@@ -72,15 +73,18 @@ QString QRender::checkForExe( QString qsExe )
 	QString qsExePath;
 	QFileInfo fileInfo(QString ("/tmp/%1_out.txt").arg(getlogin()));
 	// the next check is to see if we can find 
-	int iRet = system ((const char *)QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin())); 
+	//int iRet = system ((const char *)QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin())); //ooo
+    int iRet = system (QString ("which %1 > /tmp/%2_out.txt 2>/dev/null").arg(qsExe).arg(getlogin()).toLatin1().data());    //xxx
 	iRet = iRet;
 
 	fileInfo.setFile(QString("/tmp/%1_out.txt").arg(getlogin()));
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() > 4)	{
                 QFile theFile   (QString ("/tmp/%1_out.txt").arg(getlogin()));
-		theFile.open    (IO_ReadOnly);
-		theFile.readLine(qsExePath, 4096);
+		//theFile.open    (IO_ReadOnly);  //ooo
+        theFile.open    (QIODevice::ReadOnly);  //xxx
+		//theFile.readLine(qsExePath, 4096);  //ooo
+        theFile.readLine(qsExePath.toLatin1().data(), 4096);    //xxx
 		theFile.close();
 		if (!qsExePath.isEmpty())	{
 			qsExePath.remove("\n");
@@ -118,13 +122,13 @@ void QRender::transcode ()
 			"# add -e 48000,16,2 to the transcode command \n"
 			"# so the sync adjustment is set by transcode to -1600@1000 \n"
 			"sound='-e 48000,16,2' \n"
-			"# and make it into toolame mp2 format, nice! \n"
-			"nice -19 toolame -p 2 -b 384 output.wav output.mp2 > /dev/null 2>&1  \n"
+			"# and make it into twolame mp2 format, nice! \n"
+			"nice -19 twolame -p 2 -b 384 output.wav output.mp2 > /dev/null 2>&1  \n"
 			"rm -f audiodump.wav output.wav \n"
 		"else \n"
 			"# otherwise sound is 48000 \n"
 			"sound= \n"
-			"nice -19 toolame -p 2 -b 384 audiodump.wav output.mp2 > /dev/null 2>&1 \n"
+			"nice -19 twolame -p 2 -b 384 audiodump.wav output.mp2 > /dev/null 2>&1 \n"
 			"# there will be a stub 44 byte long output.wav from the failed sox \n"
 //			"rm -f output.wav audiodump.wav \n"
 		"fi \n\n"
@@ -143,14 +147,18 @@ void QRender::transcode ()
 //		"rm -f output.m2v output.mp2 ;\n"
 	);
 
-printf ("transcode :\n%s\n\n", (const char *)qsConversionScript);
+//printf ("transcode :\n%s\n\n", (const char *)qsConversionScript); //ooo
+printf ("transcode :\n%s\n\n", qsConversionScript.toLatin1().data());   //xxx
 	generateFile (qsFileName, qsConversionScript);
-	chmod  (qsFileName, S_IEXEC | S_IRUSR | S_IWRITE);
-	int iRet = system (qsCommand);
+	//chmod  (qsFileName, S_IEXEC | S_IRUSR | S_IWRITE);   //ooo
+    chmod  (qsFileName.toLatin1().data(), S_IEXEC | S_IRUSR | S_IWRITE);    //xxx
+	//int iRet = system (qsCommand);   //ooo
+    int iRet = system (qsCommand.toLatin1().data());    //xxx
 	iRet = iRet;
-	for (t=0;t<m_xmlQRender.qrender().mmm.listOfClips.count();t++)	{
+	for (t=0;t<static_cast<uint>(m_xmlQRender.qrender().mmm.listOfClips.count());t++)	{    //oxx
 		qsCommand = QString ("convert.sh");
-		iRet = system (qsCommand);
+		//iRet = system (qsCommand);  //ooo
+        iRet = system (qsCommand.toLatin1().data());    //xxx
 	}
 }
 
@@ -158,7 +166,8 @@ void QRender::generateFile (QString qsFileName, QString qsConversionScript)
 {
 	QFile theFile (qsFileName);
 
-	if ( theFile.open( IO_WriteOnly ) ) {
+	//if ( theFile.open( IO_WriteOnly ) ) {    //ooo
+    if ( theFile.open( QIODevice::WriteOnly ) ) {   //xxx
 		QTextStream stream( &theFile );
 		stream << qsConversionScript << "\n";
 		theFile.close();
@@ -381,7 +390,8 @@ void QRender::parseCommandLine (int argc, char **argv)
 			m_listInputOptions.last()->colorTransparent = QColor (argv[++t]);
 		}
 	}
-	m_listInputOptions.remove(m_pOutputOptions);	// remove the output options from the options for the input image
+	//m_listInputOptions.remove(m_pOutputOptions);	// remove the output options from the options for the input image   //ooo
+	m_listInputOptions.removeOne(m_pOutputOptions);	// remove the output options from the options for the input image  //xxx
 }
 
 void QRender::readXml (QString qsXmlFile)
