@@ -71,7 +71,7 @@ protected:
 	QString checkForExe ( QString );
 private:
 	int                          m_iVerbosityLevel;
-	QValueList<QRenderOptions *> m_listInputOptions;
+	QList<QRenderOptions *> m_listInputOptions;
 	QRenderOptions              *m_pOutputOptions;
 	XmlQRender                   m_xmlQRender;
 };
