@@ -74,16 +74,21 @@
 #include <qdatetime.h>
 #include <qmessagebox.h>
 #include <qapplication.h>
+//Added by qt3to4:
+#include <QTextStream>
+//#include <Q3ValueList>	//oxx
+#include <QMessageBox>		//xxx
 
 #include "startmenurender.h"
-#include "uidialogextraction.h"
+//#include "uidialogextraction.h"	//ooo
+#include "dialogextraction.h"		//xxx
 
 #include "../global.h"
 #include "../dvdmenu.h"
 #include "../movieobject.h"
 
 // First we init the static member variables ...
-QValueList<StartMenuRender *> StartMenuRender::m_listRenderObjects;
+QList<StartMenuRender *> StartMenuRender::m_listRenderObjects;		//oxx
 
 StartMenuRender::StartMenuRender (MovieObject *pMovieObject)
 	: QThread ()
@@ -142,26 +147,29 @@ void StartMenuRender::renderDVDMenu ()
 		return;
 	// Next step is to check if there is a thread currently working on this menu ...
 	// Note : m_listRenderObjects is a static object.
-	for (t=0;t<m_listRenderObjects.count();t++)	{
+	for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
 		StartMenuRender *pSMR = m_listRenderObjects[t];
 		if (pSMR->dvdMenu () == m_pDVDMenu)	{
 			// Check if the background thread is currently running and wait for it to finish ...
-			if (pSMR->running())	{
+			//if (pSMR->running())	{	//ooo
+			if (pSMR->isRunning())	{	//xxx
 				pSMR->wait ();
 				// and after the thread is done we can remove it from the Fifo
-				m_listRenderObjects.remove (pSMR);
+				//m_listRenderObjects.remove (pSMR);	//ooo
+				m_listRenderObjects.removeOne (pSMR);	//xxx
 				delete pSMR;
 				return;
 			}
 			// otherwise we want to remove this request and do it now and here in this thread (also a background thread)
 			else if (!m_bCalledFromFifo)	{
-				m_listRenderObjects.remove (pSMR);
+				//m_listRenderObjects.remove (pSMR);	//ooo
+				m_listRenderObjects.removeOne (pSMR);	//xxx
 				delete pSMR;
 			}
 		}
 	}
 	// Hello, still here, which means there is work to be done.
-	dvdMenu()->renderMenu ();
+	dvdMenu()->renderMenu ();	//oooo
 }
 
 int StartMenuRender::checkStatusFile (QString qsFullPath)
@@ -185,7 +193,7 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 	}
 	// Now we read in the status file (only a few lines anyways.
 	QStringList statusLines;
-	if ( statusFile.open( IO_ReadOnly ) ) {
+	if ( statusFile.open( QIODevice::ReadOnly ) ) {
 		QTextStream stream( &statusFile );
 		while ( !stream.atEnd() )
 			statusLines.append(stream.readLine()); // line of text excluding '\n'
@@ -196,8 +204,9 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 	// Okay we have a running number for the status's a'la " [00] startTime endTime / [01] cmd 1 ...
 	// First we are intersted in the extracted time frame.
 	QRegExp findTheTime("^\\[00\\]\\s+(\\S+)\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findTheTime.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findTheTime.search (statusLines[t]) > -1)	{	//ooo
+		if (findTheTime.indexIn (statusLines[t]) > -1)	{	//xxx
 			QTime extractedOffset, extractedDuration;
 			extractedOffset   = extractedOffset.fromString   ( findTheTime.cap(1) );
 			extractedDuration = extractedDuration.fromString ( findTheTime.cap(2) );
@@ -208,16 +217,18 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 	}
 	// Next we check if the Video STream has been cleaned okay.
 	QRegExp findClean("^\\[02\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findClean.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findClean.search (statusLines[t]) > -1)	{	//ooo
+		if (findClean.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findClean.cap(1) != QString ("Okay."))
 				return 1;
 		}
 	}
 	// So there have been problems with the extraction of the clip (the timeframe)
 	QRegExp findClip("^\\[04\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findClip.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findClip.search (statusLines[t]) > -1)	{	//ooo
+		if (findClip.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findClip.cap(1) != QString ("Okay."))	{
 				// Since the clean'ed up file will get deleted we should 
 				// generate it again, thus return 1 rather then return 2
@@ -227,31 +238,35 @@ int StartMenuRender::checkStatusFile (QString qsFullPath)
 	}
 	// Checking if the audio file exists
 	QRegExp findAudio("^\\[06\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findAudio.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findAudio.search (statusLines[t]) > -1)	{	//ooo
+		if (findAudio.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findAudio.cap(1) != QString ("Okay."))
 				return 3;
 		}
 	}
 	// Here we check if the frames have been extracted
 	QRegExp findExtract("^\\[08\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findExtract.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findExtract.search (statusLines[t]) > -1)	{	//ooo
+		 if (findExtract.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findExtract.cap(1) != QString ("Okay."))
 				return 4;
 		}
 	}
 	// Okay just to be nice, did rm work ? 
 	QRegExp findRM("^\\[10\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findRM.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findRM.search (statusLines[t]) > -1)	{	//ooo
+		if (findRM.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findRM.cap(1) != QString ("Okay."))
 				return 5;
 		}
 	}
 	QRegExp findDone("^\\[11\\]\\s+(\\S+)");
-	for (t=0;t<statusLines.count ();t++)	{
-		if (findDone.search (statusLines[t]) > -1)	{
+	for (t=0;t<(uint)statusLines.count ();t++)	{
+		//if (findDone.search (statusLines[t]) > -1)	{	//ooo
+		if (findDone.indexIn (statusLines[t]) > -1)	{	//xxx
 			if (findDone.cap(1) == QString ("Done."))
 				return 6;
 		}
@@ -264,13 +279,16 @@ void StartMenuRender::renderMovieObject ()
 {
 	QFileInfo fileInfo;
 	int     iStatusCheck;
-	QTime   timeEndpos, zeroTime;
+	//QTime   timeEndpos, zeroTime;    //ooo
+    QTime   timeEndpos, zeroTime(0,0,0,0);  //xxx
 	QString qsFullPath, qsMenuName, qsCommand, qsOffset, qsEndpos, qsFormat;
 	qsFormat = QString ("hh:mm:ss.zzz");
+
 	// This is the separate thread which extracts the images of the movie clips for this menu
 	// (after generating the status / xml - files)
 	// First we should generate the directories to store the data in ...
 	createDirectories ();
+ 
 	// then we create the images
 	qsMenuName = QString ("NoMenuError");
 	if (m_pMovieObject->dvdMenu())
@@ -283,12 +301,13 @@ void StartMenuRender::renderMovieObject ()
 
 	// First we move the current status file to a backup file.
 	qsCommand = QString ("mv \"%1/%2\" \"%3/%4.prev\"").arg(qsFullPath).arg(QString (STATUS_FILE_NAME)).arg(qsFullPath).arg(QString (STATUS_FILE_NAME));
-	if ( system (qsCommand) == -1 )
+	//if ( system (qsCommand) == -1 )			//ooo
+	if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 		return;
 
 	QFile statusFile (qsFullPath + QString ("/") + QString (STATUS_FILE_NAME));
 	// Now we read in the status ...
-	if ( !statusFile.open( IO_ReadWrite ) ) 
+	if ( !statusFile.open( QIODevice::ReadWrite ) ) 
 		return;
 	QTextStream statusStream ( &statusFile );
 
@@ -307,7 +326,8 @@ void StartMenuRender::renderMovieObject ()
 	statusStream << "[01] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 2)  {
-		if ( system (qsCommand) == -1 ) 
+		//if ( system (qsCommand) == -1 )			//ooo
+		if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
@@ -322,7 +342,8 @@ void StartMenuRender::renderMovieObject ()
 	statusStream << "[03] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 1)  {
-		if ( system (qsCommand) == -1 )
+		//if ( system (qsCommand) == -1 )			//ooo
+		if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
 	fileInfo.setFile(qsFullPath + QString ("/clean.avi"));
@@ -369,7 +390,8 @@ void StartMenuRender::renderMovieObject ()
 	statusStream  << "[05] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 3)  {
-		if ( system (qsCommand) == -1 )
+		//if ( system (qsCommand) == -1 )			//ooo
+		 if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.wav"));
@@ -382,19 +404,25 @@ void StartMenuRender::renderMovieObject ()
 	//    mplayer -ao null -vo jpeg:outdir="./snl" "snl/clip.avi"
 	qsCommand = QString ("rm \"%1/*.jpg\"").arg(qsFullPath);
 	if (iStatusCheck < 4)  {
-		if ( system (qsCommand) == -1 )
+		//if ( system (qsCommand) == -1 )			//ooo
+		if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
-		
-	qsCommand = QString ("mplayer -ao null -vo jpeg:outdir=\"%1\" \"%2/clean.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);
+	
+	int iFrames = zeroTime.secsTo ( m_pMovieObject->duration( ) ) * 25;  //xxx
+	
+	//qsCommand = QString ("mplayer -ao null -vo jpeg:outdir=\"%1\" \"%2/clean.avi\" 2>/dev/null").arg(qsFullPath).arg(qsFullPath);    //ooo
+	qsCommand = QString ("ffmpeg -i \"%1\" -ss %2 -frames:v %3 \"%4/%08d.jpg\"").arg(m_pMovieObject->fileName()).arg(qsOffset).arg(iFrames).arg(qsFullPath);  //xxx
 	statusStream  << "[07] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 4)  {
-		if ( system (qsCommand) == -1 )
+		//if ( system (qsCommand) == -1 )			//ooo
+		if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
 	QDir theDir (qsFullPath);
-	theDir.setNameFilter ("*.jpg");
+	//theDir.setNameFilter ("*.jpg");			//ooo
+	theDir.setNameFilters (QStringList(QString("*.jpg")));	//xxx
 	if (theDir.count() > 0)
 		statusStream << "[08] Okay.\n";
 	else
@@ -406,7 +434,8 @@ void StartMenuRender::renderMovieObject ()
 	statusStream  << "[09] " << QDate::currentDate().toString() << " " << QTime::currentTime().toString() << " cmd > " << qsCommand << "\n";
 	statusFile.flush();
 	if (iStatusCheck < 5)  {
-		if ( system (qsCommand) == -1 )
+		//if ( system (qsCommand) == -1 )			//ooo
+		if ( system (qsCommand.toLatin1().data()) == -1 )	//xxx
 			return;
 	}
 	fileInfo.setFile(qsFullPath + QString ("/clip.avi"));
@@ -423,7 +452,7 @@ void StartMenuRender::renderMovieObject ()
 }
 
 void StartMenuRender::createDirectories ()
-{
+{ 
 	QString qsCommand, qsFullPath, qsMenuName;
 	QFileInfo fileInfo;
 	QDir theTempDir;
@@ -442,7 +471,8 @@ void StartMenuRender::createDirectories ()
 	qsFullPath = QString ( "%1/%2/%3/%4" ).arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ). arg ( m_pMovieObject->extractionPath ( ) );
 
 	qsCommand  = QString ( "mkdir -p '%1'" ).arg ( qsFullPath );
-	if ( system ( (const char *)qsCommand ) == -1 )
+	//if ( system ( (const char *)qsCommand ) == -1 )	//ooo
+	if ( system ( qsCommand.toLatin1().data() ) == -1 )	//xxx
 		return;
 	// and now we check that the path has been created succesfully
 	theTempDir.setPath ( qsFullPath );
@@ -450,7 +480,6 @@ void StartMenuRender::createDirectories ()
 		QMessageBox::warning(NULL, QObject::tr("Could not create Path"), QObject::tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
 		return;
 	}
-
 }
 
 void StartMenuRender::createQRenderXml  ()
@@ -465,51 +494,56 @@ void StartMenuRender::executeQRender    ()
 
 void StartMenuRender::registerToExtract (MovieObject *pMovieObject)
 {
-	// This function will add the MovieObject to the Fifo and 
-	// o Check if there are threads which are done and delete them
-	// o Add the MovieObject to the pipe 
-	// o Start as many threads as there are allowed through Global::iMaxRunningThreads.
+  // This function will add the MovieObject to the Fifo and 
+  // o Check if there are threads which are done and delete them
+  // o Add the MovieObject to the pipe 
+  // o Start as many threads as there are allowed through Global::iMaxRunningThreads.
 //printf ("StartMenuRender::registerToExtract -> And here we go out into the sea of Threads independand and free, to create and live ...\n");
-	if (!pMovieObject)
-		return;
-	uint t, iCurrentRunningThreads;
-	bool bAlreadyRegistered = false;
+  if (!pMovieObject)
+    return;
+  uint t, iCurrentRunningThreads;
+  bool bAlreadyRegistered = false;
 
-	// Here we do the same for the MovieObject
-	bAlreadyRegistered = false;
-	iCurrentRunningThreads = 0;
-	for (t=0;t<m_listRenderObjects.count();t++)	{
-		// First let us get the DVDMenu pointer and append it to the listOfDVDMenus to be rendered ...
-		if (m_listRenderObjects[t]->movieObject() == pMovieObject)
-			bAlreadyRegistered = true;
-		// And since we are running through the list we can also get the count of currently running threads ...
-		if (m_listRenderObjects[t]->running())
-			iCurrentRunningThreads ++;
-	}
-	// Okay let us append the new MovieObject to the list ...
-	if (!bAlreadyRegistered)	{
-		// Now we create a StartMenuRenderObject wrapped around the MovieObject ...
-		StartMenuRender *pNewRenderObject = new StartMenuRender (pMovieObject);
-		m_listRenderObjects.append (pNewRenderObject);
-	}
-	// Then we check which threads can be started, deleted or ignored ...
-	for (t=0;t<m_listRenderObjects.count();t++)	{
-		if (m_listRenderObjects[t]->running())
-			continue;
-		else if (m_listRenderObjects[t]->finished())	{
-			StartMenuRender *pSMR = m_listRenderObjects[t];
-			m_listRenderObjects.remove (pSMR);
-			delete pSMR;
-		}
-		else if (iCurrentRunningThreads < Global::iMaxRunningThreads)	{
+  // Here we do the same for the MovieObject
+  bAlreadyRegistered = false;
+  iCurrentRunningThreads = 0;
+  for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
+    // First let us get the DVDMenu pointer and append it to the listOfDVDMenus to be rendered ...
+    if (m_listRenderObjects[t]->movieObject() == pMovieObject)
+      bAlreadyRegistered = true;
+    // And since we are running through the list we can also get the count of currently running threads ...
+    //if (m_listRenderObjects[t]->running())	//ooo
+    if (m_listRenderObjects[t]->isRunning())	//xxx
+      iCurrentRunningThreads ++;
+  }
+  // Okay let us append the new MovieObject to the list ...
+  if (!bAlreadyRegistered)	{
+    // Now we create a StartMenuRenderObject wrapped around the MovieObject ...
+    StartMenuRender *pNewRenderObject = new StartMenuRender (pMovieObject);
+    m_listRenderObjects.append (pNewRenderObject);
+  }
+  // Then we check which threads can be started, deleted or ignored ...
+  for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
+    //if (m_listRenderObjects[t]->running())	//ooo
+    if (m_listRenderObjects[t]->isRunning())	//xxx
+      continue;
+    //else if (m_listRenderObjects[t]->finished())	{	//ooo
+    else if (m_listRenderObjects[t]->isFinished())	{	//xxx
+      StartMenuRender *pSMR = m_listRenderObjects[t];
+      //m_listRenderObjects.remove (pSMR);	//ooo
+      m_listRenderObjects.removeOne (pSMR);	//xxx
+      delete pSMR;
+    }
+    else if (iCurrentRunningThreads < Global::iMaxRunningThreads)	{
+        
 #if (QT_VERSION > 0x0301FF)
-			m_listRenderObjects[t]->start (QThread::LowPriority);
+      m_listRenderObjects[t]->start (QThread::LowPriority);
 #else
-			m_listRenderObjects[t]->start ();
+      m_listRenderObjects[t]->start ();
 #endif
-			iCurrentRunningThreads ++;
-		}
-	}
+      iCurrentRunningThreads ++;
+    }
+  }
 }
 
 void StartMenuRender::waitForExtraction (DVDMenu *pDVDMenu)
@@ -519,27 +553,32 @@ void StartMenuRender::waitForExtraction (DVDMenu *pDVDMenu)
 	// This function will wait until all requests for the given Menu are done and over with ...
 	// I.e. All MovieObjects need to be extracted before we continue.
 	// Then we check which threads can be started, deleted or ignored ...
-	for (t=0;t<m_listRenderObjects.count();t++)	{
-		if (m_listRenderObjects[t]->running())
+	for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
+		//if (m_listRenderObjects[t]->running())	//ooo
+		 if (m_listRenderObjects[t]->isRunning())	//xxx
 			iCurrentRunningThreads ++;
 		// first we should remove the finished tasks
-		if (m_listRenderObjects[t]->finished ())	{
+		//if (m_listRenderObjects[t]->finished ())	{	//ooo
+		if (m_listRenderObjects[t]->isFinished ())	{	//xxx
 			StartMenuRender *pSMR = m_listRenderObjects[t];
-			m_listRenderObjects.remove (pSMR);
+			//m_listRenderObjects.remove (pSMR);	//ooo
+			m_listRenderObjects.removeOne (pSMR);	//xxx
 			delete pSMR;
 		}
 	}
 
-	uiDialogExtraction *pDialog = NULL;
+	//uiDialogExtraction *pDialog = NULL;		//ooo
+	DialogExtraction *pDialog = NULL;		//xxx
 	// Then we check which threads can be started, deleted or ignored ...
-	QValueList <StartMenuRender *> listToDelete;
+	QList <StartMenuRender *> listToDelete;		//oxx
 	while (bInnerLoop == true)	{
 		bInnerLoop = false;
 		// So we go through the full list
-		for (t=0;t<m_listRenderObjects.count();t++)	{
+		for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
 			MovieObject *pMovieObject = m_listRenderObjects[t]->movieObject();
 			// first we should mark the finished tasks for removal
-			if (m_listRenderObjects[t]->finished ())	{
+			//if (m_listRenderObjects[t]->finished ())	{	//ooo
+			if (m_listRenderObjects[t]->isFinished ())	{	//xxx
 				listToDelete.append (m_listRenderObjects[t]);
 				iCurrentRunningThreads --;
 				pMovieObject = NULL;
@@ -552,9 +591,11 @@ void StartMenuRender::waitForExtraction (DVDMenu *pDVDMenu)
 					// we wait ...
 //					if (m_listRenderObjects[t]->running   ())
 //						m_listRenderObjects[t]->wait  ();
-					if (m_listRenderObjects[t]->running   ())	{
+					//if (m_listRenderObjects[t]->running   ())	{	//ooo
+					if (m_listRenderObjects[t]->isRunning   ())	{	//xxx
 						if ( ! pDialog ) 	{
-							pDialog = new uiDialogExtraction (NULL);
+							//pDialog = new uiDialogExtraction (NULL);	//ooo
+							pDialog = new DialogExtraction (NULL);		//xxx
 							pDialog->setMenuName (pDVDMenu->name());
 							pDialog->show ();
 						}
@@ -565,23 +606,27 @@ void StartMenuRender::waitForExtraction (DVDMenu *pDVDMenu)
 						}
 						else
 							pDialog->m_pTextObject->hide();
-						while (m_listRenderObjects[t]->running   ())	{
+						//while (m_listRenderObjects[t]->running   ())	{	//ooo
+						while (m_listRenderObjects[t]->isRunning   ())	{	//xxx
 							QTimer::singleShot (900, pDialog, SLOT(slotAddASecond()));
 							
 							sleep (1);	// check back in a sec.
-							qApp->processEvents (1000);
+							//qApp->processEvents (1000);				//ooo
+							qApp->processEvents (QEventLoop::AllEvents, 1000);	//xxx
 						}
 					}
 					else if ( (iCurrentRunningThreads < Global::iMaxRunningThreads) && 
-						  (!m_listRenderObjects[t]->finished ()) )	{
+						  //(!m_listRenderObjects[t]->finished ()) )	{		//ooo
+						  (!m_listRenderObjects[t]->isFinished ()) )	{		//xxx
 						m_listRenderObjects[t]->start ();// (QThread::LowPriority);
 						iCurrentRunningThreads ++;
 					}
 				}
 			}
 		}
-		for (t=0;t<listToDelete.count();t++)	{
-			m_listRenderObjects.remove (listToDelete[t]);
+		for (t=0;t<(uint)listToDelete.count();t++)	{
+			//m_listRenderObjects.remove (listToDelete[t]);		//ooo
+			m_listRenderObjects.removeOne (listToDelete[t]);	//xxx
 			delete listToDelete[t];
 		}
 		listToDelete.clear();
@@ -666,12 +711,13 @@ void StartMenuRender::registerToRenderMenu (DVDMenu *pDVDMenu)
 	// Here we do the same for the MovieObject
 	bAlreadyRegistered = false;
 	iCurrentRunningThreads = 0;
-	for (t=0;t<m_listRenderObjects.count();t++)	{
+	for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
 		// First let us get the DVDMenu pointer and append it to the listOfDVDMenus to be rendered ...
 		if (m_listRenderObjects[t]->dvdMenu () == pDVDMenu)
 			bAlreadyRegistered = true;
 		// And since we are running through the list we can also get the count of currently running threads ...
-		if (m_listRenderObjects[t]->running())
+		//if (m_listRenderObjects[t]->running())	//ooo
+		if (m_listRenderObjects[t]->isRunning())	//xxx
 			iCurrentRunningThreads ++;
 	}
 	// Okay let us append the new MovieObject to the list ...
@@ -681,11 +727,14 @@ void StartMenuRender::registerToRenderMenu (DVDMenu *pDVDMenu)
 		m_listRenderObjects.append (pNewRenderObject);
 	}
 	// Then we check which threads can be started, deleted or ignored ...
-	for (t=0;t<m_listRenderObjects.count();t++)	{
-		if (m_listRenderObjects[t]->running())
+	for (t=0;t<(uint)m_listRenderObjects.count();t++)	{
+		//if (m_listRenderObjects[t]->running())	//ooo
+		if (m_listRenderObjects[t]->isRunning())	//xxx
 			continue;
-		else if (m_listRenderObjects[t]->finished())	{
-			m_listRenderObjects.remove (m_listRenderObjects[t]);
+		//else if (m_listRenderObjects[t]->finished())	{	//ooo
+		else if (m_listRenderObjects[t]->isFinished())	{	//xxx
+			//m_listRenderObjects.remove (m_listRenderObjects[t]);		//ooo
+			m_listRenderObjects.removeOne (m_listRenderObjects[t]);		//xxx
 			delete m_listRenderObjects[t];
 		}
 		else if (iCurrentRunningThreads < Global::iMaxRunningThreads)	{
