@@ -1,8 +1,9 @@
 
 #include <stdlib.h>
 
-#include <qdom.h>
-#include <qvaluelist.h>
+//#include <qdom.h>     //ooo
+#include <QDomNode>		//xxx
+#include <QList>
 #include <qfile.h>
 
 #include "xml_qrender.h"
