@@ -41,8 +41,9 @@
 #define CLIP_MASK          "mask"
 
 
-#include <qvaluelist.h>
-#include <qdom.h>
+#include <QList>
+//#include <qdom.h>     //ooo
+#include <QDomNode>		//xxx
 
 class XmlQRender
 {
@@ -82,7 +83,7 @@ class XmlQRender
 		float   offset;
 		float   length;
 		QString output;
-		QValueList<clip_struct *> listOfClips;
+		QList<clip_struct *> listOfClips;
 	};
 	class qrender_struct {
 		public:
