@@ -8,10 +8,17 @@
 *****************************************************************************/
 // This file uses a xml style to store all information regarding the slideshow.
 #include <qfileinfo.h>
-#include <qfiledialog.h>
+//#include <q3filedialog.h> //ooo
+#include <QFileDialog>      //xxx
 #include <qmessagebox.h>
-#include <qpopupmenu.h>
-#include <qtoolbar.h>
+#include <QMenu>
+#include <QToolBar>
+//Added by qt3to4:
+//#include <q3mimefactory.h>    //ooo
+//#include <Q3ValueList>	//ooo
+#include <QList>		//xxx
+#include <QPixmap>
+#include <QMessageBox>		//xxx
 
 #include "../xml_slideshow.h"
 #include "dialogfilter.h"
@@ -21,8 +28,9 @@
 void CSlideDialog::slotSelectImages()
 {
   QString qsFilter ("*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP");
-  QStringList slideshowFiles = QFileDialog::getOpenFileNames(tr("Images for Slideshow (")+qsFilter+QString(")"), "./",
-							     this, tr("open files dialog Select one or more files to open" ));
+  //QStringList slideshowFiles = Q3FileDialog::getOpenFileNames(tr("Images for Slideshow (")+qsFilter+QString(")"), "./",   //ooo
+							     //this, tr("open files dialog Select one or more files to open" )); //ooo
+  QStringList slideshowFiles = QFileDialog::getOpenFileNames ( NULL, QObject::tr("open files dialog Select one or more files to open"), "./", QObject::tr("Images for Slideshow (")+qsFilter+QString(")") ); 
   if (slideshowFiles.isEmpty())
     return;
   // Here we check if there are already images in the structure ...
@@ -40,7 +48,7 @@ void CSlideDialog::slotSelectImages()
   
   QString fileName;
   QFileInfo fileInfo;
-  for (uint t=0;t<slideshowFiles.count();t++)	{
+  for (uint t=0;t<(uint)slideshowFiles.count();t++)	{	//ox
     CXmlSlideshow::img_struct *pImg = m_Slideshow.addImg();
     pImg->src=slideshowFiles[t];
 //    if (m_pCheckBackground->isChecked () )  {
@@ -52,7 +60,8 @@ void CSlideDialog::slotSelectImages()
     // And here we add the filenames to the table.
     fileInfo = QFileInfo (slideshowFiles[t]);
     fileName = fileInfo.fileName ();
-    m_pListTable->insertItem (fileName);
+    //m_pListTable->insertItem (fileName);  //ooo
+    m_pListTable->addItem (fileName);       //xxx
   }
   m_slideshowFiles += slideshowFiles;
   // And finally, if there are files selected, then enable the Ok - button.
@@ -62,8 +71,10 @@ void CSlideDialog::slotSelectImages()
     m_pButtonExport->setEnabled(true);
   }
 
-  m_pListTable->setSelected (m_pListTable->numRows()-1, TRUE);
-  previewImage(m_pListTable->numRows()-1);
+  //m_pListTable->setSelected (m_pListTable->numRows()-1, TRUE);    //oooo
+  //m_pListTable->setSelected (m_pListTable->count()-1, TRUE);    //xxx
+  //previewImage(m_pListTable->numRows()-1);    //ooo
+  previewImage(m_pListTable->count()-1);    //xxx
   m_bModified = true;
   slotUpdateListInfo ();
 }
@@ -71,8 +82,9 @@ void CSlideDialog::slotSelectImages()
 void CSlideDialog::slotChooseBackground()
 {
 	QString qsFilter ("*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP");
-	QString qsBackground = QFileDialog::getOpenFileName("./", tr("Image Files (")+qsFilter+QString(")"), this,
-	tr("Select background image"), tr("Select the background image."));
+	//QString qsBackground = Q3FileDialog::getOpenFileName("./", tr("Image Files (")+qsFilter+QString(")"), this,  //xxx
+	//tr("Select background image"), tr("Select the background image."));  //xxx
+    QString qsBackground = QFileDialog::getOpenFileName(NULL, tr("Select the background image."), "./", tr("Image Files (")+qsFilter+QString(")")); //xxx
 	if (qsBackground.isNull())
 		return;
 	m_Slideshow.background  = qsBackground;
@@ -98,12 +110,15 @@ void CSlideDialog::slotExport()
 			), QMessageBox::Ok ,  QMessageBox::Cancel);
 		return;
 	}
-	QString qsExportSlideshow = QFileDialog::getSaveFileName("./", tr("Slideshow Files (*.slide)"), this, tr("Slideshow selection Dialog"), tr("Specify slideshow name."));
+	//QString qsExportSlideshow = Q3FileDialog::getSaveFileName("./", tr("Slideshow Files (*.slide)"), this, tr("Slideshow selection Dialog"), tr("Specify slideshow name.")); //ooo
+	QString qsExportSlideshow = QFileDialog::getSaveFileName(NULL, tr("Slideshow selection Dialog"), "./", tr("Slideshow Files (*.slide)"));  //xxx
 	if (qsExportSlideshow.isNull())
 		return;
-	previewImage(m_pListTable->currentItem());
+	//previewImage(m_pListTable->currentItem());   //ooo
+    previewImage(m_pListTable->currentRow());      //xxx
 	QFileInfo fileInfo (qsExportSlideshow);
-	if (fileInfo.extension(FALSE).isEmpty())	// Indication there is no extension ...
+	//if (fileInfo.extension(FALSE).isEmpty())	// Indication there is no extension ... //ooo
+    if (fileInfo.suffix().isEmpty())	// Indication there is no extension ...    //xxx
 		qsExportSlideshow += QString (".slide");
 	m_Slideshow.delay = m_pEditDelay->text().toInt();
 	m_qsSlideshowFileName=qsExportSlideshow;
@@ -126,7 +141,8 @@ void CSlideDialog::slotExport()
 
 void CSlideDialog::slotImport()
 {
-	QString qsImportSlideshow = QFileDialog::getOpenFileName("./", tr("Slideshow Files (*.slide)"), this, tr("Slideshow selection Dialog"), tr("Select a slideshow to add."));
+	//QString qsImportSlideshow = Q3FileDialog::getOpenFileName("./", tr("Slideshow Files (*.slide)"), this, tr("Slideshow selection Dialog"), tr("Select a slideshow to add."));  //ooo
+    QString qsImportSlideshow = QFileDialog::getOpenFileName(NULL, tr("Slideshow selection Dialog"), "./", tr("Slideshow Files (*.slide)"));   //xxx
 	if (qsImportSlideshow.isNull())
 		return;
 	if (m_Slideshow.count() > 0)	{
@@ -176,7 +192,8 @@ void CSlideDialog::slotImport()
 				// Last but nor least we also add those images to the QListBox ...
 				fileInfo = QFileInfo (pImg->src);
 				fileName = fileInfo.fileName ();
-				m_pListTable->insertItem (fileName);
+				//m_pListTable->insertItem (fileName);  //ooo
+                m_pListTable->addItem (fileName);   //xxx
 			}
 			else	{
 				pNewObject = (CXmlSlideshow::time_object *)m_Slideshow.addFilter();
@@ -213,7 +230,8 @@ void CSlideDialog::slotOk()
 		m_qsSlideshowFileName= m_qsTempPath + QString ("/slideshow.xml");
 
 	CXmlSlideshow execSlideshow;
-	previewImage (m_pListTable->currentItem());
+	//previewImage (m_pListTable->currentItem());  //ooo
+    previewImage (m_pListTable->currentRow());  //xxx
 	m_Slideshow.delay = m_pEditDelay->text().toInt();
 	if ( m_pCheckFilter->isChecked ( ) )
 		createFilterSlideshow  ( &execSlideshow );	// Here we insert additionally somefilters and save it.
@@ -222,13 +240,14 @@ void CSlideDialog::slotOk()
 
 	if (!m_pCheckBackground->isChecked ())
 		execSlideshow.background = QString ("");
-	hide ();
+	//hide ();	//ooo
 	DialogCreate *pDialog = new DialogCreate (this);
 	pDialog->setXmlSlideshow (&execSlideshow, m_qsTempPath);
 
 	// If this is called from DVDAuthor then we should connect to the application.
 	if (m_pSourceToolBar)	{	// Note that this OK Button only leads to the next dialog
-	  QToolBar *pSourceToolbar = (QToolBar *)m_pSourceToolBar;
+	  //Q3ToolBar *pSourceToolbar = (Q3ToolBar *)m_pSourceToolBar; //ooo
+        QToolBar *pSourceToolbar = (QToolBar *)m_pSourceToolBar;    //xxx
 		connect ((QObject *)pDialog,     SIGNAL (signalSetSlideshowEntry(QString)), 
 			pSourceToolbar, SLOT   (slotAddSlideshow       (QString)));
 		connect ((QObject *)pDialog,     SIGNAL (signalSlideshowDone    (QString, QString)), 
@@ -258,7 +277,7 @@ void CSlideDialog::slotHelp()
 	"   Note: You can fine tune the settings afterwards when you press [Continue >>>].\n\n"
 	"[Continue >>>]  This will open the filter dialog to modify the global settings \n"
 	"   on a per image/filter basis.\n"
-	), QMessageBox::Ok ,  QMessageBox::NoButton);
+	), QMessageBox::Ok ,  Qt::NoButton);
 }
 
 void CSlideDialog::slotApplyFilter()
@@ -301,27 +320,61 @@ void CSlideDialog::slotFilterToggled ( bool bToggled )
 	slotUpdateListInfo ();
 }
 
-void CSlideDialog::slotListRightMouseClicked( QListBoxItem *, const QPoint &point)
+//void CSlideDialog::slotListRightMouseClicked( Q3ListBoxItem *, const QPoint &point)   //ooo
+void CSlideDialog::slotListRightMouseClicked( QListWidgetItem *pItem)   //xxx
 {
+    
+    
+    QPoint globalPos;   //xxx
+    //globalPos.setX(pItem->listWidget()->visualItemRect(pItem).x());  //xxx
+    //globalPos.setY(pItem->listWidget()->visualItemRect(pItem).y());  //xxx
+    globalPos.setX(this->pos().x()+pItem->listWidget()->pos().x());  //xxx
+    globalPos.setY(this->pos().y()+pItem->listWidget()->pos().y());  //xxx
+    
 	if (m_pListTable->count () < 1)
 		return;
-	QPopupMenu *pMenu = new QPopupMenu (this);
-	pMenu->insertItem ( tr ("Rotate 90") , m_pPreview, SLOT(slotRotate90()));
+    
+    QAction *rotate90Action = new QAction("Rotate 90", this); //xxx
+    QAction *rotate180Action = new QAction("Rotate 180", this); //xxx
+    QAction *rotate270Action = new QAction("Rotate 270", this); //xxx
+    QAction *rotateFree = new QAction("Rotate Free ...", this); //xxx
+    QAction *editImageAction = new QAction("Edit Image ...", this); //xxx
+    
+	QMenu *pMenu = new QMenu (this);
+	/*pMenu->insertItem ( tr ("Rotate 90") , m_pPreview, SLOT(slotRotate90()));
 	pMenu->insertItem ( tr ("Rotate 180"), m_pPreview, SLOT(slotRotate180()));
 	pMenu->insertItem ( tr ("Rotate 270"), m_pPreview, SLOT(slotRotate270()));
 	pMenu->insertItem ( tr ("Rotate Free ..."), m_pPreview, SLOT(slotRotateFree()));
 	pMenu->insertSeparator ();
 	pMenu->insertItem ( tr ("Edit Image ..."), m_pPreview, SLOT(slotEditImage()));
-	pMenu->exec(point);
+	pMenu->exec(point);*/  //oooo
+	pMenu->addAction ( rotate90Action );   //xxx
+    pMenu->addAction ( rotate180Action );   //xxx
+    pMenu->addAction ( rotate270Action );   //xxx
+    pMenu->addAction ( rotateFree );   //xxx
+    pMenu->addSeparator (); //xxx
+    pMenu->addAction ( editImageAction );   //xxx
+    
+    connect(rotate90Action,    SIGNAL(triggered()), m_pPreview, SLOT(slotRotate90()));  //xxx
+    connect(rotate180Action,   SIGNAL(triggered()), m_pPreview, SLOT(slotRotate180()));  //xxx
+    connect(rotate270Action,   SIGNAL(triggered()), m_pPreview, SLOT(slotRotate270()));  //xxx
+    connect(rotateFree,        SIGNAL(triggered()), m_pPreview, SLOT(slotRotateFree()));  //xxx
+    connect(editImageAction,   SIGNAL(triggered()), m_pPreview, SLOT(slotEditImage()));  //xxx
+    
+    pMenu->exec(globalPos);  //xxx
 }
 
 void CSlideDialog::slotSelectionChanged()
 {
-  previewImage ( m_pListTable->currentItem ( ) );
+  //previewImage ( m_pListTable->currentItem ( ) ); //ooo
+  previewImage ( m_pListTable->currentRow ( ) );    //xxx
+  
   uint t;
-  for ( t=0;t<m_pListTable->count ( ); t++ ) {
-    if ( m_pListTable->isSelected ( t ) ) {
-      m_pButtonDelete->setEnabled ( TRUE );
+  for ( t=0;t<(uint)m_pListTable->count ( ); t++ ) {	//ox
+    //if ( m_pListTable->isSelected ( t ) ) {   //ooo
+    if ( m_pListTable->currentRow ( ) == t ) {  
+      //m_pButtonDelete->setEnabled ( TRUE );   //ooo
+      m_pButtonDelete->setEnabled ( true );     //xxx
       return;
     }
   }
@@ -369,13 +422,22 @@ void CSlideDialog::initMe(void *pSourceToolBar, QString qsTempPath)
 
 	m_pPreview->setMinimumSize( QSize( 150, 150 ) );
 	m_pPreview->setMaximumSize( QSize( 250, 32767 ) );
+	
+	m_pPreview->setScaledContents         ( true );		//xxx
+	m_pPreview->setAutoFillBackground     ( true );		//xxx
 
 	m_pFramePreviewLayout->addWidget( m_pPreview, 0, 0 );
 	m_bModified = false;
 	m_pButtonBackground->setEnabled(false);
 	m_pButtonFilter->setEnabled(false);
 	m_pButtonExport->setEnabled(false);
-	m_pPreview->setPaletteBackgroundPixmap ( QPixmap::fromMimeSource ("checkered.png") );
+	//m_pPreview->setPaletteBackgroundPixmap ( qPixmapFromMimeSource (":/images/checkered.png") );		//ooo
+	//m_pPreview->setPaletteBackgroundPixmap ( QPixmap (":/images/checkered.png") );			//xxx
+	QPalette palette;									//xxx
+	//palette.setBrush(QPalette::Window, QBrush(":/images/checkered.png"));			//xxx
+	palette.setBrush(QPalette::Window, QBrush( QPixmap (":/images/checkered.png") ) );	//xxx
+	//palette.setColor (QPalette :: Background, QColor (192,253,123));			//xxx
+	m_pPreview->setPalette(palette);							//xxx
 }
 
 void CSlideDialog::previewImage(int iItem)
@@ -385,9 +447,9 @@ void CSlideDialog::previewImage(int iItem)
   if (pImg == NULL)
     return;
   
-  if ( m_pCheckBackground->isChecked() )
+  if ( m_pCheckBackground->isChecked() ) {
     m_pPreview->setBackground(m_Slideshow.background, false);	// false = no refresh, done int setImage
-  else {
+  } else {
     QPixmap background ( m_pPreview->width ( ), m_pPreview->height ( ) );
     background.fill ( QColor ( 0, 0, 0 ) );    
     m_pPreview->setBackground(background, false); // false = no refresh, done int setImage
@@ -436,17 +498,19 @@ void CSlideDialog::slotDelete()
   uint t, i;
   QString   qsTemp;
   QFileInfo fileInfo;
-  QValueList<QListBoxItem *> list;
+  //Q3ValueList<Q3ListBoxItem *> list;		//ooo
+  QList<QListWidgetItem *> list;			//xxx
   // Make sure we leave at least one image ...
   if ( m_pListTable->count ( ) < 2 )
     return;
 
   for ( t=0;t<m_pListTable->count ( ); t++ ) {
-    if ( m_pListTable->isSelected ( t ) ) {
+    //if ( m_pListTable->isSelected ( t ) ) {   //ooo
+    if ( m_pListTable->currentRow ( ) == t) {  //xxx
       list.append(m_pListTable->item( t ) );
     }
   }
-  for ( t=0; t<list.count ( ); t++ ) {
+  for ( t=0; t<(uint)list.count ( ); t++ ) {		//ooo
     qsTemp = list[t]->text ( );
     for ( i=0; i<m_Slideshow.countImg ( ); i++ ) {
       CXmlSlideshow::img_struct *pImg = m_Slideshow.getImg ( i );
@@ -454,7 +518,8 @@ void CSlideDialog::slotDelete()
 	fileInfo.setFile ( pImg->src );
 	if ( fileInfo.fileName ( ) == qsTemp ) {
 	  // delete entry from QStringLIst and m_Slideshow ...
-	  m_slideshowFiles.remove ( pImg->src );
+	  //m_slideshowFiles.remove ( pImg->src ); //ooo
+      m_slideshowFiles.removeOne ( pImg->src ); //xxx
 	  m_pPreview->resetImage ( );
 	  m_Slideshow.delImg ( pImg );
 	  break; // exit inner loop
