@@ -1,19 +1,34 @@
-////////////////////////////////////////////////////////////////////////////////
-//
-// Here we start the class ImageLine.
-// This class handles the generation, and display of the images.
-//
-////////////////////////////////////////////////////////////////////////////////
+/***************************************************************************
+    imageline.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    Here we start the class ImageLine.
+    This class handles the generation, and display of the images.
+    
+****************************************************************************/
 
-#include <qwmatrix.h>
+#include <qmatrix.h>
 #include <qlabel.h>
 #include <qimage.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
+//#include <q3popupmenu.h>  //ooo
+#include <QMenu>       //xxx
 #include <qinputdialog.h>
+//Added by qt3to4:
+//#include <QCustomEvent>   //ooo
+#include <QEvent>           //xxx
+#include <QFrame>
+#include <QPixmap>
+#include <QMouseEvent>
+#include <QEvent>
 
 #include "imageline.h"
-#include "dialogimage.h"
+#include "dialogimage.h"		//ooo
 
 static const char* const image0_data[] = {
 "21 10 2 1",
@@ -31,40 +46,64 @@ static const char* const image0_data[] = {
 "....................."};
 
 
-ImageLine::ImageLine(QWidget * parent, const char * name, WFlags f)
-    : QFrame( parent, name, f )
+//ImageLine::ImageLine(QWidget * parent, const char * name, Qt::WFlags f)   //ooo
+ImageLine::ImageLine(QWidget * parent, const char * name, Qt::WindowFlags f)    //xxx
+    //: Q3Frame( parent, name, f )  //ooo
+    : QFrame( parent )  //xxx
     , m_Image( (const char **) image0_data )
 {
-	setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );
+	//setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );  //oooo
 	setMinimumSize( QSize( 600, 122 ) );
 	setMaximumSize( QSize( 32767, 122 ) );
-	setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
+	//setPaletteBackgroundColor( QColor( 0, 0, 0 ) );  //ooo
+	QPalette palette;	//xxx
+	palette.setBrush(QPalette::Base, QColor( 0, 0, 0 ));			//xxx
+	this->setPalette(palette);					//xxx
 	setFrameShape( QFrame::StyledPanel );
 	setFrameShadow( QFrame::Raised );
 
-	m_pPixmapLabel1 = new QLabel( this, "pixmapLabel1" );
+	//m_pPixmapLabel1 = new QLabel( this, "pixmapLabel1" );    //ooo
+    m_pPixmapLabel1 = new QLabel( "pixmapLabel1", this );   //xxx
 	m_pPixmapLabel1->setGeometry( QRect( 0, 0, 800, FRAME_HEIGHT ) );
-	m_pPixmapLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pPixmapLabel1->sizePolicy().hasHeightForWidth() ) );
+	//m_pPixmapLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pPixmapLabel1->sizePolicy().hasHeightForWidth() ) );    //oooo
 	m_pPixmapLabel1->setMaximumSize( QSize( 32767, FRAME_HEIGHT ) );
-	m_pPixmapLabel1->setPaletteBackgroundPixmap( m_Image );
+	m_pPixmapLabel1->setScaledContents         ( true );		//xxx	
+	m_pPixmapLabel1->setAutoFillBackground     ( true );		//xxx
+	//m_pPixmapLabel1->setPaletteBackgroundPixmap( m_Image );	//ooo
+	QPalette palette2;						//xxx
+	palette2.setBrush(QPalette::Window, QBrush(m_Image));		//xxx
+	m_pPixmapLabel1->setPalette(palette2);				//xxx
 	m_pPixmapLabel1->setLineWidth( 0 );
-	m_pPixmapLabel1->setScaledContents( FALSE );
+	//m_pPixmapLabel1->setScaledContents( FALSE ); //ooo
+    m_pPixmapLabel1->setScaledContents( false );    //xxx
 
-	m_pImageLabel = new QLabel( this, "imageLabel" );
+	//m_pImageLabel = new QLabel( this, "imageLabel" );    //ooo
+    m_pImageLabel = new QLabel( "imageLabel", this );   //xxx
 	m_pImageLabel->setGeometry( QRect( 0, FRAME_HEIGHT+1, 800, height()-2*FRAME_HEIGHT) );
-	m_pImageLabel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pImageLabel->sizePolicy().hasHeightForWidth() ) );
+	//m_pImageLabel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pImageLabel->sizePolicy().hasHeightForWidth() ) );    //oooo
 	m_pImageLabel->setMaximumSize( QSize( 32767, 122 - 2*FRAME_HEIGHT ) );
 	m_pImageLabel->setLineWidth( 0 );
-	m_pImageLabel->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
-	m_pImageLabel->setScaledContents( FALSE );
+	//m_pImageLabel->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );   //ooo
+	QPalette palette3;	//xxx
+	palette3.setBrush(m_pImageLabel->backgroundRole(), QColor( 0, 0, 0 ));	//xxx
+	m_pImageLabel->setPalette(palette3);						//xxx
+	//m_pImageLabel->setScaledContents( FALSE );   //ooo
+    m_pImageLabel->setScaledContents( false );  //xxx
 
-	m_pPixmapLabel2 = new QLabel( this, "pixmapLabel2" );
+	//m_pPixmapLabel2 = new QLabel( this, "pixmapLabel2" );    //ooo
+    m_pPixmapLabel2 = new QLabel( "pixmapLabel2", this );   //xxx
 	m_pPixmapLabel2->setGeometry( QRect( 0, 110, 800, FRAME_HEIGHT ) );
-	m_pPixmapLabel2->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pPixmapLabel2->sizePolicy().hasHeightForWidth() ) );
+	//m_pPixmapLabel2->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, m_pPixmapLabel2->sizePolicy().hasHeightForWidth() ) );    //oooo
 	m_pPixmapLabel2->setMaximumSize( QSize( 32767, FRAME_HEIGHT ) );
-	m_pPixmapLabel2->setPaletteBackgroundPixmap( m_Image );
+	m_pPixmapLabel2->setScaledContents         ( true );		//xxx	
+	m_pPixmapLabel2->setAutoFillBackground     ( true );		//xxx
+	//m_pPixmapLabel2->setPaletteBackgroundPixmap( m_Image );	//ooo
+	QPalette palette4;						//xxx
+	palette4.setBrush(QPalette::Window, QBrush(m_Image));		//xxx
+	m_pPixmapLabel2->setPalette(palette4);				//xxx
 	m_pPixmapLabel2->setLineWidth( 0 );
-	m_pPixmapLabel2->setScaledContents( FALSE );
+	//m_pPixmapLabel2->setScaledContents( FALSE ); //ooo
+    m_pPixmapLabel2->setScaledContents( false );    //xxx
 	m_pSlideshow = NULL;
 	initMe ();
 }
@@ -85,7 +124,7 @@ void ImageLine::mousePressEvent (QMouseEvent *pEvent)
 	int iImage;
 	// First we check if the user clicked with the left mouse button
 	// we don't handle this.
-	if (pEvent->button () == LeftButton)
+	if (pEvent->button () == Qt::LeftButton)
 		return;
 	// Here we get the ObjectNumber of the Image the user clicked on (or -1 if not an image).
 	iImage = getImageByPos (pEvent->x());
@@ -93,21 +132,21 @@ void ImageLine::mousePressEvent (QMouseEvent *pEvent)
 		return;
 	// m_iHotObject marks the ImageObject for the callbacks of the following drop down menu.
 	m_iHotObject = iImage;
-	QPopupMenu *pMenu = new QPopupMenu (this);
-	pMenu->insertItem ( tr ("Rotate 90") , this, SLOT(slotRotate90()));
+	QMenu *pMenu = new QMenu (this);
+/*	pMenu->insertItem ( tr ("Rotate 90") , this, SLOT(slotRotate90()));
 	pMenu->insertItem ( tr ("Rotate 180"), this, SLOT(slotRotate180()));
 	pMenu->insertItem ( tr ("Rotate 270"), this, SLOT(slotRotate270()));
 	pMenu->insertItem ( tr ("Rotate Free ..."), this, SLOT(slotRotateFree()));
 	pMenu->insertSeparator ();
-	pMenu->insertItem ( tr ("Edit Image ..."), this, SLOT(slotEditImage()));
+	pMenu->insertItem ( tr ("Edit Image ..."), this, SLOT(slotEditImage()));*/ //oooo
 	/**
 	 * F.J. Cruz - neke
 	 *18/10/04
 	 **/
-	pMenu->insertSeparator();
+	/*pMenu->insertSeparator();
 	pMenu->insertItem( tr ("Add Subtittle..."), this, SLOT(slotInsertSubtittle()));
 	
-	pMenu->exec(pEvent->globalPos());
+	pMenu->exec(pEvent->globalPos());*/    //oooo
 }
 
 void ImageLine::mouseDoubleClickEvent (QMouseEvent *pEvent)
@@ -129,7 +168,7 @@ int ImageLine::getImageByPos (int iMouseX)
 	uint t = 0;
 	uint iTotalX = 0;
 	// get the object of the current cursor position.
-	while ((iTotalX < (uint)iMouseX) && (t < m_pCurrentRange->listX.count()))	{
+	while ((iTotalX < (uint)iMouseX) && (t < (uint)m_pCurrentRange->listX.count()))	{	//ox
 		iTotalX += m_pCurrentRange->listX[t];
 		t++;
 	}
@@ -149,7 +188,8 @@ void ImageLine::slotInsertSubtittle()
 	if (pTimeObject->node_name != "img")
 		return;
 	CXmlSlideshow::filter_struct *pImage = (CXmlSlideshow::filter_struct *)pTimeObject;
-	pImage->subtitle = QInputDialog::getText (tr("Please type the subtitle."), tr ("Subtitle : "), QLineEdit::Normal, tr("My Subtitle"));
+	//pImage->subtitle = QInputDialog::getText (tr("Please type the subtitle."), tr ("Subtitle : "), QLineEdit::Normal, tr("My Subtitle"));    //ooo
+    pImage->subtitle = QInputDialog::getText (this, tr("Please type the subtitle."), tr ("Subtitle : "), QLineEdit::Normal, tr("My Subtitle")); //xxx
 }
 
 void ImageLine::rotate (float fRot, bool bClear)
@@ -170,9 +210,10 @@ void ImageLine::rotate (float fRot, bool bClear)
 	QPixmap theThumb;
 	// The we rotate the image
 	if( !myImage.isNull() )	{
-		QWMatrix m;
+		QMatrix m;
 		m.rotate( pImage->rotate );
-		myImage = myImage.xForm( m );
+		//myImage = myImage.xForm( m );   //ooo
+        myImage = myImage.transformed( m ); //xxx
 	}
 
 	// and finallly we scale it back down again.
@@ -180,7 +221,8 @@ void ImageLine::rotate (float fRot, bool bClear)
 	float fXExtension = fAspectRatio * (height() - m_pPixmapLabel1->height() - m_pPixmapLabel2->height());
 	float fTotalTime = m_pCurrentRange->fEndTime -  m_pCurrentRange->fStartTime;
 
-	theThumb.convertFromImage(myImage.smoothScale((int)fXExtension, m_pImageLabel->height()-6, QImage::ScaleMin));
+	//theThumb.convertFromImage(myImage.smoothScale((int)fXExtension, m_pImageLabel->height()-6, Qt::KeepAspectRatio));    //ooo
+    theThumb.convertFromImage(myImage.scaled((int)fXExtension, m_pImageLabel->height()-6, Qt::KeepAspectRatio));    //xxx
 //printf ("theThumb<%d><%d> \n", theThumb.width(), theThumb.height());
 
 	float fMiddleX = (pImage->fEndTime - pImage->fStartTime) / 2.0 + pImage->fStartTime - m_pCurrentRange->fStartTime;
@@ -196,8 +238,12 @@ void ImageLine::rotate (float fRot, bool bClear)
 	thePainter.fillRect((int)fStartX+1, 1, (int)fWidthX-2, m_pImageLabel->height()-6, theBrush);
 
 
-	bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,
-			&theThumb, 0, 0, myImage.width(), myImage.height(), Qt::CopyROP, true );
+	//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//ooo
+	//		&theThumb, 0, 0, myImage.width(), myImage.height(), Qt::CopyROP, true );			//ooo
+	//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//xxx
+	//		&theThumb, 0, 0, myImage.width(), myImage.height()/*, Qt::CopyROP, true*/ );			//xxx
+    QPainter p( &m_pCurrentRange->pixmapRangeThumbs );
+    p.drawPixmap((int)fMiddleX-(int)((double) theThumb.width()/2.0), 1, theThumb, 0, 0, myImage.width(), myImage.height() );  //xxx
 	refreshPixmap();
 }
 
@@ -219,7 +265,8 @@ void ImageLine::slotRotate270 ()
 void ImageLine::slotRotateFree ()
 {
 	bool bOk = 0;
-	double fRotate = QInputDialog::getDouble (tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk);
+	//double fRotate = QInputDialog::getDouble (tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk); //ooo
+    double fRotate = QInputDialog::getDouble (this, tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk);  //xxx
 	if (!bOk)
 		return;
 	rotate (fRotate, true);
@@ -227,7 +274,7 @@ void ImageLine::slotRotateFree ()
 
 void ImageLine::slotEditImage ()
 {
-	DialogImage *pDialog = new DialogImage (this);
+	DialogImage *pDialog = new DialogImage (this);	//ooo
 	pDialog->initMe (m_pSlideshow->getTimeObject(m_iHotObject), m_pSlideshow->background);
 	pDialog->show();
 	connect (pDialog, SIGNAL (signalDone(void *)), this, SLOT(slotImageDialogDone (void *)));
@@ -235,7 +282,7 @@ void ImageLine::slotEditImage ()
 
 void ImageLine::slotImageDialogDone (void *pDlg)
 {
-	DialogImage *pDialog = (DialogImage *) pDlg;
+	DialogImage *pDialog = (DialogImage *) pDlg;		//ooo
 	CXmlSlideshow::img_struct *pImage = pDialog->getPreview()->getImage();
 	QPixmap theThumb;
 	// and finallly we scale it back down again.
@@ -257,14 +304,21 @@ void ImageLine::slotImageDialogDone (void *pDlg)
 
 	thePainter.fillRect((int)fStartX+1, 1, (int)fWidthX-2, m_pImageLabel->height()-6, theBrush);
 
-	bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,
-			&theThumb, 0, 0, theThumb.width(), theThumb.height(), Qt::CopyROP, true );
+	//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//ooo
+	//		&theThumb, 0, 0, theThumb.width(), theThumb.height(), Qt::CopyROP, true );			//ooo
+	//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//xxx
+	//		&theThumb, 0, 0, theThumb.width(), theThumb.height() );						//xxx
+    QPainter p( &m_pCurrentRange->pixmapRangeThumbs );           //xxx
+    p.drawPixmap((int)fMiddleX-(int)((double) theThumb.width()/2.0), 1, theThumb, 0, 0, theThumb.width(), theThumb.height() );  //xxx
 	refreshPixmap();
 }
 
 void ImageLine::mouseReleaseEvent (QMouseEvent *)
 {
-	setPaletteBackgroundColor (QColor (170, 170, 255));
+	//setPaletteBackgroundColor (QColor (170, 170, 255));  //ooo
+    QPalette palette;								//xxx
+    palette.setBrush(QPalette::Base, QBrush(QColor(170, 170, 255)));	//xxx
+    this->setPalette(palette);						//xxx
 }
 
 void ImageLine::setCurrentRange (DialogFilter::range_struct *pRange)
@@ -397,7 +451,8 @@ giProgress = 0;
 		createFrames ();
 		m_createThumbs.initThumbs (this);
 		// If the thread is still running we skip this one ...
-		if (!m_createThumbs.running ())
+		//if (!m_createThumbs.running ()) //ooo
+        if (!m_createThumbs.isRunning ())   //xxx
 			m_createThumbs.start ();
 		return;
 	}
@@ -431,7 +486,8 @@ giProgress = 0;
 
 //		emit (signalProgress ( (int)fProgress));
 giProgress = (int)fProgress;
-QApplication::postEvent (this, new QCustomEvent(QEvent::User+2));
+//QApplication::postEvent (this, new QCustomEvent(QEvent::User+2)); //ooo
+QApplication::postEvent (this, new QEvent((QEvent::Type)(QEvent::User+2))); //xxx
 
 		pImg = m_pSlideshow->getImg (t);
 		if (pImg  != NULL)	{
@@ -442,17 +498,23 @@ QApplication::postEvent (this, new QCustomEvent(QEvent::User+2));
 
 			theImage.load (pImg->src);
 			if( !theImage.isNull() )	{
-				QWMatrix m;
+				QMatrix m;
 				m.rotate( pImg->rotate );
-				theImage = theImage.xForm( m );
+				//theImage = theImage.xForm( m );   //ooo
+                theImage = theImage.transformed( m );   //xxx
 			}
 
-			theThumb.convertFromImage(theImage.smoothScale((int)fXExtension, m_pImageLabel->height()-6, QImage::ScaleMin));
+			//theThumb.convertFromImage(theImage.smoothScale((int)fXExtension, m_pImageLabel->height()-6, Qt::KeepAspectRatio)); //ooo
+			theThumb.convertFromImage(theImage.scaled((int)fXExtension, m_pImageLabel->height()-6, Qt::KeepAspectRatio));   //xxx
 
 			fMiddleX = (pImg->fEndTime - pImg->fStartTime) / 2.0 + pImg->fStartTime - m_pCurrentRange->fStartTime;
 			fMiddleX *= m_pCurrentRange->iXExtension / fTotalTime;
-			bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,
-					&theThumb, 0, 0, theThumb.width(), theThumb.height(), Qt::CopyROP, true );
+			//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//ooo
+			//		&theThumb, 0, 0, theThumb.width(), theThumb.height(), Qt::CopyROP, true );			//ooo
+			//bitBlt (&m_pCurrentRange->pixmapRangeThumbs, (int)fMiddleX-(int)((double) theThumb.width()/2.0), 1,		//xxx
+			//		&theThumb, 0, 0, theThumb.width(), theThumb.height()/*, Qt::CopyROP, true*/ );			//xxx
+            QPainter p( &m_pCurrentRange->pixmapRangeThumbs );           //xxx
+            p.drawPixmap((int)fMiddleX-(int)((double) theThumb.width()/2.0), 1, theThumb, 0, 0, theThumb.width(), theThumb.height() );  //xxx
 			if (t%10 == 5)
 				refreshPixmap ();
 		}
@@ -492,7 +554,8 @@ return;
 //	}
 }
 
-void ImageLine::customEvent (QCustomEvent* pEvent) {
+//void ImageLine::customEvent (QCustomEvent* pEvent) {  //ooo
+void ImageLine::customEvent (QEvent* pEvent) {  //xxx
 	if (pEvent)	{
 		if (pEvent->type() == QEvent::User+1) {
 			m_bSemaphore = true;
