@@ -1,37 +1,51 @@
-/****************************************************************************
-** ImagePreview class
-**
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
-**
-** This class is the encapsulation of the ImagePreview from the FileSelection
-** Dialog.
-** It is also used in the ImageDialog.
-**
+/***************************************************************************
+    imagepreview.cpp
+                             -------------------
+    ImagePreview class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class is the encapsulation of the ImagePreview from the FileSelection
+    Dialog.
+    It is also used in the ImageDialog.
+    
 ****************************************************************************/
 
 #include <qlabel.h>
 #include <qimage.h>
-#include <qwmatrix.h>
+#include <qmatrix.h>
 #include <qpixmap.h>
 #include <qinputdialog.h>
-#include <qpopupmenu.h>
+//#include <q3popupmenu.h>  //ooo
+#include <QMenu>    //xxx
 #include <qpainter.h>
 #include <qcursor.h>
 #include <qfileinfo.h>
+//Added by qt3to4:
+#include <QResizeEvent>
+#include <QMouseEvent>
+#include <QMessageBox>		//xxx
 
 #include "imagepreview.h"
-#include "dialogimage.h"
+#include "dialogimage.h"	//ooo
+//#include "dialogimage_xxx.h"	//xxx
+
 #ifdef QDVD_SLIDESHOW
 #include "modifiers2.h"
 #else
 #include "../modifiers.h"
 #endif
 
-ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
-	: QLabel (pParent, name, f) // |WRepaintNoErase)
+//ImagePreview::ImagePreview (QWidget *pParent, const char * name, Qt::WFlags f )       //ooo
+ImagePreview::ImagePreview (QWidget *pParent, const char * name, Qt::WindowFlags f )    //xxx
+	//: QLabel (pParent, name, f) // |WRepaintNoErase) //ooo
+    : QLabel (pParent) // |WRepaintNoErase) //xxx
 {
-	setScaledContents( TRUE );
+	//setScaledContents( TRUE );   //ooo
+    setScaledContents( true );  //xxx
 	m_fStartZoom         = 1.0;
 	m_bFastPreview       = false; 
 	m_pImage             = NULL;
@@ -79,7 +93,8 @@ void ImagePreview::setBackground ( QString &fileName, bool bRefresh )
       background.fill (QColor (0, 0, 0));
     }
     else
-      background.convertFromImage(theImage.smoothScale(width(), height()));
+      //background.convertFromImage(theImage.smoothScale(width(), height()));   //ooo
+      background.convertFromImage(theImage.scaled(width(), height()));  //xxx
 // Crashes when no pixmap yet set ...
 //    background.convertFromImage(theImage.smoothScale(pixmap()->width(),pixmap()->height()));
     setPixmap (background);
@@ -89,7 +104,8 @@ void ImagePreview::setBackground ( QString &fileName, bool bRefresh )
     background = QPixmap (width(), height());
     background.fill (QColor (0, 0, 0));
   }
-  m_background = background.convertToImage();
+  //m_background = background.convertToImage(); //ooo
+  m_background = background.toImage();  //xxx
   setFixedSize(m_background.width(), m_background.height());
   // Before we go on we should calculate the correct m_iStartX, and m_iStartY
   if ( (m_manipulator.fStartX == 0.0 ) && (m_manipulator.fStartY == 0.0) ) {
@@ -106,14 +122,16 @@ void ImagePreview::setBackground (QPixmap &pix, bool bRefresh)
 {
 	// Here we set the background.
 	if (!pix.isNull())	{
-		m_background = pix.convertToImage();
+		//m_background = pix.convertToImage();    //ooo
+        m_background = pix.toImage();   //xxx
 		setPixmap (pix);
 	}
 	else	{	// no background image, lets create a black, empty background ...
 		QPixmap background;
 		background = QPixmap (pixmap()->width(),pixmap()->height());
 		background.fill (QColor (0, 0, 0));
-		m_background = background.convertToImage();
+		//m_background = background.convertToImage(); //ooo
+        m_background = background.toImage();    //xxx
 		setPixmap (background);
 	}
 	setFixedSize(m_background.width(), m_background.height());
@@ -123,7 +141,8 @@ void ImagePreview::setBackground (QPixmap &pix, bool bRefresh)
 
 void ImagePreview::setImage (QPixmap &theImage, ImageManipulator *pManipulator)
 {
-	m_image = theImage.convertToImage();
+	//m_image = theImage.convertToImage(); //ooo
+    m_image = theImage.toImage();   //xxx
 	if ( pManipulator ) {  // This is called when we want to render the 
 	  // image (rotate, zoom etc) before we deliver it to dvd-slideshow.
 	  m_pImage = NULL; // To make sure ...
@@ -144,7 +163,7 @@ void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
 {
   // before we change the image, we should connect the current 
   // ImageManipulator to the current image struct.
-  getModifier ( );
+  getModifier ( );	//ooo
   m_pImage = pImg;
   setModifier ( );	// get the additional infos for this image
   preloadImage( );
@@ -153,6 +172,7 @@ void ImagePreview::setImage (CXmlSlideshow::img_struct *pImg)
   
   if ( ! pImg->src.isEmpty ( ) )
     rotate ( 0.0, false );
+  
 }
 
 CXmlSlideshow::img_struct *ImagePreview::getImage()
@@ -162,15 +182,15 @@ CXmlSlideshow::img_struct *ImagePreview::getImage()
 
 void ImagePreview::mousePressEvent (QMouseEvent *pEvent)
 {
-	if ( ( pEvent->button  ( ) == MidButton  ) || // If the midle button was pressed
-	     ( ( pEvent->button  ( ) == RightButton ) && ( m_bActiveCursor ) ) )  { // or first the left and second the right button ...
+	if ( ( pEvent->button  ( ) == Qt::MidButton  ) || // If the midle button was pressed
+	     ( ( pEvent->button  ( ) == Qt::RightButton ) && ( m_bActiveCursor ) ) )  { // or first the left and second the right button ...
 		m_currentMousePos = pEvent->pos ( );
 		m_bActiveCursor   = false;
 		m_bActiveZoom     = true;
 		setFastPreview    ( true );
 		return;
 	}
-	else if ( pEvent->button ( ) == LeftButton )  {
+	else if ( pEvent->button ( ) == Qt::LeftButton )  {
 		m_currentMousePos = pEvent->pos  ( );
 		m_bActiveCursor   = true;
 		setFastPreview    ( true );
@@ -178,14 +198,14 @@ void ImagePreview::mousePressEvent (QMouseEvent *pEvent)
 	}
 	if (m_pImage == NULL)
 		return;
-	QPopupMenu *pMenu = new QPopupMenu (this);
-	pMenu->insertItem ( tr ("Rotate 90") , this, SLOT(slotRotate90()));
+	QMenu *pMenu = new QMenu (this);
+	/*pMenu->insertItem ( tr ("Rotate 90") , this, SLOT(slotRotate90()));
 	pMenu->insertItem ( tr ("Rotate 180"), this, SLOT(slotRotate180()));
 	pMenu->insertItem ( tr ("Rotate 270"), this, SLOT(slotRotate270()));
 	pMenu->insertItem ( tr ("Rotate Free ..."), this, SLOT(slotRotateFree()));
 	pMenu->insertSeparator ();
 	pMenu->insertItem ( tr ("Edit Image..."), this, SLOT(slotEditImage()));
-	pMenu->exec(pEvent->globalPos());
+	pMenu->exec(pEvent->globalPos());*/    //oooo
 }
 
 void ImagePreview::mouseReleaseEvent (QMouseEvent *)
@@ -197,7 +217,7 @@ void ImagePreview::mouseReleaseEvent (QMouseEvent *)
 }
 
 void ImagePreview::mouseMoveEvent (QMouseEvent *pEvent)
-{
+{ 
 	static bool bActive = false;
 	if ( bActive )
 		return;
@@ -251,9 +271,9 @@ void ImagePreview::rotate (float fRot, bool bClear)
 
 void ImagePreview::drawContents(QPainter *pPainter)
 {
-	QLabel::drawContents (pPainter);
+	//QLabel::drawContents (pPainter);	//ooo
 	if (m_bFastPreview)	{
-		QWMatrix matrix;
+		QMatrix matrix;
 		QRect startRect, boundingRect;
 		float fZoom = m_manipulator.fZoom * m_fStartZoom;
 		// Next we move the Image but keep the moving point centered.
@@ -274,11 +294,11 @@ void ImagePreview::drawContents(QPainter *pPainter)
 		pPainter->drawRect(boundingRect);
 		pPainter->setWorldMatrix (matrix);
 		pPainter->drawRect(startRect);
-	}
+	} 
 }
 
 void ImagePreview::refreshPreview ()
-{
+{ 
 	if (m_imageColored.isNull())
 		return;
 	if (m_bFastPreview)	{
@@ -294,12 +314,12 @@ void ImagePreview::refreshPreview ()
 	int iTargetStartX, iTargetStartY, iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight;
 	QRect startRect, boundingRect;
 	float fZoom = m_manipulator.fZoom * m_fStartZoom;
-	QWMatrix matrix;
+	QMatrix matrix;
 	QPixmap background;
 	QImage theImage;
 
-	if (m_manipulator.iTransformationMode == 1)
-		matrix.setTransformationMode(QWMatrix::Areas);
+	/*if (m_manipulator.iTransformationMode == 1)
+		matrix.setTransformationMode(QMatrix::Areas);*/		//ooo
 	matrix.translate ((int)(m_manipulator.fStartX * m_background.width ())+(int)((float)m_image.width ()/2.0*fZoom), 
 			  (int)(m_manipulator.fStartY * m_background.height())+(int)((float)m_image.height()/2.0*fZoom) );
 //	matrix.translate (m_manipulator.iStartX, m_manipulator.iStartY);
@@ -319,7 +339,8 @@ void ImagePreview::refreshPreview ()
 	}
 	// Now we twist and twitch the actual interesting image ...
 	// Note: we only need a QImage because we need to get access to the pixel, which we can't with a Pixmap.
-	theImage = m_imageColored.xForm ( matrix );
+	//theImage = m_imageColored.xForm ( matrix );  //ooo
+	theImage = m_imageColored.transformed ( matrix );  //xxx
 
 	// We need the bounding Rect for copiing purposes, so first create the original rectangle
 	startRect = QRect((int)-(m_image.width()/ 2.0), (int)-(m_image.height()/2.0), m_image.width(), m_image.height());
@@ -346,9 +367,13 @@ void ImagePreview::refreshPreview ()
 	if (m_manipulator.fTransparency != 0.0)	{
 		// First we generate a QImage object of the size needed from the background Image ...
 		QPixmap sourcePix (iSourceWidth, iSourceHeight);
-		bitBlt (&sourcePix, 0, 0, thePainter.device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+		//bitBlt (&sourcePix, 0, 0, thePainter.device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);		//oooo
+		//bitBlt (&sourcePix, 0, 0, thePainter.device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, true);			//xxx
+        //QPainter p( this );           //xxx
+        //p.drawPixmap(0, 0, temp );  //xxx
 		// To get Pixe information we need a QImage however ...
-		sourceImg = sourcePix.convertToImage();
+		//sourceImg = sourcePix.convertToImage(); //ooo
+        sourceImg = sourcePix.toImage();    //xxx
 	}
 
 	// Okay if the rotation is any angle, then we get black background even with background image enabled.
@@ -392,7 +417,8 @@ void ImagePreview::adjustColor()
 	if ( m_image.isNull  ( ) )
 		preloadImage ( );
 	// create empty image.
-	m_imageColored = QImage (m_image.width(), m_image.height(), m_image.depth());
+	//m_imageColored = QImage (m_image.width(), m_image.height(), m_image.depth());    //ooo
+    m_imageColored = QImage (m_image.width(), m_image.height(), QImage::Format_RGB32);  //xxx
 
 	if (m_manipulator.fBrightness > 0.0)	{
 		bLighter = true;
@@ -440,7 +466,8 @@ void ImagePreview::preloadImage ( )
 	QFileInfo fileInfo ( m_pImage->src ); 
 	if ( ( m_pImage->src.isEmpty ( ) ) || 
 	     ( ! fileInfo.exists     ( ) ) )  {
-		m_image = QImage::fromMimeSource ("error.jpg");
+		//m_image = QImage::fromMimeSource ("error.jpg");	//ooo
+		m_image = QImage (":/images/error.jpg");		//xxx
 	}
 	else
 		m_image = QImage  ( m_pImage->src );
@@ -449,9 +476,12 @@ void ImagePreview::preloadImage ( )
 //	int iWidth  = m_image.width ();
 	// adjust colors by scaling down to a manageable level.
 	if (m_bFastPreview)
-		m_image = m_image.scale((int)(width()/4.0), (int)(height()/4.0), QImage::ScaleMin);
+		//m_image = m_image.scale((int)(width()/4.0), (int)(height()/4.0), Qt::KeepAspectRatio);	//ooo
+		m_image = m_image.scaled((int)(width()/4.0), (int)(height()/4.0), Qt::KeepAspectRatio);		//xxx
 	else
-		m_image = m_image.smoothScale(width(), height(), QImage::ScaleMin);
+		//m_image = m_image.smoothScale(width(), height(), Qt::KeepAspectRatio);			//ooo
+		m_image = m_image.scaled(width(), height(), Qt::KeepAspectRatio);				//xxx
+        
 	// And here we create the right m_coloredImage;
 //	m_manipulator.fZoom = (float)((float) m_image.width () / iWidth);
 //	m_fStartZoom = (float)((float) m_image.width () / iWidth);
@@ -476,7 +506,8 @@ void ImagePreview::slotRotate270 ()
 void ImagePreview::slotRotateFree ()
 {
 	bool bOk = 0;
-	double fRotate = QInputDialog::getDouble (tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk);
+	//double fRotate = QInputDialog::getDouble (tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk); //ooo
+    double fRotate = QInputDialog::getDouble (this, tr("Please type the rotation angle."), tr ("Rotate : "), 0.0, -360.0, 360.0, 1, &bOk);  //xxx
 	if (!bOk)
 		return;
 	rotate (fRotate, true);
@@ -490,7 +521,7 @@ void ImagePreview::slotEditImage ()
 	else
 		pDialog->initMe(m_pImage, qsEmptyString);
 
-	connect (pDialog, SIGNAL (signalDone(void *)), this, SLOT(slotImageDialogDone (void *)));
+	connect (pDialog, SIGNAL (signalDone(void *)), this, SLOT(slotImageDialogDone (void *)));  //oooo
 }
 
 void ImagePreview::slotImageDialogDone (void *)
@@ -597,12 +628,13 @@ void ImagePreview::setFastPreview (bool bFast)
 {
 	m_bFastPreview = bFast;
 //	preloadImage ();
-	QCursor myCursor (QCursor::WaitCursor);
+	QCursor myCursor (Qt::WaitCursor);
 	setCursor(myCursor);
 	if (m_bNeedToAdjustColor)
 		adjustColor();
 	refreshPreview();
-	myCursor = QCursor(QCursor::ArrowCursor);
+	//myCursor = QCursor(QCursor::ArrowCursor);	//ooo
+	myCursor = QCursor(Qt::ArrowCursor);		//xxx
 	setCursor(myCursor);
 	// If the user releases the slider bar then we have two big images, of which we only need the colored one ...
 //	if (!bFast)
@@ -651,13 +683,12 @@ void ImagePreview::getModifier ()
 	// We don't need such a modifier if nothing has changed ...
 	if ( m_manipulator.isUnchanged () )
 	    return;
-
+	
 	// Okay, there were some changes, so we should take care of them.
 	pManipulator = new ImageManipulator;
 	*pManipulator = m_manipulator;
 	pManipulator->fZoom = m_manipulator.fZoom * m_fStartZoom;
 	pManipulator->fRotate = m_pImage->rotate;
-
 	m_pImage->pModifier = pManipulator;
 }
 
@@ -671,8 +702,10 @@ QPixmap &ImagePreview::getPixmap (int iWidth, int iHeight)
 		m_pixmap = *pixmap();
 	}
 	else	{
-		QImage theImage = pixmap ()->convertToImage();
-		theImage = theImage.smoothScale (iWidth, iHeight);
+		//QImage theImage = pixmap ()->convertToImage();  //ooo
+        QImage theImage = pixmap ()->toImage(); //xxx
+		//theImage = theImage.smoothScale (iWidth, iHeight);  //ooo
+        theImage = theImage.scaled (iWidth, iHeight);   //xxx
 		m_pixmap.convertFromImage(theImage);
 	}
 	return m_pixmap;
@@ -681,11 +714,11 @@ QPixmap &ImagePreview::getPixmap (int iWidth, int iHeight)
 QPixmap &ImagePreview::getObject()
 {
 	float fZoom = m_manipulator.fZoom * m_fStartZoom;
-	QWMatrix matrix;
+	QMatrix matrix;
 	QImage theImage;
 
 	if (m_manipulator.iTransformationMode == 1)
-		matrix.setTransformationMode(QWMatrix::Areas);
+		//matrix.setTransformationMode(QMatrix::Areas);		//ooo
 	matrix.translate ((int)(m_manipulator.fStartX*width())+(int)((float)m_image.width()/2.0), (int)(m_manipulator.fStartY*height())+(int)((float)m_image.height()/2.0));
 	matrix.scale (fZoom, fZoom);
 	matrix.rotate(m_pImage->rotate);
@@ -693,8 +726,9 @@ QPixmap &ImagePreview::getObject()
 
 	// Now we twist and twitch the actual interesting image ...
 	// Note: we only need a QImage because we need to get access to the pixel, which we can't with a Pixmap.
-	theImage = m_imageColored.xForm ( matrix );
-	m_pixmap.convertFromImage(theImage);
+	//theImage = m_imageColored.xForm ( matrix );  //ooo
+    theImage = m_imageColored.transformed ( matrix );   //xxx
+	m_pixmap.convertFromImage(theImage); 
 	return m_pixmap;
 }
 
