@@ -1,21 +1,23 @@
-/****************************************************************************
-** Modifiers / ImageManipulator class implementation.
-**
-**   Created : ?
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
-**
-**
+/***************************************************************************
+    modifiers2.cpp
+                             -------------------
+    Modifiers / ImageManipulator class implementation.
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
-#include <qlistview.h>
+//#include <q3listview.h>   //ooo
+#include <QListWidget>      //xxx
 
 #include "modifiers2.h"
-#include "xml_dvd.h"
-#include "rgba.h"
+//#include "xml_dvd.h"		//ooo
+#include "../xml_dvd.h"		//xxx
+//#include "rgba.h"		//ooo
+#include "../rgba.h"		//xxx
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -184,7 +186,7 @@ ImageManipulator::~ImageManipulator()
 {
 	uint t;
 	if (listColorKeys.count())	{
-		for (t=0;t<listColorKeys.count();t++)
+		for (t=0;t<static_cast<uint>(listColorKeys.count());t++)  //oxx
 			delete listColorKeys[t];
 		listColorKeys.clear();
 	}
@@ -274,7 +276,7 @@ bool ImageManipulator::readProjectFile (QDomNode &theNode)
 	if ( fKenBurnsY2 >  1.0 )
 	     fKenBurnsY2 = -1.0;
 
-	for (uint t=0;t<listColorKeys.count();t++)
+	for (uint t=0;t<static_cast<uint>(listColorKeys.count());t++)  //oxx
 		delete listColorKeys[t];
 	listColorKeys.clear ();
 	QDomNode    manipulatorNodes = theNode.firstChild();
@@ -375,7 +377,7 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
       manipulatorNode.setAttribute( MANIPULATOR_BLUE, QString ("%1").arg(fBlue) );
     if (fBrightness != initialValues.fBrightness)
       manipulatorNode.setAttribute( MANIPULATOR_BRIGHTNESS, QString ("%1").arg(fBrightness) );
-    for (uint t=0;t<listColorKeys.count ();t++)	{
+    for (uint t=0;t<static_cast<uint>(listColorKeys.count ());t++)	{    //oxx
       QDomElement colorKeyNode = xmlDoc.createElement ( MANIPULATOR_COLOR_KEY );
       Rgba        theColor ( listColorKeys[t]->theColor );
       if ( listColorKeys[t]->fDeltaColor != 0.0 )
@@ -389,12 +391,14 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
   return true;
 }
 
-void ImageManipulator::createStructure (QListViewItem *pParentItem)
+//void ImageManipulator::createStructure (Q3ListViewItem *pParentItem)  //ooo
+void ImageManipulator::createStructure (QListWidgetItem *pParentItem)   //xxx
 {
-	QListViewItem *pModifierItem;
+	//Q3ListViewItem *pModifierItem;   //ooo
+    QListWidgetItem *pModifierItem;     //xxx
 	QString qsName;
 
-	ImageManipulator initialValues;
+/*	ImageManipulator initialValues;
 	// And finally we create the modifiers info ...
 	if ( !( 	(fRotate       == initialValues.fRotate)       &&
 			(fShearX       == initialValues.fShearX)       &&
@@ -416,41 +420,51 @@ void ImageManipulator::createStructure (QListViewItem *pParentItem)
 			(iStartFrame   == initialValues.iStartFrame)   &&
 			(iStopFrame    == initialValues.iStopFrame)    &&
 			(listColorKeys.count() > 0) ) )	{
-		pModifierItem = new QListViewItem(pParentItem, QString ("Modifiers"), NULL);
-		pParentItem->setExpandable (TRUE);
+		//pModifierItem = new Q3ListViewItem(pParentItem, QString ("Modifiers"), NULL);   //ooo
+        pModifierItem = new QListWidgetItem(QString ("Modifiers"), pParentItem);    //xxx
+		//pParentItem->setExpandable (TRUE);  //ooo
+        pParentItem->setExpandable (true);  //xxx
 
 		if (	(fRed        != initialValues.fRed)   ||
 			(fGreen      != initialValues.fGreen) ||
 			(fBlue       != initialValues.fBlue) )
-			new QListViewItem(pModifierItem, QString ("Color Adjust"),
+			//new Q3ListViewItem(pModifierItem, QString ("Color Adjust"),    //ooo
+            new QListWidgetItem(pModifierItem, QString ("Color Adjust"),    //xxx
 				QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
 		if (fBrightness  != initialValues.fBrightness)
-			new QListViewItem(pModifierItem, QString ("Brightness"),
+			//new Q3ListViewItem(pModifierItem, QString ("Brightness"),  //ooo
+            new QListWidgetItem(pModifierItem, QString ("Brightness"),  //xxx
 				QString ("%1").arg(fBrightness));
 		if (fTransparency  != initialValues.fTransparency)
-			new QListViewItem(pModifierItem, QString ("Transparency"),
+			//new Q3ListViewItem(pModifierItem, QString ("Transparency"),    //ooo
+            new QListWidgetItem(pModifierItem, QString ("Transparency"),    //xxx
 				QString ("%1").arg(fTransparency));
 		if ((fShearX  != initialValues.fShearX) ||
 			(fShearY  != initialValues.fShearY)  )
-			new QListViewItem(pModifierItem, QString ("Shear (x, y)"),
+			//new Q3ListViewItem(pModifierItem, QString ("Shear (x, y)"),    //ooo
+            new QListWidgetItem(pModifierItem, QString ("Shear (x, y)"),    //xxx
 				QString ("%1, %2").arg(fShearX).arg(fShearY));
 		if ((iStartFrame  != initialValues.iStartFrame) ||
 			(iStopFrame  != initialValues.iStopFrame)  )
-			new QListViewItem(pModifierItem, QString ("VisibleFromTo"),
+			//new Q3ListViewItem(pModifierItem, QString ("VisibleFromTo"),   //ooo
+            new QListWidgetItem(pModifierItem, QString ("VisibleFromTo"),   //xxx
 				QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
 		if (fZoom  != initialValues.fZoom)
-			new QListViewItem(pModifierItem, QString ("Zoom"),
+			//new Q3ListViewItem(pModifierItem, QString ("Zoom"),    //ooo
+            new QListWidgetItem(pModifierItem, QString ("Zoom"),    //xxx
 				QString ("%1").arg(fZoom));
 		if (fRotate  != initialValues.fRotate)
-			new QListViewItem(pModifierItem, QString ("Rotate"),
+			//new Q3ListViewItem(pModifierItem, QString ("Rotate"),  //ooo
+            new QListWidgetItem(pModifierItem, QString ("Rotate"),  //xxx
 				QString ("%1 deg").arg(fRotate));
 		if (listColorKeys.count() > 0)	{
 			QString qsColorKeys("|");
 			for (uint t=0;t<listColorKeys.count();t++)
 				qsColorKeys += QString("0x%1|").arg(listColorKeys[t]->theColor, 16);
-			new QListViewItem (pModifierItem, QString ("ColorKey"), qsColorKeys);
+			//new Q3ListViewItem (pModifierItem, QString ("ColorKey"), qsColorKeys); //ooo
+            new QListWidgetItem (pModifierItem, QString ("ColorKey"), qsColorKeys); //xxx
 		}
-	}
+	}*/    //oooo
 }
 
 ImageManipulator& ImageManipulator::operator = (ImageManipulator &theOther)
