@@ -1,5 +1,5 @@
 #include <qapplication.h>
-#include "dialogslide.h"
+#include "dialogslide.h"	//ooo
 
 int main( int argc, char ** argv )
 {
