@@ -1,17 +1,24 @@
-/****************************************************************************
-** FilterLine class
-**
-** Created: Tue Feb 02 22:06:51 2004
-**      by: Varol Okan using Kate
-**
+/***************************************************************************
+    slidertime.cpp
+                             -------------------
+    FilterLine class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #include <qslider.h>
+//Added by qt3to4:
+#include <QMouseEvent>
 
 #include "slidertime.h"
 
 SliderTime::SliderTime (QWidget * parent, const char * name)
-	: QSlider (parent, name)
+	//: QSlider (parent, name) //ooo
+    : QSlider (parent)  //xxx
 {
 }
 
@@ -30,12 +37,14 @@ void SliderTime::mousePressEvent (QMouseEvent *pEvent)
 	// get automagically to the clicked position.
 	int iSliderPos = 0;
 	// first we get the range
-	int iRange = maxValue()-minValue();
+	//int iRange = maxValue()-minValue();  //ooo
+    int iRange = maximum()-minimum();
 	// Then we get the pixel length of this slider control.
 	int iWidth = width();
 	float fSliderPos = (float)iRange / iWidth * pEvent->pos().x();
 	iSliderPos = (int)fSliderPos;
-	iSliderPos += minValue();
+	//iSliderPos += minValue();    //ooo
+    iSliderPos += minimum();    //xxx
 	setValue (iSliderPos);
 	emit (sliderMoved (iSliderPos));
 }
