@@ -1,25 +1,37 @@
-/****************************************************************************
-** Client - class
-**
-**   Created : Fri Jun 6 12:09:08 2008
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    render_client.h
+                             -------------------
+    Client - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #ifndef RENDER_CLIENT_H
 #define RENDER_CLIENT_H
 
 #include <qthread.h>
-#include <qsocket.h>
-#include <qpixmap.h>
-#include <qdatetime.h>
-#include <qvaluelist.h>
-#include <qwaitcondition.h>
+//#include <q3socket.h>			//ooo
+//#include <QtNetwork/QTcpSocket>		//xxx
+#include <QTcpSocket>		//xxx
+//#include <qpixmap.h>			//ooo
+#include <QPixmap>			//xxx
+//#include <qdatetime.h>		//ooo
+#include <QDateTime>			//xxx
+//#include <q3valuelist.h>		//oxx
+//#include <qwaitcondition.h>		//ooo
+#include <QWaitCondition>		//xxx
+#include <QMutex>			//xxx
+//Added by qt3to4:
+#include <QTimerEvent>
+#include <string.h> //xxx
+#include <QByteArray>   //xxx
 
 class QFile;
+class QTcpSocket;   //xxx
 
 #define EVENT_RENDER_EXIT      11111
 #define EVENT_RENDER_PROGRESS  11112
@@ -34,10 +46,58 @@ class CXmlSlideshow;
 class SourceFileEntry;
 class ButtonTransition;
 
+/*class SleeperThread6 : public QThread	//xxx
+{
+public:
+    static void msleep(unsigned long int msecs)
+    {
+        QThread::msleep(msecs);
+    }
+};*/
+
+/*class Worker : public QObject   //xxx
+{
+    Q_OBJECT
+private slots:
+    void onTimeout()
+    {
+        qDebug()<<"Worker::onTimeout get called from?: "<<QThread::currentThreadId();
+    }
+protected:
+    void enableTimer ( bool );  //xxx
+};*/    //xxx
+
 namespace Render
 {
+    
+class Worker : public QObject   //xxx
+{
+    Q_OBJECT
+    
+public:
+    Worker(QObject *parent = 0);
+    
+    void enableTimer ( bool );  //xxx
+    
+private slots:
+    void onTimeout()
+    {
+        qDebug()<<"Worker::onTimeout get called from?: "<<QThread::currentThreadId();
+    }
 
-class Client : public QObject, public QThread
+protected:
+    //void enableTimer ( bool );  //xxx
+    //virtual void timerEvent ( QTimerEvent   * );    //xxx
+    void timerEvent ( QTimerEvent   *pEvent );    //xxx
+private:
+  //void enableTimer ( bool );  //xxx
+  int               m_iKeepaliveTimer; // Checks if the server has a heartbeat    //xxx
+  QDateTime         m_lastPing;        // Last received ping    //xxx
+};
+
+//class Client : public QObject, public QThread		//ooo
+class Client : public QThread				//xxx-!
+//class Client : public QObject				//xxx-!
 {
   Q_OBJECT
 
@@ -53,8 +113,15 @@ class Client : public QObject, public QThread
   };
 
 public:
-  Client ( SourceFileEntry  * );
-  Client ( ButtonTransition * );
+  Client ( SourceFileEntry  * );  //ooo
+  //Client ( QObject *parent = 0, SourceFileEntry  *pEntry = 0 );   //xxx
+  Client ( ButtonTransition * );  //ooo
+  //Client ( QObject *parent = 0, ButtonTransition *pTrans = 0 );   //xxx
+  /*Client(int socketDescriptor)  //xxx
+        : m_socketDescriptor(socketDescriptor)
+    {
+        //setAutoDelete(false);
+    }*/
   virtual  ~Client ( );
 
   virtual void run ( );
@@ -70,12 +137,15 @@ public:
   void  setWaiting  ( bool );
   SourceFileEntry  *sourceFileEntry  ( );
   ButtonTransition *buttonTransition ( );
+  //void enableTimer ( bool );    //xxx
+  //QTimer *m_NotificationTimer;  //xxx
+  QByteArray byteArrayfromMessageID ( quint16 );    //xxx
 
 protected:
   virtual void timerEvent ( QTimerEvent   * );
   void runSlideshow       ( CXmlSlideshow * );
   bool sendFile ( QString );
-  void enableTimer ( bool );
+  //void enableTimer ( bool );  //ooo
   void runEntry         ( );
   void runTrans         ( );
   void startServer      ( );
@@ -85,12 +155,21 @@ protected:
   void receivedFileAck  ( );
   void displayProgress  ( );
   void receivedProgress ( );
-  Q_UINT64 fileFromSocket        ( );
+  //Q_UINT64 fileFromSocket        ( );		//ooo
+  quint64 fileFromSocket        ( );		//xxx
   void receivedServerDone        ( );
   void receivedServerState       ( );
   void receivedVersionAndHost    ( );
   bool sendVersionAndHostRequest ( );
   static void reRequest ( Client * );
+  
+signals:    //xxx
+  void signalEnableTimer    ( bool );
+  //void error ( QAbstractSocket::SocketError );    //xxx
+  void signalWrite(QByteArray Data);  //xxx
+  void signalWrite(QString Data);  //xxx
+  //void signalWrite(std::string Data);  //xxx
+  void signalFlush( );   //xxx
 
 private slots:
   virtual void closeConnection ( );
@@ -99,23 +178,39 @@ private slots:
   virtual void socketClosed    ( );
   virtual void slotReconnect   ( );
   virtual void slotRecovered   ( );
-  virtual void socketError ( int );
+  //virtual void socketError ( int );   //ooo
+  virtual void socketError ( QAbstractSocket::SocketError );    //xxx
+  //void displayError ( QAbstractSocket::SocketError socketError );  //xxx
+  //void displayError ( QAbstractSocket::SocketError );  //xxx
   virtual void socketConnectionClosed ( );
   virtual void slotConnectAndStart    ( );
   virtual void socketConnectAndStart  ( );
+  void onTimeout();  //xxx
+  //void enableTimer1 ( bool );  //xxx
+  void enableTimer ( bool );  //xxx
+  void slotWrite(QByteArray Data);  //xxx
+  void slotWrite(QString Data);  //xxx
+  //void slotWrite(std::string Data);  //xxx
+  void slotFlush( );    //xxx
 
 private:
   // Something for the server connection
   QFile            *m_pFile;
-  QSocket          *m_pSocket;
+  //Q3Socket          *m_pSocket;	//ooo
+  QTcpSocket       *m_pSocket;		//xxx
+  QDataStream       stream;    //xxx
+  QDataStream       stream1;    //xxx
   QString           m_qsTempXMLFile;
   SourceFileEntry  *m_pSourceFileEntry;
   ButtonTransition *m_pButtonTransition;
   QWaitCondition    m_waiter;
+  QMutex            m_waiterMutex;	//xxx
   QMutex            m_mutex;
   float             m_fProgress;
-  Q_ULONG           m_iMessageLen;     // to keep track of the incoming slideshow video file
-  Q_UINT16          m_iMessageID;      // The current MessageID being processed
+  //Q_ULONG           m_iMessageLen;     // to keep track of the incoming slideshow video file	//oooo
+  qint64           m_iMessageLen;     // to keep track of the incoming slideshow video file
+  //Q_UINT16          m_iMessageID;      // The current MessageID being processed	//oooo
+  quint16          m_iMessageID;      // The current MessageID being processed		//xxx
   bool              m_bRemoteServer;   // The server is on a different computer
   bool              m_bSendImageFiles; // The server needs the image files ( def. true )
   bool              m_bWaitInQueue;    // If the server has currently more then the set threads running
@@ -123,6 +218,9 @@ private:
   int               m_iKeepaliveTimer; // Checks if the server has a heartbeat
   QDateTime         m_lastPing;        // Last received ping
   int               m_iRetryCounter;   // The numer of times to try to re-establish the connection
+  QTimer           *m_NotificationTimer;  //xxx
+  int               m_socketDescriptor;   //xxx
+  QScopedPointer<QTcpSocket> m_socket;    //xxx
 };
 
 // Singleton class Manager
@@ -157,7 +255,7 @@ public:
     bool                 m_bRecoveryMode;
     bool                 m_bStartingServer; // After issuing the bash command through system() we should prevent other threads
 
-    QValueList<Client *> m_listOfClients;
+    QList<Client *>      m_listOfClients;	//oxx
   };
 
 public:
@@ -178,7 +276,7 @@ public:
 
   static Manager *m_pSelf; // Pointer to the sole instance of itself
   QMutex m_mutex;
-  QValueList<ServerInfo *> m_listOfServer;
+  QList<ServerInfo *> m_listOfServer;	//oxx
   QStringList              m_listFilterNames;
 };
 
