@@ -1,12 +1,18 @@
-/****************************************************************************
-** Rgba class to encapsulate color plus Alpha channel.
-**
-**   Created : Sat Nov 3'rd 2007
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    rgba.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   Rgba class to encapsulate color plus Alpha channel.
+
 ****************************************************************************/
+
+#include <QMessageBox>
+
 #include "rgba.h"
 
 
@@ -93,7 +99,8 @@ bool Rgba::fromString ( QString strColor )
   QRgb rgba  = 0x00FFFFFF;
   QString cleanColor;
   strColor   = strColor.remove ( "#" );
-  strColor   = strColor.upper ( );
+  //strColor   = strColor.upper ( );	//ooo
+  strColor   = strColor.toUpper ( );	//xxx
   cleanColor = strColor;
   if ( strColor.length ( ) == 3 ) {
     // Format = RGB -> convert to AARRGGBB
