@@ -1,14 +1,17 @@
-/****************************************************************************
-** rgba.h
-**   Created : Sat Nov 3'rd 2007
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-** License   : GPL v 2.0
-**
-** This class will superceed the QColor class and add an Alpha channel
-** to it.
-**
+/***************************************************************************
+    rgba.h
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class will superceed the QColor class and add an Alpha channel
+   to it.
+    
 ****************************************************************************/
+
 #ifndef RGBA_H
 #define RGBA_H
 
