@@ -1,17 +1,23 @@
-/****************************************************************************
-** ShadowObject class
-**
-**   Created : Tue Aug 08 22:06:51 2006
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class 
-**
+/***************************************************************************
+    shadowobject.cpp
+                             -------------------
+    ShadowObject class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class
+    
 ****************************************************************************/
 
 #include <math.h>
 #include <qpainter.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QPixmap>
+#include <QMouseEvent>
 
 #include "global.h"
 #include "xml_dvd.h"
@@ -257,15 +263,18 @@ void ShadowObject::drawShadow ( QPainter *pPainter )
 
   QRect objectRect = m_pMenuObject->rect ( );
 
-  QWMatrix theMatrix;
+  QMatrix theMatrix;
   //ImageManipulator *pManipulator = ;
   Modifiers *pModifiers = m_pMenuObject->modifiers ( );
   // Here we calculate the center point of gravity (rotation)
   QPoint centerPos;
-  centerPos.setX ( objectRect.x ( ) + (int) ( (float) objectRect.width  ( ) / 2.0 ) );
-  centerPos.setY ( objectRect.y ( ) + (int) ( (float) objectRect.height ( ) / 2.0 ) );
+  //centerPos.setX ( objectRect.x ( ) + (int) ( (float) objectRect.width  ( ) / 2.0 ) );    //ooo
+  centerPos.setX ( objectRect.x ( ) + static_cast<int> ( static_cast<float> ( objectRect.width  ( ) ) / 2.0 ) );  //xxx
+  //centerPos.setY ( objectRect.y ( ) + (int) ( (float) objectRect.height ( ) / 2.0 ) );    //ooo
+  centerPos.setY ( objectRect.y ( ) + static_cast<int> ( static_cast<float> ( objectRect.height ( ) ) / 2.0 ) );    //xxx
   // Here we define the cenetered rect.
-  QRect theRect ((int)-( objectRect.width ( ) / 2.0), (int)-( objectRect.height ( ) / 2.0 ), objectRect.width ( ), objectRect.height ( ) );
+  //QRect theRect ((int)-( objectRect.width ( ) / 2.0), (int)-( objectRect.height ( ) / 2.0 ), objectRect.width ( ), objectRect.height ( ) );   //ooo
+  QRect theRect (static_cast<int> (-( objectRect.width ( ) / 2.0)), static_cast<int> (-( objectRect.height ( ) / 2.0 )), objectRect.width ( ), objectRect.height ( ) ); //xxx
 
   // From the Qt documentation ...
   // This transformation engine is a three-step pipeline
@@ -274,7 +283,8 @@ void ShadowObject::drawShadow ( QPainter *pPainter )
   // The third step uses the viewport.
 
   // First we translate to the appropriate location,
-  theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );
+  //theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );   //ooo
+  theMatrix.translate ( static_cast<double>(centerPos.x ( )), static_cast<double>(centerPos.y ( )) );   //xxx
 
   // then we apply the other modifications ...
   theMatrix.scale  ( pModifiers->fScaleX, pModifiers->fScaleY );
@@ -282,7 +292,8 @@ void ShadowObject::drawShadow ( QPainter *pPainter )
   theMatrix.rotate ( pModifiers->fRotate );
 
   pPainter->setWorldMatrix ( theMatrix );
-  pPainter->drawImage ( theRect.x ( ) + deltaX ( ), theRect.y ( ) + deltaY ( ), m_imageShadow );
+  pPainter->drawImage ( theRect.x ( ) + deltaX ( ), theRect.y ( ) + deltaY ( ), m_imageShadow );  //ooo
+  //pPainter->drawImage ( theRect.x ( ) + deltaX ( ), theRect.y ( ) + deltaY ( ), m_imageShadow, 0, 0, 100, 50 );    //xxx
 
   theMatrix.reset ( );
   pPainter->setWorldMatrix ( theMatrix );
@@ -304,7 +315,7 @@ void ShadowObject::drawMirror ( QPainter *pPainter )
   int iX       = m_pMenuObject->rect ( ).x ( );
   int iY       = m_pMenuObject->rect ( ).y ( );
   enMType    mType = mirrorType      ( );
-  QWMatrix   theMatrix;
+  QMatrix   theMatrix;
   Modifiers *pModifiers = m_pMenuObject->modifiers ( );
 
   int iDeltaX = (int)( iWidth  / 2.0 * ( 1.0 - pModifiers->fScaleX ) );
@@ -345,7 +356,7 @@ void ShadowObject::drawReflection ( QPainter * )
 void ShadowObject::drawContents ( QPainter *pPainter, int iRenderFrameNumber, int )
 {
   // Next is to set the AnimationAttributes
-  for ( uint t=0; t<m_listAnimationAttributes.count ( ) ;t++ )
+  for ( uint t=0; t<(uint)m_listAnimationAttributes.count ( ) ;t++ )
     m_listAnimationAttributes[t]->setValue ( iRenderFrameNumber );
 
   // And then we ought to refresh the pixmap ...
@@ -390,11 +401,15 @@ StructureItem *ShadowObject::createStructure ( StructureItem *pParentItem )
   pShadowItem = m_pStructureItem;
   if ( ! pShadowItem ) {
     pShadowItem = new StructureItem ( this, StructureItem::Attributes, pParentItem, pParentItem->lastChild ( ), qsName, qsInfo );
-    pShadowItem->setExpandable ( TRUE );
+    //pShadowItem->setExpandable ( TRUE );  //ooo
+    pShadowItem->setExpanded ( true );      //xxx
     m_pStructureItem = pShadowItem;
   }
-  else
-    pShadowItem->setText ( qsName, qsInfo );
+  else {
+    //pShadowItem->setText ( qsName, qsInfo );  //ooo
+    pShadowItem->setText ( 0, qsName );         //xxx
+    pShadowItem->setText ( 1, qsInfo );         //xxx
+  }
 
   QString qsArgs;
 
@@ -557,7 +572,7 @@ void ShadowObject::createMirror ( MenuObject *pMenuObject, int iFrameWidth, bool
   if ( ! pMenuObject )
     return;
   // Now that we have the object to draw we should create the QImage - object ...
-  QWMatrix theMatrix;
+  QMatrix theMatrix;
   theMatrix.scale  ( m_fScaleX, m_fScaleY );
   theMatrix.shear  ( m_fShearX, m_fShearY );
 
@@ -578,7 +593,8 @@ void ShadowObject::createMirror ( MenuObject *pMenuObject, int iFrameWidth, bool
       pMenuObject->setRect      ( theRect );
       pMenuObject->drawContents ( &thePainter );
       // At this point we should have the image 
-      theImage = thePix.convertToImage ( );
+      //theImage = thePix.convertToImage ( );   //ooo
+      theImage = thePix.toImage ( );            //xxx
       filterColor ( theImage, backgroundColor );
     }
 
@@ -588,16 +604,20 @@ void ShadowObject::createMirror ( MenuObject *pMenuObject, int iFrameWidth, bool
     enMType mType = mirrorType ( );
     // Okay flip the image aongside the Y - Axis
     if ( ( mType == MIRROR_TOP ) || ( mType == MIRROR_BOTTOM ) )
-      theImage = theImage.mirror ( false, true );
+      //theImage = theImage.mirror ( false, true );     //ooo
+      theImage = theImage.mirrored ( false, true );     //xxx
     else
-      theImage = theImage.mirror ( true, false );
+      //theImage = theImage.mirror ( true, false );     //ooo
+      theImage = theImage.mirrored ( true, false );     //xxx
 
-    theImage.setAlphaBuffer ( true );
+    //theImage.setAlphaBuffer ( true );         //ooo
+    theImage.createAlphaMask ( Qt::AutoColor ); //xxx
     cutOffImage ( theImage, mType  );
     m_imageBuffer = theImage.copy( );
   }
   // If cut off has not changed, then we can use the buffered image.
-  m_imageShadow = m_imageBuffer.xForm ( theMatrix );
+  //m_imageShadow = m_imageBuffer.xForm ( theMatrix );      //ooo
+  m_imageShadow = m_imageBuffer.transformed ( theMatrix );  //xxx
   applyColorFading ( );
   blurShadow ( );
   applyTransparency ( );
@@ -709,15 +729,21 @@ void ShadowObject::createShadow ( MenuObject *pMenuObject, int iFrameWidth )
          ( pMenuObject->objectType ( ) == MOVIE_OBJECT ) )  {
       ImageObject *pImageObject = (ImageObject *)pMenuObject;
       QImage img = pImageObject->image ( ).copy ( );
-      img = img.convertDepth ( 32 );
-      theImage = QImage ( img.width ( ) + iOffset1, img.height ( ) + iOffset2, 32 ); //theRect.size ( ), 32 );
-      theImage.setAlphaBuffer ( true );
+      //img = img.convertDepth ( 32 );                      //ooo
+      img = img.convertToFormat ( QImage::Format_RGB32 );   //xxx
+      //theImage = QImage ( img.width ( ) + iOffset1, img.height ( ) + iOffset2, 32 ); //theRect.size ( ), 32 );    //ooo
+      theImage = QImage ( img.width ( ) + iOffset1, img.height ( ) + iOffset2, QImage::Format_RGB32 );              //xxx
+      //theImage.setAlphaBuffer ( true );           //ooo
+      theImage.createAlphaMask ( Qt::AutoColor );   //xxx
       QRgb  *pBits = (QRgb *)theImage.bits ( );
-      int    iSize = (int)( theImage.numBytes ( ) / 4.0 );
+      //int    iSize = (int)( theImage.numBytes ( ) / 4.0 );    //ooo
+      int    iSize = (int)( theImage.byteCount ( ) / 4.0 );     //xxx
       for ( int t=0; t<iSize; t++ )
         pBits[t] = 0x00FFFFFF;
 
-      bitBlt ( &theImage, iOffset1, iOffset2, &img );
+      //bitBlt ( &theImage, iOffset1, iOffset2, &img ); //ooo
+      QPainter p( &theImage );                          //xxx
+      p.drawImage( iOffset1, iOffset2, img );           //xxx
     }
     else  {  // Text, or Frame Objects
       QPixmap  thePix      ( r.width ( ) + iOffset2, r.height ( ) + iOffset2 );
@@ -727,8 +753,10 @@ void ShadowObject::createShadow ( MenuObject *pMenuObject, int iFrameWidth )
       pMenuObject->setRect ( theRect );
       pMenuObject->drawContents ( &thePainter );
       // At this point we should have thePix as we want/need with a shadowee backdrop
-      theImage = thePix.convertToImage ( );
-      theImage.setAlphaBuffer ( true );
+      //theImage = thePix.convertToImage ( );   //ooo
+      theImage = thePix.toImage ( );            //xxx
+      //theImage.setAlphaBuffer ( true );           //ooo
+      theImage.createAlphaMask ( Qt::AutoColor );   //xxx
       bImageOrText = false;
     }
   }
@@ -746,9 +774,12 @@ void ShadowObject::createShadow ( MenuObject *pMenuObject, int iFrameWidth )
   // transparency of the final shadow.
   // Thus we will create an image that has only one color and only modulate the 
   // transparency.
-  iRed   = m_color.red   ( );
-  iGreen = m_color.green ( );
-  iBlue  = m_color.blue  ( );
+  //iRed   = m_color.Qt::red   ( );	//ooo
+  iRed   = m_color.red   ( );		//xxx
+  //iGreen = m_color.Qt::green ( );	//ooo
+  iGreen = m_color.green ( );		//xxx
+  //iBlue  = m_color.Qt::blue  ( );	//ooo
+  iBlue  = m_color.blue  ( );		//xxx
   if ( bImageOrText )    {  // For performance reasons I check only once and have the loop in here twice
     for ( y=0;  y < m_imageShadow.height ( ); y++ ) {
       pLine = (QRgb *) m_imageShadow.scanLine ( y );
@@ -846,8 +877,8 @@ bool ShadowObject::filterColorKeys ( QImage &theShadow )
   // Next we create the min/max Color keys, to check if we ought to filter the pixel out or not
   ImageManipulator *pManipulator = &pImageObject->manipulator ( );
   QImage theImage   = pImageObject->image ( );
-  QValueList<QColor *>listColorKeyMin;
-  QValueList<QColor *>listColorKeyMax;
+  QList<QColor *>listColorKeyMin;		//oxx
+  QList<QColor *>listColorKeyMax;		//oxx
   QColor *pColorMin, *pColorMax, theColor, targetColor;
   QRgb thePixel, *pLine, *pShadowLine;
 
@@ -904,17 +935,21 @@ bool ShadowObject::filterColorKeys ( QImage &theShadow )
 
 // This function checks if pColor is within the min/max of one of the color keys.
 // Same as ImageObject::filterColorKey.
-bool ShadowObject::filterColorKey ( QColor *pColor, int iColorKeyCount, QValueList<QColor *> *pListColorMin, QValueList<QColor *>*pListColorMax )
+bool ShadowObject::filterColorKey ( QColor *pColor, int iColorKeyCount, QList<QColor *> *pListColorMin, QList<QColor *>*pListColorMax )		//oxx
 {
   int iRed, iGreen, iBlue, t;
 
   if ( ( iColorKeyCount < 1 ) || ( ! pListColorMin ) || ( ! pListColorMax ) )
     return false;
-  iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();
+  //iRed = pColor->Qt::red(); iGreen = pColor->Qt::green(); iBlue = pColor->Qt::blue ();	//ooo
+  iRed = pColor->red(); iGreen = pColor->green(); iBlue = pColor->blue ();			//xxx
   for (t=0;t<iColorKeyCount;t++)	{
-    if (	(iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) && 
-		(iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&
-		(iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )
+    //if (	(iRed   >= (*pListColorMin)[t]->Qt::red  () && iRed   <= (*pListColorMax)[t]->Qt::red  ()) &&		//ooo
+    if (	(iRed   >= (*pListColorMin)[t]->red  () && iRed   <= (*pListColorMax)[t]->red  ()) &&			//xxx
+		//(iGreen >= (*pListColorMin)[t]->Qt::green() && iGreen <= (*pListColorMax)[t]->Qt::green()) &&		//ooo
+		(iGreen >= (*pListColorMin)[t]->green() && iGreen <= (*pListColorMax)[t]->green()) &&			//xxx
+		//(iBlue  >= (*pListColorMin)[t]->Qt::blue () && iBlue  <= (*pListColorMax)[t]->Qt::blue ()) )		//ooo
+                (iBlue  >= (*pListColorMin)[t]->blue () && iBlue  <= (*pListColorMax)[t]->blue ()) )			//xxx
       return true;
   }
   return false;
