@@ -1,19 +1,24 @@
-/****************************************************************************
-** Shadow object 
-**
-**   Created : Sun Aug 08 21:45:00 20046
-**        by : Varol Okan using XEmacs
-** Copyright : (c) Varol Okan
-** License   : GPL v 2.0
-**
-**  This class will create a shadow of the associated MenuObject
-**
+/***************************************************************************
+    shadowobject.h
+                             -------------------
+    Shadow object
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class will create a shadow of the associated MenuObject
+    
 ****************************************************************************/
 
 #ifndef SHADOW_H
 #define SHADOW_H
 
 #include <qimage.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+//#include <Q3ValueList>	//oxx
 
 #include "imageobject.h"
 
@@ -100,7 +105,7 @@ protected:
   virtual AnimationAttribute *getSpecificAttributes (long, QString);
 
 private:
-  bool filterColorKey ( QColor *, int, QValueList<QColor *> *, QValueList<QColor *>* );
+  bool filterColorKey ( QColor *, int, QList<QColor *> *, QList<QColor *>* );		//oxx
   void blurShadow        ( );
   void applyTransparency ( );
   void applyColorFading  ( );
