@@ -1,14 +1,17 @@
-/****************************************************************************
-** slidedefaults.cpp
-**
-**   Created : 2009 June 7'th
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This file holds the implementation for the slideshow defaults which are
-** set in DialogSetup
-*****************************************************************************/
+/***************************************************************************
+    slidedefaults.cpp
+                             -------------------
+    MenuPreview class                             
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This file holds the implementation for the slideshow defaults which are
+   set in DialogSetup
+    
+****************************************************************************/
 
 #include <stdlib.h>
 #include <time.h>
@@ -16,6 +19,7 @@
 #include <qfileinfo.h>
 #include <qdom.h>
 #include <qdir.h>
+#include <QMessageBox>
 
 #include "global.h"
 #include "qdvdauthor.h"
@@ -58,7 +62,7 @@ SlideDefaults &SlideDefaults::operator = ( const SlideDefaults &theOther )
 }
 
 void SlideDefaults::initSlideshow ( CXmlSlideshow *pSlideshow )
-{
+{    
   if ( ! pSlideshow )
     return;
 
@@ -86,16 +90,22 @@ void SlideDefaults::initSlideshow ( CXmlSlideshow *pSlideshow )
       //int iIdx = (int)( ( (float) rand ( ) / RAND_MAX ) * tempList.size ( ) );
       int iIdx = rand ( )%tempList.size ( );
       QString qsAudio = tempList[iIdx];
-      tempList.remove ( qsAudio );
+      //tempList.remove ( qsAudio );	//ooo
+      tempList.removeOne ( qsAudio );	//xxx
       // Next we check if we found an audio file or a directory.
       QFileInfo fileInfo ( qsAudio );
       if ( fileInfo.isDir ( ) )  {
         QDir theDir ( qsAudio );
         theDir.setFilter      ( QDir::Files | QDir::Readable );
-        theDir.setNameFilter  ( qsAudioFilter );
-        QFileInfoList *pList = (QFileInfoList*)theDir.entryInfoList  ( );
-        iIdx = (int)( ( (float) rand ( ) / RAND_MAX ) * pList->count ( ) );
-        qsAudio = pList->at ( iIdx )->absFilePath ( );
+	QStringList qsAudioFilter_ ( qsAudioFilter );				//xxx
+        //theDir.setNameFilter  ( qsAudioFilter );				//ooo
+	theDir.setNameFilters  ( qsAudioFilter_ );				//xxx
+        //QFileInfoList *pList = (QFileInfoList*)theDir.entryInfoList  ( );	//ooo
+	QList<QFileInfo> pList = theDir.entryInfoList  ( );			//xxx
+        //iIdx = (int)( ( (float) rand ( ) / RAND_MAX ) * pList->count ( ) );	//ooo
+	iIdx = (int)( ( (float) rand ( ) / RAND_MAX ) * pList.count ( ) );	//xxx
+        //qsAudio = pList->at ( iIdx )->absFilePath ( );			//ooo
+	qsAudio = pList.at ( iIdx ).absoluteFilePath ( );			//xxx
         // found an issue with this file.
         if ( qsAudio.isEmpty ( ) )  {
           t --;
@@ -159,17 +169,17 @@ void SlideDefaults::readIniFile ( QDomElement &rootNode )
     if ( qsChildTag == QString ( TAG_BACKGROUND ) )  {
       qsChildText = childElem.text ( );
       if ( ! qsChildText.isEmpty ( ) )
-        m_listBackground = QStringList::split ( ",", qsChildText );
+        m_listBackground = qsChildText.split ( "," );
     }
     else if ( qsChildTag == QString ( TAG_AUDIO ) )  {
       qsChildText = childElem.text ( );
       if ( ! qsChildText.isEmpty ( ) )
-        m_listAudio = QStringList::split ( ",", qsChildText );
+        m_listAudio = qsChildText.split ( "," );
     }
     else if ( qsChildTag == QString ( TAG_TRANSITION ) )  {
       qsChildText = childElem.text ( );
       if ( ! qsChildText.isEmpty ( ) )
-        m_listTransitions = QStringList::split ( ",", qsChildText );
+        m_listTransitions = qsChildText.split ( "," );
     }
 
     xmlNode = xmlNode.nextSibling ( );
