@@ -1,16 +1,17 @@
-/*****************************************************************************
- ** Class SlideDefaults
- **
- ** This class stores the globally set parameters for th default values
- ** when creating a slideshow.
- **
- **   Created : Tue June 7 07:53:05 2009
- **        by : Varol Okan using the kate editor
- ** Copyright : (c) Varol Okan
- **   License : GPL v 2.0
- **
- **
- *****************************************************************************/
+/***************************************************************************
+    slidedefaults.h
+                             -------------------
+    Class SlideDefaults
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class stores the globally set parameters for th default values
+   when creating a slideshow.
+    
+****************************************************************************/
 
 #ifndef __SLIDE_DEFAULTS_H__
 #define __SLIDE_DEFAULTS_H__
