@@ -1,20 +1,29 @@
-/****************************************************************************
-** SourceFileEntry - class
-**
-**   Created : Tue Mar 22 12:09:08 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class is a simple container class to store the info
-** for a entry in the Source File List.
-**
+/***************************************************************************
+    sourcefileentry.cpp
+                             -------------------
+    SourceFileEntry - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is a simple container class to store the info
+   for a entry in the Source File List.
+    
 ****************************************************************************/
 
-#include <qfileinfo.h>
-#include <qimage.h>
-#include <qdom.h>
-#include <qdatetime.h>
+//#include <qfileinfo.h>	//ooo
+#include <QFileInfo>		//xxx
+//#include <qimage.h>		//ooo
+#include <QImage>		//xxx
+//#include <qdom.h>		//ooo
+#include <QtXml/QDomElement>	//xxx
+//#include <qdatetime.h>	//ooo
+#include <QDateTime>		//xxx
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QMessageBox>		//xxx
 
 #include "global.h"
 #include "utils.h"
@@ -22,7 +31,7 @@
 #include "messagebox.h"
 #include "sourcefileentry.h"
 #include "xml_slideshow.h"
-#include "render_client.h"
+//#include "render_client.h"	//ooo
 
 AudioEntry::AudioEntry ( )
 {
@@ -114,7 +123,7 @@ bool Audio::readProjectFile  ( QDomNode &xmlNode )
 }
 
 bool Audio::writeProjectFile ( QDomElement &inElement )
-{
+{ 
   QDomDocument xmlDoc = inElement.ownerDocument();
   QDomElement  tmpFileElement, theElement, transcodeElement;
   QDomText     text;
@@ -127,7 +136,8 @@ bool Audio::writeProjectFile ( QDomElement &inElement )
 
   // store the file name too ...
   tmpFileElement = xmlDoc.createElement( AUDIO_FILE_NAME );
-  text = xmlDoc.createTextNode( qsFileName.utf8 ( ) );
+  //text = xmlDoc.createTextNode( qsFileName.utf8 ( ) );	//ooo
+  text = xmlDoc.createTextNode( qsFileName.toUtf8 ( ) );	//xxx
   tmpFileElement.appendChild( text );
   theElement.appendChild ( tmpFileElement );
   if ( pTranscodeInterface )  {
@@ -206,7 +216,7 @@ bool TranscodeInterface::operator != (const TranscodeInterface &theOther)
 }
 
 bool TranscodeInterface::readProjectFile  (QDomNode &xmlNode)
-{
+{ 
   QString qsAttribute;
   QDomElement theElement = xmlNode.toElement();
 
@@ -417,17 +427,20 @@ QString SourceFileInfo::getFileName ()
         qsReturn = arraySubtitles[t]->m_qsTempFile;
     }
     if ( qsReturn.isEmpty ( ) )
-      qsReturn = QString ( "%1/subtitles.vob" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) );
+      //qsReturn = QString ( "%1/subtitles.vob" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) );	//ooo
+      qsReturn = QString ( "%1/subtitles.vob" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( ) ) );		//xxx
     return qsReturn;
   }
   if ( pTranscodeInterface ) {
     if ( ! pTranscodeInterface->qsTempFile.isEmpty () )
       return pTranscodeInterface->qsTempFile;
     else  // nothing in so we should create the file name
-      return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) ).arg( fileInfo.baseName ( TRUE ) );
+      //return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) ).arg( fileInfo.baseName ( TRUE ) );	//ooo
+      return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( ) ) ).arg( fileInfo.baseName ( ) );		//xxx
   }
   else if ( audioCount ( ) > 0 )
-    return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) ).arg( fileInfo.baseName ( TRUE ) );
+    //return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( TRUE ) ) ).arg( fileInfo.baseName ( TRUE ) );	//ooo
+    return QString ( "%1/%2.mpeg2" ).arg ( theUtils.getTempPath ( fileInfo.baseName ( ) ) ).arg( fileInfo.baseName ( ) );		//xxx
 
   return qsFileName;
 }
@@ -530,7 +543,8 @@ bool SourceFileInfo::readProjectFile ( QDomNode &xmlNode )
     }
     else if ( SOURCE_OBJECT_CHAPTERS == infoName )  {
       if ( ! infoText.isEmpty ( ) )
-        listChapters = QStringList::split (",", infoText);
+        //listChapters = QStringList::split (",", infoText);	//ooo
+	listChapters = infoText.split (",");			//xxx
     }
     else if ( SOURCE_OBJECT_PROPERTIES == infoName )  {
       qsAttribute = infoElement.attributeNode ( SOURCE_PROPERTIES_POST ).value ( );
@@ -753,12 +767,12 @@ SourceFileEntry::SourceFileEntry ( )
 SourceFileEntry::~SourceFileEntry()
 {
 	uint t;
-	for (t=0;t<listFileInfos.count();t++)	
+	for (t=0;t<(uint)listFileInfos.count();t++)	//oxx
 		delete listFileInfos[t];
 }
 
 bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
-{
+{ 
   int t;
   QString qsAttribute, infoName, infoText;
 
@@ -833,7 +847,8 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
     }
     else if (SOURCE_OBJECT_CHAPTERS == tagName)	{
       infoText = theElement.text ();
-      listChapters = QStringList::split ( QString (","), infoText);
+      //listChapters = QStringList::split ( QString (","), infoText);	//ooo
+      listChapters = infoText.split ( "," );				//xxx
     }
     // Otherwise go to the next node ...
     sourceNode = sourceNode.nextSibling();
@@ -850,7 +865,7 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
       QFileInfo fileInfo ( qsFileName );
       if ( ! fileInfo.exists ( ) ) { // generated file does not exist.
         bIsSlideshow = true;
-        Render::Manager::registerEntry ( this );
+        //Render::Manager::registerEntry ( this );	//ooo
       }
     }
   }
@@ -865,7 +880,7 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
 }
 
 bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave )
-{
+{ 
   uint t;
   SourceFileInfo *pInfo;
   QDomDocument   xmlDoc     = theElement.ownerDocument ( );
@@ -902,7 +917,7 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave
   }
 
   if (listFileInfos.count() > 0)	{
-    QValueList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );
+    QList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );	//oxx
     while ( it != listFileInfos.end ( ) )  {
       pInfo = *it++;
       pInfo->writeProjectFile ( sourceNode, bAutosave );
@@ -1020,7 +1035,7 @@ void SourceFileEntry::changeAudioTrack ( uint iAudioNumber, QString qsCode )
   if ( iAudioNumber >= MAX_AUDIO )
     return;
 
-  QValueList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );	//oxx
   while ( it != listFileInfos.end ( ) )  {
     pInfo = *it++;
     if ( pInfo->arrayAudio[iAudioNumber] )  {
@@ -1047,7 +1062,7 @@ void SourceFileEntry::changeSubtitleTrack ( uint iSubtitleNumber, QString qsCode
   if ( iSubtitleNumber >= MAX_SUBTITLES )
     return;
 
-  QValueList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );	//oxx
   while ( it != listFileInfos.end ( ) )  {
     pInfo = *it++;
     if ( pInfo->arraySubtitles[iSubtitleNumber] )  {
@@ -1075,7 +1090,7 @@ void SourceFileEntry::synchTracks ( bool bSynchAudioTracks, bool bSynchSubtitleT
   SubtitleEntry *pSubtitleEntry;
   SourceFileInfo *pInfo;
 
-  QValueList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );
+  QList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );	//oxx
   while ( it != listFileInfos.end ( ) )  {
     pInfo = *it++;
     if ( bSynchAudioTracks )  {
@@ -1108,14 +1123,14 @@ SourceFileEntry & SourceFileEntry::operator = (SourceFileEntry &theOther)
 	SourceFileInfo *pInfo;
 	// First we take care of the entries in the list. Please note that we should keep the current ones around
 	// in case we are cloning this entry.
-	QValueList<SourceFileInfo *> listTemp2;
-	for (t=0;t<theOther.listFileInfos.count();t++)	{
+	QList<SourceFileInfo *> listTemp2;		//oxx
+	for (t=0;t<(uint)theOther.listFileInfos.count();t++)	{	//oxx
 		pInfo = new SourceFileInfo ();
 		*pInfo = *theOther.listFileInfos[t];
 		listTemp2.append (pInfo);
 	}
 	// Now we should be save here to remove the entries ...	
-	for (t=0;t<listFileInfos.count ();t++)
+	for (t=0;t<(uint)listFileInfos.count ();t++)	//oxx
 		delete listFileInfos[t];
 	listFileInfos.clear();
 
