@@ -1,14 +1,16 @@
-/****************************************************************************
-** SourceFileEntry - class
-**
-**   Created : Tue Mar 22 12:09:08 2004
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-** License   : GPL v 2.0
-**
-** This class is a simple container class to store the info
-** for a entry in the Source File List.
-**
+/***************************************************************************
+    sourcefileentry.h
+                             -------------------
+    SourceFileEntry - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is a simple container class to store the info
+   for a entry in the Source File List.
+    
 ****************************************************************************/
 
 #ifndef SOURCEFILEENTRY_H
@@ -17,8 +19,10 @@
 #include <qstringlist.h>
 #include <qfont.h>
 #include <qsize.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
-#include "subtitles.h"
+#include "subtitles.h"	//ooo
 
 class QImage;
 class QDomNode;
@@ -161,7 +165,7 @@ public:
 	void changeSubtitleTrack ( uint, QString );
 
 	QString qsDisplayName;          // The name that appears on the display
-	QValueList <SourceFileInfo *> listFileInfos;
+	QList <SourceFileInfo *> listFileInfos;			//oxx
 	QStringList listChapters;       // The chapters of this SourceFile entry
 	bool bIsSlideshow;              // Will be re-set, once the slideshow has been created into a mpeg2 movie.
 	bool bSoundSource;              // Indicates if this is a movie or a Sound source
