@@ -1,27 +1,47 @@
-/****************************************************************************
-** Subtitles - class
-**
-**   Created : Tue Dec 27 12:09:08 2006
-**        by : Varol Okan using XEmacs editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class encapsulates the attributes for the subtitle generation.
-**
+/***************************************************************************
+    subtitles.cpp
+                             -------------------
+    Subtitles - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class encapsulates the attributes for the subtitle generation.
+    
 ****************************************************************************/
 
-#include <qdesktopwidget.h>
-#include <qprogressbar.h>
-#include <qapplication.h>
-#include <qdatetime.h>
-#include <qtextedit.h>
-#include <qfileinfo.h>
-#include <qpainter.h>
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qimage.h>
-#include <qdom.h>
-#include <qdir.h>
+//#include <qdesktopwidget.h>	//ooo
+#include <QDesktopWidget>	//xxx
+//#include <q3progressbar.h>	//ooo
+#include <QProgressBar>		//xxx
+//#include <qapplication.h>	//ooo
+#include <QApplication>		//xxx
+//#include <qdatetime.h>	//ooo
+#include <QDateTime>		//xxx
+//#include <q3textedit.h>	//ooo
+#include <QTextEdit>		//xxx
+//#include <qfileinfo.h>	//ooo
+#include <QFileInfo>		//xxx
+//#include <qpainter.h>		//ooo
+#include <QPainter>		//xxx
+//#include <qdialog.h>		//ooo
+#include <QDialog>		//xxx
+//#include <qlayout.h>		//ooo
+#include <QLayout>		//xxx
+//#include <qimage.h>		//ooo
+#include <QImage>		//xxx
+//#include <qdom.h>		//ooo
+#include <QtXml/QDomElement>		//xxx
+//#include <qdir.h>		//ooo
+#include <QDir>			//xxx
+//Added by qt3to4:
+//#include <Q3GridLayout>	//ooo
+#include <QGridLayout>		//xxx
+#include <QPixmap>
+
+#include <QMessageBox>		//xxx
 
 #include "global.h"
 #include "utils.h"
@@ -88,7 +108,7 @@ Subtitles::Subtitles (  int iWidth, int iHeight )
 
 Subtitles::~Subtitles ()
 {
-  for (uint t=0;t<m_listOfSubtitles.count(); t++)
+  for (uint t=0;t<(uint)m_listOfSubtitles.count(); t++)		//oxx
     delete m_listOfSubtitles[t];
   m_listOfSubtitles.clear ();
 }
@@ -115,12 +135,12 @@ Subtitles &Subtitles::operator = ( Subtitles &theOther )
     m_subColors[t] = theOther.m_subColors[t];
 
   if ( m_listOfSubtitles.count () ) {
-    for ( t=0;t<theOther.m_listOfSubtitles.count();t++) 
+    for ( t=0;t<(uint)theOther.m_listOfSubtitles.count();t++) 	//oxx
       delete m_listOfSubtitles[t];
   }
   m_listOfSubtitles.clear ();
 
-  for ( t=0;t<theOther.m_listOfSubtitles.count();t++) {
+  for ( t=0;t<(uint)theOther.m_listOfSubtitles.count();t++) {	//oxx
     entry *pNewEntry = new entry;
     *pNewEntry = *theOther.m_listOfSubtitles[t];
     m_listOfSubtitles.append ( pNewEntry );
@@ -130,7 +150,7 @@ Subtitles &Subtitles::operator = ( Subtitles &theOther )
 }
 
 bool Subtitles::readProjectFile ( QDomNode &xmlNode )
-{
+{ 
   int t;
   QString     qsAttribute, infoName, infoText;
   QDomNode    infoNode;
@@ -177,7 +197,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   qsAttribute = theElement.attributeNode ( SUBTITLES_RECT ).value();
   if ( ! qsAttribute.isEmpty ( ) ) {
     // QString "x,y,width,height" 
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );	//ooo
+    QStringList list = qsAttribute.split ( "," );			//xxx
     QRect theRect;
     if (list.count() == 4)
       theRect = QRect(list[0].toInt(), list[1].toInt(),  list[2].toInt(),  list[3].toInt() );
@@ -186,7 +207,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   qsAttribute = theElement.attributeNode ( SUBTITLES_VIDEO_SIZE ).value();
   if ( ! qsAttribute.isEmpty ( ) ) {
     // QString "x,y,width,height" 
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );	//ooo
+    QStringList list =  qsAttribute.split ( "," );			//xxx
     QSize theSize;
     if ( list.count ( ) == 2)
       theSize = QSize ( list[0].toInt ( ), list[1].toInt ( ) );
@@ -195,7 +217,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   qsAttribute = theElement.attributeNode ( SUBTITLES_ALIGNMENT ).value();
   if ( ! qsAttribute.isEmpty ( ) ) {
     // QString "x,y,width,height" 
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );	//ooo
+    QStringList list = qsAttribute.split ( "," );			//xxx
     QPoint theAlignment;
     if (list.count() == 2)
       theAlignment = QPoint( list[0].toInt(), list[1].toInt() );
@@ -203,7 +226,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   }
   qsAttribute = theElement.attributeNode ( SUBTITLES_COLORS ) .value ();
   if ( ! qsAttribute.isEmpty ( ) ) {
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );	//ooo
+    QStringList list = qsAttribute.split ( "," );			//xxx
     if ( list.count() == MAX_SUBTITLE_COLORS ) {
       for ( t=0;t<MAX_SUBTITLE_COLORS; t++ )
         m_subColors[t].fromString ( list[t] );
@@ -212,7 +236,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   qsAttribute = theElement.attributeNode ( SUBTITLES_TRANSPARENCY ) .value ();
   if ( ! qsAttribute.isEmpty ( ) ) {
     // old format when color / transparency was separate.
-    QStringList list = QStringList::split ( ",", qsAttribute );
+    //QStringList list = QStringList::split ( ",", qsAttribute );	//ooo
+    QStringList list = qsAttribute.split ( "," );			//xxx
     if ( list.count ( ) == MAX_SUBTITLE_COLORS ) {
       for ( t=0;t<MAX_SUBTITLE_COLORS; t++ )  
 	m_subColors[t].setAlpha ( list[t].toInt ( ) );
@@ -253,7 +278,7 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
 }
 
 bool Subtitles::writeProjectFile ( QDomElement &inElement )
-{
+{ 
   uint t;
   QDomDocument xmlDoc = inElement.ownerDocument();
   QDomElement  infoElement, tmpFileElement, theElement;
@@ -299,7 +324,7 @@ bool Subtitles::writeProjectFile ( QDomElement &inElement )
   }
 
   if ( m_listOfSubtitles.count ( ) > 0)	{
-    for (t=0;t<m_listOfSubtitles.count();t++)	{
+    for (t=0;t<(uint)m_listOfSubtitles.count();t++)	{	//oxx
       pEntry = m_listOfSubtitles[t];
       infoElement = xmlDoc.createElement( SUBTITLES_SUBTITLE_ENTRY );
       infoElement.setAttribute( SUBTITLES_SUBTITLE_INDEX, QString ("%1").arg( pEntry->iIndex ) );
@@ -342,7 +367,8 @@ QString Subtitles::getXMLFileName ()
 
   qsReturn = m_qsXmlFile;
   if ( m_qsXmlFile.isEmpty ( ) )
-    qsReturn = QString ("%1/%2_%3.xml").arg( fileInfo.filePath () ).arg ( fileInfo.baseName ( TRUE ).arg ( m_iSubtitleNumber ) );
+    //qsReturn = QString ("%1/%2_%3.xml").arg( fileInfo.filePath () ).arg ( fileInfo.baseName ( TRUE ).arg ( m_iSubtitleNumber ) );	//ooo
+    qsReturn = QString ("%1/%2_%3.xml").arg( fileInfo.filePath () ).arg ( fileInfo.baseName ( ).arg ( m_iSubtitleNumber ) );		//xxx
   return qsReturn;
 }
 
@@ -431,21 +457,24 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   QRect     theRect;
   QPainter  thePainter;
   QDialog   progressDialog   ( NULL );
-  QProgressBar *pProgressBar = NULL;
+  //Q3ProgressBar *pProgressBar = NULL;		//ooo
+  QProgressBar *pProgressBar = NULL;		//xxx
   QFileInfo fileInfo ( qsFileInfoName );
   iTotalCount = (int)m_listOfSubtitles.count ( );
 
   // The following widgets will create the progress dialog on the fly.
   if ( iTotalCount > 20 ) { // no progress for only a few subtitles.
-    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );
-    pProgressBar = new QProgressBar ( &progressDialog );
+    //Q3GridLayout  *pProgressLayout = new Q3GridLayout  ( &progressDialog );	//ooo
+    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );	//xxx
+    //pProgressBar = new Q3ProgressBar ( &progressDialog );	//ooo
+    pProgressBar = new QProgressBar ( &progressDialog );	//xxx
     pProgressLayout->addWidget( pProgressBar, 0, 0 );
     progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
     progressDialog.show  ( );
   }
   Subtitles::entry *pEntry;
   qsLang = theUtils.iso639  ( m_qsIso639, false );
-  progressDialog.setCaption ( QObject::tr ( "Creating %1 Subtitles[%2] for %3" ).arg ( qsLang ).arg ( m_iSubtitleNumber ).arg ( fileInfo.fileName ( ) ) );
+  //progressDialog.setCaption ( QObject::tr ( "Creating %1 Subtitles[%2] for %3" ).arg ( qsLang ).arg ( m_iSubtitleNumber ).arg ( fileInfo.fileName ( ) ) );	//ooo
 
   qsSubIdx.sprintf ( "/sub%02d_", m_iSubtitleNumber );
   qsThePath = qsBasePath + qsSubIdx;
@@ -484,7 +513,8 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   QRect boundingRect;
   iTotalCount = (int)m_listOfSubtitles.count ();
   // Processing some Qt events / messages
-  qApp->processEvents ( 100 ); // do some event processing ...
+  //qApp->processEvents ( 100 ); // do some event processing ...				//ooo
+  qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
 
   int    iDiameter = m_iOutline*2 + 1;
   QImage theBrush;
@@ -492,14 +522,16 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     // First we need to create a brush to follow ...
     QPixmap  createCircle ( iDiameter, iDiameter ); //, 1 ); // monochrome pixmap
     QPainter circlePainter;
-    QPen     circlePen  ( colors[1], 1, Qt::SolidLine );
+    //QPen     circlePen  ( colors[1], 1, Qt::SolidLine );			//ooo
+    QPen     circlePen  ( QBrush(QColor(colors[1])), 1, Qt::SolidLine );	//xxx
     circlePainter.begin ( &createCircle ); {
       createCircle.fill ( colors[0] );
       circlePainter.setPen   ( circlePen );
       circlePainter.setBrush ( QBrush ( colors[1] ) );
       circlePainter.drawEllipse ( 0, 0, iDiameter, iDiameter );
     } circlePainter.end ( );
-    theBrush = createCircle.convertToImage ( );
+    //theBrush = createCircle.convertToImage ( );	//ooo
+    theBrush = createCircle.toImage ( );		//xxx
     // Then we reduce the colors to the max avail color space.
     theUtils.reduceColors ( theBrush, 2, (QRgb *)&colors );
   }
@@ -507,15 +539,16 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   iWidth  = m_rect.width  ( );
   iHeight = m_rect.height ( );
 
-  QTextEdit edit ( NULL );
-  QStyleSheet *pStyleSheet = edit.styleSheet ( ); // modify blockquote stylesheet to remove 40px margins left and right
-  QStyleSheetItem *pStyle = NULL;
+  //Q3TextEdit edit ( NULL );	//ooo
+  QTextEdit edit ( NULL );	//xxx
+  /*Q3StyleSheet *pStyleSheet = edit.styleSheet ( ); // modify blockquote stylesheet to remove 40px margins left and right
+  Q3StyleSheetItem *pStyle = NULL;
   if ( pStyleSheet )  {
-    pStyle = new QStyleSheetItem ( pStyleSheet, "qdvd" );
+    pStyle = new Q3StyleSheetItem ( pStyleSheet, "qdvd" );
     if ( pStyle )  {
-      pStyle->setDisplayMode ( QStyleSheetItem::DisplayBlock );
-      pStyle->setMargin ( QStyleSheetItem::MarginLeft,  4 + m_iOutline );
-      pStyle->setMargin ( QStyleSheetItem::MarginRight, 4 + m_iOutline );
+      pStyle->setDisplayMode ( Q3StyleSheetItem::DisplayBlock );
+      pStyle->setMargin ( Q3StyleSheetItem::MarginLeft,  4 + m_iOutline );
+      pStyle->setMargin ( Q3StyleSheetItem::MarginRight, 4 + m_iOutline );
       if ( m_alignment.x ( ) == 1 ) // AlignCenter
         pStyle->setAlignment ( Qt::AlignHCenter );
       if ( m_alignment.x ( ) == 2 ) // AlignLeft
@@ -526,17 +559,18 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
         pStyle->setAlignment ( Qt::AlignJustify );
     }
     // edit.setStyleSheet ( pStyleSheet ); not required ...
-  }
+  }*/	//ooo
 
-  edit.setPaletteBackgroundColor ( colors[0] );
-  edit.setPaletteForegroundColor ( colors[1] );
-  edit.setTextFormat ( Qt::RichText );
+  //edit.setPaletteBackgroundColor ( colors[0] );	//ooo
+  //edit.setPaletteForegroundColor ( colors[1] );	//ooo
+  //edit.setTextFormat ( Qt::RichText );		//ooo
   edit.resize   ( iWidth + 2 * ( m_iOutline + 4 ), iHeight + 2 * ( m_iOutline + 4 ) );
   edit.setFont  ( m_font  );
 
   // This is to set the edit.viewport() to max width, so one line of text does not get word wrapped.
   edit.setText ( "<p>12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890</p>" );
-  qApp->processEvents ( 100 ); // do some event processing ...
+  //qApp->processEvents ( 100 ); // do some event processing ...				//ooo
+  qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
 
   for ( t=0; t<iTotalCount; t++ )  {
     theRect = m_rect;
@@ -553,11 +587,11 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     qsText = qsText.replace ( "\n", "<br>" );
 
     edit.setText   ( "<qdvd>" + qsText + "</qdvd>" );
-    boundingRect = edit.paragraphRect ( 0 );
+    //boundingRect = edit.paragraphRect ( 0 );		//ooo
     QPixmap theDrawingBoard = QPixmap::grabWidget ( edit.viewport ( ) );
-    boundingRect.setX ( boundingRect.x ( ) + m_iOutline + 4 );
+    /*boundingRect.setX ( boundingRect.x ( ) + m_iOutline + 4 );
     boundingRect.setY ( boundingRect.y ( ) + m_iOutline + 4 );
-    boundingRect.setWidth ( iWidth );
+    boundingRect.setWidth ( iWidth );*/		//ooo
 
 /*
 QString qq=qsHorizAlign + pEntry->qsText + qsHorizAlignClose;
@@ -580,10 +614,10 @@ theDrawingBoard.save ( q, "PNG" );
       h = theRect.height ( ); // should be iHeight
       // We should always adjust the height
       if ( m_bFit ) {
-        x = boundingRect.x      ( ) - m_iOutline;
+        /*x = boundingRect.x      ( ) - m_iOutline;
         y = boundingRect.y      ( ) - m_iOutline;
         w = boundingRect.width  ( ) + m_iOutline * 2;
-        h = boundingRect.height ( ) + m_iOutline * 2;
+        h = boundingRect.height ( ) + m_iOutline * 2;*/		//ooo
         if ( x <  0 )       x = 0;
         if ( y <  0 )       y = 0;
         if ( w >= iWidth  ) w = iWidth -1;
@@ -604,12 +638,13 @@ theDrawingBoard.save ( q, "PNG" );
 
       // create new dimensioned pixmap
       QPixmap thePixmap = QPixmap ( w, h );
-#if ( QT_VERSION > 0x0301FF )
-      copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h );
-#else
-      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP );
-#endif
-      theImage = thePixmap.convertToImage ( );
+//#if ( QT_VERSION > 0x0301FF )		//ooo
+      //copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h );	//ooo
+//#else
+//      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP );
+//#endif
+      //theImage = thePixmap.convertToImage ( );	//ooo
+      theImage = thePixmap.toImage ( );			//xxx
 
     }  thePainter.end ( );
 
@@ -637,11 +672,13 @@ theDrawingBoard.save ( q, "PNG" );
         iOffsetY = theRect.height ( ) - temp.height ( );
 
       // and finally we'll have to copy the text to the right position
-      bitBlt ( &theImage, iOffsetX, iOffsetY, &temp );
+      //bitBlt ( &theImage, iOffsetX, iOffsetY, &temp );	//oooo
+      QPainter p( &theImage );					//xxx
+      p.drawImage( iOffsetX, iOffsetY, temp );			//xxx
     }
 
     // Enable transparency ...
-    theImage.setAlphaBuffer ( true );
+    //theImage.setAlphaBuffer ( true );		//ooo
 
     // Then we reduce the colors to the max avail color space.
     theUtils.reduceColors ( theImage, MAX_SUBTITLE_COLORS, (QRgb *)&colors );
@@ -678,7 +715,8 @@ theDrawingBoard.save ( q, "PNG" );
 
     if ( m_iOutline > 0 ) {
       // Next is to inclrease the number of colors to 4
-      theImage.setNumColors ( 4 );
+      //theImage.setNumColors ( 4 );	//ooo
+      theImage.setColorCount ( 4 );	//xxx
       //theImage.setColor ( 3, 0xFF101010 ); // FF == Opaque // 00=Transparent
       theImage.setColor ( 0, 0x00000000 );
       theImage.setColor ( 3, m_subColors[0].rgb ( ) ); //real deal ...
@@ -715,9 +753,11 @@ theDrawingBoard.save ( q, "PNG" );
     theImage.save ( qsFileName, "PNG", 100 );  // 100%== No compression. png image
 
     if ( ( iTotalCount > 20 ) && ( pProgressBar ) ) {
-      pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );
+      //pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );	//ooo
+      pProgressBar->setValue ( (int)((float)t / iTotalCount * 100.0) );		//xxx
       if ( t%10 == 0 ) 
-        qApp->processEvents ( 100 ); // do some event processing ...
+        //qApp->processEvents ( 100 ); // do some event processing ...					//ooo
+	qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
     }
   }
   // that's it ...
@@ -747,14 +787,16 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   QRect     theRect;
   QPainter  thePainter;
   QDialog   progressDialog   ( NULL );
-  QProgressBar *pProgressBar = NULL;
+  //Q3ProgressBar *pProgressBar = NULL;		//ooo
+  QProgressBar *pProgressBar = NULL;		//xxx
   QFileInfo fileInfo ( qsFileInfoName );
   iTotalCount = (int)m_listOfSubtitles.count ( );
 
   // The following widgets will create the progress dialog on the fly.
   if ( iTotalCount > 20 ) { // no progress for only a few subtitles.
-    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );
-    pProgressBar = new QProgressBar ( &progressDialog );
+    Q3GridLayout  *pProgressLayout = new Q3GridLayout  ( &progressDialog );
+    //pProgressBar = new Q3ProgressBar ( &progressDialog );	//ooo
+    pProgressBar = new QProgressBar ( &progressDialog );	//xxx
     pProgressLayout->addWidget( pProgressBar, 0, 0 );
     progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
     progressDialog.show  ( );
@@ -801,7 +843,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
   QRect boundingRect;
   QPen  thePen ( colors[1], 2, Qt::DashDotLine );
-  int   iFlags = Qt::DontClip | Qt::WordBreak;
+  int   iFlags = Qt::TextDontClip | Qt::TextWordWrap;
 
   switch   ( m_alignment.x ( ) ) {
   case 2:
@@ -829,7 +871,8 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
   iTotalCount = (int)m_listOfSubtitles.count ();
   // Processing some Qt events / messages
-  qApp->processEvents ( 100 ); // do some event processing ...
+  //qApp->processEvents ( 100 ); // do some event processing ...				//ooo
+  qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
 
   int    iDiameter = m_iOutline*2 + 1;
   QImage theBrush;
@@ -903,11 +946,11 @@ theDrawingBoard.save ( q, "PNG" );
 
       // create new dimensioned pixmap
       QPixmap thePixmap = QPixmap ( w, h );
-#if ( QT_VERSION > 0x0301FF )
+//#if ( QT_VERSION > 0x0301FF )		//ooo
       copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h );
-#else
-      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP);
-#endif
+//#else
+//      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP);
+//#endif
       theImage = thePixmap.convertToImage ( );
     }  thePainter.end ( );
     // Enable transparency ...
@@ -987,7 +1030,8 @@ theDrawingBoard.save ( q, "PNG" );
     if ( ( iTotalCount > 20 ) && ( pProgressBar ) ) {
       pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );
       if ( t%10 == 0 ) 
-        qApp->processEvents ( 100 ); // do some event processing ...
+        //qApp->processEvents ( 100 ); // do some event processing ...					//ooo
+	qApp->processEvents ( QEventLoop::AllEvents, 100 ); // do some event processing ...		//xxx
     }
   }
   // that's it ...
@@ -1054,10 +1098,11 @@ void Subtitles::cutHorizontal ( QImage &img, QRgb filter )
 
   iWidth  = iMaxX-iMinX;
   iHeight = iMaxY-iMinY;
-  QImage image ( iWidth, iHeight, 32 );
+  //QImage image ( iWidth, iHeight, 32 );			//ooo
+  QImage image ( iWidth, iHeight, QImage::Format_RGB32 );	//xxx
 
   // Now we have the min/max values, lets cut the cake ...
-  bitBlt ( &image, 0, 0, &img, iMinX, iMinY, iWidth, iHeight );
+  //bitBlt ( &image, 0, 0, &img, iMinX, iMinY, iWidth, iHeight );	//ooo
   img = image;
 }
 
@@ -1086,7 +1131,8 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
     }
   }
   // lastly we see if we can extract the MetaInfo ( DV only at this time )
-  if ( fileInfo.extension ( ).lower ( ) != "dv" )
+  //if ( fileInfo.extension ( ).lower ( ) != "dv" )	//ooo
+  if ( fileInfo.suffix ( ).toLower ( ) != "dv" )	//xxx
     return;
 
   // Okay we do actually want to create subtitles here ...    
@@ -1101,7 +1147,8 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
   fFPS =  pInfo->qsFPS.toFloat ( &bOkay );
   if ( ( ! bOkay ) || ( fFPS < 19.0f ) ) {
     fFPS = 29.97f;
-    if ( pInfo->qsVideoFormat.upper ( ) == "PAL" )  {
+    //if ( pInfo->qsVideoFormat.upper ( ) == "PAL" )  {		//ooo
+    if ( pInfo->qsVideoFormat.toUpper ( ) == "PAL" )  {		//xxx
       fFPS = 25.0f;
       rect = QRect ( 0, 0, 720, 576 );
     }
@@ -1114,7 +1161,8 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
 
   fileInfo.setFile  ( pInfo->qsFileName );
   qsXmlFile.sprintf ( "/subtitle_%d.xml", iFirstNewSubtitleNumber );
-  qsXmlFile = theUtils.getTempFile ( fileInfo.baseName ( TRUE ) ) + qsXmlFile;
+  //qsXmlFile = theUtils.getTempFile ( fileInfo.baseName ( TRUE ) ) + qsXmlFile;	//ooo
+  qsXmlFile = theUtils.getTempFile ( fileInfo.baseName ( ) ) + qsXmlFile;		//xxx
 
   pSubtitles = new Subtitles ( rect.width ( ), rect.height ( ) );
   // Set subtitle parameters ...
