@@ -36,20 +36,28 @@
 #include <unistd.h>
 #endif
 
-#include <qprogressbar.h>
+//#include <q3progressbar.h>    //ooo
+#include <QProgressBar> //xxx
 #include <qradiobutton.h>
 #include <qpushbutton.h>
 #include <qtabwidget.h>
 #include <qcombobox.h>
-#include <qtextedit.h>
-#include <qiconview.h>
-#include <qprocess.h>
+//#include <q3textedit.h>   //ooo
+#include <QTextEdit>    //xxx
+//#include <q3iconview.h>   //ooo
+#include <QGraphicsView>        //xxx
+//#include <q3process.h>    //ooo
+//#include <QProcess>  //xxx>
 #include <qlabel.h>
 #include <qfile.h>
 #include <qdir.h>
 
 
-#include <qnetwork.h>
+//#include <q3network.h>    //ooo
+//#include <QNetworkAccessManager>    //xxx
+//Added by qt3to4:
+//#include <Q3TextStream>   //ooo
+#include <QTextStream>  //xxx
 
 #include "win32.h"
 #include "CONFIG.h"
@@ -146,26 +154,48 @@ void TemplateDownload::Xml::clear ( )
 // Download - dialog for the Templates.
 //
 /////////////////////////////////////////////////////////////////////////////////
-TemplateDownload::TemplateDownload (QWidget *pParent, const char *pName, WFlags f )
-	: uiTemplateDownload (pParent, pName, f)
+//TemplateDownload::TemplateDownload (QWidget *pParent, const char *pName, Qt::WFlags f )	//ooo
+TemplateDownload::TemplateDownload (QWidget *pParent)						//xxx
+	//: uiTemplateDownload (pParent, pName, f)	//ooo
+	: QDialog (pParent)				//xxx
 {
-  qInitNetworkProtocols ( );
+  setupUi(this);	//xxx
+  //q3InitNetworkProtocols ( ); //oooo
   resetDialog ( );
   m_pNewProcess = NULL;
 
-  m_pIconViewStatic->setSelectionMode     ( QIconView::Extended );
-  m_pIconViewAnimated->setSelectionMode   ( QIconView::Extended );
-  m_pIconViewTransition->setSelectionMode ( QIconView::Extended );
+  //m_pIconViewStatic->setSelectionMode     ( Q3IconView::Extended );   //ooo
+  m_pIconViewStatic->setSelectionMode( QAbstractItemView::ExtendedSelection );  //xxx
+  //m_pIconViewAnimated->setSelectionMode   ( Q3IconView::Extended );   //ooo
+  m_pIconViewAnimated->setSelectionMode   ( QAbstractItemView::ExtendedSelection ); //xxx
+  //m_pIconViewTransition->setSelectionMode ( Q3IconView::Extended );   //ooo
+  m_pIconViewTransition->setSelectionMode ( QAbstractItemView::ExtendedSelection ); //xxx
 
   connect ( m_pButtonConnect,  SIGNAL ( clicked ( ) ), this, SLOT ( slotConnect  ( ) ) );
   connect ( m_pButtonDownload, SIGNAL ( clicked ( ) ), this, SLOT ( slotDownload ( ) ) );
   connect ( m_pButtonNext,     SIGNAL ( clicked ( ) ), this, SLOT ( slotNext     ( ) ) );
   connect ( m_pButtonHelp,     SIGNAL ( clicked ( ) ), this, SLOT ( slotHelp     ( ) ) );
+  connect ( buttonCancel,      SIGNAL ( clicked ( ) ), this, SLOT ( reject       ( ) ) );   //xxx
+  
+  QString qsUrl = m_pComboServer->currentText ( ) + "/index.xml";   //xxx
+  
+  //manager = new QNetworkAccessManager;    //xxx
+  
+  QNetworkRequest request;    //xxx
+  //request.setUrl(QUrl(fileURL));  //xxx
+  request.setUrl(QUrl(qsUrl));  //xxx
+  //m_reply = manager->get(request);    //xxx
+  m_reply = m_Network.get(request);    //xxx
 
-  connect ( &m_Network, SIGNAL ( start    ( QNetworkOperation * ) ), this, SLOT ( slotNetworkStart    ( QNetworkOperation * ) ) );
-  connect ( &m_Network, SIGNAL ( finished ( QNetworkOperation * ) ), this, SLOT ( slotNetworkFinished ( QNetworkOperation * ) ) );
-  connect ( &m_Network, SIGNAL ( data( const QByteArray &, QNetworkOperation * ) ),        this, SLOT ( slotNetworkData ( const QByteArray &, QNetworkOperation * ) ) );
-  connect ( &m_Network, SIGNAL ( dataTransferProgress ( int, int, QNetworkOperation * ) ), this, SLOT ( slotNetworkProgress ( int, int, QNetworkOperation * ) ) );
+  //connect ( &m_Network, SIGNAL ( start    ( Q3NetworkOperation * ) ), this, SLOT ( slotNetworkStart    ( Q3NetworkOperation * ) ) );  //ooo
+  connect ( m_reply, SIGNAL ( start    ( QNetworkAccessManager * ) ), this, SLOT ( slotNetworkStart    ( QNetworkAccessManager * ) ) );  //xxx
+  //connect ( &m_Network, SIGNAL ( finished ( Q3NetworkOperation * ) ), this, SLOT ( slotNetworkFinished ( Q3NetworkOperation * ) ) );  //ooo
+  connect ( &m_Network, SIGNAL ( finished ( QNetworkReply* ) ), this, SLOT ( slotNetworkFinished ( QNetworkReply* ) ) );  //xxx
+  //connect ( &m_Network, SIGNAL ( data( const QByteArray &, Q3NetworkOperation * ) ),        this, SLOT ( slotNetworkData ( const QByteArray &, Q3NetworkOperation * ) ) );    //ooo
+  connect ( &m_Network, SIGNAL ( readyRead( ) ),        this, SLOT ( slotNetworkData ( ) ) );    //xxx
+  //connect ( &m_Network, SIGNAL ( dataTransferProgress ( int, int, Q3NetworkOperation * ) ), this, SLOT ( slotNetworkProgress ( int, int, Q3NetworkOperation * ) ) );  //ooo
+  connect ( m_reply, SIGNAL ( downloadProgress ( qint64, qint64 ) ), this, SLOT ( slotNetworkProgress ( qint64, qint64 ) ) );  //xxx
+  connect ( m_reply, SIGNAL ( error ( QNetworkReply::NetworkError ) ), this, SLOT ( slotError ( QNetworkReply::NetworkError ) ) );   //xxx
 }
 
 TemplateDownload::~TemplateDownload ()
@@ -175,7 +205,8 @@ TemplateDownload::~TemplateDownload ()
 void TemplateDownload::resetDialog ()
 {
   m_pLabelPleaseWait->hide ( );
-  m_pProgressConnect->setProgress ( 0 );  
+  //m_pProgressConnect->setProgress ( 0 );  //ooo
+  m_pProgressConnect->setValue ( 0 );    //xxx  
   m_iStage           = -1;
   m_iTotalBytes      =  0;
   m_iCurrentEntry    =  0;
@@ -183,13 +214,17 @@ void TemplateDownload::resetDialog ()
   m_bytes = QByteArray ( );
   m_qsIndexFile      =  "";
   m_xml.clear ( );
-  m_pTabMain->setCurrentPage ( 0 );
-  QWidget *pServerTab = m_pTabMain->page       ( 0 );
-  m_pTabMain->setTabEnabled ( pServerTab,     true );
-  QWidget *pSelectionTab = m_pTabMain->page    ( 1 );
-  m_pTabMain->setTabEnabled ( pSelectionTab, false );
-  QWidget *pInstallTab = m_pTabMain->page      ( 2 );
-  m_pTabMain->setTabEnabled ( pInstallTab,   false );
+  //m_pTabMain->setCurrentPage ( 0 );   //ooo
+  m_pTabMain->setCurrentIndex ( 0 ); //xxx
+  //QWidget *pServerTab = m_pTabMain->page       ( 0 ); //ooo
+  QWidget *pServerTab = m_pTabMain->widget       ( 0 );  //xxx
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pServerTab),     true );  //xxx
+  //QWidget *pSelectionTab = m_pTabMain->page    ( 1 ); //ooo
+  QWidget *pSelectionTab = m_pTabMain->widget    ( 1 );  //xxx
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pSelectionTab), false );   //xxx
+  //QWidget *pInstallTab = m_pTabMain->page      ( 2 ); //ooo
+  QWidget *pInstallTab = m_pTabMain->widget      ( 2 );  //xxx
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pInstallTab),   false ); //xxx
   m_pEditConnect->clear        ( );
   m_pEditDownload->clear       ( );
   m_pIconViewStatic->clear     ( );
@@ -216,8 +251,9 @@ void TemplateDownload::slotConnect ()
 
   m_iStage      = 1; // getting the index file
   m_qsIndexFile = "";
-  m_Network     = QUrlOperator ( qsUrl );
-  m_Network.get ( );
+  //m_Network     = Q3UrlOperator ( qsUrl );    //ooo
+  //m_Network.get ( );  //ooo
+  m_Network.get(QNetworkRequest(QUrl(qsUrl))); //xxx
 }
 
 void TemplateDownload::slotNext ( )
@@ -244,15 +280,18 @@ void TemplateDownload::slotHelp ()
 {
   QString qsHtml;
 
-  if ( m_pTabMain->currentPageIndex ( ) == 0 ) {
+  //if ( m_pTabMain->currentPageIndex ( ) == 0 ) {  //ooo
+  if ( m_pTabMain->currentIndex ( ) == 0 ) {    //xxx
     qsHtml  = tr ("You have to connect to the server by clicking on [<B>Connect</B>].<P>");
     qsHtml += tr ("After the information was found on the server you will be able to select and Download / Install the templates.<BR>");
   }
-  else if ( m_pTabMain->currentPageIndex ( ) == 1 ) {
+  //else if ( m_pTabMain->currentPageIndex ( ) == 1 ) { //ooo
+  else if ( m_pTabMain->currentIndex ( ) == 1 ) {   //xxx
     qsHtml  = tr ("In this tab you can select the templates you want to install on your computer.<P>"); 
     qsHtml += tr ("You can select multiple templates by pressing SHIFT, or CTRL while selecting the templates.");
   }
-  else if ( m_pTabMain->currentPageIndex ( ) == 2 ) {
+  //else if ( m_pTabMain->currentPageIndex ( ) == 2 ) { //ooo
+  else if ( m_pTabMain->currentIndex ( ) == 2 ) {   //xxx
     qsHtml  = tr ("First you <U>have to</U> decide if you want to install the templates in your home directory or or the whole system.<P>");
     qsHtml += tr ("[<B>Download & Install</B>] will then install all selcted templates on your computer.");
   }
@@ -263,15 +302,17 @@ void TemplateDownload::slotHelp ()
 bool TemplateDownload::verifyUrl ( QString &qsUrl )
 {
   QString qsProtocol;
-  QUrl::decode ( qsUrl );
-  QUrl  theUrl ( qsUrl );
+  //Q3Url::decode ( qsUrl );    //ooo
+  //Q3Url  theUrl ( qsUrl );    //ooo
+  QUrl  theUrl ( qsUrl );   //xxx
 
   if ( ! theUrl.isValid () ) {
     m_pEditConnect->append ( tr ( "This does not seem to be a valid URL : %1.\n" ).arg ( qsUrl ) );
     return false;
   }
 
-  qsProtocol = theUrl.protocol ( );
+  //qsProtocol = theUrl.protocol ( );   //ooo
+  qsProtocol = theUrl.scheme ( );   //xxx
   if ( qsProtocol.isEmpty ( ) )
     qsProtocol = "http";
 
@@ -282,15 +323,18 @@ bool TemplateDownload::verifyUrl ( QString &qsUrl )
   return true;
 }
 
-void TemplateDownload::slotNetworkStart  ( QNetworkOperation * )
+//void TemplateDownload::slotNetworkStart  ( Q3NetworkOperation * ) //ooo
+void TemplateDownload::slotNetworkStart  ( QNetworkAccessManager * )   //xxx
 {
   m_pEditConnect->append ( "slotNetworkStart\n" );
 
 }
 
-void TemplateDownload::slotNetworkFinished  ( QNetworkOperation *pOperation )
+//void TemplateDownload::slotNetworkFinished  ( Q3NetworkOperation *pOperation )    //ooo
+void TemplateDownload::slotNetworkFinished  ( QNetworkReply *pOperation )  //xxx
 {
-  if ( pOperation->operation ( ) != QNetworkProtocol::OpGet )
+  //if ( pOperation->operation ( ) != Q3NetworkProtocol::OpGet )    //ooo
+  if ( pOperation->error ( ) != QNetworkReply::NoError )    //xxx  
     return;
   Xml::Entry *pEntry = NULL;
   //  m_pEditConnect->append ( QString("slotNetworkFinished <%1><%2>\n" ).arg ( m_iCurrentBytes ).arg ( m_iTotalBytes) );
@@ -333,7 +377,8 @@ void TemplateDownload::createThumbnails ( )
   for (t=0; t<(uint)m_xml.entryCount ();t++) {
     Xml::Entry *pEntry = m_xml.entry ( t );
     if ( pEntry ) {
-      QUrl  theUrl ( pEntry->qsThumbnail );
+      //Q3Url  theUrl ( pEntry->qsThumbnail );  //ooo
+      QUrl  theUrl ( pEntry->qsThumbnail ); //xxx
       QString qsFile = "/tmp/" + theUrl.fileName ( );
       pEntry->theThumbnail = QImage ( qsFile );
     }
@@ -370,9 +415,10 @@ void TemplateDownload::downloadThumbnail ( int iCurrentEntry )
 	downloadThumbnail ( ++m_iCurrentEntry );
 	return;
       }
-      m_Network = QUrlOperator ( qsUrl );
+      //m_Network = Q3UrlOperator ( qsUrl );    //ooo
       //      m_Network.get ( );
-      m_Network.copy ( qsUrl, "/tmp" );
+      //m_Network.copy ( qsUrl, "/tmp" );   //ooo
+      m_Network.get ( QNetworkRequest ( QUrl(qsUrl) ) ); //xxx
       return;
     }
   }
@@ -399,32 +445,54 @@ void TemplateDownload::downloadThumbnails ( )
       listOfThumbnails.append ( qsUrl );
     }
   }
-  if (listOfThumbnails.count () > 0 )
-    m_Network.copy ( listOfThumbnails, "/tmp" );
+  //if (listOfThumbnails.count () > 0 ) //ooo
+    //m_Network.copy ( listOfThumbnails, "/tmp" );  //ooo
+    //QUrl url(listOfThumbnails);    //xxx
+    //m_Network.put(QNetworkRequest(QUrl(listOfThumbnails)), "/tmp"); //xxx
+    //m_Network.put(QNetworkRequest(QUrl(listOfThumbnails)), "/tmp"); //xxx
+
+  //while (!listOfThumbnails.isEmpty())   //xxx
+    //m_Network.put(QNetworkRequest(QUrl(listOfThumbnails)), "/tmp"); //xxx
+  for (int i = 0; i < listOfThumbnails.size(); ++i) //xxx
+        //m_Network.put(QNetworkRequest(listOfThumbnails.at(i)), "/tmp"); //xxx
+        m_Network.get ( QNetworkRequest ( listOfThumbnails.at(i) ) ); //xxx  
+    
 }
 
-void TemplateDownload::slotNetworkData ( const QByteArray &someBytes, QNetworkOperation * )
+//void TemplateDownload::slotNetworkData ( const QByteArray &someBytes, Q3NetworkOperation * )  //ooo
+void TemplateDownload::slotNetworkData ( )    //xxx
 {
   switch ( m_iStage ) {
   case 1:
-    m_qsIndexFile += QString ( someBytes );
+    //m_qsIndexFile += QString ( someBytes );   //ooo
+    m_qsIndexFile += QString ( m_reply->readAll() );    //xxx
     break;
   }
   //  m_pEditConnect->append ( QString( "slotNetworkData <%1><%2>\n" ).arg(m_iCurrentBytes).arg(m_bytes.size()) );
 }
 
-void TemplateDownload::slotNetworkProgress ( int iDone, int iTotal, QNetworkOperation *pOperation )
+//void TemplateDownload::slotNetworkProgress ( int iDone, int iTotal, Q3NetworkOperation *pOperation )  //ooo
+void TemplateDownload::slotNetworkProgress ( qint64 iDone, qint64 iTotal )    //xxx
 {
-  QProgressBar *pProgress = m_pProgressConnect;
+  //Q3ProgressBar *pProgress = m_pProgressConnect;  //ooo
+  QProgressBar *pProgress = m_pProgressConnect; //xxx
   if ( m_iStage == 4 )
     pProgress = m_pProgressDownload;
 
-  if ( pOperation->operation ( ) == QNetworkProtocol::OpGet ) {
+  //if ( pOperation->operation ( ) == Q3NetworkProtocol::OpGet ) {  //ooo
+  //if ( pOperation->error ( ) != QNetworkReply::NoError )    //xxx
     if ( m_iTotalBytes > 0 )
-      pProgress->setProgress ( m_iCurrentBytes + iDone, m_iTotalBytes );
+      //pProgress->setProgress ( m_iCurrentBytes + iDone, m_iTotalBytes );  //ooo
+      pProgress->setRange ( m_iCurrentBytes + iDone, m_iTotalBytes );   //xxx
     else
-      pProgress->setProgress ( iDone, iTotal );
-  }
+      //pProgress->setProgress ( iDone, iTotal );   //ooo
+      pProgress->setRange ( iDone, iTotal );  
+  //}   //ooo
+}
+
+void TemplateDownload::slotError ( QNetworkReply::NetworkError code )  //xxx
+{
+  m_pEditConnect->append ( "slotNetworkError\n" );    
 }
 
 void TemplateDownload::parseIndexFile ( )
@@ -482,19 +550,27 @@ void TemplateDownload::displayStatus ( QString &qsStatus )
 void TemplateDownload::createSelection () 
 {
   // This function will fill in the previews in their preview tabs for the user to select
-  QWidget *pServerTab = m_pTabMain->page      ( 0 );
-  m_pTabMain->setTabEnabled ( pServerTab,   false );
-  QWidget *pSelectionTab = m_pTabMain->page   ( 1 );
-  m_pTabMain->setTabEnabled ( pSelectionTab, true );
-  QWidget *pInstallTab = m_pTabMain->page     ( 2 );
-  m_pTabMain->setTabEnabled ( pInstallTab,   true );
-  m_pTabMain->setCurrentPage ( 1 );
+  //QWidget *pServerTab = m_pTabMain->page      ( 0 );  //ooo
+  QWidget *pServerTab = m_pTabMain->widget      ( 0 );      //xxx
+  //m_pTabMain->setTabEnabled ( pServerTab,   false );  //ooo
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pServerTab),     true );  //xxx
+  //QWidget *pSelectionTab = m_pTabMain->page   ( 1 );  //ooo
+  QWidget *pSelectionTab = m_pTabMain->widget   ( 1 );  //xxx
+  //m_pTabMain->setTabEnabled ( pSelectionTab, true );  //ooo
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pSelectionTab),     true );  //xxx
+  //QWidget *pInstallTab = m_pTabMain->page     ( 2 );  //ooo
+  QWidget *pInstallTab = m_pTabMain->widget     ( 2 );  //xxx
+  //m_pTabMain->setTabEnabled ( pInstallTab,   true );  //ooo
+  m_pTabMain->setTabEnabled ( m_pTabMain->indexOf(pInstallTab),     true );  //xxx
+  //m_pTabMain->setCurrentPage ( 1 );   //ooo
+  m_pTabMain->setCurrentIndex ( 1 );    //xxx
 
   createThumbnails ( );
 
   int t;
   Xml::Entry *pEntry;
-  QIconView  *pIconView;
+  //Q3IconView  *pIconView; //ooo
+  QListWidget  *pIconView;  //xxx
   for (t=0;t<(int)m_xml.entryCount ();t++) {
     pEntry = m_xml.entry ( t );
     if ( pEntry ) {
@@ -504,9 +580,16 @@ void TemplateDownload::createSelection ()
       else if ( pEntry->qsType == "transition" )
 	pIconView = m_pIconViewTransition;
       QString qsDesc = pEntry->qsName + "\n" + pEntry->qsDescription;
-      QIconViewItem *pItem = new QIconViewItem ( pIconView, qsDesc, pEntry->theThumbnail );
-      pItem->setKey ( pEntry->qsName );
-      pItem->setSelectable  ( true  );
+      //Q3IconViewItem *pItem = new Q3IconViewItem ( pIconView, qsDesc, pEntry->theThumbnail );				//ooo
+      //Q3IconViewItem *pItem = new Q3IconViewItem ( pIconView, qsDesc, QPixmap::fromImage(pEntry->theThumbnail) );	//xxx
+      QListWidgetItem *pItem = new QListWidgetItem ( QPixmap::fromImage(pEntry->theThumbnail), qsDesc,  pIconView );	//xxx
+      QVariant v;   //xxx
+      v = QVariant(pEntry->qsName);  //xxx
+      v.setValue(v.toString());  //xxx
+      //pItem->setKey ( pEntry->qsName );   //ooo
+      pItem->setData ( Qt::UserRole, v); //xxx
+      //pItem->setSelectable  ( true  );    //ooo
+      pItem->setSelected  ( true  );    //xxx
      }
   }
 }
@@ -523,23 +606,29 @@ void TemplateDownload::slotDownload ( )
   int t, i, iSelectedCounter;
   Xml::Entry             *pEntry;
   QString                 qsOutput;
-  QIconViewItem          *pItem;
-  QIconView              *pIconView = m_pIconViewStatic;
+  //Q3IconViewItem          *pItem; //ooo
+  QListWidgetItem          *pItem;  //xxx
+  //Q3IconView              *pIconView = m_pIconViewStatic; //ooo
+  QListWidget              *pIconView = m_pIconViewStatic;  //xxx
 
-  m_pTabMain->setCurrentPage ( 2 );
+  //m_pTabMain->setCurrentPage ( 2 );   //ooo
+  m_pTabMain->setCurrentIndex ( 2 );    //xxx
   m_pButtonNext->setText ( "Finish" );
   m_iStage         = 4;
   m_iTotalBytes    = 0;
   m_iCurrentBytes  = 0;
   iSelectedCounter = 0;
   for (t=0;t<3;t++) {
-    pItem  = pIconView->firstItem ( );    
+    //pItem  = pIconView->firstItem ( );    //ooo
+    pItem  = pIconView->item (0);   //xxx
     while ( pItem ) {
       if  ( pItem->isSelected ( ) ) {	
 	for (i=0;i<m_xml.entryCount ();i++) {
 	  pEntry = m_xml.entry ( i );
 	  if ( pEntry ) {
-	    if ( ( pEntry->qsName        == pItem->key  ( ) ) && 
+        QVariant v = pItem->data(Qt::UserRole);   //xxx  
+	    //if ( ( pEntry->qsName        == pItem->key  ( ) ) && //ooo
+        if ( ( pEntry->qsName        == v.value<QString>() ) && //xxx
 		 ( pEntry->qsDescription == pItem->text ( ) ) ) {
 	      pEntry->bSelectedForInstall = true;
 	      iSelectedCounter ++;
@@ -548,7 +637,8 @@ void TemplateDownload::slotDownload ( )
 	  }
 	}
       } // if pItem->isSelected ()
-      pItem = pItem->nextItem ( );
+      //pItem = pItem->nextItem ( );    //ooo
+      pItem = pItem->listWidget()->item ( pItem->listWidget()->row(pItem) + 1 ); //xxx
     }   // while ( pItem ) ...
 
     if ( t == 0 )
@@ -591,9 +681,10 @@ void TemplateDownload::downloadTemplate ( int iCurrentEntry )
 	downloadTemplate ( ++m_iCurrentEntry );
 	return;
       }
-      m_Network = QUrlOperator ( qsUrl );
+      //m_Network = Q3UrlOperator ( qsUrl );    //ooo
       //      m_Network.get ( );
-      m_Network.copy ( qsUrl, "/tmp" );
+      //m_Network.copy ( qsUrl, "/tmp" );   //ooo
+      m_Network.put(QNetworkRequest(qsUrl), "/tmp"); //xxx  
       return;
     }
   }
@@ -615,8 +706,9 @@ void TemplateDownload::installTemplates ( )
   if ( m_pRadioSystemWide->isChecked ( ) )
     qsTemplatePath = Global::qsSystemPath + "/share/qdvdauthor/";
 
-  if ( file.open( IO_WriteOnly ) ) {
-    QTextStream stream( &file );
+  if ( file.open( QIODevice::WriteOnly ) ) {
+    //Q3TextStream stream( &file ); //ooo
+    QTextStream stream( &file );    //xxx
     stream << Global::qsBashString;
     stream << "mkdir -p " << qsTemplatePath << "static\n";
     stream << "mkdir -p " << qsTemplatePath << "animated\n";
@@ -632,7 +724,8 @@ void TemplateDownload::installTemplates ( )
     file.close();
   }
   // And here we grant read/write/execute permission.
-  chmod ((const char *)QString( qsExecutable ), S_IXGRP | S_IWGRP | S_IRGRP | S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
+  //chmod ((const char *)QString( qsExecutable ), S_IXGRP | S_IWGRP | S_IRGRP | S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );   //ooo
+  chmod (QString( qsExecutable ).toLatin1().data(), S_IXGRP | S_IWGRP | S_IRGRP | S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH ); //xxx
 
   // install the Templates ...
   installToSystem ( qsExecutable, m_pRadioLocally->isChecked ( ) );
@@ -641,21 +734,27 @@ void TemplateDownload::installTemplates ( )
 void TemplateDownload::installToSystem ( QString &qsCommand, bool bInstallLocally )
 {
   if (m_pNewProcess)	{
-    if (m_pNewProcess->isRunning())
+    //if (m_pNewProcess->isRunning())   //ooo
+    if (!m_pNewProcess->atEnd())    //xxx
       return;
     else 
       delete m_pNewProcess;
   }
 
   Utils theUtils;
-  m_pNewProcess  = new QProcess ( this );
-  connect( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
-  connect( m_pNewProcess, SIGNAL ( readyReadStderr ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
-  connect( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited   ( ) ) );
+  //m_pNewProcess  = new Q3Process ( this );    //ooo
+  m_pNewProcess  = new QProcess ( this );   //xxx
+  //connect( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );   //ooo
+  connect( m_pNewProcess, SIGNAL ( readyReadStandardOutput ( ) ), this, SLOT ( slotReadFromProcess ( ) ) ); //xxx
+  //connect( m_pNewProcess, SIGNAL ( readyReadStderr ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );   //ooo
+  connect( m_pNewProcess, SIGNAL ( readyReadStandardError ( ) ), this, SLOT ( slotReadFromProcess ( ) ) ); //xxx
+  //connect( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited   ( ) ) );   //ooo
+  connect( m_pNewProcess, SIGNAL (finished  ( int, QProcess::ExitStatus)), this, SLOT ( slotProcessExited   ( ) ) );    //xxx
 
   if ( ! bInstallLocally ) {
     // the next check is to see if we can find kdesu
     QString qsGuiSU = theUtils.findGuiSU ( );
+    QStringList arguments;    //xxx
     if ( qsGuiSU.isEmpty ( ) ) {
       MessageBox::information (NULL, tr ( "Could not find kdesu, xsu, or gnomesu" ),
         tr ( "Without kdesu, xsu, or gnomesu I can not istall them templates in %1/share/qdvdauthor/.\n").
@@ -663,29 +762,36 @@ void TemplateDownload::installToSystem ( QString &qsCommand, bool bInstallLocall
       return;
     }
     if (qsGuiSU == QString ("kdesu"))	{
-      m_pNewProcess->addArgument ("kdesu");
-      m_pNewProcess->addArgument ("-n");
-      m_pNewProcess->addArgument ("-t");
-      m_pNewProcess->addArgument ("-c");
+      //m_pNewProcess->addArgument ("kdesu");   //ooo
+      //m_pNewProcess->addArgument ("-n");  //ooo
+      //m_pNewProcess->addArgument ("-t");  //ooo
+      //m_pNewProcess->addArgument ("-c");  //ooo
+      arguments << "kdesu" << "-n" << "-t" << "-c"; //xxx
+      m_pNewProcess->setArguments (arguments); //xxx
     }
     else if (qsGuiSU == QString ("xsu"))	{
-      m_pNewProcess->addArgument ("xsu");
-      m_pNewProcess->addArgument ("--username");
-      m_pNewProcess->addArgument ("root");
-      m_pNewProcess->addArgument ("--message");
-      m_pNewProcess->addArgument ("Please type in the root password");
-      m_pNewProcess->addArgument ("--command");
+      //m_pNewProcess->addArgument ("xsu"); //ooo
+      //m_pNewProcess->addArgument ("--username");  //ooo
+      //m_pNewProcess->addArgument ("root");    //ooo
+      //m_pNewProcess->addArgument ("--message");   //ooo
+      //m_pNewProcess->addArgument ("Please type in the root password");    //ooo
+      //m_pNewProcess->addArgument ("--command");   //ooo
+      arguments << "xsu" << "--username" << "root" << "--message" << "Please type in the root password" << "--command"; //xxx
+      m_pNewProcess->setArguments (arguments);   //xxx  
     }
     else if (qsGuiSU == QString ("gnomesu"))	{
-      m_pNewProcess->addArgument ("xsu");
-      m_pNewProcess->addArgument ("--username");
-      m_pNewProcess->addArgument ("root");
-      m_pNewProcess->addArgument ("--message");
-      m_pNewProcess->addArgument ("Please type in the root password");
-      m_pNewProcess->addArgument ("--command");
+      //m_pNewProcess->addArgument ("xsu"); //ooo
+      //m_pNewProcess->addArgument ("--username");  //ooo
+      //m_pNewProcess->addArgument ("root");    //ooo
+      //m_pNewProcess->addArgument ("--message");   //ooo
+      //m_pNewProcess->addArgument ("Please type in the root password");    //ooo
+      //m_pNewProcess->addArgument ("--command");   //ooo
+      arguments << "xsu" << "--username" << "root" << "--message" << "Please type in the root password" << "--command"; //xxx
+      m_pNewProcess->setArguments (arguments);   //xxx  
     }
   }
-  m_pNewProcess->addArgument ( qsCommand );
+  //m_pNewProcess->addArgument ( qsCommand );   //ooo
+  m_pNewProcess->setArguments ( m_pNewProcess->arguments() << qsCommand );  //xxx
 
   m_pNewProcess->start ( );
 }
@@ -694,10 +800,12 @@ void TemplateDownload::slotReadFromProcess  ( )
 {
   if ( ! m_pNewProcess )
     return;
-  QString stdOut = m_pNewProcess->readStdout ( );
+  //QString stdOut = m_pNewProcess->readStdout ( ); //ooo
+  QString stdOut = m_pNewProcess->readAllStandardOutput().data();   //xxx
   if (stdOut.length() > 5)
     m_pEditDownload->append ( stdOut );
-  QString stdErr = m_pNewProcess->readStderr ( );
+  //QString stdErr = m_pNewProcess->readStderr ( ); //ooo
+  QString stdErr = m_pNewProcess->readAllStandardError ().data();   //xxx
   if (stdErr.length() > 5)
     m_pEditDownload->append ( stdErr );
 }
@@ -706,7 +814,8 @@ void TemplateDownload::slotProcessExited ()
 {
   m_iStage = 5;
   slotReadFromProcess ( );
-  m_pProgressInstall->setProgress ( 100, 100 );
+  //m_pProgressInstall->setProgress ( 100, 100 );   //ooo
+  m_pProgressInstall->setValue ( 100 ); //xxx
   // Allow closing this dialog again.
   lockDialog      ( false    );
 
