@@ -1,22 +1,21 @@
-/****************************************************************************
-** TextObject class
-**
-**   Created : Tue Feb 02 22:06:51 2004
-**        by : Varol Okan using Kate
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    textobject.cpp
+                             -------------------
+    TextObject class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
 ****************************************************************************/
 
-#include <qpen.h>
-#include <qfont.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpopupmenu.h>
-#include <qwmatrix.h>
+#include <QPen>
+#include <QPainter>
+#include <QMenu>
+#include <QMouseEvent>
+
+#include <QMessageBox>
 
-#include "messagebox.h"
 #include "global.h"
 #include "xml_dvd.h"
 #include "dialogtextfont.h"
@@ -89,19 +88,20 @@ MenuObject::Data *TextObject::TextData::clone ( )
 TextObject::TextObject ( QWidget *pParent )
   : MenuObject ( pParent )
 {
-  if ( m_pData )
-    delete m_pData;        // part of the base class
+   if ( m_pData )
+    delete m_pData;        // part of the base class			//oooo
   m_pData = new TextData; // will be deleted in base class
 
   m_qsObjectType    = QString ( TEXT_OBJECT );
-  m_pContextMenu    = NULL;
+  m_pContextMenu    = NULL; 	//oooo
+
 }
 
 TextObject::~TextObject ( )
 {
   if ( m_pContextMenu )
     delete m_pContextMenu;
-  m_pContextMenu = NULL;
+  m_pContextMenu = NULL; 
 }
 
 TextObject::TextData *TextObject::textData ( )
@@ -127,14 +127,12 @@ void TextObject::setWordBreak ( bool bBreak )
 void TextObject::setText (QString &theText)
 {
   textData ( )->m_qsText = theText;
-
   // Here we seal off after 20 char and remove special characters from the Object Name.
   QString qsTemp = theText;
   qsTemp = qsTemp.remove  ( '\n' );
   qsTemp = qsTemp.remove  ( '\t' );
   if ( qsTemp.length ( )  > 20 )
     qsTemp = qsTemp.left  ( 20 );
-
   setName ( qsTemp );
 }
 
@@ -164,14 +162,6 @@ int TextObject::getStyleStrategy ()
   return (int)textData ( )->m_iStyleStrategy;
 }
 
-void TextObject::replaceColor ( Rgba theColor, Rgba oldColor )
-{
-  if ( getForegroundColor ( ) == oldColor )
-       setForegroundColor ( theColor );
-  if ( getBackgroundColor ( ) == oldColor )
-       setBackgroundColor ( theColor );
-}
-
 void TextObject::setForegroundColor ( const Rgba &theColor)
 {
   textData ( )->m_colorForeground = theColor;
@@ -193,12 +183,12 @@ Rgba &TextObject::getBackgroundColor ()
 }
 
 void TextObject::drawSemiTransparent (QPainter *pPainter)
-{
+{  
   //printf ( "%s::%s : %d  \n", __FILE__, __FUNCTION__, __LINE__ );
   if ( m_pShadow && ! m_bDrawRect )
        m_pShadow->drawContents ( pPainter );
 
-  QWMatrix theMatrix;
+  QMatrix theMatrix;
   QRect dummyRect, theRect;
   int iFlags, x, y;
   int iSourceHeight, iSourceWidth, iTargetStartX, iTargetStartY;
@@ -213,11 +203,14 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 
   QPen thePen ( textData ( )->m_colorForeground.color ( ), 2, Qt::DashDotLine );
   // Here we define the cenetered rect.
-  theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+  //theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height()); //ooo
+  theRect = QRect(static_cast<int>(-(rect().width()/ 2.0)), static_cast<int>(-(rect().height()/2.0)), rect().width(), rect().height()); //xxx
 
   // First we translate to the center of the rect.
-  theMatrix.translate ( (double)rect().x() + (int)(rect().width () / 2.0), 
-		        (double)rect().y() + (int)(rect().height() / 2.0) );
+  //theMatrix.translate ( (double)rect().x() + (int)(rect().width () / 2.0),                        //ooo
+  theMatrix.translate ( static_cast<double>(rect().x()) + static_cast<int>(rect().width () / 2.0),  //xxx
+		        //(double)rect().y() + (int)(rect().height() / 2.0) );                          //ooo
+                        static_cast<double>(rect().y()) + static_cast<int>(rect().height() / 2.0) );    //xxx
   //. then we apply the other modifications ...
   theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
   theMatrix.rotate (modifiers()->fRotate);
@@ -226,7 +219,8 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
   m_boundingRect = theMatrix.mapRect(theRect);
   // And for the source we need to set the right matrix.
   theMatrix.reset  ();
-  theMatrix.translate ((double)m_boundingRect.width()/2.0, (double)m_boundingRect.height()/2.0);
+  //theMatrix.translate ((double)m_boundingRect.width()/2.0, (double)m_boundingRect.height()/2.0);                          //ooo
+  theMatrix.translate (static_cast<double>(m_boundingRect.width())/2.0, static_cast<double>(m_boundingRect.height())/2.0);  //xxx
   theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
   theMatrix.rotate (modifiers()->fRotate);
   theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
@@ -235,26 +229,34 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
   if (thePixmap.isNull())
     return;
 
-  thePixmap.fill ( QColor ( TRANSPARENT_COLOR ) );
+  thePixmap.fill ( QColor ( TRANSPARENT_COLOR ) );    //ooo
   QPainter pmPainter (&thePixmap);
   //  then we actually set the world matrix 
   pmPainter.setWorldMatrix(theMatrix);
 
   pmPainter.setPen   ( Qt::NoPen );
-  pmPainter.setBrush ( QBrush    ( textData ( )->m_colorBackground.color ( ) ) );
-  pmPainter.drawRect ( theRect   );
+  pmPainter.setBrush ( QBrush    ( textData ( )->m_colorBackground.color ( ) ) ); //ooo
+  pmPainter.drawRect ( theRect   );   //ooo
 
   textData ( )->m_Font.setStyleStrategy ((QFont::StyleStrategy)textData ( )->m_iStyleStrategy);
   pmPainter.setFont(textData ( )->m_Font);
 
   // Okay, I abused a QPoint class to hold some other infos ... so what ???
   //iFlags = Qt::DontClip|Qt::WordBreak|textData ( )->m_ptTextAlign.x()|textData ( )->m_ptTextAlign.y();
-  iFlags = Qt::DontClip|textData ( )->m_ptTextAlign.x ( )|textData ( )->m_ptTextAlign.y ( );
+  iFlags = Qt::TextDontClip|textData ( )->m_ptTextAlign.x ( )|textData ( )->m_ptTextAlign.y ( );
   if ( textData ( )->m_bAllowWordBreak )
-    iFlags |= Qt::WordBreak;
-
-  pmPainter.drawText(theRect, iFlags, textData ( )->m_qsText, -1, &dummyRect);
+    iFlags |= Qt::TextWordWrap;
 
+  //pmPainter.setPen(Qt::blue);   //xxx
+  pmPainter.setPen(textData ( )->m_colorForeground.color ( ));   //xxx
+  //pmPainter.setFont(QFont("Arial", 30));    //xxx
+  //pmPainter.drawText(theRect, iFlags, textData ( )->m_qsText, -1, &dummyRect);	//ooo
+  pmPainter.drawText(theRect, iFlags, textData ( )->m_qsText, &dummyRect);		//xxx
+  //pmPainter.drawText( 0, 0, 100, 50, Qt::AlignCenter, "Qt");  //xxx
+  //p.drawText( 0, 0, iSourceWidth, iSourceHeight, Qt::AlignCenter, "Qt");  //xxx
+  //pmPainter.drawText( 0, 0, iSourceWidth, iSourceHeight, Qt::AlignCenter, "Qt");  //xxx
+  pmPainter.end();  //xxx
+  
   // At this point we should have the text on a memory Bitmap object, and now 
   // we should copy this over, bit for bit. 
   iSourceHeight = thePixmap.height(); 
@@ -267,15 +269,67 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
   if (pPDPainter == 0)
     return;
 
-  sourceImg = thePixmap.convertToImage();
+  //sourceImg = thePixmap.convertToImage();	//ooo
+  sourceImg = thePixmap.toImage();		//xxx
 
   QPixmap *pPixmap = new QPixmap(iSourceWidth, iSourceHeight);
   if ( ! pPixmap )
     return;
-  bitBlt (pPixmap, 0, 0, pPainter->device(), 
-	  iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+
+  //bitBlt (pPixmap, 0, 0, pPainter->device(), 							//oooo
+//	  //iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);	//oooo
+  //        iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::AutoColor);		//xxx
+    //QRect devRect(0, 0, pPainter->device()->width(), pPainter->device()->height());                     //xxx
+  //QImage image(48, 48, QImage::Format_RGB32);   //xxx
+  //QImage image(iSourceWidth, iSourceHeight, QImage::Format_RGB32);   //xxx
+  //image.fill(QColor(0,0,0));    //xxx
+  //image.load(pPainter->device());    //xxx
+  //image(pPainter->widget());    //xxx
+  QPainter p( pPixmap );											//xxx
+    //p.setPen(Qt::blue); //xxx
+    //p.setFont(QFont("Arial", 30));  //xxx
+    //p.drawText( 0, 0, iSourceWidth, iSourceHeight, Qt::AlignCenter, "Qt");  //xxx
+    //p.drawRect( 0, 0, iSourceWidth, iSourceHeight );	                                //xxx
+    //p.begin(pPainter->device());    //xxx
+    //pmPainter.begin(pPainter->device());    //xxx
+    //p.fillRect(0, 0, iSourceWidth, iSourceHeight, pPainter->background());  //xxx
+    //p.drawImage(0,0, (QImage) (*((QImage*)pPainter->device())); //xxx
+    //p.drawImage(0,0, (QImage) (*((QImage*)pPainter->device()))); //xxx
+    //p.drawImage( 0, 0, pPainter->device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );		//xxx
+    //p.drawImage( 0, 0, image );		//xxx
+    //p.end();    //xxx
+
+  //QPainter p( pPixmap );  
+    //pmPainter.drawImage( 0, 0, image );		//xxx
+    //pmPainter.drawText(theRect, iFlags, textData ( )->m_qsText, &dummyRect);		//xxx
+    //pPainter->background();		//xxx
+    //p.drawPixmap( iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, the_Pixmap );		//xxx
+    //p.drawPixmap( 0, 0, iSourceWidth, iSourceHeight, the_Pixmap );		//xxx
+    p.drawPixmap( 0, 0, the_Pixmap, iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );		//xxx
+    //p.drawImage( 0, 0, pPainter->background(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );	//xxx
+    //p.drawRect( iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );	                                //xxx
+    //p.drawText( iTargetStartX, iTargetStartY, "Qt5" );	                                //xxx
+
+    p.end();    //xxx
+    //pmPainter.end();    //xxx
+    //QPainter p;									//xxx
+  //p.begin(pPainter->device());							//xxx
+    //p.drawRect(iTargetStartX, iTargetStartY, iSourceWidth-10, iSourceHeight-10 );	//xxx
+  //p.setViewport(iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );	//xxx
+    //QPen myPen(Qt::black, 2, Qt::SolidLine);                                      //xxx
+    //myPen.setColor(Qt::red);                                                      //xxx
+    //p.drawPoint(iTargetStartX+10,iTargetStartY+10);                                                         //xxx
+  //p.end();                                                                      //xxx
+    //QPainter p(pPainter->device());   //xxx
+    //p.drawLine(1,1,100,100);    //xxx
+    //p.drawRect( iTargetStartX+5, iTargetStartY+5, iSourceWidth-5, iSourceHeight-5 );  //xxx
+    //p.drawRect(1,1,100,100);    //xxx
+    //QImage image(pPainter->device()); //xxx
+    //image.copy(iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight );     //xxx
   // To get Pixel information we need a QImage however ...
-  targetImg = pPixmap->convertToImage();
+  //targetImg = pPixmap->convertToImage();	//ooo
+  targetImg = pPixmap->toImage();		//xxx
+  
   delete pPixmap;
 
   iTargetStartX -= pPainter->viewport().x();
@@ -289,9 +343,12 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 	targetPixel &= 0x00ffffff;	// filter out the transparency part of the color
 	targetColor = Rgba ( targetPixel );
 	sourceColor = Rgba ( sourcePixel );
-	theColor    = Rgba ( (int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
-			     (int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
-			     (int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
+	theColor    = Rgba ( (int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),                    //ooo
+    //theColor    = Rgba ( static_cast<int>(fSourceTrans * sourceColor.red()   + /*static_cast<int>*/(fTargetTrans * targetColor.red())), //xxx
+			     (int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),                        //ooo
+                 //static_cast<int>(fSourceTrans * sourceColor.green() + /*static_cast<int>*/(fTargetTrans * targetColor.green())),   //xxx
+			     (int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))                          //ooo
+                 //static_cast<int>(fSourceTrans * sourceColor.blue()  + /*static_cast<int>*/(fTargetTrans * targetColor.blue()))     //xxx
 			     );
 	pPainter->setPen ( theColor.color ( ) );
 	pPainter->drawPoint(x+iTargetStartX, y+iTargetStartY);
@@ -302,19 +359,21 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
 
 void TextObject::drawContents ( QPainter *painter )
 {
-  QWMatrix theMatrix;
+  QMatrix theMatrix;
   // If we have a complete transparent text we should not draw at all.
   if ( modifiers ( )->fTransparency == 1.0 )
     return;
   else if ( (modifiers ( )->fTransparency != 0.0 ) && ( ! m_bDrawRect ) )
-    return drawSemiTransparent ( painter );
+    return drawSemiTransparent ( painter );	//oooo
 
   if ( m_pShadow && ! m_bDrawRect )
     m_pShadow->drawContents ( painter );
   // Here we calculate the center point of gravity (rotation)
   QPoint centerPos;
-  centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
-  centerPos.setY (rect().y() + (int)(rect().height() / 2.0));
+  //centerPos.setX (rect().x() + (int)(rect().width () / 2.0));             //ooo
+  centerPos.setX (rect().x() + static_cast<int>(rect().width () / 2.0));    //xxx
+  //centerPos.setY (rect().y() + (int)(rect().height() / 2.0));             //ooo
+  centerPos.setY (rect().y() + static_cast<int>(rect().height() / 2.0));    //xxx
   // Here we define the cenetered rect.
   QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
 
@@ -325,7 +384,8 @@ void TextObject::drawContents ( QPainter *painter )
   // The third step uses the viewport.
 
   // First we translate to the appropriate location,
-  theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );
+  //theMatrix.translate ( (double)centerPos.x ( ), (double)centerPos.y ( ) );                           //ooo
+  theMatrix.translate ( static_cast<double>(centerPos.x ( )), static_cast<double>(centerPos.y ( )) );   //xxx
 
   //. then we apply the other modifications ...
   theMatrix.scale  ( modifiers ( )->fScaleX, modifiers ( )->fScaleY );
@@ -360,14 +420,16 @@ void TextObject::drawContents ( QPainter *painter )
   QRect boundingRect;
   bool  bUpdateAgain = false;
   // Okay, I abused a QPoint class to hold some other infos ... so what ???
-  int iFlags = Qt::DontClip|textData ( )->m_ptTextAlign.x ( )|textData ( )->m_ptTextAlign.y ( );
+  int iFlags = Qt::TextDontClip|textData ( )->m_ptTextAlign.x ( )|textData ( )->m_ptTextAlign.y ( );
   if ( textData ( )->m_bAllowWordBreak )
-    iFlags |= Qt::WordBreak;
+    iFlags |= Qt::TextWordWrap;
 
   if ( m_bDrawRect )
     painter->drawRect ( theRect );
 
-  painter->drawText ( theRect, iFlags, textData ( )->m_qsText, -1, &boundingRect );
+  //painter->drawText ( theRect, iFlags, textData ( )->m_qsText, -1, &boundingRect );	//ooo
+  painter->drawText ( theRect, iFlags, textData ( )->m_qsText, &boundingRect );		//xxx
+  
   // Here we expand the rectangle if needs be, and update again, to re-draw.
   if ( rect ( ).width ( ) < boundingRect.width ( ) )  {
     rect ( ).setWidth ( boundingRect.width ( ) );
@@ -390,7 +452,7 @@ void TextObject::drawContents ( QPainter *painter )
 
 void TextObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
-  // Next is to set the AnimationAttributes
+/*  // Next is to set the AnimationAttributes
   for (uint t=0;t<m_listAnimationAttributes.count();t++)
     m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
 
@@ -399,7 +461,7 @@ void TextObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
        ( ( iRenderFrameNumber > modifiers ( )->iStopFrame  ) && ( modifiers ( )->iStopFrame  != -1 ) ) ) 
     return;
 
-  drawContents (pPainter);
+  drawContents (pPainter);*/	//oooo
 }
 
 bool TextObject::readProjectFile  (QDomNode &theNode)
@@ -414,7 +476,8 @@ bool TextObject::readProjectFile  (QDomNode &theNode)
   attribute = theElement.attributeNode ( TEXT_OBJECT_TEXT_ALIGN );
   if (!attribute.isNull())	{
     // QString "x,y" - we abused a QPoint object for the Align info.
-    QStringList list = QStringList::split (",", attribute.value());
+    //QStringList list = QStringList::split (",", attribute.value());	//ooo
+    QStringList list = attribute.value().split (",");			//xxx
     QPoint textAlign;
     if (list.count() == 2)
       textAlign = QPoint(list[0].toInt(), list[1].toInt());
@@ -477,8 +540,8 @@ bool TextObject::writeProjectFile (QDomElement &theElement)
 
 bool TextObject::createContextMenu (QPoint globalPos)
 {
-	QPoint globalPos2 = globalPos;
-	QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+	/*QPoint globalPos2 = globalPos;
+	Q3PopupMenu *pStackMenu = new Q3PopupMenu(m_pParent);
 	pStackMenu->insertItem ( tr ("Cut") , this, SLOT ( slotCut  ( ) ) );
 	pStackMenu->insertItem ( tr ("Copy"), this, SLOT ( slotCopy ( ) ) );
 	pStackMenu->insertSeparator ( );
@@ -490,7 +553,7 @@ bool TextObject::createContextMenu (QPoint globalPos)
 
 	if (m_pContextMenu)
 		delete m_pContextMenu;
-	m_pContextMenu = new QPopupMenu(m_pParent);
+	m_pContextMenu = new Q3PopupMenu(m_pParent);
 	m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT ( slotEdit   ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT ( slotMatrix ( ) ) );
 	m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT ( slotDelete ( ) ) );
@@ -513,52 +576,135 @@ bool TextObject::createContextMenu (QPoint globalPos)
 	if (m_pContextMenu)
 		delete m_pContextMenu;
 	m_pContextMenu = NULL;
-	return true;
+	return true;*/		//oooo
+
+  //QPoint globalPos2 = globalPos;
+  //globalPos.setY ( globalPos.y ( ) - 25 );
+  //globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
+  
+  QPoint globalPos2 = globalPos;
+  
+  QMenu *pStackMenu = new QMenu(m_pParent);
+  
+  QAction *cutNewAction = new QAction("&Cut", this);
+  QAction *copyNewAction = new QAction("&Copy", this);
+  QAction *toFontNewAction = new QAction("&To Front", this);
+  QAction *toBackNewAction = new QAction("&To Back", this);
+  
+  pStackMenu->addAction(cutNewAction);
+  pStackMenu->addAction(copyNewAction);
+  pStackMenu->addSeparator ( );
+  pStackMenu->addAction(toFontNewAction);
+  pStackMenu->addAction(toBackNewAction);
+  
+  globalPos.setY ( globalPos.y ( ) - 25 );
+  globalPos.setX ( globalPos.x ( ) - pStackMenu->sizeHint().width()); // -100);
+  
+  //pStackMenu->exec( globalPos );
+  pStackMenu->popup(globalPos, cutNewAction);
+
+  if (m_pContextMenu)
+    delete m_pContextMenu;
+
+  QAction *editNewAction = new QAction("&Edit ...", this);
+  QAction *matrixNewAction = new QAction("&Matrix ...", this);
+  QAction *deleteNewAction = new QAction("&Delete", this);
+  QAction *editShadowNewAction = new QAction("&Edit Shadow ...", this);
+  QAction *deleteShadowNewAction = new QAction("&Delete Shadow", this);
+  QAction *addShadowNewAction = new QAction("&Add Shadow ...", this);
+  QAction *defineAsButtonNewAction = new QAction("&Define as Button", this);
+  
+  //QMenu *pMenu = new QMenu (this);
+  //pMenu->addAction(defineAsButtonNewAction);
+  m_pContextMenu = new QMenu (m_pParent);
+  m_pContextMenu->addAction(editNewAction);
+  m_pContextMenu->addAction(matrixNewAction);
+  m_pContextMenu->addAction(deleteNewAction);
+  m_pContextMenu->addSeparator();
+  if ( shadow ( ) )  {
+    m_pContextMenu->addAction(editShadowNewAction);
+    m_pContextMenu->addAction(deleteShadowNewAction);
+  }
+  else
+    m_pContextMenu->addAction(addShadowNewAction);
+  
+  m_pContextMenu->addSeparator();
+  m_pContextMenu->addAction(defineAsButtonNewAction);
+  
+  connect(editNewAction,           SIGNAL(triggered()), this, SLOT( slotEdit            ( ) ) );
+  connect(matrixNewAction,         SIGNAL(triggered()), this, SLOT( slotMatrix          ( ) ) );
+  connect(deleteNewAction,         SIGNAL(triggered()), this, SLOT( slotDelete          ( ) ) );
+  connect(defineAsButtonNewAction, SIGNAL(triggered()), this, SLOT( slotDefineAsButton  ( ) ) );
+  
+  //pMenu->exec( globalPos );
+  m_pContextMenu->exec( globalPos2, deleteNewAction );
+  // Here we mark that the user called a menu item thus we don't want the
+  // base classes to continue with the mouse event
+  delete pStackMenu;
+  //delete pMenu;
+  // Note the menu might have been already deleted in slotToFront/slotToBack
+  if (m_pContextMenu)
+    delete m_pContextMenu;
+  m_pContextMenu = NULL;
+  return true;
+
 }
 
 StructureItem *TextObject::createStructure ( StructureItem *pParentItem )
 {
   StructureItem *pTemp=NULL;
 
-  if ( ! pParentItem )  {
+  if ( ! pParentItem )  { 
     if ( m_pOverlay  )
       pTemp = m_pOverlay->createStructure ( NULL );
     if ( m_pShadow )
       pTemp = m_pShadow->createStructure  ( NULL );
-    modifiers ( )->createStructure  ( NULL, NULL );
+    //modifiers ( )->createStructure  ( NULL, NULL );	//oooo
     m_pStructureItem = NULL;
     return NULL;
   }
 
   QString qsName = tr ( "Text Object" );
-  if ( ! m_pStructureItem ) {
+  if ( ! m_pStructureItem ) { 
     m_pStructureItem = new StructureItem ( this, StructureItem::Text, pParentItem, qsName, textData ( )->m_qsText );
-    m_pStructureItem->setExpandable      ( TRUE );
+    //m_pStructureItem->setText ( 0, qsName );				//xxx
+    //m_pStructureItem->setText ( 1, textData ( )->m_qsText );		//xxx
+    //m_pStructureItem->setExpandable      ( TRUE );	//ooo
+    m_pStructureItem->setExpanded      ( false );	//xxx
   }
-  else
-    m_pStructureItem->setText ( qsName, textData ( )->m_qsText );
-
+  else {
+    //m_pStructureItem->setText ( qsName, textData ( )->m_qsText );	//ooo
+    m_pStructureItem->setText ( 0, qsName );				//xxx
+    m_pStructureItem->setText ( 1, textData ( )->m_qsText );		//xxx
+  }
+  
   pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ( "Geometry" ), QString ( "%1, %2, %3, %4" ).
        	         arg ( rect().x()).arg(rect().y()).arg(rect().width()).arg(rect().height()) );
 
   pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Foreground"),
-                tr ("color(%1, %2, %3)").
+                //tr ("color(%1, %2, %3)").	//ooo
+		QString ("color(%1, %2, %3)").	//xxx
 		arg ( textData ( )->m_colorForeground.red   ( ) ).
 		arg ( textData ( )->m_colorForeground.green ( ) ).
 		arg ( textData ( )->m_colorForeground.blue  ( ) ) );
 
-  if ( textData ( )->m_colorBackground == Rgba ( TRANSPARENT_COLOR ) )
+  if ( textData ( )->m_colorBackground == Rgba ( TRANSPARENT_COLOR ) ) {
+
     pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Background"), tr ("Transparent") );
-  else
+  } else {
+ 
     pTemp = m_pStructureItem->setSibling ( this, pTemp, tr ("Background"),
 			tr  ( "color(%1, %2, %3)").
 			arg ( textData ( )->m_colorBackground.red   ( ) ).
 			arg ( textData ( )->m_colorBackground.green ( ) ).
 			arg ( textData ( )->m_colorBackground.blue  ( ) ) );
+  }
+  
   if ( m_pShadow )
     pTemp = m_pShadow->createStructure ( m_pStructureItem );
 
   modifiers ( )->createStructure ( m_pStructureItem, pTemp );
+	//oooo
 
   return m_pStructureItem;
 }
@@ -578,7 +724,7 @@ bool TextObject::mousePressEvent ( QMouseEvent *pEvent )
 bool TextObject::mouseReleaseEvent ( QMouseEvent * )
 {
   UndoBuffer *pUndo = Global::pApp->getUndoBuffer ( );
-  pUndo->removeUnchanged ( );
+  pUndo->removeUnchanged ( );		//oooo
 
   m_bDrawRect = false;
   emit ( signalUpdatePixmap    ( ) );
@@ -668,10 +814,10 @@ void TextObject::slotMatrix ( )
 
 void TextObject::slotDefineAsButton ()
 {
-	// We want to convert this TextObject into a ButtonObject.
-	// Thus the class TextObject is no longer the logical place for doing this, now is it ?
-	// Okay we call the MenuPreview and let this handle the task.
-	emit (signalDefineAsButton(this));
+  // We want to convert this TextObject into a ButtonObject.
+  // Thus the class TextObject is no longer the logical place for doing this, now is it ?
+  // Okay we call the MenuPreview and let this handle the task.
+  emit (signalDefineAsButton(this));
 }
 
 MenuObject *TextObject::clone ( QWidget *pParent, MenuObject * )
@@ -715,15 +861,18 @@ AnimationAttribute *TextObject::getSpecificAttributes (long iMaxNumberOfFrames,
     pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
   else if (qsProperty == "foregroundColor.red")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorForeground, TYPE_COLOR_RED );
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.red(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.Qt::red(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.red(), callMeBack);		//xxx
   }
   else if (qsProperty == "foregroundColor.green")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorForeground, TYPE_COLOR_GREEN);
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.green(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.Qt::green(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.green(), callMeBack);		//xxx
   }
   else if (qsProperty == "foregroundColor.blue")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorForeground, TYPE_COLOR_BLUE);
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.blue(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.Qt::blue(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorForeground.blue(), callMeBack);		//xxx
   }
   else if (qsProperty == "foregroundColor.alpha")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorForeground, TYPE_COLOR_ALPHA);
@@ -731,15 +880,18 @@ AnimationAttribute *TextObject::getSpecificAttributes (long iMaxNumberOfFrames,
   }
   else if (qsProperty == "backgroundColor.red")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorBackground, TYPE_COLOR_RED);
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.red(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.Qt::red(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.red(), callMeBack);		//xxx
   }
   else if (qsProperty == "backgroundColor.green")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorBackground, TYPE_COLOR_GREEN);
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.green(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.Qt::green(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.green(), callMeBack);		//xxx
   }
   else if (qsProperty == "backgroundColor.blue")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorBackground, TYPE_COLOR_BLUE);
-    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.blue(), callMeBack);
+    //pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.Qt::blue(), callMeBack);	//ooo
+    pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, textData ( )->m_colorBackground.blue(), callMeBack);		//xxx
   }
   else if (qsProperty == "backgroundColor.alpha")	{
     FunctionCallback<Rgba> *callMeBack = new FunctionCallback<Rgba>(textData ( )->m_colorBackground, TYPE_COLOR_ALPHA);
@@ -747,4 +899,3 @@ AnimationAttribute *TextObject::getSpecificAttributes (long iMaxNumberOfFrames,
   }
   return pAnimAttr;
 }
-
