@@ -1,13 +1,17 @@
-/****************************************************************************
-** UndoBuffer and UndoObject code
-**
-**   Created : Thursday Jan 2'nd 2003
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    undobuffer.cpp
+                             -------------------
+    UndoBuffer and UndoObject code
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
+#include <QMessageBox>		//xxx
+
 #include "global.h"
 #include "qdvdauthor.h"
 #include "undobuffer.h"
@@ -28,9 +32,11 @@ UndoBuffer::~UndoBuffer ( )
 {
   uint t;
   // Here we remove all Objects stored in the Undo- and Redo-Buffers
-  for ( t=0; t<count ( ); t++ )
+  //for ( t=0; t<(uint)count ( ); t++ )                 //ooo
+  for ( t=0; t<static_cast<uint> ( count ( ) ); t++ )    //xxx
     delete at ( t );
-  for ( t=0; t<m_redoBuffer.count ( ); t++ )
+  //for ( t=0; t<(uint)m_redoBuffer.count ( ); t++ )                //ooo
+  for ( t=0; t<static_cast<uint> ( m_redoBuffer.count ( ) ); t++ )  //xxx
     delete m_redoBuffer.at ( t );
 }
 
@@ -48,6 +54,7 @@ bool UndoBuffer::removeUnchanged ( )
       }
     }
   }
+
   if ( bFound )
     Global::pApp->updateUndoStack ( );
   return bFound;
@@ -97,12 +104,13 @@ void UndoBuffer::push ( UndoObject *pUndoObject )
   if ( m_bFromOutsidePush )  {
     // Here we check if push was called from this class itself,
     // then we're going to delete the redo Buffer
-    for ( t=0; t<m_redoBuffer.count ( ); t++ )
+    for ( t=0; t<(uint)m_redoBuffer.count ( ); t++ )    //ox
       delete m_redoBuffer.at ( t );
     m_redoBuffer.clear ( );
   }
   m_bFromOutsidePush = true;
-  if ( count ( ) > m_iDepth )  {
+  //if ( (uint)count ( ) > m_iDepth )  {                    //ooo
+  if ( static_cast<uint> ( count ( ) ) > m_iDepth )  {      //xxx
     // here we check and see if the maximal depth of the Undo Buffer has been reached.
     // If so, we delete the first entry before we add another one.
     UndoObject *pUndoObject = first ( );
