@@ -1,38 +1,61 @@
-/****************************************************************************
-** Class Utils implementation ...
-**
-**   Created : Wed Sep 09 07:53:05 2004
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** Here we have some misc functions which are needed by a few classes 
-** but can not really be assigned to any of those classes.
-**
+/***************************************************************************
+    utils.cpp
+                             -------------------
+    Class Utils implementation ...
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   Here we have some misc functions which are needed by a few classes
+   but can not really be assigned to any of those classes.
+    
 ****************************************************************************/
 
 #include <stdlib.h>
-#ifdef QDVD_LINUX
+//#ifdef QDVD_LINUX	//ooo
 #include <unistd.h>
-#endif
+//#endif
 
-#include <qfileinfo.h>
-#include <qregexp.h>
-#include <qimage.h>
-#include <qfile.h>
-#include <qdir.h>
+//#include <qfileinfo.h>	//ooo
+#include <QFileInfo>		//xxx
+//#include <qregexp.h>		//ooo
+#include <QRegExp>		//xxx
+//#include <qimage.h>		//ooo
+#include <QImage>		//xxx
+//#include <qfile.h>		//ooo
+#include <QFile>		//xxx
+//#include <qdir.h>		//ooo
+#include <QDir>			//xxx
+#include <QMessageBox>		//xxx
 
-#include <qstylefactory.h>
-#include <qapplication.h>
-#include <qurloperator.h>
-#include <qmetaobject.h>
-#include <qstyle.h>
+//#include <qstylefactory.h>	//ooo
+#include <QStyleFactory>	//xxx
+//#include <qapplication.h>	//ooo
+#include <QApplication>		//xxx
+//#include <q3urloperator.h>	//ooo
+#include <QUrl>	//xxx
+#include <qmetaobject.h>	//ooo
+#include <QMetaObject>		//xxx
+//#include <qstyle.h>		//ooo
+#include <QStyle>		//xxx
+//Added by qt3to4:
+//#include <Q3TextStream>	//ooo
+#include <QTextStream>		//xxx
+//#include <Q3ValueList>	//oxx
+//#include <Q3PtrList>		//ooo
+#include <QListIterator>		//xxx
+#include <QPixmap>
+#include <QNetworkAccessManager>    //xxx
+#include <QNetworkRequest>  //xxx
+#include <QNetworkReply>    //xxx
 
 #include "global.h"
 #include "utils.h"
-#include "messagebox.h"
+//#include "messagebox.h"	//ooo
 
-#include "win32.h"
+//#include "win32.h"		//ooo
 
 Utils::Utils()
 {
@@ -53,19 +76,23 @@ float Utils::getVersionInfo ( QString &qsFileName )
   QRegExp rx  ( "\\d*\\.\\d+"  ); // floating point
   QString qsLine, qsPath;
   QFileInfo fileInfo ( qsFileName );
-  qsPath = fileInfo.dirPath( true );
+  //qsPath = fileInfo.dirPath( true );		//ooo
+  qsPath = fileInfo.path( );			//xxx
   fileInfo.setFile   ( qsPath );
   if ( ! fileInfo.exists  ( ) )
     return 0.0;
 
   QFile     file ( qsFileName  );
-  if ( file.open ( IO_ReadOnly ) )  {
-    QTextStream stream ( &file );
+  if ( file.open ( QIODevice::ReadOnly ) )  {
+    //Q3TextStream stream ( &file );	//ooo
+    QTextStream stream ( &file );	//xxx
     while ( ! stream.atEnd ( ) )  {
       qsLine= stream.readLine( );
-      if ( rx.search ( qsLine, 0 ) == -1 ) // line must start with a character
+      //if ( rx.search ( qsLine, 0 ) == -1 ) // line must start with a character	//ooo
+      if ( rx.indexIn ( qsLine, 0 ) == -1 ) // line must start with a character		//xxx
         continue;
-      fVersion = atof ( qsLine );
+      //fVersion = atof ( qsLine );			//ooo
+      fVersion = atof ( qsLine.toLatin1().data() );	//xxx
       break;
     }
     file.close ( );
@@ -75,34 +102,83 @@ float Utils::getVersionInfo ( QString &qsFileName )
 }
 
 bool Utils::webToFile ( QString &qsURL, QString &qsLocal )
-{
-  QUrlOperator op; // ( qsServerVersion );
-  QPtrList<QNetworkOperation> list = op.copy ( qsURL, qsLocal );
+{    
+  //Q3UrlOperator op; // ( qsServerVersion );   //ooo
+  QNetworkAccessManager op; // ( qsServerVersion );  //xxx
+  
+  QNetworkAccessManager *manager;   //xxx
+  //QNetworkReply *reply; //xxx
+  
+  //Q3PtrList<Q3NetworkOperation> list = op.copy ( qsURL, qsLocal );    //ooo
+  
+  //op.put(QNetworkRequest(QUrl(qsURL)), QUrl(qsLocal).path().toLatin1()); //xxx
+  
+  m_file = new QFile; //xxx
+  //file->setFileName(saveFilePath);  //xxx
+  m_file->setFileName(QUrl(qsLocal).path().toLatin1() + "/" + QUrl(qsURL).fileName().toLatin1());  //xxx
+  m_file->open(QIODevice::WriteOnly); //xxx
+  
+  manager = new QNetworkAccessManager;  //xxx
+  
+  QNetworkRequest request;  //xxx
+  //request.setUrl(QUrl(fileURL));  //xxx
+  request.setUrl(QUrl(qsURL));  //xxx
+  
+  connect(manager, SIGNAL ( finished ( QNetworkReply * ) ), this, SLOT ( onDownloadFileComplete ( QNetworkReply * ) ) ); //xxx
+  
+  //reply = manager->get(request);    //xxx
+  manager->get(request);    //xxx
+  //manager->put(QNetworkRequest(QUrl(qsURL)), QUrl(qsLocal).path().toLatin1()); //xxx
+  
+  //QList<QNetworkReply> list = op.put(QNetworkRequest(QUrl(qsURL)), QUrl(qsLocal).path().toLatin1()); //xxx
+  //QList<QNetworkReply*> list = op.get ( QNetworkRequest( QUrl(qsURL) ) ); //xxx
+  //QList<QNetworkReply*> list;   //xxx
+  //list << op.get ( QNetworkRequest( QUrl(qsURL) ) ); //xxx
   // Next we make sure we get the whole file ( less then 1k )
   bool bDone = false;
   int iMaxCounter = 30; // 30 * 100 msec = 3sec
-  while ( bDone == false )  {
+/*  while ( bDone == false )  {
     bDone = false;
-    QPtrList<QNetworkOperation>::iterator it = list.begin ( );
+    //Q3PtrList<Q3NetworkOperation>::iterator it = list.begin ( );  //ooo
+    QList<QNetworkReply*>::iterator it = list.begin ( );    //xxx
     while ( it != list.end ( ) )  {
-      QNetworkOperation *pNO = *it++;
-      if ( pNO->state ( ) != QNetworkProtocol::StDone )
+      //Q3NetworkOperation *pNO = *it++;    //ooo
+      QNetworkReply *pNO = *it++;   //xxx 
+      //if ( pNO->state ( ) != Q3NetworkProtocol::StDone )  //ooo
+      if ( pNO->error ( ) != QNetworkReply::NoError )    //xxx
         break;
-      if ( pNO->state ( ) == QNetworkProtocol::StFailed )
-        return false;
+      //if ( pNO->state ( ) == Q3NetworkProtocol::StFailed )    //ooo
+      if ( pNO->error ( ) == QNetworkReply::NoError ) { //xxx
+        onDownloadFileComplete(pNO);    //xxx
+        return false;   //ooo
+      }
       bDone = true;
     }
     if ( ! bDone )  {
       // Not yet done.
       qApp->processEvents ( );
       iMaxCounter --;
-      usleep ( 100000 ); // sleep for a 100 milli seconds.
+      //usleep ( 100000 ); // sleep for a 100 milli seconds.			//ooo
+      SleeperThread8::msleep ( 100 ); // sleep for a 100 milli seconds.		//xxx
       if ( iMaxCounter == 0 )  // exit after max attempts.
            bDone = true;
     }
-  }
+  }*/   //ooo
 
-  return ( iMaxCounter > 0 );
+  return ( iMaxCounter > 0 ); //ooo
+}
+
+void Utils::onDownloadFileComplete(QNetworkReply *reply) {  //xxx
+    if (!m_file->isWritable()) {
+        m_isReady = true;
+        return; // TODO: error check
+    }
+
+    m_file->write(reply->readAll());
+    m_file->close(); // TODO: delete the file from the system later on
+    m_isReady = true;
+    
+    delete m_file;  //xxx
 }
 
 QStringList Utils::localTemplates ( )
@@ -114,10 +190,13 @@ QStringList Utils::localTemplates ( )
   QStringList::iterator it2;
   QDir theDir;
   bool bFound;
-  const QFileInfoList *pList;
-  QFileInfo *pFileInfo;
+  //const QFileInfoList *pList;		//ooo
+  QFileInfoList pList;			//xxx
+  //QFileInfo *pFileInfo;		//ooo
+  QFileInfo pFileInfo;			//xxx
 
-  qsBasePath = QDir::homeDirPath ( ) + "/.qdvdauthor/";
+  //qsBasePath = QDir::homeDirPath ( ) + "/.qdvdauthor/";	//ooo
+  qsBasePath = QDir::homePath ( ) + "/.qdvdauthor/";		//xxx
   qsSubPaths[0] = "static";
   qsSubPaths[1] = "animated";
   qsSubPaths[2] = "transition";
@@ -129,13 +208,19 @@ QStringList Utils::localTemplates ( )
       theDir.setPath    ( qsPath );
       theDir.setFilter  ( QDir::Dirs );
       pList = theDir.entryInfoList ( );
-      if ( ! pList || pList->count ( ) < 1 )
+      //if ( ! pList || pList->count ( ) < 1 )		//ooo
+      if ( pList.count ( ) < 1 )		//xxx
+      //if ( pList.isEmpty ( ) )				//xxx
         continue;
 
-      QFileInfoListIterator  it ( *pList );
-      while( (pFileInfo = it.current ( ) ) != 0 )  {
-        ++it;
-        qsTemplate = pFileInfo->fileName ( );
+      //QFileInfoListIterator  it ( *pList );		//ooo
+      QListIterator<QFileInfo> it ( pList );		//xxx
+      //while( (pFileInfo = it.current ( ) ) != 0 )  {	//ooo
+      while( it.hasNext( ) )  {				//xxx
+        //++it;						//ooo
+	pFileInfo = it.next ( );			//xxx
+        //qsTemplate = pFileInfo->fileName ( );		//ooo
+	qsTemplate = pFileInfo.fileName ( );		//xxx
         if ( ( qsTemplate == "."  ) ||
              ( qsTemplate == ".." ) )
           continue;
@@ -154,9 +239,10 @@ QStringList Utils::localTemplates ( )
     }
     qsBasePath = Global::qsSystemPath + "/share/qdvdauthor/";
   }
-//for (t=0; t<list.size ( ); t++ )
-//  printf ( "%s \n", list[t].ascii() );
-//printf ( "2 list<%d>\n", list.size() );
+//for (t=0; t<list.size ( ); t++ )    //ooo //
+//    printf ( "%s \n", list[t].ascii() );  //ooo //
+//  printf ( "%s \n", list[t].toLatin1().data() );  //xxx //  
+//printf ( "2 list<%d>\n", list.size() ); //ooo //
 
   return list;
 }
@@ -170,7 +256,8 @@ QString Utils::findGuiSU ( )
   QFileInfo fileInfo ( qsTmpOut );
   for ( t=0; t<3; t++ )     {
     // the next check is to see if we can find kdesu
-    int iRet = system ((const char *)QString ( "which %1 > %2 2>/dev/null").arg ( arraySUs[t] ).arg ( qsTmpOut ) );
+    //int iRet = system ((const char *)QString ( "which %1 > %2 2>/dev/null").arg ( arraySUs[t] ).arg ( qsTmpOut ) );		//ooo
+    int iRet = system (QString ( "which %1 > %2 2>/dev/null").arg ( arraySUs[t] ).arg ( qsTmpOut ).toLatin1().data() );		//xxx
     iRet = iRet;
     fileInfo.setFile ( qsTmpOut );
     // Okay we cna not find it, so we wont bother asking the user ...
@@ -197,7 +284,7 @@ void Utils::createStructureIcons ( )
     temp = QPixmap ( QString ( "/home/varol/structure_icons/" ) + files[t] );
     if ( temp.isNull ( ) )
       continue;
-    copyBlt ( &final, t*32, 0, &temp );
+    //copyBlt ( &final, t*32, 0, &temp );	//ooo
   }
 
   final.save ( "/tmp/structure_icons.png", "PNG", 100 );
@@ -286,7 +373,8 @@ QString Utils::currentStyleName ( )
     QString styleName = *it;
     QStyle *candidate = QStyleFactory::create(styleName);
     Q_ASSERT(candidate);
-    if (candidate->metaObject()->className() == QApplication::style().metaObject()->className()) {
+    //if (candidate->metaObject()->className() == QApplication::style().metaObject()->className()) {	//ooo
+    if (candidate->metaObject()->className() == QApplication::style()->metaObject()->className()) {	//xxx
       delete candidate;
       return styleName;
     }
@@ -299,7 +387,8 @@ bool Utils::getWidthHeight ( QString qsDimension, int &iWidth, int &iHeight )
 {
   iWidth  = 0;
   iHeight = 0;
-  QStringList listSize = QStringList::split ( "x", qsDimension );
+  //QStringList listSize = QStringList::split ( "x", qsDimension );	//ooo
+  QStringList listSize = qsDimension.split ( "x" );			//xxx
   bool bReturn = false;
   if ( listSize.count ( ) > 1 )  {
     iWidth  = listSize[0].toInt ( );
@@ -317,7 +406,8 @@ QString Utils::formatChapter (QString qsInput)
 	if (qsInput == QString ("0"))
 		return qsReturn;
 	// Here we tidy up the chapter. E.g. 0 gets converted to 00:00:00.000, 0.0.32 to 00:00:32.000 etc
-	QStringList listParts = QStringList::split(":", qsInput);
+	//QStringList listParts = QStringList::split(":", qsInput);	//ooo
+	QStringList listParts = qsInput.split(":");			//xxx
 	// SanityCheck ...
 	if (listParts.count() < 3)
 		return qsReturn;
@@ -356,23 +446,26 @@ long Utils::normToLong ( QString qsInput )
 	uint t, i;
 	long iReturn, iMultiplicator = 1;
 	// Here we take a string like 4400kbps and return 4400000.
-	for (t=0;t<qsInput.length();t++)	{
-		for (i=0;i<arrayDigit.length();i++)	{
+	for (t=0;t<(uint)qsInput.length();t++)	{	//ox
+		for (i=0;i<(uint)arrayDigit.length();i++)	{	//ox
 			if ( qsInput.at ( t ) == arrayDigit.at ( i ) )	{
 				qsValue += qsInput.at ( t );
 				i = 10;
 				continue;
 			}
 		}
-		if (qsInput.at ( t ).upper () == "K")	{
+		//if (qsInput.at ( t ).upper () == "K")	{	//ooo
+		if (qsInput.at ( t ).toUpper () == 'K')	{	//xxx
 			iMultiplicator = 1000;
 			break;
 		}
-		if (qsInput.at ( t ).upper () == "M")	{
+		//if (qsInput.at ( t ).upper () == "M")	{	//ooo
+		if (qsInput.at ( t ).toUpper () == 'M')	{	//xxx
 			iMultiplicator = 1000000;
 			break;
 		}
-		if (qsInput.at ( t ).upper () == "G")	{
+		//if (qsInput.at ( t ).upper () == "G")	{	//ooo
+		if (qsInput.at ( t ).toUpper () == 'G')	{	//xxx
 			iMultiplicator = 1000000000;
 			break;
 		}
@@ -385,13 +478,15 @@ QString Utils::getAttribute (QString qsAttrName, QString qsFullString)
 {
 	QString qsReturn;
 	int iStart, iEnd;
-	iStart = qsFullString.find (qsAttrName);
+	//iStart = qsFullString.find (qsAttrName);	//ooo
+	iStart = qsFullString.indexOf (qsAttrName);	//xxx
 	if (iStart < 1)
 		return qsReturn;
 	// increase iStart to skip e.g.[chapters="] and get to the start of the chapters.
 	iStart += qsAttrName.length() + 2;
 	// Now we find the end ...
-	iEnd = qsFullString.find ("\"", iStart);
+	//iEnd = qsFullString.find ("\"", iStart);	//ooo
+	iEnd = qsFullString.indexOf ("\"", iStart);	//xxx
 	if (iEnd < 1) 
 		return qsReturn;
 	qsReturn = qsFullString.mid (iStart, iEnd-iStart);
@@ -463,15 +558,19 @@ void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
   uchar *pLine;
   unsigned long iCounter = 0;
   int  x, y, t, iIndex, iImageColors;
-  QRgb theNearestColor, theColor, *pImageColors;
+  //QRgb theNearestColor, theColor, *pImageColors;	//ooo
+  QRgb theNearestColor, theColor;			//xxx
+  QVector<QRgb> pImageColors;				//xxx
 
   // First we have to ensure that we do have a color indexed image.
-  theImage = theImage.convertDepthWithPalette (8, (QRgb *)pPalette, iNumColors, Qt::ThresholdDither);
+  //theImage = theImage.convertDepthWithPalette (8, (QRgb *)pPalette, iNumColors, Qt::ThresholdDither);		//ooo
+  theImage = theImage.convertToFormat (QImage::Format_Indexed8, Qt::ThresholdDither);		//xxx
 
   // This will create a image which might have more then the requested colors.
   // So we replace all colors with the nearest color of the four.
   pImageColors = theImage.colorTable ();
-  iImageColors = theImage.numColors  ();
+  //iImageColors = theImage.numColors  ();	//ooo
+  iImageColors = theImage.colorCount  ();	//xxx
   for (t=0;(int)t<iImageColors; t++) {
     theNearestColor = nearestColor (pPalette, iNumColors, pImageColors[t]);
     theImage.setColor (t, theNearestColor );
@@ -507,7 +606,8 @@ void Utils::reduceColors ( QImage &theImage, int iNumColors, QRgb *pPalette )
 //  }
 //  printf ("\n\n" );
   // Then we should cut down the number of colors used ...
-  theImage.setNumColors ( iNumColors );
+  //theImage.setNumColors ( iNumColors );	//ooo
+  theImage.setColorCount ( iNumColors );	//xxx
 
   // and then set the right colors ...
   for (t=0;t<iNumColors;t++)
@@ -521,7 +621,8 @@ long Utils::countColors ( QImage &theImage )
 
   if ( theImage.depth () == 8 )  {
     uchar *pLine;
-    QValueList<int> listFoundColors;
+    //Q3ValueList<int> listFoundColors;		//ooo
+    QList<int> listFoundColors;			//xxx
     // Here we are going to shift all colors down to the first iNumColors places
     for (y=0;y<theImage.height();y++) {
       pLine = theImage.scanLine ( y );
@@ -544,7 +645,7 @@ long Utils::countColors ( QImage &theImage )
 //static bool bFirst=true;
 
     QRgb *pLine, rgb;
-    QValueList<QRgb> listFoundColors;
+    QList<QRgb> listFoundColors;		//oxx
     for (y=0;y<theImage.height();y++) {
       pLine = (QRgb *)theImage.scanLine ( y );
       for (x=0;x<theImage.width();x++) {
@@ -612,6 +713,7 @@ int Utils::getFormat (int iWidth, int iHeight)
 		iFormat = FORMAT_PAL3;
 	else if  ((iWidth == 352) && (iHeight == 288) )
 		iFormat = FORMAT_PAL4;
+	
 	return iFormat;
 }
 
@@ -715,21 +817,30 @@ QString Utils::checkForExe( QString qsExe )
 	QString qsExePath;
 	QFileInfo fileInfo(QString ("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// the next check is to see if we can find 
-	if ( system ((const char *)QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin())) == -1)
+	//if ( system ((const char *)QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin())) == -1)	//ooo
+	if ( system (QString ("which %1 > %2/%3_out.txt 2>/dev/null").arg(qsExe).arg(Global::qsTempPath).arg(getlogin()).toLatin1().data()) == -1)	//xxx
 		return QString ();
 	fileInfo.setFile(QString("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
 	// Okay we can not find it, so we wont bother asking the user ...
 	if (fileInfo.size() > 4)	{
 	  QFile theFile   (QString ("%1/%2_out.txt").arg(Global::qsTempPath).arg(getlogin()));
-		theFile.open    (IO_ReadOnly);
-		theFile.readLine(qsExePath, 4096);
-		theFile.close();
-		if (!qsExePath.isEmpty())	{
-			qsExePath.remove("\n");
-			return qsExePath;
+		//theFile.open    (QIODevice::ReadOnly);	//ooo
+		//theFile.readLine(qsExePath, 4096);		//ooo
+		if ( theFile.open ( QIODevice::ReadOnly ) )  {	//xxx
+			QTextStream in(&theFile);
+			qsExePath = in.readLine();
+			if (!qsExePath.isEmpty())	{
+				qsExePath.remove("\n");
+			}
 		}
+		theFile.close();
+		//if (!qsExePath.isEmpty())	{	//ooo
+		//	qsExePath.remove("\n");
+		//	return qsExePath;
+		//}
 	}
-	return QString();
+	//return QString();	//ooo
+	return qsExePath;	//xxx
 }
 
 QString Utils::getToolsDisplayName (QString qsExecutableName)
@@ -787,7 +898,7 @@ QString Utils::getToolPath ( QString qsToolName )
   QString qsReturn;
   Utils::toolsPaths *pToolPath;
   uint t;
-  for ( t=0; t<Global::listToolsPaths.count ( ); t++ ) {
+  for ( t=0; t<(uint)Global::listToolsPaths.count ( ); t++ ) {	//ox
     pToolPath = Global::listToolsPaths[ t ];
     if ( pToolPath && ( pToolPath->qsExecutableName == qsToolName ) )
       return pToolPath->qsFullPath;
@@ -795,9 +906,9 @@ QString Utils::getToolPath ( QString qsToolName )
   return qsReturn;
 }
 
-QValueList<Utils::toolsPaths *>Utils::scanSystem()
+QList<Utils::toolsPaths *>Utils::scanSystem()			//oxx
 {
-	static QValueList<Utils::toolsPaths *>listToolsPaths;
+	static QList<Utils::toolsPaths *>listToolsPaths;	//oxx
 	Utils::toolsPaths *pEntry;
 
 	uint t, iNrOfTools;
@@ -837,7 +948,8 @@ bool Utils::isMandatory(uint iIndex)
 		char pDescription[1024];
 	};
 	const structTools toolsArray[] = { EXTERNAL_TOOLS };
-	if (QString (toolsArray[iIndex].pDescription).find ("Mandatory") > -1)
+	//if (QString (toolsArray[iIndex].pDescription).find ("Mandatory") > -1)	//ooo
+	if (QString (toolsArray[iIndex].pDescription).indexOf ("Mandatory") > -1)	//xxx
 		return true;
 	return false;
 }
@@ -877,14 +989,17 @@ QString Utils::getUniqueTempFile (QString qsOrigFileName)
 	QString qsUniqueFileName, qsFileName;
 	QFileInfo fileInfo (qsOrigFileName);
 	QString qsOrigBaseName   = fileInfo.baseName ();
-	QString qsOrigExtension  = fileInfo.extension();
+	//QString qsOrigExtension  = fileInfo.extension();	//ooo
+	QString qsOrigExtension  = fileInfo.suffix();		//xxx
 
-	qsFileName.sprintf ("%s%03d.%s", (const char *)qsOrigBaseName, t++, (const char *)qsOrigExtension);
+	//qsFileName.sprintf ("%s%03d.%s", (const char *)qsOrigBaseName, t++, (const char *)qsOrigExtension);		//ooo
+	qsFileName.sprintf ("%s%03d.%s", qsOrigBaseName.toLatin1().data(), t++, qsOrigExtension.toLatin1().data());	//xxx
 	qsUniqueFileName = getTempFile(qsFileName);
 	// The same as above but we ensure the file does not yet exist.
 	fileInfo.setFile(qsUniqueFileName);
 	while (fileInfo.exists())	{
-		qsFileName.sprintf ("%s%03d.%s", (const char *)qsOrigBaseName, t++, (const char *)qsOrigExtension);
+		//qsFileName.sprintf ("%s%03d.%s", (const char *)qsOrigBaseName, t++, (const char *)qsOrigExtension);	//ooo
+	  qsFileName.sprintf ("%s%03d.%s", qsOrigBaseName.toLatin1().data(), t++, qsOrigExtension.toLatin1().data());	//xxx
 		qsUniqueFileName = getTempFile(qsFileName);
 		fileInfo.setFile(qsUniqueFileName);
 	}
@@ -908,9 +1023,12 @@ QStringList Utils::getProjectsFromTempPath()
 		if ( ( qsTemp == "." ) || ( qsTemp == ".." ) )
 			continue;
 		// three criterias
-		backgroundFile.setName ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM/background.jpg" ).arg ( qsTemp ) );
-		menuBackgroundFile.setName ( tempDir.absPath ( ) + QString ("/%1/background.jpg" ).arg ( qsTemp ) );
-		mainMenuDir.setPath ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM" ).arg ( qsTemp ) );
+		//backgroundFile.setName ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM/background.jpg" ).arg ( qsTemp ) );				//ooo
+		backgroundFile.setFileName ( tempDir.absoluteFilePath (Global::qsTempPath) + QString ( "/%1/Main Menu VMGM/background.jpg" ).arg ( qsTemp ) );	//xxx
+		//menuBackgroundFile.setName ( tempDir.absPath ( ) + QString ("/%1/background.jpg" ).arg ( qsTemp ) );						//ooo
+		menuBackgroundFile.setFileName ( tempDir.absoluteFilePath (Global::qsTempPath) + QString ("/%1/background.jpg" ).arg ( qsTemp ) );		//xxx
+		//mainMenuDir.setPath ( tempDir.absPath ( ) + QString ( "/%1/Main Menu VMGM" ).arg ( qsTemp ) );						//ooo
+		mainMenuDir.setPath ( tempDir.absoluteFilePath (Global::qsTempPath) + QString ( "/%1/Main Menu VMGM" ).arg ( qsTemp ) );			//xxx
 		if ( backgroundFile.exists ( ) )
 			listOfProjects.append ( qsTemp );
 		else if (menuBackgroundFile.exists ( ) )
@@ -926,13 +1044,16 @@ QImage  Utils::convertStringToImage (QString &qsImage)
 	uint t;
 	bool bOk;
 	QImage theImage;
-	QByteArray baData(qsImage.length());
+	//QByteArray baData(qsImage.length());					//ooo
+	QByteArray baData(qsImage.toLatin1().data(), qsImage.length());		//xxx
 
 	// Here we convert the hex values to char ...
-	for (t=0;t<qsImage.length();t++)
-		baData.at ( t ) = qsImage.mid (t*2, 2).toUInt(&bOk, 16);
+	for (t=0;t<(uint)qsImage.length();t++)	//ox
+		//baData.at ( t ) = qsImage.mid (t*2, 2).toUInt(&bOk, 16);	//ooo
+		baData[ t ] = qsImage.mid (t*2, 2).toUInt(&bOk, 16);		//xxx
 	
-	QDataStream stream( baData, IO_ReadOnly );
+	//QDataStream stream( baData, QIODevice::ReadOnly );	//ooo
+	QDataStream stream( &baData, QIODevice::ReadOnly );	//xxx
 	stream >> theImage;
 
 	return theImage;
@@ -943,9 +1064,10 @@ QString Utils::convertImageToString (QImage &theImage)
 	uint t;
 	QString qsTemp, qsResult;
 	QByteArray baData;
-	QDataStream stream( baData, IO_WriteOnly );
+	//QDataStream stream( baData, QIODevice::WriteOnly );	//ooo
+	QDataStream stream( &baData, QIODevice::WriteOnly );	//xxx
 	stream << (const QImage &)theImage;
-	for (t=0;t<baData.count();t++)	{
+	for (t=0;t<(uint)baData.count();t++)	{	//ox
 		qsTemp.sprintf ("%02X", (uchar)baData.at ( t ) );
 		qsResult += qsTemp;
 	}
@@ -958,16 +1080,20 @@ bool Utils::recRmdir( const QString &dirName, const char *pExcludeFiles ) const
 	// Recursively removes directroy and all sub-directories.
 	// Attention this can be devestating !
 	QString dirN = dirName;
+
 	if(QDir::isRelativePath(dirN)) // if not absolute path, make it absolute
 		dirN = QDir::current().path() + dirN; // FIXME: I'm not really sure that this works
 	QDir dir(dirN);
-	QStringList list = dir.entryList(QDir::All); // make list of entries in directory
+	//QStringList list = dir.entryList(QDir::All); // make list of entries in directory		//ooo
+	QStringList list = dir.entryList(QDir::AllEntries); // make list of entries in directory	//xxx
 	unsigned int i, lstCnt = list.count();
 	QFileInfo fileInfo;
 	QString curItem, lstAt;
 	bool bRemove;
 	for(i = 0; i < lstCnt; i++){ // loop through all items of list
-		lstAt = *list.at(i);
+		//lstAt = *list.at(i);		//ooo
+		lstAt = list.at(i);		//xxx
+
 		if(!(lstAt == ".") && !(lstAt == "..")){
 			curItem = dirN + "/" + lstAt;
 			fileInfo.setFile(curItem);
@@ -976,7 +1102,8 @@ bool Utils::recRmdir( const QString &dirName, const char *pExcludeFiles ) const
 			else	{                  // is file
 				bRemove = true;
 				if (pExcludeFiles)	{		// If we want to keep files
-					if (lstAt.find (pExcludeFiles) == 0)	// which begin with the string *pExcludeFiles
+					//if (lstAt.find (pExcludeFiles) == 0)	// which begin with the string *pExcludeFiles	//ooo
+					if (lstAt.indexOf (pExcludeFiles) == 0)	// which begin with the string *pExcludeFiles	//xxx
 						bRemove = false;	// Then we flag so ...
 				}
 				if (bRemove)
@@ -996,8 +1123,10 @@ bool Utils::recMkdir ( const QString &qsDir )
 
   int t;
   QString qsFullPath, qsPartialDir;
-  qsFullPath = theDir.absPath ( );
-  QStringList dirList = QStringList::split ( "/", qsFullPath );
+  //qsFullPath = theDir.absPath ( );			//ooo
+  qsFullPath = theDir.absoluteFilePath ( qsDir );	//xxx
+  //QStringList dirList = QStringList::split ( "/", qsFullPath );	//ooo
+  QStringList dirList = qsFullPath.split ( "/" );			//xxx
 
   for ( t=0; t<(int)dirList.count ( ); t++ )  {
     qsPartialDir += "/" + dirList[t];
@@ -1011,7 +1140,8 @@ bool Utils::recMkdir ( const QString &qsDir )
   // Sanity check if the dir exists ...
   theDir.setPath ( qsFullPath );
   if ( ! theDir.exists ( ) )  {
-    MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),
+    //MessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),	//ooo
+    QMessageBox::warning ( NULL, QObject::tr ("Could not create temp directory"),	//xxx
     QObject::tr ("Failed to create temp directory\n%1\nPlease make sure you have the read/write access.").arg  ( qsFullPath ),
     QMessageBox::Ok, QMessageBox::NoButton);
     return false;
@@ -1020,14 +1150,15 @@ bool Utils::recMkdir ( const QString &qsDir )
 }
 
 long Utils::getMsFromString ( QString qsInput )
-{
+{ 
   long iMilliSeconds;
   uint iHours, iMinutes, iSeconds, iStepper;
   float fSeconds=0.0;
   iStepper=0;
   // 00:00:00.000
   iHours = iMinutes = iSeconds = iMilliSeconds = 0;
-  QStringList listParts = QStringList::split (":", qsInput);
+  //QStringList listParts = QStringList::split (":", qsInput);	//ooo
+  QStringList listParts = qsInput.split (":");			//xxx
   if (listParts.count() > 3)
     return 0;
   if (listParts.count() > 2)
@@ -1102,7 +1233,8 @@ int Utils::getWHFromResolution ( QString qsResolution, bool bWidth )
   int iXPos;
   QString qsWidth, qsHeight;
 
-  iXPos = qsResolution.find ("x");
+  //iXPos = qsResolution.find ("x");	//ooo
+  iXPos = qsResolution.indexOf ("x");	//xxx
   if ( bWidth ) {
     qsWidth  = qsResolution.left (iXPos);
     return qsWidth.toInt ();
@@ -1116,21 +1248,31 @@ bool Utils::isMpeg2 ( QString qsFileName )
   unsigned char Mpeg2Header[4] = { 0x00, 0x00, 0x01, 0xba };
   int t, iByte;
   unsigned char c;
+  //char *ch;				//xxx
+  char ch;				//xxx
   QFile theFile ( qsFileName );
 
   if ( ! theFile.exists () )
     return false;
 
-  if ( ! theFile.open ( IO_ReadOnly ) )
+  if ( ! theFile.open ( QIODevice::ReadOnly ) )
     return false;
 
   for (t=0;t<4;t++) {
-    iByte = theFile.getch ();
+    //iByte = theFile.getch ();			//ooo
+    theFile.getChar (&ch);			//xxx
+    //iByte = theFile.pos();			//xxx
+    //QByteArray line = theFile.readLine();	//xxx
+
+    //iByte = line.at(t);	//xxx
+    iByte = (int) ch;		//xxx
+
     if ( iByte == -1 ) {
       theFile.close ();
       return false;
     }
     c = (unsigned char) iByte;
+
     if ( Mpeg2Header[t] != c )
       return false;
   }
@@ -1158,26 +1300,31 @@ bool Utils::hasVobus ( QString qsFileName )
   unsigned char DSI_PACK[] = { 0x00, 0x00, 0x01, 0xBF, 0x03, 0xFA };
 
   QFile theFile ( qsFileName );
-  if ( ! theFile.open ( IO_ReadOnly ) )
+  if ( ! theFile.open ( QIODevice::ReadOnly ) )
     return false;
 
   // skip zeroes at start of file
   int zeroCnt = 0;
   char c;
-  while ( (c = (char)theFile.getch ( ) ) == 0)
-    zeroCnt++;
 
-  if ( zeroCnt < 2 || c != 1 )
+  //while ( (c = (char)theFile.getch ( ) ) == 0)	//ooo
+  while ( ( theFile.getChar ( &c ) ) && ( c == 0x00 ) )	//xxx
+      zeroCnt++;
+
+  //if ( zeroCnt < 2 || c != 1 )	//ooo
+  if ( zeroCnt < 2 || c != 0x01 )	//xxx
     return false;
 
   const long MAX_LENGTH = 16*1024; // only looking at 1st 16KB - enough to contain nav packs
   unsigned char *buffer = new unsigned char[MAX_LENGTH];
 
   buffer[0] = buffer[1] = 0; buffer[2] = 1;
-  int iRead = theFile.readBlock ( (char *)(buffer+3), MAX_LENGTH-3);
+  //int iRead = theFile.readBlock ( (char *)(buffer+3), MAX_LENGTH-3);	//ooo
+  int iRead = theFile.read ( (char *)(buffer+3), MAX_LENGTH-3);		//xxx
 
   bool bValidPCI = false;
   bool bValidDSI = false;
+
   for ( int i=0; i<iRead-(int)sizeof(PCI_PACK); i++ )  {
     int j;
     for ( j=0; j<(int)sizeof(PCI_PACK); j++ )  {
@@ -1210,7 +1357,8 @@ bool Utils::checkCommand ( const char *pCommand )
   QString qsTmpFile = QString ( "%1"  ).arg ( tmpName  );
   QString qsCommand = QString ( "%1 > %2 " ).arg ( pCommand ).arg ( qsTmpFile );
 
-  int iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;
+  //int iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;		//ooo
+  int iRet = system ( qsCommand.toLatin1().data ( ) ); iRet = iRet;	//xxx
   QFile theFile ( qsTmpFile );
   if ( theFile.exists ( ) ) {
     if ( theFile.size ( ) > 2 )
@@ -1231,11 +1379,11 @@ QString Utils::getDefaultParameter ( enDefaultParameter enWhich )
          qsReturn = QString ( "420_mpeg2" ); // must be mjpegtools version smaller then 1.8.0 !!!
   }
   break;
-  case toolameSampleRate:
+  case twolameSampleRate:
   default: {
     qsReturn = QString ( "48000" ); // E.g. toolame 0.2m
     // execute [toolame -h 2>&1 | grep sfrq | grep "rate in Hz" > /tmp/test ] and check if result is empty.
-    if ( checkCommand ( "toolame -h 2>&1 | grep sfrq | grep \"rate in kHz\"" ) )
+    if ( checkCommand ( "twolame -h 2>&1 | grep sfrq | grep \"rate in kHz\"" ) )
        qsReturn = QString ( "48" ); // E.g.  toolame 0.2i
   }
   break;
