@@ -21,7 +21,8 @@
 // Version 1.1 RC3 = 1. 01 03
 // Note the minor version is one behind the RC version
 #define QDVDAUTHOR_VERSION                     "XMLVersion"
-#define QDVDAUTHOR_VERSION_NUMBER              "2.0301"
+#define QDVDAUTHOR_VERSION_NUMBER              "2.0301-015"
+#define QDVDAUTHOR_RELEASE_DATE                "Apr 13, 2025" //xxx
 
 // Here we goof around with the Templates
 // Nodes
