@@ -1,20 +1,24 @@
-/************************************************************
-  **
-  **   Created :
-  **        by : Varol Okan 
-  ** Copyright : (c) Varol Okan
-  **   License : GPL v 2.0
-  **
-  **********************************************************/
-#include "../bugs_workaround.h"
+/***************************************************************************
+    xml_dvdauthor.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+****************************************************************************/
+
+//#include "../bugs_workaround.h"	//ooo
 #include "global.h"
 #include "xml_dvdauthor.h"
 #include "messagebox.h"
 
-#include <qfiledialog.h>
-#include <qfile.h>
-#include <qstring.h>
-#include <qdom.h>
+#include <QFileDialog>
+#include <QFile>
+#include <QString>
+#include <QObject>	//xxx
+//#include <QDom>	//ooo
 
 #ifndef MAX_AUDIO
 #define MAX_AUDIO 8
@@ -57,7 +61,8 @@ bool CXmlDVDAuthor::readXml ()
 	// Later on this is done a level further up and only QDomNode * is sent.
 	//
 	//////////////////////////////////////////////////////////////////////////////////
-	QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));
+	//QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));		//ooo
+	QString fileName = QFileDialog::getOpenFileName ( NULL, QObject::tr("Open File"), QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));
 	return readXml ( fileName );
 }
 
@@ -65,7 +70,7 @@ bool CXmlDVDAuthor::readXml (QString &fileName )
 {
 	// Assign the file
 	QFile projectFile(fileName);
-	if (!projectFile.open( IO_ReadWrite))
+	if (!projectFile.open( QIODevice::ReadWrite))
 		return false;
 
 	QDomDocument xmlDoc( DVD_DOCTYPE );
@@ -91,7 +96,8 @@ bool CXmlDVDAuthor::dvdauthor_struct::readXml ( QDomElement *pDocElem )
 	titleset_struct  tempTitleset;  // temp to get the node_name.
 	titleset_struct *pTitleset = NULL;
 	bool bReturn = true;
-	debug_out ("CXmlDVDAuthor::dvdauthor_struct::readXml <%s><%s>\n",(const char *)pDocElem->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::dvdauthor_struct::readXml <%s><%s>\n",(const char *)pDocElem->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::dvdauthor_struct::readXml <%s><%s>\n",pDocElem->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	if ( pDocElem->tagName ( ) != node_name )
 		return false;
 	// So lets get first the attributes for this node.
@@ -121,7 +127,8 @@ bool CXmlDVDAuthor::dvdauthor_struct::readXml ( QDomElement *pDocElem )
 
 bool CXmlDVDAuthor::vmgm_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ( "CXmlDVDAuthor::vmgm_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ( "CXmlDVDAuthor::vmgm_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ( "CXmlDVDAuthor::vmgm_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	// vmgm has no attributes thus far I can tell.
 	// And now read in all remaining nodes and handle them accordingly.
@@ -149,7 +156,8 @@ bool CXmlDVDAuthor::vmgm_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::titleset_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::titleset_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::titleset_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::titleset_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	// titleset has no attributes thus far I can tell.
 	// And now read in all remaining nodes and handle them accordingly.
@@ -180,7 +188,8 @@ bool CXmlDVDAuthor::titleset_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::menus_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::menus_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::menus_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::menus_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int iAudioChannel = 0;
 	int iSubpicture   = 0;
@@ -225,7 +234,8 @@ bool CXmlDVDAuthor::menus_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::video_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::video_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::video_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::video_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// The video node has only attributes and nothing else.
 	QDomAttr a = pNodeElement->attributeNode ( VIDEO_FORMAT );
 	format = a.value();
@@ -242,7 +252,8 @@ bool CXmlDVDAuthor::video_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::audio_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::audio_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::audio_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::audio_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// The audio node has only attributes and nothing else.
 	QDomAttr a = pNodeElement->attributeNode ( AUDIO_FORMAT );
 	format = a.value();
@@ -259,7 +270,8 @@ bool CXmlDVDAuthor::audio_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::subpicture_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::subpicture_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::subpicture_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::subpicture_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// The subpicture node has only attributes and nothing else.
 	QDomAttr a = pNodeElement->attributeNode ( SUBPICTURE_LANG );
 	lang = a.value();
@@ -267,7 +279,8 @@ bool CXmlDVDAuthor::subpicture_struct::readXml(QDomElement *pNodeElement)
 }
 bool CXmlDVDAuthor::titles_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::titles_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::titles_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::titles_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int iAudioChannel = 0;
 	int iSubpicture   = 0;
@@ -306,7 +319,8 @@ bool CXmlDVDAuthor::titles_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::pgc_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::pgc_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::pgc_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::pgc_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	button_struct tempButton;
 	vob_struct tempVob;
@@ -347,7 +361,8 @@ bool CXmlDVDAuthor::pgc_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::button_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::button_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::button_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::button_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// First read the attributes
 	QDomAttr a = pNodeElement->attributeNode ( BUTTON_NAME );
 	name = a.value();
@@ -358,7 +373,8 @@ bool CXmlDVDAuthor::button_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::cell_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::cell_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::cell_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::cell_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// First read the attributes
 	QDomAttr a = pNodeElement->attributeNode ( CELL_START );
 	start = a.value();
@@ -375,7 +391,8 @@ bool CXmlDVDAuthor::cell_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::vob_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::vob_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::vob_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::vob_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	// First read the attributes
 	QDomAttr a = pNodeElement->attributeNode ( VOB_FILE );
@@ -405,7 +422,8 @@ bool CXmlDVDAuthor::vob_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::fpc_struct::readXml ( QDomElement *pNodeElement )
 {
-	debug_out ("CXmlDVDAuthor::fpc_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::fpc_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::fpc_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// read the commands to be executed before.
 	value = pNodeElement->text();
 	return true;
@@ -413,7 +431,8 @@ bool CXmlDVDAuthor::fpc_struct::readXml ( QDomElement *pNodeElement )
 
 bool CXmlDVDAuthor::pre_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::pre_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::pre_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::pre_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// read the commands to be executed before.
 	value = pNodeElement->text();
 	return true;
@@ -421,7 +440,8 @@ bool CXmlDVDAuthor::pre_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlDVDAuthor::post_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::post_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::post_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::post_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// read the commands to be executed after.
 	value = pNodeElement->text();
 	return true;
@@ -429,7 +449,8 @@ bool CXmlDVDAuthor::post_struct::readXml(QDomElement *pNodeElement)
 // Here the readXml functions for CXmlSpumux - class
 bool CXmlSpumux::subpictures_struct::readXml(QDomElement *pNodeElement)
 {
-        debug_out ("CXmlSpumux::subpictures_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+        //debug_out ("CXmlSpumux::subpictures_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::subpictures_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// vmgm has no attributes thus far I can tell.
 	// And now read in all remaining nodes and handle them accordingly.
 	QDomNode xmlNode = pNodeElement->firstChild();
@@ -443,7 +464,8 @@ bool CXmlSpumux::subpictures_struct::readXml(QDomElement *pNodeElement)
 
 bool CXmlSpumux::stream_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::stream_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::stream_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::stream_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool            bReturn = true;
 	spu_struct      tempSpu;
 	textsub_struct  tempTextsub;
@@ -472,7 +494,8 @@ bool CXmlSpumux::stream_struct::readXml(QDomElement *pNodeElement)
 }
 bool CXmlSpumux::spu_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumuxr::spu_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumuxr::spu_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumuxr::spu_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	button_struct tempButton, *pNewButton=NULL;
 	action_struct tempAction, *pNewAction=NULL;
@@ -525,7 +548,8 @@ bool CXmlSpumux::spu_struct::readXml(QDomElement *pNodeElement)
 }
 bool CXmlSpumux::textsub_struct::readXml(QDomElement *pNodeElement)
 {
-  debug_out ("CXmlSpumuxr::textsub_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+  //debug_out ("CXmlSpumuxr::textsub_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+  debug_out ("CXmlSpumuxr::textsub_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
   // First read the attributes
   QDomAttr a = pNodeElement->attributeNode ( TEXTSUB_FILENAME );
   filename = a.value();
@@ -562,7 +586,8 @@ bool CXmlSpumux::textsub_struct::readXml(QDomElement *pNodeElement)
 }
 bool CXmlSpumux::button_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::button_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::button_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::button_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// First read the attributes
 	QDomAttr a = pNodeElement->attributeNode ( BUTTON_LABEL );
 	label = a.value();
@@ -586,7 +611,8 @@ bool CXmlSpumux::button_struct::readXml(QDomElement *pNodeElement)
 }
 bool CXmlSpumux::action_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::action_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::action_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::action_struct::readXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	// First read the attributes
 	QDomAttr a;
 #ifdef DVDAUTHOR_VERSION_LESS_0_6_10
@@ -612,7 +638,8 @@ bool CXmlDVDAuthor::writeXml ()
 	//
 	//////////////////////////////////////////////////////////////////////////////////
 	debug_out ("CXmlDVDAuthor::writeXml ()>\n");
-	QString fileName = QFileDialog::getSaveFileName ( QString("./"), QString ("XML files ( *.xml)"));
+	//QString fileName = QFileDialog::getSaveFileName ( QString("./"), QString ("XML files ( *.xml)"));					//ooo
+	QString fileName = QFileDialog::getSaveFileName ( NULL, QObject::tr("Save File"), QString("./"), QString ("XML files ( *.xml)"));	//xxx
 	if (fileName.isNull())
 		return false;
 	// Assign the file
@@ -620,8 +647,9 @@ bool CXmlDVDAuthor::writeXml ()
 }
 
 bool CXmlDVDAuthor::writeXml (QString &fileName)
-{
-	debug_out ("CXmlDVDAuthor::writeXml (%s)\n",(const char *)fileName);
+{ 
+	//debug_out ("CXmlDVDAuthor::writeXml (%s)\n",(const char *)fileName);		//ooo
+	debug_out ("CXmlDVDAuthor::writeXml (%s)\n",fileName.toLatin1().data());	//xxx
 	// First we create the document, ...
 	QDomDocument xmlDoc( DVD_DOCTYPE );	// <""> for now.
 	if (!m_dvdauthor.writeXml (&xmlDoc))	{
@@ -629,7 +657,7 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 	}
 	// Then we open the file for writing ...
 	QFile projectFile(fileName);
-	if (!projectFile.open(IO_WriteOnly))
+	if (!projectFile.open(QIODevice::WriteOnly))
 		return false;
 
 	QString xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
@@ -637,9 +665,12 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 	// QDomDocument converts '<' to "&lt;", So if we want comments in
 	// the generated file, we should replace them here.
 	xml.replace ( "&lt;", "<"); 
-	debug_out ("%s\n", (const char *)xml);
-	xml = xml.utf8 ( );
-	projectFile.writeBlock ( xml, qstrlen ( xml ) );
+	//debug_out ("%s\n", (const char *)xml);	//ooo
+	debug_out ("%s\n", xml.toLatin1().data());	//xxx
+	//xml = xml.utf8 ( );	//ooo
+	xml = xml.toUtf8 ( );	//xxx
+	//projectFile.writeBlock ( xml, qstrlen ( xml ) );				//ooo
+	projectFile.write ( xml.toLatin1().data(), qstrlen ( xml.toLatin1().data() ) );	//xxx
 
 	projectFile.close();
 	return true;
@@ -647,7 +678,8 @@ bool CXmlDVDAuthor::writeXml (QString &fileName)
 
 bool CXmlDVDAuthor::dvdauthor_struct::writeXml ( QDomDocument *pDocument, QDomElement * )
 {
-	debug_out ("CXmlDVDAuthor::dvdauthor_struct::writeXml <%s>\n", (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::dvdauthor_struct::writeXml <%s>\n", (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::dvdauthor_struct::writeXml <%s>\n", node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement rootDVDAuthor = pDocument->createElement ( node_name ); // <dvdauthor>
@@ -678,7 +710,8 @@ bool CXmlDVDAuthor::dvdauthor_struct::writeXml ( QDomDocument *pDocument, QDomEl
 
 bool CXmlDVDAuthor::vmgm_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::vmgm_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::vmgm_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::vmgm_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 
@@ -705,7 +738,8 @@ bool CXmlDVDAuthor::vmgm_struct::writeXml(QDomDocument *pDocument, QDomElement *
 
 bool CXmlDVDAuthor::titleset_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::titleset_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::titleset_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::titleset_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement titlesetNode = pDocument->createElement( node_name );	// <titleset>
@@ -739,7 +773,8 @@ bool CXmlDVDAuthor::titleset_struct::writeXml(QDomDocument *pDocument, QDomEleme
 
 bool CXmlDVDAuthor::menus_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::menus_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::menus_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::menus_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement menusNode = pDocument->createElement( node_name );	// <menus>
@@ -784,7 +819,8 @@ bool CXmlDVDAuthor::video_struct::writeXml(QDomDocument *pDocument, QDomElement
 	// First check if this node holds any information at all ...
 	if ( (format.isNull()) && (aspect.isNull()) && (resolution.isNull()) && (caption.isNull()) && (widescreen.isNull()) )
 		return true;
-	debug_out ("CXmlDVDAuthor::video_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::video_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::video_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 
 	QDomElement videoNode = pDocument->createElement( node_name );	// <video>
 	if ( ! comment.isEmpty ( ) )  {
@@ -813,7 +849,8 @@ bool CXmlDVDAuthor::audio_struct::writeXml(QDomDocument *pDocument, QDomElement
 	// First check if this node holds any information at all ...
 	if ( (format.isNull()) && (channels == 0) && (quant.isNull()) && (dolby.isNull()) && (lang.isNull()) )
 		return true;
-	debug_out ("CXmlDVDAuthor::audio_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::audio_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::audio_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 
 	QDomElement audioNode = pDocument->createElement( node_name );	// <audio>
 	if ( ! comment.isEmpty ( ) )  {
@@ -843,7 +880,8 @@ bool CXmlDVDAuthor::subpicture_struct::writeXml(QDomDocument *pDocument, QDomEle
 	// First check if this node holds any information at all ...
 	if (lang.isNull())
 		return true;
-	debug_out ("CXmlDVDAuthor::subpicture_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::subpicture_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::subpicture_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement subpictureNode = pDocument->createElement( node_name );	// <dvdauthor>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n   " ).arg ( comment );
@@ -861,7 +899,8 @@ bool CXmlDVDAuthor::subpicture_struct::writeXml(QDomDocument *pDocument, QDomEle
 
 bool CXmlDVDAuthor::titles_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::titles_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::titles_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::titles_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement titlesNode = pDocument->createElement( node_name );	// <titles>
@@ -899,7 +938,8 @@ bool CXmlDVDAuthor::titles_struct::writeXml(QDomDocument *pDocument, QDomElement
 
 bool CXmlDVDAuthor::pgc_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::pgc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::pgc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::pgc_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement pgcNode = pDocument->createElement( node_name );	// <pgc>
@@ -946,7 +986,8 @@ bool CXmlDVDAuthor::button_struct::writeXml(QDomDocument *pDocument, QDomElement
 	// First check if this node holds any information at all ...
 	if ( (name.isNull()) && (value.isNull()) )
 		return true;
-	debug_out ("CXmlDVDAuthor::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+	debug_out ("CXmlDVDAuthor::button_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement buttonNode = pDocument->createElement( node_name );	// <button>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -968,7 +1009,8 @@ bool CXmlDVDAuthor::cell_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	// First check if this node holds any information at all ...
 	if ( (start.isNull()) && (end.isNull()) && (program.isNull()) )
 		return true;
-	debug_out ("CXmlDVDAuthor::cell_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::cell_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::cell_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement cellNode = pDocument->createElement( node_name );	// <cell>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -993,7 +1035,8 @@ bool CXmlDVDAuthor::cell_struct::writeXml(QDomDocument *pDocument, QDomElement *
 
 bool CXmlDVDAuthor::vob_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::vob_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::vob_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::vob_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement vobNode = pDocument->createElement( node_name );	// <vob>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -1017,7 +1060,8 @@ bool CXmlDVDAuthor::fpc_struct::writeXml ( QDomDocument *pDocument, QDomElement
 	// First check if this node holds any information at all ...
 	if ( value.isNull ( ) )
 		return true;
-	debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement fpcNode = pDocument->createElement ( node_name );	// <fpc>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -1036,7 +1080,8 @@ bool CXmlDVDAuthor::pre_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	// First check if this node holds any information at all ...
 	if ( value.isEmpty ( ) )
 	  return true;
-	debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement preNode = pDocument->createElement( node_name );	// <pre>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -1055,7 +1100,8 @@ bool CXmlDVDAuthor::post_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	// First check if this node holds any information at all ...
 	if ( value.isEmpty ( ) )
 	  return true;
-	debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement postNode = pDocument->createElement( node_name );	// <post>
 	if ( ! comment.isEmpty ( ) )  {
 		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
@@ -1088,7 +1134,8 @@ bool CXmlSpumux::readXml ()
   // Later on this is done a level further up and only QDomNode * is sent.
   //
   //////////////////////////////////////////////////////////////////////////////////
-  QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));
+  //QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));					//ooo
+  QString fileName = QFileDialog::getOpenFileName ( NULL, QObject::tr("Open File"), QString("./"), QObject::tr ("XML files ( *.xml *.XML)"));	//xxx
   return readXml ( fileName );
 }
 
@@ -1096,7 +1143,7 @@ bool CXmlSpumux::readXml ( QString &fileName )
 {
   // Assign the file
   QFile projectFile(fileName);
-  if (!projectFile.open( IO_ReadWrite))
+  if (!projectFile.open( QIODevice::ReadWrite))
     return false;
   
   QDomDocument xmlDoc( DVD_DOCTYPE );
@@ -1126,38 +1173,44 @@ bool CXmlSpumux::writeXml ()
 	//
 	//////////////////////////////////////////////////////////////////////////////////
 	debug_out ("CXmlSpumux::writeXml\n");
-	QString fileName = QFileDialog::getSaveFileName ( QString("./"), QObject::tr ("XML files ( *.xml)"));
+	//QString fileName = QFileDialog::getSaveFileName ( QString("./"), QObject::tr ("XML files ( *.xml)"));					//ooo
+	QString fileName = QFileDialog::getSaveFileName ( NULL, QObject::tr("Save File"), QString("./"), QObject::tr ("XML files ( *.xml)"));	//xxx
 	if (fileName.isNull())
 		return false;
 	return writeXml(fileName);
 }
 
 bool CXmlSpumux::writeXml ( QString &fileName )
-{
-	debug_out ( "CXmlSpumux::writeXml (%s)\n",(const char *)fileName );
-	// Assign the file
-	QFile  projectFile ( fileName );
-	if ( ! projectFile.open ( IO_WriteOnly ) )
-		return false;
+{  
+  //debug_out ( "CXmlSpumux::writeXml (%s)\n",(const char *)fileName );		//ooo
+  debug_out ( "CXmlSpumux::writeXml (%s)\n",fileName.toLatin1().data() );		//xxx
+  // Assign the file
+  QFile  projectFile ( fileName );
+  if ( ! projectFile.open ( QIODevice::WriteOnly ) )
+    return false;
 
-	QDomDocument xmlDoc( DVD_DOCTYPE );	// <""> for now.
-	bool bRet = m_subpictures.writeXml (&xmlDoc);
-	if (bRet)	{
-		QString xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
-		xml += xmlDoc.toString (    );
-		xml.replace    ( "&lt;", "<"); 
-		debug_out      ("%s\n", (const char *)xml );
-		xml = xml.utf8 ( );
-		projectFile.writeBlock ( xml, qstrlen ( xml ) );
-	}
+  QDomDocument xmlDoc( DVD_DOCTYPE );	// <""> for now.
+  bool bRet = m_subpictures.writeXml (&xmlDoc);
+  if (bRet)	{
+    QString xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
+    xml += xmlDoc.toString (    );
+    xml.replace    ( "&lt;", "<"); 
+    //debug_out      ("%s\n", (const char *)xml );		//ooo
+    debug_out      ("%s\n", xml.toLatin1().data() );	//xxx
+    //xml = xml.utf8 ( );		//ooo
+    xml = xml.toUtf8 ( );		//xxx
+    //projectFile.writeBlock ( xml, qstrlen ( xml ) );					//ooo
+    projectFile.write ( xml.toLatin1().data(), qstrlen ( xml.toLatin1().data() ) );		//xxx
+  }
 
-	projectFile.close();
-	return bRet;
+  projectFile.close();
+  return bRet;
 }
 
 bool CXmlSpumux::subpictures_struct::writeXml(QDomDocument *pDocument, QDomElement *)
 {
-	debug_out ("CXmlSpumux::subpictures_struct::writeXml <%s>\n",(const char *)node_name);
+	//debug_out ("CXmlSpumux::subpictures_struct::writeXml <%s>\n",(const char *)node_name);	//ooo
+	debug_out ("CXmlSpumux::subpictures_struct::writeXml <%s>\n",node_name.toLatin1().data());	//xxx
 
 	QDomElement subpicturesNode = pDocument->createElement( node_name );	// <subpictures>
 	// And now proceed to writing the rest of the file.
@@ -1167,7 +1220,8 @@ bool CXmlSpumux::subpictures_struct::writeXml(QDomDocument *pDocument, QDomEleme
 
 bool CXmlSpumux::stream_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::stream_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::stream_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::stream_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement streamNode = pDocument->createElement( node_name );	// <stream>
@@ -1195,7 +1249,8 @@ bool CXmlSpumux::stream_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 
 bool CXmlSpumux::spu_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-	debug_out ("CXmlSpumux::spu_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::spu_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::spu_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	bool bReturn = true;
 	int t = 0;
 	QDomElement spuNode = pDocument->createElement( node_name );	// <spu>
@@ -1247,7 +1302,8 @@ bool CXmlSpumux::spu_struct::writeXml(QDomDocument *pDocument, QDomElement *pNod
 }
 bool CXmlSpumux::textsub_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
-  debug_out ("CXmlSpumux::textsub_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+  //debug_out ("CXmlSpumux::textsub_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);	//ooo
+  debug_out ("CXmlSpumux::textsub_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
   QDomElement txtNode = pDocument->createElement( node_name );	// <spu>
   if ( ! filename.isNull())
     txtNode.setAttribute( TEXTSUB_FILENAME, filename );
@@ -1290,7 +1346,8 @@ bool CXmlSpumux::button_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	if ( (label.isNull()) && (x0 == -1) && (y0 == -1) && (x1 == -1) && (y1 == -1) &&
 		(up.isNull()) && (down.isNull()) && (left.isNull()) && (right.isNull()) )
 		return true;
-	debug_out ("CXmlSpumux::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::button_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement buttonNode = pDocument->createElement( node_name );	// <button>
 	if (!label.isNull())
 		buttonNode.setAttribute( BUTTON_LABEL, label );
@@ -1318,7 +1375,8 @@ bool CXmlSpumux::action_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	// First check if this node holds any information at all ...
 	if (label.isNull())
 		return true;
-	debug_out ("CXmlSpumux::action_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	//debug_out ("CXmlSpumux::action_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);		//ooo
+	debug_out ("CXmlSpumux::action_struct::writeXml <%s><%s>\n",pNodeElement->tagName().toLatin1().data(), node_name.toLatin1().data());	//xxx
 	QDomElement actionNode = pDocument->createElement( node_name );	// <action>
 	if (!label.isNull())
 #ifdef DVDAUTHOR_VERSION_LESS_0_6_10
