@@ -1,20 +1,23 @@
-/////////////////////////////////////////////////////////
-//
-// This file contains the import filter for
-// dvdauthor-xml files, and spumux-xml files.
-//
-//
-//   Created : 
-//        by : Varol OKan
-// Copyright : (c) Varol Okan
-// License   : GPL v 2.0
-//
-/////////////////////////////////////////////////////////
+/***************************************************************************
+    xml_dvdauthor.h
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This file contains the import filter for
+   dvdauthor-xml files, and spumux-xml files.
+    
+****************************************************************************/
+
 #ifndef XML_DVDAUTHOR_H
 #define XML_DVDAUTHOR_H
 
-#include <qstring.h>
-#include <qdom.h>
+#include <QString>
+#include <QDomDocument>
+#include <QDomElement>
 
 #define DVD_DOCTYPE              ""
 // Here we define all attributes for the structures.
