@@ -1,40 +1,56 @@
-/******************************************************************
- **
- ** This file is shared between 
- ** QRender    ( Qt 4.x ) and
- ** QSlideshow ( Qt 3.x )
- **
- ** It would not be wise to re-write the whole file or 
- ** to have two copies of essentially the same code in
- ** a project. This way changes in one art of the app
- ** will automagically be available in the other part.
- **
- *****************************************************************/
+/***************************************************************************
+    xml_slideshow.cpp
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This file is shared between
+   QRender    ( Qt 4.x ) and
+   QSlideshow ( Qt 3.x )
+   
+   It would not be wise to re-write the whole file or
+   to have two copies of essentially the same code in
+   a project. This way changes in one art of the app
+   will automagically be available in the other part.
+    
+****************************************************************************/
+
 #include <stdlib.h>
 #include <math.h>
 
 #include "xml_slideshow.h"
 
+#define QDVD_RENDER 1	//xxx
+
 //#if (QT_VERSION > 0x0301FF)
 #ifdef QDVD_RENDER
-  #include <QDomDocument>
+  #include <QtXml/QDomDocument>
   #include <QFile>
   #include <QColor>
   #include <QMatrix>
-  #include <QListView>
-  #include <QFileDialog>
+  //#include <Q3ListView>	//ooo
+  #include <QListView>		//xxx
+  //#include <Q3FileDialog>	//ooo
+  #include <QFileDialog>	//xxx
   #include <QMessageBox>
 #else
   #include <qdom.h>
   #include <qfile.h>
   #include <qcolor.h>
-  #include <qwmatrix.h>
-  #include <qlistview.h>
-  #include <qfiledialog.h>
+  #include <qmatrix.h>
+  #include <q3listview.h>
+  #include <q3filedialog.h>
   #include <qmessagebox.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
+#include <QList>		//xxx
 
   #include "xml_dvd.h"
-  #include "qslideshow/modifiers2.h"
+  #include "qslideshow/modifiers2.h"		//ooo
+  //#include "modifiers.h"			//xxx
 
   #ifndef toAscii
     #define toAscii ascii
@@ -699,7 +715,8 @@ uint CXmlSlideshow::vidsLength ( )
 {
 	uint iTotalPlayTime = 0;
 	vid_struct *pVid = NULL;
-	QValueList<vid_struct *>::iterator it = m_listVids.begin ( );
+	//Q3ValueList<vid_struct *>::iterator it = m_listVids.begin ( );	//ooo
+	QList<vid_struct *>::iterator it = m_listVids.begin ( );		//xxx
 	while ( it != m_listVids.end ( ) )  {
 		pVid = *it++;
 		if ( ! pVid )
@@ -901,9 +918,10 @@ bool CXmlSlideshow::readXml ()
 	//////////////////////////////////////////////////////////////////////////////////
 //#if (QT_VERSION > 0x0301FF)
 #ifdef QDVD_RENDER
-	QString fileName = QFileDialog::getOpenFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
+	//QString fileName = Q3FileDialog::getOpenFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));		//ooo
+	QString fileName = QFileDialog::getOpenFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));		//xxx
 #else
-	QString fileName = QFileDialog::getOpenFileName ( QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
+	QString fileName = Q3FileDialog::getOpenFileName ( QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
 #endif
 	return readXml (fileName);
 }
@@ -923,7 +941,7 @@ bool CXmlSlideshow::readXml ( QString &fileName, bool bMessageBox )
 	if ( ! projectFile.open ( QIODevice::ReadWrite ) )
 		return false;
 #else
-	if ( ! projectFile.open ( IO_ReadWrite ) )
+	if ( ! projectFile.open ( QIODevice::ReadWrite ) )
 		return false;
 #endif
 	QDomDocument xmlDoc ( SLIDESHOW_DOCTYPE );
@@ -939,8 +957,10 @@ bool CXmlSlideshow::readXml ( QString &fileName, bool bMessageBox )
 				return readXml (); // Okay, user wants to specify another project file.
 		}
 		else  {
-			printf ( "Slideshow file <%s> seems to be defective\n", (const char *)fileName.toAscii ( ) );
-			printf ( "Error row<%d> col<%d> . ErrorString<%s>\n", iErrorLine, iErrorCol, (const char *)qsErrorMsg.toAscii ( ) );
+			//printf ( "Slideshow file <%s> seems to be defective\n", (const char *)fileName.toAscii ( ) );		//ooo
+			printf ( "Slideshow file <%s> seems to be defective\n", fileName.toLatin1().data() );			//xxx
+			//printf ( "Error row<%d> col<%d> . ErrorString<%s>\n", iErrorLine, iErrorCol, (const char *)qsErrorMsg.toAscii ( ) );		//ooo
+			printf ( "Error row<%d> col<%d> . ErrorString<%s>\n", iErrorLine, iErrorCol, qsErrorMsg.toLatin1().data() );			//xxx
 			return false;
 		}
 	}
@@ -1053,9 +1073,10 @@ bool CXmlSlideshow::writeXml ()
 	//
 	//////////////////////////////////////////////////////////////////////////////////
 #ifdef QDVD_RENDER
-	QString fileName = QFileDialog::getSaveFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
+	//QString fileName = Q3FileDialog::getSaveFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));		//ooo
+	QString fileName = QFileDialog::getSaveFileName ( NULL, QString("./"), QObject::tr ("Slideshow files ( *.slide)"));		//xxx
 #else
-	QString fileName = QFileDialog::getSaveFileName ( QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
+	QString fileName = Q3FileDialog::getSaveFileName ( QString("./"), QObject::tr ("Slideshow files ( *.slide)"));
 #endif
 	if (fileName.isNull())
 		return false;
@@ -1063,7 +1084,7 @@ bool CXmlSlideshow::writeXml ()
 	return writeXml(fileName);
 }
 
-bool CXmlSlideshow::writeXml (QString &fileName)
+bool CXmlSlideshow::writeXml (QString &fileName)    //ooooo
 {
 //	debug_out ("CXmlSlideshow::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	// Assign the file
@@ -1072,7 +1093,7 @@ bool CXmlSlideshow::writeXml (QString &fileName)
 	if ( ! projectFile.open ( QIODevice::WriteOnly ) )
 		return false;
 #else
-	if ( ! projectFile.open ( IO_WriteOnly ) )
+	if ( ! projectFile.open ( QIODevice::WriteOnly ) )
 		return false;
 #endif
 	QDomDocument xmlDoc ( SLIDESHOW_DOCTYPE );	// <""> for now.
@@ -1208,7 +1229,7 @@ bool CXmlSlideshow::insertImg ( uint iPos, CXmlSlideshow::img_struct *pImg )
   bool bRet = false;
   int  iCount = 0, iImagePos = 0;
   time_object *pTimeObject = NULL;
-  QValueList<time_object *>::iterator it = m_listTimeObjects.begin ( );
+  QList<time_object *>::iterator it = m_listTimeObjects.begin ( );	//oxx
   while ( it != m_listTimeObjects.end ( ) )  {
     iCount++; // Always increase
     pTimeObject = *it++;
@@ -1223,7 +1244,7 @@ bool CXmlSlideshow::insertImg ( uint iPos, CXmlSlideshow::img_struct *pImg )
   if ( ! bRet ) // Not yet found, then we should push it to the end ...
     m_listTimeObjects.push_back ( pImg );
 
-  QValueList<img_struct *>::iterator it2 = m_listImages.begin ( );
+  QList<img_struct *>::iterator it2 = m_listImages.begin ( );		//oxx
   while ( it2 != m_listImages.end ( ) || iImagePos-- >= 0 )  {
     it2++;
   }
@@ -1244,7 +1265,7 @@ bool CXmlSlideshow::insertVid ( uint iPos, CXmlSlideshow::vid_struct *pVid )
   bool bRet = false;
   int  iCount = 0, iVideoPos = 0;
   time_object *pTimeObject = NULL;
-  QValueList<time_object *>::iterator it = m_listTimeObjects.begin ( );
+  QList<time_object *>::iterator it = m_listTimeObjects.begin ( );	//oxx
   while ( it != m_listTimeObjects.end ( ) )  {
     iCount++; // Always increase
     pTimeObject = *it++;
@@ -1259,7 +1280,7 @@ bool CXmlSlideshow::insertVid ( uint iPos, CXmlSlideshow::vid_struct *pVid )
   if ( ! bRet ) // Not yet found, then we should push it to the end ...
     m_listTimeObjects.push_back ( pVid );
 
-  QValueList<vid_struct *>::iterator it2 = m_listVids.begin ( );
+  QList<vid_struct *>::iterator it2 = m_listVids.begin ( );		//oxx
   while ( it2 != m_listVids.end ( ) || iVideoPos-- >= 0 )  {
     it2++;
   }
