@@ -1,12 +1,16 @@
-/****************************************************************************
-** CXmlSlideshow - class
-**
-** Created: May 27 2008
-**      by: Varol Okan using kate editor
-**
-** This class is very similar to qslideshow/xml_slideshow.h
-** The difference is the missing ImageFilter - object
-**
+/***************************************************************************
+    xml_slideshow.h
+                             -------------------
+    CXmlSlideshow - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+   This class is very similar to qslideshow/xml_slideshow.h
+   The difference is the missing ImageFilter - object
+    
 ****************************************************************************/
 
 #ifndef XML_SLIDESHOW_H
@@ -14,17 +18,19 @@
 
 // Make sure we have the QT_VERSION defined.
 #include <qglobal.h>
+//Added by qt3to4:
+//#include <Q3ValueList>	//oxx
 
 //#if (QT_VERSION > 0x0301FF)
 #ifdef QDVD_RENDER
   #include <QString>
   #include <QStringList>
-  #define QValueList QList
+  #define Q3ValueList QList
   #define QT4
 #else
   #include <qstring.h>
   #include <qstringlist.h>
-  #define QMatrix QWMatrix
+  #define QMatrix QMatrix
 #endif
 
 
@@ -241,10 +247,10 @@ public:
 	bool  bImgBackgroundImg;
 	bool  bKenBurns;
 	// Note: filter and img are on the same level, to get a continous structure as stored in the file we need to check the iPosition of those structures ...
-	QValueList<time_object   *> m_listTimeObjects;
-	QValueList<filter_struct *> m_listFilter;
-	QValueList<img_struct    *> m_listImages;
-	QValueList<vid_struct    *> m_listVids;
+	QList<time_object   *> m_listTimeObjects;		//oxx
+	QList<filter_struct *> m_listFilter;			//oxx
+	QList<img_struct    *> m_listImages;			//oxx
+	QList<vid_struct    *> m_listVids;			//oxx
 	void *id; // used to ID where the Slideshow object belongs to
 };
 
