@@ -1,14 +1,16 @@
-/****************************************************************************
-** Class Utils implementation ...
-**
-**   Created : Wed Jun 17 07:53:05 2008
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** Here we have some misc functions which are needed by a few classes 
-** but can not really be assigned to any of those classes.
-**
+/***************************************************************************
+    encoder.cpp
+                             -------------------
+    Class Utils implementation ...
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    Here we have some misc functions which are needed by a few classes 
+    but can not really be assigned to any of those classes.
+    
 ****************************************************************************/
 
 #include "encoder.h"
