@@ -1,22 +1,23 @@
-/****************************************************************************
- ** Encode - class
- **
- **   Created : Wed 18 2008
- **        by : Varol Okan using kate editor
- ** Copyright : (c) Varol Okan
- ** License   : GPL v 2.0
- **
- ** Pure virtual calss to define the encoder interface.
- ** The first incarnation will be based on ffmpeg.
- ** At a later point we can create another encoder class 
- ** based on e.g. Phonon or Xine in which case we should create
- ** a plug-in based system.
- **
- ** Goal: take images and add it to stream to be written 
- **       to a file in VOB format
- **
- ****************************************************************************/
+/***************************************************************************
+    encoder.h
+                             -------------------
+    Encode - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
 
+    Pure virtual calss to define the encoder interface.
+    The first incarnation will be based on ffmpeg.
+    At a later point we can create another encoder class 
+    based on e.g. Phonon or Xine in which case we should create
+    a plug-in based system.
+
+    Goal: take images and add it to stream to be written 
+          to a file in VOB format
+
+****************************************************************************/
 #ifndef ENCODER_ENCODER_H
 #define ENCODER_ENCODER_H
 
