@@ -1,12 +1,15 @@
-/****************************************************************************
-** Class Encode::FFmpeg implementation ...
-**
-**   Created : Wed Jun 17 07:53:05 2008
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**pktdumper.c demo how to in -> enc -> out
+/***************************************************************************
+    ffmpeg_enc.cpp
+                             -------------------
+    Class Encode::FFmpeg implementation ...
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    pktdumper.c demo how to in -> enc -> out
+    
 ****************************************************************************/
 
 #include <QImage>
@@ -27,7 +30,8 @@ extern "C" {
 #define VIDEO_BUF_SIZE 1835008
 
 // Changes happened at around Version 0.6.3
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   #define QRENDER_TYPE_AUDIO CODEC_TYPE_AUDIO
   #define QRENDER_TYPE_VIDEO CODEC_TYPE_VIDEO
   #define QRENDER_PKT_FLAG_KEY PKT_FLAG_KEY
@@ -90,7 +94,8 @@ void SWSScale (struct SwsContext *pCtx, uint8_t **pData, int *iSrc, int iWidth,
 
 int qrender_avcodec_open ( AVCodecContext *pAvctx, AVCodec *pCodec, void *ppDict = NULL )
 {
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   ppDict = ppDict;
   return avcodec_open ( pAvctx, pCodec );
 #else
@@ -145,7 +150,8 @@ bool FFmpeg::Media::openStream ( QString qsStreamName )
 
   debugOut ( "%s : %d : streamName<%s>\n", __FUNCTION__, __LINE__, (const char *)m_qsStreamName.toUtf8 ( ) );
   // Open audio file
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   if ( av_open_input_file ( &m_pFormatCtx, (const char *)m_qsStreamName.toUtf8 ( ), NULL, 0, NULL ) !=0 )
     return false; // Couldn't open file
 
@@ -248,7 +254,8 @@ void FFmpeg::Media::closeStream ( )
   unlockEngine ( );
   // Close the file
   if ( m_pFormatCtx )
-    av_close_input_file ( m_pFormatCtx );
+    av_close_input_file ( m_pFormatCtx ); //ooo
+    //avformat_close_input ( m_pFormatCtx );  //xxx
 
   m_pAudioCodecCtx = NULL;
   m_pVideoCodecCtx = NULL;
@@ -517,7 +524,8 @@ FFmpeg::Buffer *FFmpeg::Audio::decodeAudio ( bool &bEOF )
   int    iOutSampleRate    = m_pOutputAudio->sample_rate;
   int    iOutFrameSize     = m_pOutputAudio->frame_size;
 
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   if ( ! m_pResample && m_pAudioCodecCtx )
          m_pResample  = audio_resample_init ( iOutChannels, m_pAudioCodecCtx->channels, iOutSampleRate, m_pAudioCodecCtx->sample_rate );
 #else
@@ -580,7 +588,8 @@ FFmpeg::Buffer *FFmpeg::Audio::decodeAudio ( AVPacket *pPacket )
   int    iOutSampleRate    = m_pOutputAudio->sample_rate;
   int    iOutFrameSize     = m_pOutputAudio->frame_size;
 
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   if ( ! m_pResample && m_pAudioCodecCtx )
          m_pResample  = audio_resample_init ( iOutChannels, m_pAudioCodecCtx->channels, iOutSampleRate, m_pAudioCodecCtx->sample_rate );
 #else
@@ -812,7 +821,8 @@ void FFmpeg::Vid::setSWScale ( int iTargetWidth, int iTargetHeight, int iAspectR
 
   if ( ! m_pFrame )
     printf ( "Could not allocate picture\n" );
-#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 ) //ooo
+#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 123, 0 )  //xxx
   else  {
     m_pFrame->width  = iTargetWidth  + 2 * m_iPadding[0]; // Should always be 720
     m_pFrame->height = iTargetHeight + 2 * m_iPadding[1]; // Should always be 480;
@@ -867,9 +877,11 @@ AVPacket *FFmpeg::Vid::hasRemainingAudio ( AVStream *pOutputAudioStream )
   const struct AVCodec *codec = pCodec->codec;
 
   if ( codec )
-#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 )
-    m_pPacket->size = codec->encode2 ( pCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );
-#else
+//#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 ) //ooo
+#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 123, 0 )   //xxx
+    m_pPacket->size = codec->encode2 ( pCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );    //ooo
+    //m_pPacket->size = codec->encode2 ( pCodec, m_pPacket, m_pFrame, (int *)pSamples->pBuffer );      //xxx
+#else   
     m_pPacket->size = codec->encode ( pCodec, m_pAudioBuffer, iSize, pSamples );
 #endif
   pOutputAudioStream->codec->frame_number++;
@@ -1029,8 +1041,10 @@ AVPacket *FFmpeg::Vid::getNextPacket ( AVStream *pOutputVideoStream, AVStream *p
       AVCodecContext *pCodec = pOutputAudioStream->codec;
       const struct AVCodec *codec = pCodec->codec;
       if ( codec )
-#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 )
-        m_pPacket->size = codec->encode2 ( pCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );
+//#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 72, 2 ) //ooo
+#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT ( 52, 123, 0 )   //xxx
+        m_pPacket->size = codec->encode2 ( pCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );    //ooo
+        //m_pPacket->size = codec->encode2 ( pCodec, m_pPacket, m_pFrame, (int *)pSamples->pBuffer );      //xxx
 #else
         m_pPacket->size = codec->encode ( pCodec, m_pAudioBuffer, iSize, pSamples );
 #endif
@@ -1295,7 +1309,8 @@ FFmpeg::FFmpeg  ( )
   m_iSampleSize  = 0;
 
   // Called automatically through avcodec_register, and avcodec_register_all
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 )     //ooo
+  #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 123, 0 )    //xxx
   // must be called before using avcodec lib
   avcodec_init ( );
 #endif 
@@ -1361,7 +1376,8 @@ bool FFmpeg::initStream ( QString qsFileName, enVideo videoFormat, enAudio audio
   if ( ! addAudioStream ( pOutputFormat->audio_codec ) )
     return false;
 
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 ) //ooo
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 123, 0 )  //xxx
   if ( av_set_parameters ( m_pOutputCtx, NULL ) < 0 )
     return false;
 #endif
@@ -1390,7 +1406,8 @@ bool FFmpeg::initStream ( QString qsFileName, enVideo videoFormat, enAudio audio
 #endif
   m_pOutputCtx->max_delay   = (int)( 0.7*AV_TIME_BASE );
 
-#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 72, 2 )    //ooo
+#if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT ( 52, 123, 0 )     //xxx
   av_write_header ( m_pOutputCtx );
 #else
   avformat_write_header ( m_pOutputCtx, NULL );
@@ -1551,7 +1568,8 @@ bool FFmpeg::OpenAudioEncoder ( )
   AVCodecContext *pAudio = m_pAudioStream->codec;
 
   // find the audio encoder and open it
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 )
+//#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 72, 2 ) //ooo
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT ( 52, 123, 0 )  //xxx
   AVCodec *pCodec = avcodec_find_encoder ( pAudio->codec_id );
 #else
   AVCodec *pCodec = NULL;
@@ -1773,13 +1791,15 @@ bool FFmpeg::writeAudioFrame ( float fVolume )
   if ( m_pInputAudio )  {
     Buffer *pSamples = decodeAudio ( fVolume );
     unsigned int iSize = m_pInputAudio->getTotalSamples ( );
-    pkt.size = pAudioCodec->codec->encode ( pAudioCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );
+    pkt.size = pAudioCodec->codec->encode ( pAudioCodec, m_pAudioBuffer, iSize, (void *)pSamples->pBuffer );  //ooo
+    //pkt.size = pAudioCodec->codec->encode2 ( pAudioCodec, m_pPacket, m_pFrame, (int *)pSamples->pBuffer );      //xxx
   }
   else  {
     int   iSize   = m_iSampleSize * sizeof ( short );
     char *pBuffer = new char [ iSize ];
     memset ( pBuffer, 0, iSize );
-    pkt.size = pAudioCodec->codec->encode ( pAudioCodec, m_pAudioBuffer, iSize, (void *)pBuffer );
+    pkt.size = pAudioCodec->codec->encode ( pAudioCodec, m_pAudioBuffer, iSize, (void *)pBuffer );    //ooo
+    //pkt.size = pAudioCodec->codec->encode2 ( pAudioCodec, m_pPacket, m_pFrame, (int *)pBuffer );      //xxx
     delete []pBuffer;
   }
 
