@@ -1,11 +1,13 @@
-/****************************************************************************
-** Class Filter implementation ...
-**
-**   Created : Wed Jan 10 07:53:05 2009
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
+/***************************************************************************
+    filter.cpp
+                             -------------------
+    Class Filter implementation ...
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
 ****************************************************************************/
 
 #include <time.h>
