@@ -1,19 +1,20 @@
-/****************************************************************************
- ** Filter - class
- **
- **   Created : Sat Jan 10 2009
- **        by : Varol Okan using kate editor
- ** Copyright : (c) Varol Okan
- ** License   : GPL v 2.0
- **
- ** Class to implement the base for additional filter.
- ** This class also includes the basic CrossFade, and
- ** KenBurns filter.
- **
- ** Derived class AlphaFilter will handle gray scale
- ** filter.
- **
- ****************************************************************************/
+/***************************************************************************
+    filter.h
+                             -------------------
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
+    Class to implement the base for additional filter.
+    This class also includes the basic CrossFade, and
+    KenBurns filter.
+
+    Derived class AlphaFilter will handle gray scale
+    filter.
+
+****************************************************************************/
 
 #ifndef RENDER_FILTER_H
 #define RENDER_FILTER_H
