@@ -1,13 +1,15 @@
-/****************************************************************************
-** Main file
-**
-**   Created : Wed Jun 25 07:53:05 2008
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This is the main file.
-**
+/***************************************************************************
+    logger.cpp
+                             -------------------
+    Main file
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This is the main file.
+    
 ****************************************************************************/
 
 #include <stdio.h>
@@ -159,12 +161,14 @@ void Logger::log ( type enLogLevel, const char *fmt, ... )
 
 void Logger::log ( QString qsLog )
 {
-  log ((const char *)qsLog.toAscii ( ) );
+  //log ((const char *)qsLog.toAscii ( ) );         //ooo
+  log ((const char *)qsLog.toLatin1 ( ).data ( ) ); //xxx
 }
 
 void Logger::log ( type iLogLevel, QString qsLog )
 {
-  log ( iLogLevel, (const char *)qsLog.toAscii ( ) );
+  //log ( iLogLevel, (const char *)qsLog.toAscii ( ) );         //ooo
+  log ( iLogLevel, (const char *)qsLog.toLatin1 ( ).data ( ) ); //xxx
 }
 
 void Logger::line ( void *pObj, unsigned long iThreadID, const char *pFile, const char *pFunction, long iLine, type enLogLevel, const char *fmt, ... )
