@@ -1,12 +1,13 @@
-/****************************************************************************
-** Logger - class
-**
-**   Created : Fri Jun 6 12:09:08 2008
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    logger.h
+                             -------------------
+    Logger - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
 ****************************************************************************/
 
 #ifndef RENDER_LOGGER_H
