@@ -1,14 +1,16 @@
-/****************************************************************************
-** Parser - class
-**
-**   Created : Tue Jun 24 12:09:08 2008
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class will parse the command line options and execute the propper
-** actions.
-**
+/***************************************************************************
+    parser.h
+                             -------------------
+    Parser - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
+    This class will parse the command line options and execute the propper
+    actions.
+
 ****************************************************************************/
 
 #ifndef RENDER_PARSER_H
