@@ -1,24 +1,24 @@
-/*****************************************************************************
- ** Class QRender::Render
- **
- ** 
- **   Created : Fri Jun 6 12:09:08 2008
- **        by : Varol Okan using kate editor
- ** Copyright : (c) Varol Okan
- ** License   : GPL v 2.0
- **
- **
- ** This class will be created by Render::Server, when a new 
- ** socket connection is established
- **
- ** 1) The first thing to happen is the exchange of the Host and Version
- ** 2) Next is the recetion of the Slideshow XML file
- ** 3) Followed by a check if the slideshow exists and is up-to-date
- ** 4) If not, then the client will send the image files
- ** 5) Then we render the Slideshow and
- ** 6) send the generated VOB file back to the client.
- **
- *****************************************************************************/
+/***************************************************************************
+    render.cpp
+                             -------------------
+    Class QRender::Render
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class will be created by Render::Server, when a new 
+    socket connection is established
+
+    1) The first thing to happen is the exchange of the Host and Version
+    2) Next is the recetion of the Slideshow XML file
+    3) Followed by a check if the slideshow exists and is up-to-date
+    4) If not, then the client will send the image files
+    5) Then we render the Slideshow and
+    6) send the generated VOB file back to the client.
+    
+****************************************************************************/
 
 #include <unistd.h>
 
@@ -29,6 +29,9 @@
 #include <QByteArray>
 #include <QTimerEvent>
 #include <QApplication>
+#include <QMessageBox>
+#include <QTimer>   //xxx
+#include <QMutexLocker> //xxx
 
 #include "utils.h"
 #include "shared.h"
@@ -44,9 +47,12 @@ extern Render::Server *g_pServer;
 namespace Render
 {
 
-Render::Render ( int iSocketDescriptor, QObject *pParent )
+//Render::Render ( int iSocketDescriptor, QObject *pParent )    //ooo
+Render::Render ( qintptr iSocketDescriptor, QObject *pParent )  //xxx
+    //Render::Render ( qint64 iSocketDescriptor, QObject *pParent )  //xxx
      : QThread ( pParent ), m_iSocketDescriptor ( iSocketDescriptor )
-{
+     , m_pTcpSocket(new QTcpSocket)   //xxx
+{    
   m_iMessageLen =    0;
   m_iMessageID  =    0;
   m_iTimerID    =   -1;
@@ -67,15 +73,23 @@ Render::Render ( int iSocketDescriptor, QObject *pParent )
   m_logger.setLogInfo ( 3, qsLogFile    );
   m_logger.setLogObjectInfo ( true );
 //printf ( "QRender::QRender <%p> thread<%X>\n", this, pthread_self ( ) );
-  m_pTcpSocket = new QTcpSocket; 
+  //m_pTcpSocket = new QTcpSocket;  //ooo
 
   if ( ! m_pTcpSocket->setSocketDescriptor ( m_iSocketDescriptor ) )  {
       emit ( error ( m_pTcpSocket->error ( ) ) );
       return;
   }
 
-  connect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
+  connect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );  //ooo
+  //connect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ), Qt::DirectConnection );  //xxx
   connect ( this,         SIGNAL ( finished  ( ) ), this, SLOT ( slotExiting    ( ) ) );
+  //connect ( this,         SIGNAL ( Write(QByteArray) ), m_pTcpSocket, SLOT ( slotWrite(QByteArray Data) ) );    //xxx
+  connect ( this,         SIGNAL ( Write(QByteArray) ), this, SLOT ( slotWrite(QByteArray) ) );    //xxx
+  //connect ( this,         SIGNAL ( Write(QString) ), m_pTcpSocket, SLOT ( slotWrite(QString Data) ) );    //xxx
+  connect ( this,         SIGNAL ( Write(QString) ), this, SLOT ( slotWrite(QString) ) );    //xxx
+  //connect ( this,         SIGNAL ( MyExit(int) ), m_pTcpSocket, SLOT ( slotMyExit(int Data) ) );    //xxx
+  connect ( this,         SIGNAL ( MyExit(int) ), this, SLOT ( slotMyExit(int) ) );    //xxx
+  connect ( this,         SIGNAL ( flush( ) ), this, SLOT ( slotFlush( ) ) );    //xxx
 }
 
 Render::~Render ( )
@@ -101,7 +115,7 @@ QTcpSocket *Render::switchSockets ( QTcpSocket *pTakeMe )
 }
 
 void Render::run ( )
-{
+{    
   // Kick off the pinger ...
   m_iTimerID = startTimer ( I_AM_ALIVE_INTERVAL );;
 
@@ -125,8 +139,9 @@ void Render::run ( )
 }
 
 void Render::slotReadSocket ( )
-{
+{    
   qint64 iBytesAvail = m_pTcpSocket->bytesAvailable ( );
+  
 //printf ( "iBytesAvail<0x%016llX>\n", iBytesAvail );
   if  (  iBytesAvail <= 0 )
     return;
@@ -194,7 +209,7 @@ void Render::slotReadSocket ( )
   }
 }
 
-void Render::myExit ( int iExitCode )
+void Render::slotMyExit ( int iExitCode )   //xxx
 {
   m_pTcpSocket->flush   ( );
   m_pTcpSocket->disconnectFromHost ( );
@@ -202,7 +217,21 @@ void Render::myExit ( int iExitCode )
 
   if ( m_pTcpSocket->state ( ) != QAbstractSocket::UnconnectedState )
        m_pTcpSocket->waitForDisconnected ( 5000 );  // wait for up to 5 seconds to be disconnected
+       
   qApp->processEvents ( );
+}
+
+void Render::myExit ( int iExitCode )
+{
+  /*m_pTcpSocket->flush   ( );
+  m_pTcpSocket->disconnectFromHost ( );
+  qApp->processEvents ( );
+
+  if ( m_pTcpSocket->state ( ) != QAbstractSocket::UnconnectedState )
+       m_pTcpSocket->waitForDisconnected ( 5000 );  // wait for up to 5 seconds to be disconnected
+  qApp->processEvents ( );*/    //ooo
+  
+  emit MyExit(iExitCode);   //xxx
 
   QThread::exit ( iExitCode );
   logger ( ).iLOG ( "Server exited \n" );
@@ -215,7 +244,7 @@ bool Render::killClient ( )
 }
 
 void Render::sendProgress ( float fProgress )
-{
+{    
   logger ( ).dLOG ( "Progress <%f>\n", fProgress );
   status ( ).log  ( "PROGRESS:%f\n", fProgress );
   if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
@@ -224,12 +253,16 @@ void Render::sendProgress ( float fProgress )
   QByteArray block;
   // build the progress message
   block = Message<quint16>::create ( SERVER_YOUR_PROGRESS_SIR )   +
-          Message<quint64>::create ( (quint64)sizeof ( double ) ) +
-          Message<double>::create  ( (double)fProgress );
+          //Message<quint64>::create ( (quint64)sizeof ( double ) ) +   //ooo
+          Message<quint64>::create ( static_cast<quint64>(sizeof ( double ) ) ) +   //xxx
+          //Message<double>::create  ( (double)fProgress ); //ooo
+          Message<double>::create  ( static_cast<double>(fProgress) );  //xxx
 
   // Send progress message
-  m_pTcpSocket->write ( block );
-  m_pTcpSocket->flush ( );
+  //m_pTcpSocket->write ( block );  //ooo
+  emit Write(block); //xxx
+  //m_pTcpSocket->flush ( );    //ooo
+  emit flush( );    //xxx
 }
 
 bool Render::isLocalServer ( )
@@ -247,13 +280,45 @@ Logger &Render::status ( )
   return m_status;
 }
 
+void Render::slotWrite(QByteArray Data) //xxx
+{
+  // Must always be called on thread 1
+  m_pTcpSocket->write(Data);
+}
+
+void Render::slotWrite(QString Data) //xxx
+{
+  // Must always be called on thread 1
+  QDataStream stream ( m_pTcpSocket );
+  stream << Data;
+  //m_pTcpSocket->flush ( );
+}
+
+void Render::slotFlush( )   //xxx
+{
+  m_pTcpSocket->flush ( );
+}
+
 void Render::sendMessage ( quint16 iMessageID, QString qsMessage )
 {
   if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
     return;
 
-  m_pTcpSocket->write  ( Message<quint16>::create ( iMessageID ) );
-  m_pTcpSocket->write  ( Message<quint64>::create ( (quint64)qsMessage.length ( ) ) );
+  //m_pTcpSocket->write  ( Message<quint16>::create ( iMessageID ) );   //ooo
+  
+  // Fill with data
+  QByteArray Data;  //xxx
+  Data = Message<quint16>::create ( iMessageID );   //xxx
+  
+  // An event gets put onto thread 1's event queue after this
+  emit Write(Data); //xxx
+  //m_pTcpSocket->write( Data );  //xxx
+  
+  //m_pTcpSocket->write  ( Message<quint64>::create ( (quint64)qsMessage.length ( ) ) );    //ooo
+  
+  Data = Message<quint64>::create ( (quint64)qsMessage.length ( ) );    //xxx
+  
+  emit Write(Data); //xxx
 
 /*
 quint64 iLen = (quint64)qsMessage.length ( );
@@ -261,10 +326,12 @@ char *cLen = (char *)&iLen;
 printf ( "%s::%d > len<%llu> [%02x %02x %02x %02x]\n", __FILE__, __LINE__, iLen, cLen[0], cLen[1], cLen[2], cLen[3] );
 */
 
-  QDataStream stream ( m_pTcpSocket );
-  stream << qsMessage;
+  //QDataStream stream ( m_pTcpSocket );    //ooo
+  //stream << qsMessage;    //ooo
+  emit Write(qsMessage);   //xxx
 
-  m_pTcpSocket->flush ( );
+  //m_pTcpSocket->flush ( );    //ooo
+  emit flush(); //xxx
 }
 
 void Render::sendVersionAndHost ( )
@@ -283,7 +350,8 @@ void Render::sendVersionAndHost ( )
   if ( qsClientHost == qsHostName )
     m_bLocalClientAndServer = true;
 
-  logger ( ).iLOG ( " Version<%d> client<%s>\n", m_bLocalClientAndServer, (const char *)qsClientHost.toAscii ( ) );
+  //logger ( ).iLOG ( " Version<%d> client<%s>\n", m_bLocalClientAndServer, (const char *)qsClientHost.toAscii ( ) );           //ooo
+  logger ( ).iLOG ( " Version<%d> client<%s>\n", m_bLocalClientAndServer, (const char *)qsClientHost.toLatin1 ( ).data ( ) );   //xxx
 
 #ifdef FAKE_REMOTE_HOST
   m_bLocalClientAndServer = false;
@@ -329,7 +397,8 @@ bool Render::sendFile ( QString qsFileName )
   m_pFile->open ( QIODevice::ReadOnly );
   killTimer ( m_iTimerID );
 
-  logger ( ).iLOG ( " <%s> msgID<0x%04X>\n", (const char *)qsFileName.toAscii ( ), (quint16)SERVER_TAKE_A_FILE );
+  //logger ( ).iLOG ( " <%s> msgID<0x%04X>\n", (const char *)qsFileName.toAscii ( ), (quint16)SERVER_TAKE_A_FILE );         //ooo
+  logger ( ).iLOG ( " <%s> msgID<0x%04X>\n", (const char *)qsFileName.toLatin1 ( ).data ( ), (quint16)SERVER_TAKE_A_FILE ); //xxx
   status ( ).log  ( "SIZE:%lld\n", m_pFile->size ( ) );
   // This will kick off the sendPacket protocol until the whole file is transmittet.
   QByteArray cString = qsFileName.toUtf8 ( );
@@ -359,7 +428,8 @@ void Render::sendNextPacket ( )
     if ( iPos >= iSize  ) {
       m_pFile->close    ( );
       m_pTcpSocket->flush ( );
-      logger ( ).iLOG ( " Finished <%s> WAKE ALL\n", (const char *)m_pFile->fileName ( ).toAscii ( ) );
+      //logger ( ).iLOG ( " Finished <%s> WAKE ALL\n", (const char *)m_pFile->fileName ( ).toAscii ( ) );           //ooo
+      logger ( ).iLOG ( " Finished <%s> WAKE ALL\n", (const char *)m_pFile->fileName ( ).toLatin1 ( ).data ( ) );   //xxx
       status ( ).log  ( "VIDEO DONE\n" );
       delete m_pFile;
       m_pFile = NULL;
@@ -575,12 +645,14 @@ bool Render::loadSlideshowXML ( QString qsFileName )
     if (    iXMLHash == m_iXMLHash )  {
       // We can reasenably be sure the xml file has not changed
       // thus the current existing VOB file is up-to-date.
-      logger ( ).iLOG ( "File <%s> seems to exist already (Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), iXMLHash );
+      //logger ( ).iLOG ( "File <%s> seems to exist already (Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), iXMLHash );            //ooo
+      logger ( ).iLOG ( "File <%s> seems to exist already (Hash=<0x%016llX>)\n", (const char *)qsFileName.toLatin1 ( ).data ( ), iXMLHash );    //xxx
       bReturn = false;
     }
   }
 
-  logger ( ).iLOG ( "Create Slideshow object(Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), m_iXMLHash );
+  //logger ( ).iLOG ( "Create Slideshow object(Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), m_iXMLHash );            //ooo
+  logger ( ).iLOG ( "Create Slideshow object(Hash=<0x%016llX>)\n", (const char *)qsFileName.toLatin1 ( ).data ( ), m_iXMLHash );    //xxx
   m_pSlideshow = new CXmlSlideshow;
   m_pSlideshow->readXml ( qsFileName, false );
 
@@ -603,7 +675,7 @@ void Render::createSlideshow ( )
 
   status ( ).log  ( "START SLIDESHOW\n" );
 
-  Slideshow slide ( this );
+  Slideshow slide ( this ); //ooo --> slideshow.cpp
   slide.initMe    ( m_pSlideshow, qsTempPath );
   if ( slide.exec ( ) )  {
     // Presumably success. Let us send the final product back to the client ( QDVDAuthor )
