@@ -1,12 +1,13 @@
-/****************************************************************************
-** Client - class
-**
-**   Created : Fri Jun 6 12:09:08 2008
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    render.h
+                             -------------------
+    Client - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
 ****************************************************************************/
 
 #ifndef RENDER_RENDER_H
@@ -17,6 +18,8 @@
 #include <QTcpSocket>
 #include <QEventLoop>
 #include <QWaitCondition>
+//Added by qt3to4:
+#include <QTimerEvent>
 
 #include "logger.h"
 
@@ -46,10 +49,15 @@ class Render : public QThread
   };
 
 public:
-           Render ( int, QObject * );
+           //Render ( int, QObject * );     //ooo
+           //Render ( int iSocketDescriptor, QObject *parent );     //xxx
+           //Render ( qintptr, QObject * );   //xxx
+           Render ( qintptr iSocketDescriptor, QObject *parent );     //xxx
+           //Render ( qint64 iSocketDescriptor, QObject *parent );     //xxx
   virtual ~Render ( );
 
-  void run    (     );
+  void run    (     );    //ooo
+  //void run    (     ) Q_DECL_OVERRIDE;  //xxx
   void myExit ( int );
   bool killClient ( );
 
@@ -81,10 +89,18 @@ protected:
 protected slots:
   virtual void slotReadSocket  (       );
   virtual void slotExiting     (       );
+  void slotWrite(QByteArray Data);  //xxx
+  void slotWrite(QString Data);  //xxx
+  void slotMyExit(int iExitCode);   //xxx
+  void slotFlush( );    //xxx
 
 signals:
   void error ( QTcpSocket::SocketError );
   void signalIAmDone ( ::Render::Render * );
+  void Write(QByteArray Data);  //xxx
+  void Write(QString Data);  //xxx
+  void MyExit(int Data);    //xxx
+  void flush( );   //xxx
 
 private:
   CXmlSlideshow *m_pSlideshow;
@@ -104,7 +120,8 @@ private:
   QWaitCondition m_waiter;
   QMutex         m_mutex;
 
-  int m_iSocketDescriptor;
+  //int m_iSocketDescriptor;    //ooo
+  qintptr m_iSocketDescriptor;  //xxx
   int m_iTimerID;
   QTcpSocket *m_pTcpSocket;
 };
