@@ -1,14 +1,14 @@
-/*****************************************************************************
- ** Class QRender::Server
- **
- ** 
- **   Created : Fri Jun 6 12:09:08 2008
- **        by : Varol Okan using kate editor
- ** Copyright : (c) Varol Okan
- ** License   : GPL v 2.0
- **
- **
- *****************************************************************************/
+/***************************************************************************
+    server.cpp
+                             -------------------
+    Class QRender::Server
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+****************************************************************************/
 
 #include "server.h"
 #include "render.h"
@@ -17,14 +17,17 @@
 
 #include <QApplication>
 #include <qdir.h>
+#include <QMessageBox>
 
 #include "utils.h"
 
 namespace Render
 {
 
-Server::Server ( QObject *pParent )
-    : QTcpServer ( pParent )
+//Server::Server ( QObject *pParent )   //ooo
+Server::Server ( QObject *parent )  //xxx
+    //: QTcpServer ( pParent )  //ooo
+    : QTcpServer ( parent ) //xxx
 {
   QString qsTempPath, qsLogFile;
   qsTempPath  = QDir::tempPath ( ) + "/qrender/";
@@ -37,16 +40,20 @@ Server::Server ( QObject *pParent )
   m_logger.setLogObjectInfo ( true );
 }
 
-void Server::incomingConnection ( int iSocketDescriptor )
+//void Server::incomingConnection ( int iSocketDescriptor ) //ooo
+void Server::incomingConnection ( qintptr socketDescriptor )   //xxx
 {
-  Render *pRender  =  new Render ( iSocketDescriptor, this      );
+  //Render *pRender  =  new Render ( iSocketDescriptor, this      );    //ooo
+  Render *pRender  =  new Render ( socketDescriptor, this      );  //xxx --> render.cpp
   pRender->logger ( ).setLogInfo ( m_iLogLevel, m_qsLogFileName );
 
   connect ( pRender, SIGNAL ( signalIAmDone ( ::Render::Render * ) ), this, SLOT ( slotRenderExited ( ::Render::Render * ) ) );
+  //connect ( pRender, SIGNAL(finished()), pRender, SLOT(deleteLater())); //xxx
   pRender->start ( QThread::LowestPriority );
-  m_logger.iLOG ( "Server::incomingConnection<%d> start<%p>\n", iSocketDescriptor, pRender );
+  //m_logger.iLOG ( "Server::incomingConnection<%d> start<%p>\n", iSocketDescriptor, pRender ); //ooo
+  m_logger.iLOG ( "Server::incomingConnection<%d> start<%p>\n", socketDescriptor, pRender );    //xxx
   m_listOfRenderTasks.append ( pRender );
-}
+} //ooo
 
 void Server::setLogInfo ( int iLogLevel, QString qsLogFileName )
 {
