@@ -1,12 +1,13 @@
-/****************************************************************************
-** Client - class
-**
-**   Created : Fri Jun 6 12:09:08 2008
-**        by : Varol Okan using kate editor
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-**
+/***************************************************************************
+    shared.h
+                             -------------------
+    Client - class
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+
 ****************************************************************************/
 
 
@@ -24,7 +25,8 @@ namespace Render
 
 // default port the server is listening on
 // Note: Need to implement GUI to overwrite this Default setting.
-#define SERVER_PORT 5066
+//#define SERVER_PORT 5066   //ooo
+#define SERVER_PORT 5066    //xxx
 
 // All Message IDs are 16 bit
 
