@@ -1,20 +1,23 @@
-/****************************************************************************
-** Class Slideshow implementation ...
-**
-**   Created : Wed Jun 17 07:53:05 2008
-**        by : Varol Okan
-** Copyright : (c) Varol Okan
-**   License : GPL v 2.0
-**
-** This class takes care of actually rendering the slideshow.
-** It will take the inut data collected in XmlSlideshow
-** and use ffmpeg to generate the slideshow accordingly.
-**
+/***************************************************************************
+    slideshow.cpp
+                             -------------------
+    Class Slideshow implementation ...
+                             
+    begin                : March 2015
+    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
+    license              : GPL v 2.0
+    
+    This class takes care of actually rendering the slideshow.
+    It will take the inut data collected in XmlSlideshow
+    and use ffmpeg to generate the slideshow accordingly.
+    
 ****************************************************************************/
 
 #include <QColor>
 #include <QPainter>
 #include <QFileInfo>
+#include <QPixmap>  //xxx
 
 #include "utils.h"
 #include "logger.h"
@@ -27,14 +30,14 @@ namespace Render
 {
 
 Slideshow::Slideshow ( Render *pParent )
-{
+{    
   m_pParser = NULL;
   m_pParent = pParent;
   m_size    = QSize ( 720, 480 ); // NTSC
 }
 
 Slideshow::Slideshow ( Parser *pParser )
-{
+{    
   m_pParent = NULL;
   m_pParser = pParser;
   m_size    = QSize ( 720, 480 ); // NTSC
@@ -65,7 +68,7 @@ void Slideshow::setFileName ( QString &qsFileName )
 }
 
 void Slideshow::displayProgress ( float fProgress )
-{
+{    
   if ( m_pParent )  {
     m_pParent->sendProgress ( fProgress );
     if ( m_pParent->logger ( ).logLevel ( ) <= Logger::logInformation )
@@ -152,7 +155,7 @@ void Slideshow::prescaleImage ( QImage &theImage )
 // This function will iterate through the images and videos and generate the appropriate
 // transitions, and KenBurns effects ( images only )
 bool Slideshow::exec ( )
-{
+{    
   if ( ! m_pSlideshow )
     return false;
 
@@ -179,6 +182,7 @@ bool Slideshow::exec ( )
     fFPS = 25.0;
 
   displayProgress ( 0.0001f );
+  
   CXmlSlideshow::img_struct  *pXmlStart = createStartEnd (  true );
   CXmlSlideshow::img_struct  *pXmlEnd   = createStartEnd ( false );
   CXmlSlideshow::img_struct  *pXmlCurrent, *pXmlPrevious;
@@ -193,7 +197,7 @@ bool Slideshow::exec ( )
   if ( m_pSlideshow->aspect == 1 ) // 16:9
     theEncoder.setVideoParam ( 6000, Encoder::Encoder::arAspect16to9 );
   theEncoder.initStream      ( m_qsFileName, enFormat, Encoder::Encoder::afAC3, 1000 );
-
+  
   pXmlPrevious    = pXmlStart;
   uint t, iCount  = m_pSlideshow->count ( );
   float fProgress = 0.0f;
@@ -233,7 +237,8 @@ bool Slideshow::exec ( )
       continue;
 
     pXmlCurrent = (CXmlSlideshow::img_struct *)pTimeObject;
-    fProgress = 100.0f * ( ((float)++iProgress) / fCount2 );
+    //fProgress = 100.0f * ( ((float)++iProgress) / fCount2 );  //ooo
+    fProgress = 100.0f * ( static_cast<float>(++iProgress) / fCount2 ); //xxx
     displayProgress ( fProgress );
     if ( ( pXmlPrevious->node_name == "img" ) && 
          ( pXmlCurrent ->node_name == "img" ) )
@@ -248,12 +253,13 @@ bool Slideshow::exec ( )
               ( pXmlCurrent ->node_name == "vid" ) )
       createVVTransition ( (CXmlSlideshow::vid_struct *)pXmlPrevious, (CXmlSlideshow::vid_struct *)pXmlCurrent, &theEncoder, fFPS );
 
-    fProgress = 100.0f * ( (float)++iProgress / fCount2 );
+    //fProgress = 100.0f * ( (float)++iProgress / fCount2 );    //ooo
+    fProgress = 100.0f * ( static_cast<float>(++iProgress) / fCount2 );  //xxx
     displayProgress ( fProgress );
 
     pXmlPrevious = pXmlCurrent;
   }
-
+  
   // The frame is to be displayed for a bit ...
   if ( pXmlPrevious->node_name == "img" )
     createFromImage ( pXmlPrevious, &theEncoder, fFPS );
@@ -268,11 +274,14 @@ bool Slideshow::exec ( )
     else
       createVITransition ( (CXmlSlideshow::vid_struct *)pXmlPrevious, pXmlEnd, &theEncoder, fFPS );
   }
+  
   displayProgress ( 100.0f );
 
   theEncoder.endStream  ( );
+  
   delete pXmlStart;
   delete pXmlEnd;
+  
   return true;
 }
 
@@ -310,18 +319,19 @@ void Slideshow::createBackground ( )
 }
 
 CXmlSlideshow::img_struct *Slideshow::createStartEnd ( bool bStart )
-{
+{    
   if ( bStart )
     log ( "Creating intro page\n", Logger::logInformation );
   else
     log ( "Creating extro page\n", Logger::logInformation );
-
+  
   // This frunction creates the first frame and the last frame.
   int iX = m_size.width  ( );
   int iY = m_size.height ( );
 
   QFont theFont       ( "Helvetica [Cronyx]", 24, QFont::Bold );
-  QImage canvas       (    m_size, QImage::Format_ARGB32_Premultiplied );
+  QImage canvas       (    m_size, QImage::Format_ARGB32_Premultiplied ); //ooo
+  
   QPainter thePainter (   &canvas );
   thePainter.setPen   ( QColor ( "#AFAF15" ) );  // Yellow
   thePainter.setBrush ( QColor ( "#000000" ) );  // Qt::blue );
@@ -329,9 +339,15 @@ CXmlSlideshow::img_struct *Slideshow::createStartEnd ( bool bStart )
   thePainter.setFont  (   theFont );
 
   QString qsFileName = m_pSlideshow->slideshow_name;
+  
   qsFileName.replace ( "/", "_" );
+  
   if ( bStart )  {
-    thePainter.drawText ( (int)( iX / 3.0 ), (int)( iY / 2.0 - 10 ), m_pSlideshow->slideshow_name );
+    //thePainter.drawText ( (int)( iX / 3.0 ), (int)( iY / 2.0 - 10 ), m_pSlideshow->slideshow_name );  //oooo
+    //thePainter.drawText ( static_cast<int>( iX / 3.0 ), static_cast<int>( iY / 2.0 - 10 ), m_pSlideshow->slideshow_name );  //xxx
+    //thePainter.drawText ( static_cast<int>( iX / 3.0 ), static_cast<int>( iY / 2.0 - 10 ), m_pSlideshow->slideshow_name );  //xxx
+    //thePainter.drawLine ( 0, 0, iX , iY );  //xxx
+    //thePainter.drawPoint( static_cast<int>( iX / 3.0 ), static_cast<int>( iY / 2.0 - 10 ) );    //xxx
     qsFileName = m_qsTempPath + qsFileName + "-start.jpg";
   }
   else
@@ -348,6 +364,7 @@ CXmlSlideshow::img_struct *Slideshow::createStartEnd ( bool bStart )
   pXml->height = iY;
   if ( m_pSlideshow && m_pSlideshow->kenBurns ( ) )
     pXml->effect[0].randomKenBurns ( 0.5f, iX, iY, true );
+  
   return pXml;
 }
 
